### Changelog

All notable changes to this project will be documented in this file. Dates are displayed in UTC.

Generated by [`auto-changelog`](https://github.com/CookPete/auto-changelog).

#### [2.8.8](https://github.com/fomantic/Fomantic-UI/compare/2.8.7...2.8.8)

> 24 June 2021

- chore(release): update dist [`a75fbd2`](https://github.com/fomantic/Fomantic-UI/commit/a75fbd2e540e164d2f18a6a93918ea33f65b0e57)
- fix(slider): remove old dist files for renamed slider (range) [`580a6e9`](https://github.com/fomantic/Fomantic-UI/commit/580a6e98a78a337e265aecf787c782a078595cca)
- fix(nag): refactored, colors, sizes, grouping [`6f2057f`](https://github.com/fomantic/Fomantic-UI/commit/6f2057fc0c5d5b98cf69c95b699aefee287b3de6)
- build(deps): upgrade gulp-less to fully support less 4 [`1f73afd`](https://github.com/fomantic/Fomantic-UI/commit/1f73afd1aa20146998fe9a25af0e9d9255456904)
- build(deps): bump handlebars from 4.7.5 to 4.7.7 [`4aa416b`](https://github.com/fomantic/Fomantic-UI/commit/4aa416bceca5e9c3c071797acfcdac41c2260d49)
- feat(modal): js config templates, alert, confirm, prompt [`bf2f280`](https://github.com/fomantic/Fomantic-UI/commit/bf2f28065ef5dc6b080a4180d0dea6892276c003)
- feat(modal): dynamic modal content [`7e3e450`](https://github.com/fomantic/Fomantic-UI/commit/7e3e450791c7180c74d2133fd39a358ea51a6204)
- feat(dropdown): (vertical) descriptions to menu item template [`59eeee2`](https://github.com/fomantic/Fomantic-UI/commit/59eeee2cec53a6c06545001d3bb41dc55a9c6061)
- fix(core): divisions need parenthesis to support less 4 [`ec80f1e`](https://github.com/fomantic/Fomantic-UI/commit/ec80f1e27e9a21db2b50977d8a0231b5d474692a)
- feat(card): disabled and loading variant [`bedd965`](https://github.com/fomantic/Fomantic-UI/commit/bedd9651889cf2ef124aa9f22c59be647bd89b5a)
- feat(toast): top and bottom attached and centered support [`686529b`](https://github.com/fomantic/Fomantic-UI/commit/686529b0fbbca0c3e9c26d8f89e031ed4a40fdae)
- feat(icon): bordered and circular icon groups [`fc6d299`](https://github.com/fomantic/Fomantic-UI/commit/fc6d2995d405a4ae90f2af64392336ba189335b4)
- fix(dropdown): clearable inline support [`1d06e9d`](https://github.com/fomantic/Fomantic-UI/commit/1d06e9dabf5404bfc13d6fbd8f26be48c381dfc5)
- build(deps): bump gulp-json-editor from 2.5.4 to 2.5.5 [`863d712`](https://github.com/fomantic/Fomantic-UI/commit/863d7123323f642238daaa5c92f005073fb9e204)
- build(deps): bump browserslist from 4.6.4 to 4.16.6 [`248c30c`](https://github.com/fomantic/Fomantic-UI/commit/248c30c77bb332289ff4b9d0fff9018c12e390f5)
- fix(icon): support transformations in icon groups [`ab3d931`](https://github.com/fomantic/Fomantic-UI/commit/ab3d9310e24a4c7dcd76bac2abeff9a4b0d406d5)
- build(deps): bump less from 3.13.1 to 4.1.1 [`26eb499`](https://github.com/fomantic/Fomantic-UI/commit/26eb49958d70791ea86698cb60e03161de1a9138)
- fix(dropdown): fix menu item refresh logic when using remote api [`c0e49df`](https://github.com/fomantic/Fomantic-UI/commit/c0e49dfd5cec9bd06d0932d44bd91ad9a8a949a9)
- feat(checkbox): support right aligned position of checkbox variants [`db91227`](https://github.com/fomantic/Fomantic-UI/commit/db912274b24255d7f49fc6af48151f00383d6b98)
- feat(form): support range values for decimal and number validation [`6f8b533`](https://github.com/fomantic/Fomantic-UI/commit/6f8b533168df97966e1c171548acc539ce464072)
- fix(nag): missing callbacks and fixed unused code [`6cbaa7b`](https://github.com/fomantic/Fomantic-UI/commit/6cbaa7bbbd3b929cc9bccd107153b07dc666ca26)
- fix(build): upgrade css minify and remove specialcomments [`36c6aa0`](https://github.com/fomantic/Fomantic-UI/commit/36c6aa09dafede709450b6f184e11e82200e2304)
- fix(slider): no minimum step for label generator [`fcd221b`](https://github.com/fomantic/Fomantic-UI/commit/fcd221b001d45ec6bc820d5f43a3d8bcad377bf0)
- build(deps): bump gulp-rtlcss from 1.4.1 to 1.4.2 [`f9f203a`](https://github.com/fomantic/Fomantic-UI/commit/f9f203a59e5d00f611b07e7a6bab87064c251ec8)
- feat(toast): horizontal variant and dynamic content support [`b41338d`](https://github.com/fomantic/Fomantic-UI/commit/b41338df93ba88063c1115e9d542db7d4ba2273e)
- build(deps): bump gulp-replace from 1.0.0 to 1.1.1 [`add0828`](https://github.com/fomantic/Fomantic-UI/commit/add0828531700b25ff9305dd6a79eb406184e6a7)
- fix(form): support mix of shorthand and full object rules [`d1b6dea`](https://github.com/fomantic/Fomantic-UI/commit/d1b6dea09e19cb4b56ef0fa2dadb5679f44368b5)
- feat(icon): use corner offset variables [`de42d96`](https://github.com/fomantic/Fomantic-UI/commit/de42d96e2b3a70fa25678d911de9129915ac20dc)
- fix(form): inverted state forms colors [`2f78f4e`](https://github.com/fomantic/Fomantic-UI/commit/2f78f4e1cc8c576145667f0c50aff87ba820d1bf)
- build(deps-dev): bump all-contributors-cli from 6.17.2 to 6.17.3 [`2bb7df1`](https://github.com/fomantic/Fomantic-UI/commit/2bb7df156fb5b534aa0a52612f4db644aa3bce6b)
- feat(segment): disabled, inverted and loading groups [`9ade8b7`](https://github.com/fomantic/Fomantic-UI/commit/9ade8b7cef894867d7937bf5fc9c9df08be2ad9d)
- feat(dropdown): support readonly variant [`185e234`](https://github.com/fomantic/Fomantic-UI/commit/185e234ce0a424f93f183b10f01628024d088d93)
- fix(slider): onchange is triggered without moving slider [`2f554c0`](https://github.com/fomantic/Fomantic-UI/commit/2f554c062420ba42f1913e3d6f1a64f4539dda21)
- build(deps): bump gulp-replace from 1.1.1 to 1.1.2 [`00d33f8`](https://github.com/fomantic/Fomantic-UI/commit/00d33f8d5f4f0c83bf549f956c2aab4ae7b65575)
- feat(button): support stackable buttons [`943961b`](https://github.com/fomantic/Fomantic-UI/commit/943961bd65a851d476d5e3a097a02fcc664b041b)
- feat(progress): support right aligned progress bar [`8bbda5f`](https://github.com/fomantic/Fomantic-UI/commit/8bbda5f51e9a5eb6ffe12555bd1dacc2155e36ec)
- feat(chore): remove support issue template in favor of using discussions [`5e93a11`](https://github.com/fomantic/Fomantic-UI/commit/5e93a1137dfcd13498ad44d97e5d4d8dbd592ef5)
- build(deps-dev): bump all-contributors-cli from 6.19.0 to 6.20.0 [`4a10f16`](https://github.com/fomantic/Fomantic-UI/commit/4a10f16d895871434c9bce649c2a4bf53e7a2cd6)
- build(deps): bump less from 3.13.0 to 3.13.1 [`1f0334e`](https://github.com/fomantic/Fomantic-UI/commit/1f0334e1165f4198c3515ce0930015c7ce8c53cc)
- build(deps-dev): bump all-contributors-cli from 6.17.4 to 6.18.0 [`6ed1526`](https://github.com/fomantic/Fomantic-UI/commit/6ed152690b59caf049c8d0a4c874422abcad4da8)
- feat(message): support centered variant [`48c4716`](https://github.com/fomantic/Fomantic-UI/commit/48c47168b9fa6b405efafdc86b5b0c0ea6130432)
- feat(dropdown): dropdown formatted with label [`65fe7e5`](https://github.com/fomantic/Fomantic-UI/commit/65fe7e50a9905cc8cab7c0388ffc11e4bf3b704d)
- feat(dropdown,popup): support individual show and hide transition and duration [`a5d471c`](https://github.com/fomantic/Fomantic-UI/commit/a5d471c6071efc9a39ab0bd203c7e4886c66a6ce)
- fix(dropdown): multiselect values encoding, removing label [`19806d4`](https://github.com/fomantic/Fomantic-UI/commit/19806d490bca6a9e2ad57070a92f678bd786ea87)
- fix(dropdown): preventchangetrigger on clear for multiple [`8a6f11b`](https://github.com/fomantic/Fomantic-UI/commit/8a6f11b24f7e25387eca814257ddff1db7a8189d)
- feat(modal): centered variant for any content [`aa04e6d`](https://github.com/fomantic/Fomantic-UI/commit/aa04e6d96d322c558020c11ba0f3668d0a6aa05f)
-  feat(form): added errorfocus option to focus first error field or dom node [`d10077a`](https://github.com/fomantic/Fomantic-UI/commit/d10077aa4182b04905cf89078d6d42879ca138e7)
- feat(dropdown): support submenu values [`cfc5a74`](https://github.com/fomantic/Fomantic-UI/commit/cfc5a748c7c5f3f2419eb4238c6e9e1a7fd0b082)
- feat(dropdown): support inverted menu in non-inverted dropdown [`46a91bb`](https://github.com/fomantic/Fomantic-UI/commit/46a91bb07e1b18a08367cc0430599bad098c133a)
- Upgrade to GitHub-native Dependabot [`c05f0a5`](https://github.com/fomantic/Fomantic-UI/commit/c05f0a55f9a08865c31c6781030fea09a2899233)
- fix(modal): bodyfixed selector did not work with existing padding [`ef3d810`](https://github.com/fomantic/Fomantic-UI/commit/ef3d8105f011362bd4a55f4163dd7597e761c161)
- fix(toast): attached toast margin and border [`a706ce9`](https://github.com/fomantic/Fomantic-UI/commit/a706ce9930b6c7ebfe983428825acc796c2b5204)
- build(deps): bump gulp-json-editor from 2.5.5 to 2.5.6 [`df7caef`](https://github.com/fomantic/Fomantic-UI/commit/df7caef97d86175ccc852b4c678c8bbc21ddc13f)
- fix(search): fetch "Cannot read property 'top' of undefined [`2d69a7c`](https://github.com/fomantic/Fomantic-UI/commit/2d69a7c58b798541372f8c6ce4a95bf2afd59eaf)
- fix(form): simplify blur and respect revalidation [`214751b`](https://github.com/fomantic/Fomantic-UI/commit/214751bcda12bfdd74e39dc6a0d213eef90bafb2)
- fix(grid): incorrect margins in compact and very compact grid [`0354793`](https://github.com/fomantic/Fomantic-UI/commit/0354793368c5e08537b09c48b2c4cf6a9c8e4353)
- fix(progress): fix calculations when total &gt; 100 [`998c222`](https://github.com/fomantic/Fomantic-UI/commit/998c22207d8c5b03683150246add458915abead1)
- build(deps-dev): bump all-contributors-cli from 6.18.0 to 6.19.0 [`b8551c5`](https://github.com/fomantic/Fomantic-UI/commit/b8551c53a9f4d4e0722e263180701764d7df573d)
- feat(dropdown): support separate transition displaytype [`8ae681c`](https://github.com/fomantic/Fomantic-UI/commit/8ae681cd6e4e6e91f7515a7de32361354f33a019)
- feat(dimmer): support individual show/hide duration [`68bf29f`](https://github.com/fomantic/Fomantic-UI/commit/68bf29fdf71b929eb4439445024250ca9ffc470a)
- fix(dropdown): show callback was ignored on remote api call [`68bd08f`](https://github.com/fomantic/Fomantic-UI/commit/68bd08f0bf37314cef4f95d60baf6dbb936b3df1)
- build(deps): bump gulp-replace from 1.1.2 to 1.1.3 [`68fdc41`](https://github.com/fomantic/Fomantic-UI/commit/68fdc41872acb84b9f3fef6cd8d14903cf34eedd)
- build(deps): [security] bump y18n from 3.2.1 to 3.2.2 [`176f54d`](https://github.com/fomantic/Fomantic-UI/commit/176f54da167742a79ebab308545c288d368319e8)
- fix(icon): colored selector was wrongly placed [`91654b5`](https://github.com/fomantic/Fomantic-UI/commit/91654b54e02b9790af8ab7894ef0353d4349da9f)
- feat(icon): colored variant for bordered or circular [`ba420fe`](https://github.com/fomantic/Fomantic-UI/commit/ba420fea625ef2b287a629af9f2a6ab422a65cc7)
- build(deps): bump less from 3.12.2 to 3.13.0 [`7cd68df`](https://github.com/fomantic/Fomantic-UI/commit/7cd68df88b4fef6707edcd2bd857945e3f11bdeb)
- feat(form): apply state color also to label class [`d092f48`](https://github.com/fomantic/Fomantic-UI/commit/d092f482109e43f60e68c48980f6390b3cc8fd43)
- fix(build): use current year and implement version in header [`1b7159a`](https://github.com/fomantic/Fomantic-UI/commit/1b7159a94933a42e0ade530e43874368fa399a47)
- fix(header): support icon groups [`271d062`](https://github.com/fomantic/Fomantic-UI/commit/271d06280a5f8153e38741513498238f81458d5d)
- fix(calendar): show active and eventdates on enabled adjacent days [`9f54e14`](https://github.com/fomantic/Fomantic-UI/commit/9f54e143b3be3b0f96b9a54e8d9c7f59ca953767)
- fix(dropdown): autocomplete in chrome does not support "off" [`58b023c`](https://github.com/fomantic/Fomantic-UI/commit/58b023c24be10262583c25ae6a7377fa6436f55d)
- feat(slider): support control over change trigger [`ce85cf3`](https://github.com/fomantic/Fomantic-UI/commit/ce85cf35b64d80c51482047581059c2c31fcea58)
- build(deps): [security] bump yargs-parser from 5.0.0 to 5.0.1 [`8ec0129`](https://github.com/fomantic/Fomantic-UI/commit/8ec0129796537b585c56f54105c183e85f257dba)
- fix(card): inverted header links were not styled properly [`06fff10`](https://github.com/fomantic/Fomantic-UI/commit/06fff101f7197ca3afb987c15aea48a9d32b1025)
- fix(form): separate dirty events trigger multiple native event calls [`6e4ff1d`](https://github.com/fomantic/Fomantic-UI/commit/6e4ff1d8633b6776d83fac452d8e6c750e01e442)
- Make colored icon selector more specific [`4bea8ab`](https://github.com/fomantic/Fomantic-UI/commit/4bea8abba87f7fb4fd69203ba46825b7baab639d)
- feat(form): set optional field behavior [`6397554`](https://github.com/fomantic/Fomantic-UI/commit/6397554f5bfdf504b52b9b901ea2540411b708b3)
- fix(search): dont set value when onselect returns false [`b1765a1`](https://github.com/fomantic/Fomantic-UI/commit/b1765a1c0c3dac4c442484374065419611aea69d)
- fix(calendar): return null instead of undefined in sanitizer [`de2ba9f`](https://github.com/fomantic/Fomantic-UI/commit/de2ba9fb62937ce5221dc79f691cb66111e5b9d6)
- fix(segment): support placeholder segments for tab usage [`2138533`](https://github.com/fomantic/Fomantic-UI/commit/2138533060bec9d5c05a3455ea8a24f4fd58b802)
- build(deps): bump hosted-git-info from 2.7.1 to 2.8.9 [`c50b82b`](https://github.com/fomantic/Fomantic-UI/commit/c50b82bee81c881f5733ba297008a86aa5343065)
- build(deps): bump lodash from 4.17.19 to 4.17.21 [`9760798`](https://github.com/fomantic/Fomantic-UI/commit/97607982a98899f68b431eca65c6e3b17d5e279f)
- build(deps): bump jquery from 3.5.1 to 3.6.0 [`24eb27a`](https://github.com/fomantic/Fomantic-UI/commit/24eb27a1d86671ea6e3c44c9adf7e4f46bdc2628)
- fix(colors): avoid compile error of php less port [`e058619`](https://github.com/fomantic/Fomantic-UI/commit/e058619c818b00edfce497fa680252c9bda0eaa2)
- fix(message): support icon groups [`1af2588`](https://github.com/fomantic/Fomantic-UI/commit/1af2588246b45df1c1ab98ed2891a22649102e68)
- fix(dropdown): respect submenu on up/downward height calculation [`6bab2e8`](https://github.com/fomantic/Fomantic-UI/commit/6bab2e88d4c5547de004913f4cdcce92014c14e8)
- build(deps-dev): bump all-contributors-cli from 6.17.3 to 6.17.4 [`5bba220`](https://github.com/fomantic/Fomantic-UI/commit/5bba2200460f7a3e4adebbbcf6e718e936ff414e)
- fix(modal): dont stack same actions buttons [`3a235e6`](https://github.com/fomantic/Fomantic-UI/commit/3a235e6d076718fb5a1842a63e8a285f021ee556)
- feat(dropdown): onSearch callback [`04559bc`](https://github.com/fomantic/Fomantic-UI/commit/04559bc2e341901d629f76120cca94038d90e0a8)
- feat(icon): support loading variant for icon groups [`4d9b24c`](https://github.com/fomantic/Fomantic-UI/commit/4d9b24c24b323d60f806c8ca2f405b02cbb6367b)
- feat(segment): support equal width [`c952da3`](https://github.com/fomantic/Fomantic-UI/commit/c952da38464f9c117da73f8ee4f40b472ddc497b)
- fix(form): file upload fields trigger error using jquery &gt; 3.4.0 [`fdc46e7`](https://github.com/fomantic/Fomantic-UI/commit/fdc46e7e952dfa6caf6fa5585164ff9d95f536e6)
- feat(validation): allow credit card numbers with spaces [`f41016e`](https://github.com/fomantic/Fomantic-UI/commit/f41016eb2cea0048d933bbcf66f6162bbb4877d1)
- fix(header): icon headers should not have a left content padding [`cf7f222`](https://github.com/fomantic/Fomantic-UI/commit/cf7f222a1dafeedfdbc7f8bbf6e9a9ccb0a269e7)
- feat(dimmer): support individual show/hide transition [`5992784`](https://github.com/fomantic/Fomantic-UI/commit/59927846208ae3b6e473690e3a76df54ff1f848d)
- feat(dropdown): columns were ignored inside menus [`129b3bc`](https://github.com/fomantic/Fomantic-UI/commit/129b3bc6851f93dde0d3365a04b922cf7420ccd8)
- feat(dropdown): support icon groups margin [`2093c46`](https://github.com/fomantic/Fomantic-UI/commit/2093c46e1da1ea29d4afb015b06adb99d59d0400)
- feat(segment): prevent user selection on disabled and loading [`05955c0`](https://github.com/fomantic/Fomantic-UI/commit/05955c046cd0be135c57c7ba80dffe36e0c49276)
- fix(table): allow pointer events for non empty top left cell in definition table [`82231f8`](https://github.com/fomantic/Fomantic-UI/commit/82231f85e25bff965e36f911e0ba0dd2a4aefad9)
- fix(dropdown): fix menu show on mobile and api call [`1d8b2b1`](https://github.com/fomantic/Fomantic-UI/commit/1d8b2b18af5da5c32d414e33118975c2968f2a62)
- fix(slider): fix bottom aligned labels for size variations [`d5a27ef`](https://github.com/fomantic/Fomantic-UI/commit/d5a27ef1fad4e09ed88b0e1642b045683bc2ec10)
- fix(calender): support single digit months and days [`3bc5b77`](https://github.com/fomantic/Fomantic-UI/commit/3bc5b775029c2be9dcd0610ad772c551f53d949c)
- fix(dropdown): forceSelection trigger event with null addition [`9fc8329`](https://github.com/fomantic/Fomantic-UI/commit/9fc8329c8b416d085f443865ea0aa81277558b1d)
- feat(dropdown): support preventChangeTrigger parameter for set.selected [`c15ebfa`](https://github.com/fomantic/Fomantic-UI/commit/c15ebfabaa6326a000c027894e31c1168de95aa0)
- feat(site): update google fonts api to v2 [`d4f9aa3`](https://github.com/fomantic/Fomantic-UI/commit/d4f9aa3777f6bb7d3b2eadc1e310a836468a43ef)
- fix(tooltip): bottom center tooltip was misaligned [`46713c6`](https://github.com/fomantic/Fomantic-UI/commit/46713c6adfc6e43fb05e308d217299ff13c8ac7c)
- fix(slider): less 4 support needs parenthesis [`1f8850b`](https://github.com/fomantic/Fomantic-UI/commit/1f8850b94436823eb72d3fdbed97a18b552d1ee1)
- feat(dependency): support a possible installed v4 of less [`a246ad7`](https://github.com/fomantic/Fomantic-UI/commit/a246ad7e8f74fccb9d56d794bee358eb43241c58)
- fix(calendar): disabled week days should not affect month and year view [`5ef2c23`](https://github.com/fomantic/Fomantic-UI/commit/5ef2c23b13b0d33534514dcc8809c171ee7ceb0d)
- feat(build): check node 13 and 14 for github actions [`750a192`](https://github.com/fomantic/Fomantic-UI/commit/750a1920da943ca449bd4a053d91012b351c294d)
- fix(dimmer): fix typo in dimmer.js [`bc87d77`](https://github.com/fomantic/Fomantic-UI/commit/bc87d77c849321365a9ddcd4c9bc1c296192f641)
- fix(readme): use the official discord shield [`ad8bae5`](https://github.com/fomantic/Fomantic-UI/commit/ad8bae595983b5f800a9777d7d63550694968e42)
- feat(form): escaped caused maximum callstack exceeded [`0f51c3f`](https://github.com/fomantic/Fomantic-UI/commit/0f51c3fea724ca82fe9bedb4cebe75328b47f9c5)
- fix(docs): grammar error [`245b087`](https://github.com/fomantic/Fomantic-UI/commit/245b087a9c037905560ae4a06e7b4213c7736b33)
- feat(form): support shouldtrim per fieldrule [`7da17f7`](https://github.com/fomantic/Fomantic-UI/commit/7da17f717bf67066e0e0ac3294663ad565e1081c)
- fix(form): refresh on instance to fetch dom changes [`1408be0`](https://github.com/fomantic/Fomantic-UI/commit/1408be05462b532f23c7d9cee0c600e030fdbb34)
- fix(form): dropdown item description gets wrong state class [`5e92c42`](https://github.com/fomantic/Fomantic-UI/commit/5e92c42f1ed842b10b17e0cb938ef8e5cfbda1ab)
- fix(input): firefox has different placeholder opacity [`965d0ee`](https://github.com/fomantic/Fomantic-UI/commit/965d0ee9a1c20973b03e694a40df808bcab70202)
- fix(table): missing comma lead into wrong selector [`8e5b7d4`](https://github.com/fomantic/Fomantic-UI/commit/8e5b7d458bc499c30f34bd36c8b96983acd69da8)
- fix(button): labeled icon buttons have wrong margin [`6d5703e`](https://github.com/fomantic/Fomantic-UI/commit/6d5703eb5d6ef9e72b5077b9a1dbf9d823ddd7d1)
- fix(chore): milestones should be sorted [`4b5496c`](https://github.com/fomantic/Fomantic-UI/commit/4b5496c6453fdcc92895397843ac32cd88685a7d)
- fix(chore): use url encoded semicolons so gulp-concat doesnt break [`6645c5f`](https://github.com/fomantic/Fomantic-UI/commit/6645c5f04b5fe5d3d60c51809c526e2d484e8d74)
- fix(grid): stackable grid had wrong with inside popup [`79b4eff`](https://github.com/fomantic/Fomantic-UI/commit/79b4effbbd9e185cd5c49d0939a66b21df35dd5f)
- feat(header): icon content was not aligned [`62dcda8`](https://github.com/fomantic/Fomantic-UI/commit/62dcda8f49926b971f1702c9b058d0e10fa6295d)
- fix(slider): dividing by 0 leads into infinite loop  [`ab3001c`](https://github.com/fomantic/Fomantic-UI/commit/ab3001c6121dfda5cf644391942b62d49b52833a)
- fix(rating): disabled rating should not allow pointer events [`09d5711`](https://github.com/fomantic/Fomantic-UI/commit/09d57116868e3b0ad1f48663e88e745e7df7c471)
- fix(dropdown): double declaration of name [`a432a81`](https://github.com/fomantic/Fomantic-UI/commit/a432a81acc9b5a7e2322f8ca7ebc7628d209723d)
- fix(form): refresh module on re-initializaion [`0949b16`](https://github.com/fomantic/Fomantic-UI/commit/0949b16fdbb99fbddd6a4a159e73518e5d536a98)
- fix(progress): adjust center position [`467839f`](https://github.com/fomantic/Fomantic-UI/commit/467839fd0eb1b626ce0bb5c09d2adeeb3b000307)
- fix(card): top border thickness of horizontal card [`cd975ae`](https://github.com/fomantic/Fomantic-UI/commit/cd975aeae6d28a5d83d921d0d5d0241c71eb822b)
- fix(icon): labels in icon groups where shown italic [`595367d`](https://github.com/fomantic/Fomantic-UI/commit/595367d25ec4936facf2e87eca431ffec5ef3242)
- fix(card): leave auto height to prevent image stretch on chrome [`dbe6ee4`](https://github.com/fomantic/Fomantic-UI/commit/dbe6ee4046744d8b173aa324f96aaeae3006dcf2)
- feat(chore): add table search proposal to v3 roadmap [`cfe8022`](https://github.com/fomantic/Fomantic-UI/commit/cfe8022ae3aa54ac22cdd9e2a18e14327e335ded)

#### [2.8.7](https://github.com/fomantic/Fomantic-UI/compare/2.8.6...2.8.7)

> 6 September 2020

- feat(dropdown): vertical dropdown menu item [`#1059`](https://github.com/fomantic/Fomantic-UI/issues/1059)
- chore(release): update dist [`4607933`](https://github.com/fomantic/Fomantic-UI/commit/4607933ac4fae2731016f22e2f506c90d951221f)
- build(deps-dev): bump all-contributors-cli from 6.17.0 to 6.17.1 [`b4613f4`](https://github.com/fomantic/Fomantic-UI/commit/b4613f41681dccb6d8036b21831c2cc3042d9e5d)
- build(deps-dev): bump all-contributors-cli from 6.16.1 to 6.17.0 [`994e053`](https://github.com/fomantic/Fomantic-UI/commit/994e0535f37fa9b18f9f4bc59997ef2aaa40c2a0)
- fix(multiple): make sure real icon selectors are adressed [`5bf395a`](https://github.com/fomantic/Fomantic-UI/commit/5bf395aa7ac5532ed7357325f105c4fca465fc28)
- build(deps): bump less from 3.11.3 to 3.12.0 [`7be4748`](https://github.com/fomantic/Fomantic-UI/commit/7be4748e3e9577f144d80ac64b30e4962185a101)
- build(deps): bump @octokit/rest from 16.43.1 to 16.43.2 [`4cff0d5`](https://github.com/fomantic/Fomantic-UI/commit/4cff0d50da9218e0c970532fb2f233edb8441230)
- fix(dropdown,calendar): avoid tab to enter input on disabled variant [`9f496c3`](https://github.com/fomantic/Fomantic-UI/commit/9f496c37b8a055f417d6e41acfac3af019f60b67)
- fix(form): adjust margin for field groups on mobile view [`ff40038`](https://github.com/fomantic/Fomantic-UI/commit/ff4003811cd2f1fbb5a1323dd399bc4fc0984f6c)
- chore(release): update changelog [`59d9b40`](https://github.com/fomantic/Fomantic-UI/commit/59d9b409879ad9413ea0a3efa4ab2e51017ad9b9)
- feat(calendar): added inverted variant [`a8cd1b0`](https://github.com/fomantic/Fomantic-UI/commit/a8cd1b0275d316277752d811b925f1bca60e9bf8)
- fix(dropdown): optional scrollhint on ios devices or firefox mobile [`b10cf9d`](https://github.com/fomantic/Fomantic-UI/commit/b10cf9d302b310a09fa5b1ec616088909ab6f737)
-  feat(progress): total value of 0 was unsupported [`ef85c3d`](https://github.com/fomantic/Fomantic-UI/commit/ef85c3dadae407629355cfa49e307cde84925392)
-  fix(calendar): trigger native change event on select [`9866014`](https://github.com/fomantic/Fomantic-UI/commit/9866014c31e9d0aa9feb49846364cdc01dcf07c5)
- build(deps-dev): bump all-contributors-cli from 6.16.0 to 6.16.1 [`eb10018`](https://github.com/fomantic/Fomantic-UI/commit/eb10018ce662aed71b0a47f4933870f5984f49f0)
- feat(dimmer): support other types of background beside color [`ecf370b`](https://github.com/fomantic/Fomantic-UI/commit/ecf370bcd048a1195753ed88ea9945e87b4b836e)
- feat(button): dedicated variables for toggle and circular [`3f0ceaa`](https://github.com/fomantic/Fomantic-UI/commit/3f0ceaacb337a4fc20a51045beacfff086553f05)
- feat(text): support state colors [`f8302b7`](https://github.com/fomantic/Fomantic-UI/commit/f8302b7ff0f25d2abdb9c15858d604de4c76d60d)
- fix(dropdown): using different keyname for fields.values failed [`7225780`](https://github.com/fomantic/Fomantic-UI/commit/72257802e46f7eec3ce6c68a0519026dced695e2)
- fix(calendar): adjust tooltip positions according to popup  position [`ae0b664`](https://github.com/fomantic/Fomantic-UI/commit/ae0b66459671c6e8f009290f012d5b1db65bdab9)
- fix(dropdown): very short menu had wrong order specificity [`891f6e6`](https://github.com/fomantic/Fomantic-UI/commit/891f6e6fc576ee3ddb414f7d5f7f62cfc6b62a75)
- fix(image): support centered div and adjusted aligned groups [`51ca1ed`](https://github.com/fomantic/Fomantic-UI/commit/51ca1ede9d19352bb84f8e203b9fe0e443e675b3)
- feat(list): icon buttons were misaligned [`0905ccf`](https://github.com/fomantic/Fomantic-UI/commit/0905ccfc4455bb7bbec4844a4950c725ea3f1abb)
- fix(form): remove errors on clear, reset and non inline revalidations [`0e6526d`](https://github.com/fomantic/Fomantic-UI/commit/0e6526d54e9831be377654bc3308b54de16dc52a)
- feat(build): remove individuals from components [`e8bc467`](https://github.com/fomantic/Fomantic-UI/commit/e8bc4674ab5fa95929e30f7357740c7757c95148)
- fix(input): attached buttons and labels in grouped state fields [`e1a8393`](https://github.com/fomantic/Fomantic-UI/commit/e1a83936154ddf882ba0c8904a9ba3efbcb8acce)
- fix(dropdown): multiple search button padding and wrapping [`7d48060`](https://github.com/fomantic/Fomantic-UI/commit/7d48060b3d2d713ffc48f739a12fc00bfe7e6528)
- fix(dropdown): columnar dropdowns on raw divs [`b2ae31b`](https://github.com/fomantic/Fomantic-UI/commit/b2ae31b2d523d270ac87033c7208758ee6d5b855)
- fix(build): single individuals element breaks build [`6957237`](https://github.com/fomantic/Fomantic-UI/commit/6957237ce75ba6c6965044bea999e85eaaabd9bd)
- build(deps): [security] bump lodash from 4.17.14 to 4.17.19 [`054976f`](https://github.com/fomantic/Fomantic-UI/commit/054976f7022f7cfdfbdd6df9654fd88955e04229)
- feat(slider): support bottom aligned label and prevent line break [`eb3436f`](https://github.com/fomantic/Fomantic-UI/commit/eb3436f6ebd249938402fdf64663d586d0d02d77)
- fix(form): isvalid should not delete error state and made optional now [`33397cc`](https://github.com/fomantic/Fomantic-UI/commit/33397ccb93d71c6693e80fd92a636d5e29db1d7f)
- fix(form): multiple selects return arrays for dirtycheck [`182dd81`](https://github.com/fomantic/Fomantic-UI/commit/182dd81520b281a8a455d0059032bc2031bcb7da)
- feat(calendar): avoid unnecessary redraw [`339e7fe`](https://github.com/fomantic/Fomantic-UI/commit/339e7fe94d88fb688d2267301e1d7b83319dbbf5)
- build(deps-dev): bump node-fetch from 2.6.0 to 2.6.1 [`caea603`](https://github.com/fomantic/Fomantic-UI/commit/caea6032e401cba59da2227f4880f8cfeefa89ec)
- build(deps-dev): bump all-contributors-cli from 6.17.1 to 6.17.2 [`04eca76`](https://github.com/fomantic/Fomantic-UI/commit/04eca764de1ccd553bf307b0ca8d3a4d32d594c6)
- fix(segment): horizontal segments lost rounded corners [`7cc71fd`](https://github.com/fomantic/Fomantic-UI/commit/7cc71fd7842e93a2b93980978a035095611107c6)
- build(deps): bump less from 3.12.0 to 3.12.2 [`5c37067`](https://github.com/fomantic/Fomantic-UI/commit/5c3706709b28a1f8caa717d9d9f6b286fae486d0)
- feat(dimmer): opacity setting created invalid value on rgb background [`0f558b9`](https://github.com/fomantic/Fomantic-UI/commit/0f558b9e1bfd818b7b4ff1d2ed3b4807ba552ac7)
- fix(calendar): evenly divide cell widths [`ec510c8`](https://github.com/fomantic/Fomantic-UI/commit/ec510c81be4270bfda77b26d4d2768dc4084c141)
- chore(release): bump version [`d7921a0`](https://github.com/fomantic/Fomantic-UI/commit/d7921a02c983c8ad9169ee3f090160e1a9538963)
- fix(icon): avoid conflictions with line icon aliases [`63d53f4`](https://github.com/fomantic/Fomantic-UI/commit/63d53f49e62ef9c679cbc8dc405fdcc4eefcba24)
- fix(form): adjust error prompt display in grouped inline fields   [`57f919b`](https://github.com/fomantic/Fomantic-UI/commit/57f919b923f3ce8701f0dc4daf410386484149a7)
- docs(roadmap): spelling fixed  [`50822da`](https://github.com/fomantic/Fomantic-UI/commit/50822da562be8baad08bdeb7527fee141f757a0c)
- fix(calendar): do not pass numeric-only text to date constructor [`2239f64`](https://github.com/fomantic/Fomantic-UI/commit/2239f64603145ed8cab6d9b859c78b1d5fb40f0f)
- fix(slider): operation sometimes returns not rounded value [`b385330`](https://github.com/fomantic/Fomantic-UI/commit/b385330dbcb70522b7a7b5f6fce5c1e0d1bde164)
- fix(slider): operation sometimes returns not rounded value [`76a2637`](https://github.com/fomantic/Fomantic-UI/commit/76a2637590d43c3bd8878f88d72718f7ed09d2a2)
- fix(menu): fix icons position and alignment in submenus [`bb16207`](https://github.com/fomantic/Fomantic-UI/commit/bb16207e2dedf66905c28ff81f7a1a91c8dd0d7d)
- fix(form): dont bind events to dropdown search inputs [`77b9dbf`](https://github.com/fomantic/Fomantic-UI/commit/77b9dbfe37b6e8af7f9ea802dc62948644dbf858)
- fix(site): remove double declarations [`df26dde`](https://github.com/fomantic/Fomantic-UI/commit/df26dde8e64674a497f6ac61e5962d9f4a1a5680)
- fix(calendar): support safari to accept yyyy-mm-dd format [`2ddcc7b`](https://github.com/fomantic/Fomantic-UI/commit/2ddcc7b3dd1c92c75aefa70b515e11149d11b9bc)
- feat(icon): add the old two classes for linegraph and chartline for compatibility [`7445821`](https://github.com/fomantic/Fomantic-UI/commit/74458216193cbf22653784a98f58ce57b0fc0244)
- feat(chore): fix cdn default js file [`0c40022`](https://github.com/fomantic/Fomantic-UI/commit/0c40022d7b8eeaf848c771192529a945d353154a)
- fix(toast): error progress bar lost visibility [`656dcfc`](https://github.com/fomantic/Fomantic-UI/commit/656dcfc434f00a81a9e82045da79a85b7d3e7877)
- fix(table): inherit vertical align in table footer [`5a18189`](https://github.com/fomantic/Fomantic-UI/commit/5a181892dd2ac7e959efd0c16d5084cac574b4ce)
- fix(button): compact icon button had wrong padding [`bdf6e55`](https://github.com/fomantic/Fomantic-UI/commit/bdf6e55aa2c30ef4c2a6850ad1bf2fc37d4cd70f)
- fix(site): duplicatedVariables [`2518cce`](https://github.com/fomantic/Fomantic-UI/commit/2518cce54d5380e0f9847d0b146de719b4927bde)
- fix(dropdown): fix html for placeholder [`9bbd39f`](https://github.com/fomantic/Fomantic-UI/commit/9bbd39fd75de90739b231d8e6dd43bb5e150e9ea)
- fix(icon): numeric classname to word [`dbeeca3`](https://github.com/fomantic/Fomantic-UI/commit/dbeeca3c61c8bb11770adcd349959f99cbbc1366)
- feat(docs): add web components proposal to library implementations [`d5d9764`](https://github.com/fomantic/Fomantic-UI/commit/d5d9764b4bc73f1a84912fa623bd3ca130a6b9d7)
- fix(search): avoid unneccesary double link navigation [`c35b4b1`](https://github.com/fomantic/Fomantic-UI/commit/c35b4b10444b227092863893f389a659602cf8b7)
- feat(docs): added openbase.io badge [`da75c3c`](https://github.com/fomantic/Fomantic-UI/commit/da75c3c9c5ecd4ffeefd87569a07d91b8d765a3c)
- fix(form): reset submitting flag when validation fails to keep dirtycheck [`e2d70af`](https://github.com/fomantic/Fomantic-UI/commit/e2d70afd0fe953e248e2ebec7bf65caff6e39f9c)
- fix(sidebar): avoid scrollbar on non body pushable [`c8ad8b9`](https://github.com/fomantic/Fomantic-UI/commit/c8ad8b9e19bda084a5f7a51e65143388bab35e3f)
- fix(tooltip): remove text-shadow to avoid inheritance from parent [`0b7630b`](https://github.com/fomantic/Fomantic-UI/commit/0b7630b906b3ad8b8a6d47ac91e424242923e338)
- fix(popup): left/right center tooltips were misaligned [`580d79b`](https://github.com/fomantic/Fomantic-UI/commit/580d79b9693ddea94ce174d41c5ae1951befa885)
- feat(slider): added default value for interpretlabel setting [`589d382`](https://github.com/fomantic/Fomantic-UI/commit/589d38217303740636319535ef20733e71cf953b)

#### [2.8.6](https://github.com/fomantic/Fomantic-UI/compare/2.8.5...2.8.6)

> 17 June 2020

- feat(transition): make effects optional [`4187f1f`](https://github.com/fomantic/Fomantic-UI/commit/4187f1fed4eba1a90275be7c4c66152e3779fc07)
- chore(release): update dist [`7a8dbf8`](https://github.com/fomantic/Fomantic-UI/commit/7a8dbf8fba864c0a2b6b0106337ddc3f12ace5bb)
- fix(label): adjusted basic labels height and attached image labels [`170a07b`](https://github.com/fomantic/Fomantic-UI/commit/170a07b0369942eb2313c21021c415c26d7b029c)
- chore(release): update changelog [`0269a82`](https://github.com/fomantic/Fomantic-UI/commit/0269a8213ac2ff438965c6a82503e7561d2024ae)
- build(deps): bump less from 3.11.1 to 3.11.2 [`e78783f`](https://github.com/fomantic/Fomantic-UI/commit/e78783fc3105ac5dafa8557cd267a3547a5dff9e)
- build(deps-dev): bump all-contributors-cli from 6.15.0 to 6.16.0 [`1d7764d`](https://github.com/fomantic/Fomantic-UI/commit/1d7764d2bfe0b81d72b8fb3acb856c47e0aa9d23)
- fix(dropdown): left and right menu positioning regression [`2cd5e9c`](https://github.com/fomantic/Fomantic-UI/commit/2cd5e9cb9b43cac42ede96650a52644a39bc1f78)
- fix(grid): very compact variation specificity and alignment [`bf8c159`](https://github.com/fomantic/Fomantic-UI/commit/bf8c159c28bf33fc694d7697b03d68f644247d02)
- fix(icon): vertical position for unsized icons and sized text [`4ac35a7`](https://github.com/fomantic/Fomantic-UI/commit/4ac35a7fd39a02d34a175120195a6f77f00107c3)
- fix(calendar): fix timezone issue when time is not given [`c96ba01`](https://github.com/fomantic/Fomantic-UI/commit/c96ba01018216cf92b2a3b15e86d108af283e8d6)
- build(deps): bump less from 3.11.2 to 3.11.3 [`2f96b0b`](https://github.com/fomantic/Fomantic-UI/commit/2f96b0b1d6d60f88cd9c056102c059ad2f53e01d)
- chore(release): bump version [`275b515`](https://github.com/fomantic/Fomantic-UI/commit/275b51518850fd0d5f3de4f9b103ec672cdc6492)
- fix(dimmer): page dimmer in firefox results in misaligned modals [`790587f`](https://github.com/fomantic/Fomantic-UI/commit/790587ffadac8f0d56d226190993c80e4f99acd1)
- fix(build): location parameter to avoid missing build number [`ffbb9ec`](https://github.com/fomantic/Fomantic-UI/commit/ffbb9ec056fc2e9252a0e400a3a187e76aae30eb)
- fix(dropdown): sizer element is created every time dropdown is initialized [`b3be317`](https://github.com/fomantic/Fomantic-UI/commit/b3be31745c8ec0ec2dee93074059cf78b054bb5a)
- fix(calendar): popup should not close when its trigger event is not click [`83e45ad`](https://github.com/fomantic/Fomantic-UI/commit/83e45adfb4978cc7819748afe85a75f42ef50b6f)
- feat(chore): autoassign ko2in for pr reviews [`1d6ea76`](https://github.com/fomantic/Fomantic-UI/commit/1d6ea76d31203dad9de571822ae5e2ea95fcac93)

#### [2.8.5](https://github.com/fomantic/Fomantic-UI/compare/2.8.4...2.8.5)

> 1 June 2020

- chore(release): update dist [`a266b95`](https://github.com/fomantic/Fomantic-UI/commit/a266b95dab205f79c9c9d3b6e7ccbffd47cc87d8)
- feat(icons): update to FA 5.13.0 [`c9e768d`](https://github.com/fomantic/Fomantic-UI/commit/c9e768de50c91854c15fce8a6cc1e03005b6a629)
- build(deps-dev): bump auto-changelog from 1.16.3 to 1.16.4 [`ac35365`](https://github.com/fomantic/Fomantic-UI/commit/ac35365a5b6b249b2057ae704b9bbb7df001217c)
- build(deps-dev): bump all-contributors-cli from 6.14.0 to 6.14.1 [`16f4159`](https://github.com/fomantic/Fomantic-UI/commit/16f4159560bcbfb1174ec44464a782668569ae6f)
- chore(github): update issue templates [`be0ed70`](https://github.com/fomantic/Fomantic-UI/commit/be0ed70837500b22de96b7ca8097037a5ff55bb1)
- feat(search): scrollable search result [`7cca9f3`](https://github.com/fomantic/Fomantic-UI/commit/7cca9f3977e90f76af15fb700e56649f979da0b7)
- build(deps-dev): bump all-contributors-cli from 6.14.1 to 6.14.2 [`066ad8d`](https://github.com/fomantic/Fomantic-UI/commit/066ad8de306a831d2fdafcb15ff51b9458f84646)
- fix(input): better differ between left/right icon/action [`93605f5`](https://github.com/fomantic/Fomantic-UI/commit/93605f5935161265ea66078ddadb3a354dd385a5)
- fix(calendar): fire onchange only when date selection is complete [`6ba815e`](https://github.com/fomantic/Fomantic-UI/commit/6ba815ee457f154801809bf2e2a407070c5c6d55)
- chore(release): update changelog [`88f4e11`](https://github.com/fomantic/Fomantic-UI/commit/88f4e11e5e130379b4940fc8735dc829ebeb5d53)
- fix(progress): wrong indicating background color on float percentage &lt; 10 [`85f8e03`](https://github.com/fomantic/Fomantic-UI/commit/85f8e03eb4f35522937f7f1ac64bf41d7b704c70)
- chore(github): update issue templates [`5e31691`](https://github.com/fomantic/Fomantic-UI/commit/5e316911ff27e425557687388d2c502ecfd2ae78)
- build(deps-dev): bump auto-changelog from 1.16.2 to 1.16.3 [`8a49912`](https://github.com/fomantic/Fomantic-UI/commit/8a499124bfd3b6693dd606668b3da067bd2ff100)
- chore(github): clean up old issue templates [`aab4be3`](https://github.com/fomantic/Fomantic-UI/commit/aab4be3afc9e12fc51b11e376135ab5aad6faea9)
- chore(github): clean up old issue templates [`3f3045c`](https://github.com/fomantic/Fomantic-UI/commit/3f3045c09176875bd3db674c0874bc4b96d0d3f7)
- chore(github): update issue templates [`3f109a5`](https://github.com/fomantic/Fomantic-UI/commit/3f109a574e5101b2792c2f7ecd4611db07a91e7d)
- chore(github): clean up old issue templates [`093dc1c`](https://github.com/fomantic/Fomantic-UI/commit/093dc1cab83a608f08d6d36a8af7299251c90581)
- build(deps-dev): bump all-contributors-cli from 6.14.2 to 6.15.0 [`8193091`](https://github.com/fomantic/Fomantic-UI/commit/819309195c725a8b1a70e5dec1f1fdbee3da507f)
- feat(build): allow individual components to be build separately only [`9b1f9ef`](https://github.com/fomantic/Fomantic-UI/commit/9b1f9ef42b25bdf1939fc7cd088b9695b8229e57)
- chore(github): clean up old issue templates [`d4a2232`](https://github.com/fomantic/Fomantic-UI/commit/d4a22324f595765e4a3b44b5404bf035e317b714)
- build(deps): bump gulp-rtlcss from 1.4.0 to 1.4.1 [`bd7b981`](https://github.com/fomantic/Fomantic-UI/commit/bd7b981ffc67168d3f2cde979561c9fb898d00f6)
- fix(chore): replace jquery trim with vanilla js [`323e608`](https://github.com/fomantic/Fomantic-UI/commit/323e608eb9eb3e1260771fbd7354b8ccef4fef19)
- build(deps): bump mkdirp from 0.5.1 to 0.5.3 [`325d8e7`](https://github.com/fomantic/Fomantic-UI/commit/325d8e770535d94a12255ef48cab8feaddc0bec8)
- fix(dropdown): nested dropdown positioning [`8621c99`](https://github.com/fomantic/Fomantic-UI/commit/8621c9980b4d40c1d2a5720cf9a24e35e036f8bc)
- fix(calendar): fix the popup show function getting called twice [`8bb477b`](https://github.com/fomantic/Fomantic-UI/commit/8bb477b581eb7422b20ae2c6145b59aef642bf9b)
- fix(popup): pre-existing popup positioning inside tables [`feed67a`](https://github.com/fomantic/Fomantic-UI/commit/feed67af269a4144c8dec9d70a21e5edb733ef6a)
- chore(readme): add do sponsor content [`460566a`](https://github.com/fomantic/Fomantic-UI/commit/460566a8a38d5e03e8388005e18ffb20b75fd52e)
- fix(form): optimized disabled detection [`09e6d28`](https://github.com/fomantic/Fomantic-UI/commit/09e6d288c2124e36a3ad260c13073c8df50670d2)
- feat(divider): added variable for border style [`4929629`](https://github.com/fomantic/Fomantic-UI/commit/49296296035ead409ff13e493221968c11d9ec50)
- fix(button): correct vertical align for icons within buttons [`defb29e`](https://github.com/fomantic/Fomantic-UI/commit/defb29e84339ca69f9f664e07000400b7bceb206)
- build(deps): bump gulp-git from 2.10.0 to 2.10.1 [`4d55b74`](https://github.com/fomantic/Fomantic-UI/commit/4d55b7462da7da4bdf12c0f3e441d190090a9af3)
- fix(tab): make auto activation of tabs optional [`9f24338`](https://github.com/fomantic/Fomantic-UI/commit/9f24338e9794321ff1c808facff9255429c3d44f)
- chore(release): bump version [`cbcb931`](https://github.com/fomantic/Fomantic-UI/commit/cbcb931c994e801948f364b70dc654ed5bfd4a9d)
- chore(readme): add do sponsor content [`cabf2fe`](https://github.com/fomantic/Fomantic-UI/commit/cabf2fe0f17edcc278f9a4a0db0b31ce0c3931a4)
- chore(github): update issue templates [`a240350`](https://github.com/fomantic/Fomantic-UI/commit/a240350a15c4a0f18756a4816d243a44f3d37fa1)
- feat(step): added right vertical steps variant having the arrow to the left side [`1986ea2`](https://github.com/fomantic/Fomantic-UI/commit/1986ea2c729555962d66cb47680756c08eb4af95)
- build(css): Race condition fix for sometimes broken minified css builds [`6f8dc82`](https://github.com/fomantic/Fomantic-UI/commit/6f8dc82d045a2f3553d721f9e49781df27e6378b)
- build(deps): bump jquery from 3.5.0 to 3.5.1 [`a08f089`](https://github.com/fomantic/Fomantic-UI/commit/a08f08989fe4ab3d450e8fb031aa753675686120)
- build(deps): bump replace-ext from 1.0.0 to 1.0.1 [`1a85afe`](https://github.com/fomantic/Fomantic-UI/commit/1a85afe0dcd0e70297efb481de8943618c6582bd)
- build(deps): bump jquery from 3.4.1 to 3.5.0 [`fc2c56e`](https://github.com/fomantic/Fomantic-UI/commit/fc2c56e8654bad5dbfdac5c0530f56a5c34f0149)
- fix(button): icon adjustments in animated button  [`d580ef0`](https://github.com/fomantic/Fomantic-UI/commit/d580ef0e4081b00ea95fbab6d6c5166c44f5b471)
- build(deps): bump mkdirp from 0.5.4 to 0.5.5 [`7137827`](https://github.com/fomantic/Fomantic-UI/commit/71378278581fd4c02f722a7d2960fd915efb1b4f)
- build(deps): bump mkdirp from 0.5.3 to 0.5.4 [`0689548`](https://github.com/fomantic/Fomantic-UI/commit/0689548a55be6809fa24308878a6f8d5fe0decbe)
- chore(github): add issue template config [`abaf09b`](https://github.com/fomantic/Fomantic-UI/commit/abaf09ba1c0eb533f2ca1910fb81e188e897d996)
- fear(chore): search for semantic.json from current workspace path [`e0ccbfc`](https://github.com/fomantic/Fomantic-UI/commit/e0ccbfc34cf8b987836a24d833dd251826d4e477)
- fix(build): prevent gulp watch task from refreshing all components [`afbf492`](https://github.com/fomantic/Fomantic-UI/commit/afbf492215702d5a28f9c9987dc76a36af450e05)
- fix(modal): fix content css-inheritance on mobile [`3c70f9e`](https://github.com/fomantic/Fomantic-UI/commit/3c70f9e00ed7afe3a6879416336259d522d24957)
- fix(icon): medium/default font was missing general css properties [`fe44c89`](https://github.com/fomantic/Fomantic-UI/commit/fe44c8935241ca110efce58d3b17b6e8e23b7d10)
- fix(build): Import 'various' gulp task also in npm gulpfile [`eb8eefe`](https://github.com/fomantic/Fomantic-UI/commit/eb8eefed9e605a156de992af5820dc026b5a38b0)
- fix(dropdown): dont trigger onchange event on initiaload when values are given [`544caec`](https://github.com/fomantic/Fomantic-UI/commit/544caec08bb329bbded70f5d58f6d2a8240d36a6)
- fix(build): double check for existing object property [`0d6f106`](https://github.com/fomantic/Fomantic-UI/commit/0d6f1060e760d5ae88e92dfe541b6f2007ab5245)
- fix(modal): center fluid action buttons correctly [`5261482`](https://github.com/fomantic/Fomantic-UI/commit/526148272ae353d8705f6b096fc765599470cfe7)
- fix(visibility): jquery scrollleft is a function rather than a property [`ec615b3`](https://github.com/fomantic/Fomantic-UI/commit/ec615b366280b8380f8f0de5343254a4c4ca59e1)
- fix(dropdown): prevent showing the whole list if showOnFocus is false [`40642d3`](https://github.com/fomantic/Fomantic-UI/commit/40642d3d589fbed45f567bf60db76bfae03ecfe7)

#### [2.8.4](https://github.com/fomantic/Fomantic-UI/compare/2.8.3...2.8.4)

> 24 February 2020

- build(deps-dev): bump all-contributors-cli from 6.11.2 to 6.13.0 [`#1272`](https://github.com/fomantic/Fomantic-UI/pull/1272)
- chore(release): update dist [`6da2101`](https://github.com/fomantic/Fomantic-UI/commit/6da2101864203cd393ce17ca2ea6fbdc9e8ae66a)
- build(deps-dev): bump all-contributors-cli from 6.13.0 to 6.14.0 [`4deee38`](https://github.com/fomantic/Fomantic-UI/commit/4deee388e5cf2a4f002ae5f190012f5d271e9575)
- feat(calendar): add ability to disable months and years [`ac115ac`](https://github.com/fomantic/Fomantic-UI/commit/ac115ac8a8a435fa1d756f834fdd4e62d5f55f70)
- build(deps): bump @octokit/rest from 16.36.0 to 16.39.0 [`6639efb`](https://github.com/fomantic/Fomantic-UI/commit/6639efbb53bd5cf86adc758b826ebea5bdd9f80a)
- feat(form): auto add empty rule validation for required fields [`ca80dca`](https://github.com/fomantic/Fomantic-UI/commit/ca80dcabcbb8433b5feb6e9dd8d2cfcfd7b2e15e)
- build(deps): bump @octokit/rest from 16.40.1 to 16.43.0 [`5aff504`](https://github.com/fomantic/Fomantic-UI/commit/5aff504d4996750ca449e5123649d836d9cc61b4)
- chore(release): update changelog [`62bd670`](https://github.com/fomantic/Fomantic-UI/commit/62bd67026d8fb3bb64df935f9165f13927d8c786)
- fix(table): invented a helper class to solve the styling logic when rowspan is used in tables [`1b20446`](https://github.com/fomantic/Fomantic-UI/commit/1b20446b04476517506777daf8a2da92751ace46)
- build(deps): bump @octokit/rest from 16.39.0 to 16.40.1 [`1356f15`](https://github.com/fomantic/Fomantic-UI/commit/1356f15a5d8810efd29ecd5163d3628bb241113f)
- build(config): respect browserslist config [`fdd3cc8`](https://github.com/fomantic/Fomantic-UI/commit/fdd3cc8c36670dee059dabdd0045edd40b8685f4)
- fix(toast): make sure element does still exist before transition ends [`6a3eca1`](https://github.com/fomantic/Fomantic-UI/commit/6a3eca1dea3b2e443291c97ba3185bc9f70f3cfd)
- build(deps): bump @octokit/rest from 16.35.2 to 16.36.0 [`efdefaf`](https://github.com/fomantic/Fomantic-UI/commit/efdefaf318e5925bdc12c4441221f661ca804f99)
- fix(form): inline calendar fields did not display properly [`c2ce312`](https://github.com/fomantic/Fomantic-UI/commit/c2ce312fb2cd765f98977c6942300e6970a7e8ed)
- feat(modal): unsupported debug warning when useflex is used in ie or with detachable false [`c512cf2`](https://github.com/fomantic/Fomantic-UI/commit/c512cf243737f883caca134dac6aa4e101b37a48)
- build(deps): bump less from 3.10.3 to 3.11.1 [`fc74780`](https://github.com/fomantic/Fomantic-UI/commit/fc74780c4170c5c11dbcdd75b10b53491a5e58ce)
- feat(form): replace all rule token instances in prompt message  [`2538a8e`](https://github.com/fomantic/Fomantic-UI/commit/2538a8e7af2b2679d8e1ecde350074697c97daa7)
- build(deps): bump @octokit/rest from 16.43.0 to 16.43.1 [`46f945f`](https://github.com/fomantic/Fomantic-UI/commit/46f945fd1bb298c46c7982c03da41e01a96df57c)
- chore(release): bump version [`f58b1f3`](https://github.com/fomantic/Fomantic-UI/commit/f58b1f3b98fe33f5a6e5997fa191d24478ccb5dc)
- fix(menu): colored active items were not displayed colored [`03e9d7f`](https://github.com/fomantic/Fomantic-UI/commit/03e9d7f94bcf08b44bbae9d6efd592ef3cf38a31)
- fix(modal): border radius for inner dimmer should inherit from the modal [`8ab6b89`](https://github.com/fomantic/Fomantic-UI/commit/8ab6b89248d4407aab3f2be03525da1f2dde425c)
- fix(emoji): disabled link emoji should not have pointer cursor [`51cfaa4`](https://github.com/fomantic/Fomantic-UI/commit/51cfaa49f500c697f21f50e1e23a0316ad6c8d0b)
- fix(form): make a difference between value 0 and false for radio buttons [`e3468c7`](https://github.com/fomantic/Fomantic-UI/commit/e3468c7128ab4ae27f2381812bd6e4ba75fd53e8)
- fix(dropdown): search field cursor was barely visible on field states [`a49c823`](https://github.com/fomantic/Fomantic-UI/commit/a49c82330af6715f4de6332d40ed80f2fb070dbc)
- fix(segment): sub headers in inverted labels were not changed to in some cases [`66a15cd`](https://github.com/fomantic/Fomantic-UI/commit/66a15cd641c692fe478dfecf875e2649a1789db9)
- fix(dropdown): get item function now working properly with array of integers [`2930de5`](https://github.com/fomantic/Fomantic-UI/commit/2930de5137471b74b3a6baefd5384dbcde55c7b7)
- fix(shape): make sure chrome renders the z-translated faces properly [`37cdf31`](https://github.com/fomantic/Fomantic-UI/commit/37cdf31121e7b8a80f33b975174a790fd57b3570)
- fix(modal): basic modal header should not have a border [`bd45cb0`](https://github.com/fomantic/Fomantic-UI/commit/bd45cb01209f26355b39e903f40fdd94a1c4021b)
- fix(checkbox): dont show visual changes on disabled checkboxes [`4238b78`](https://github.com/fomantic/Fomantic-UI/commit/4238b78c215a5b7d4598fef1c231d7d0fc22f0da)

#### [2.8.3](https://github.com/fomantic/Fomantic-UI/compare/2.8.2...2.8.3)

> 23 December 2019

- fix(dropdown): do not use value as name when name is empty [`#1191`](https://github.com/fomantic/Fomantic-UI/issues/1191)
- fix(dropdown): values are incorrect if they contain some special chars [`#1207`](https://github.com/fomantic/Fomantic-UI/issues/1207)
- fix(dropdown): handle text metadata on select build dropdowns [`#1103`](https://github.com/fomantic/Fomantic-UI/issues/1103)
- fix(slider): preventCrossover should only affect range sliders [`#1231`](https://github.com/fomantic/Fomantic-UI/issues/1231)
- feat(popup): add variant to ensure width if parent container is to small [`#1213`](https://github.com/fomantic/Fomantic-UI/issues/1213)
- fix(dropdown): clearable icon is not clickable on mobile [`#647`](https://github.com/fomantic/Fomantic-UI/issues/647)
- fix(form): action input had wrong border radius in some cases [`#1184`](https://github.com/fomantic/Fomantic-UI/issues/1184)
- fix(form): avoid additional margin with nested fields [`#1202`](https://github.com/fomantic/Fomantic-UI/issues/1202)
- fix(table): dont show background on sortable headers if table is basic [`#1194`](https://github.com/fomantic/Fomantic-UI/issues/1194)
- fix(input): action input border color in state fields [`#1181`](https://github.com/fomantic/Fomantic-UI/issues/1181)
- chore(release): update dist [`3eb64b7`](https://github.com/fomantic/Fomantic-UI/commit/3eb64b76bb5dcf6f525d4edc7201c9437d0ef991)
- chore(release): update dist [`5577de3`](https://github.com/fomantic/Fomantic-UI/commit/5577de3d8371ae3ed6681ca923cfaae4bb65eb30)
- feat(icon): update icons to FA 5.12.0 [`fea61f9`](https://github.com/fomantic/Fomantic-UI/commit/fea61f918e1d6c74549661e225f2d46be10c7049)
- build(deps-dev): bump all-contributors-cli from 6.11.0 to 6.11.1 [`f5f9d14`](https://github.com/fomantic/Fomantic-UI/commit/f5f9d144398a997ffe92e890673371d2c1fc0de8)
- chore(github): update issue/pr templates [`c40be8d`](https://github.com/fomantic/Fomantic-UI/commit/c40be8dc10c09e3bd66074dcc48d3cee44035c6f)
- chore(release): update changelog [`0cbf477`](https://github.com/fomantic/Fomantic-UI/commit/0cbf477a70ac0199d00860e269b7057a6fbb827d)
- fix(form): add rule method overwrites existing rules [`70d538c`](https://github.com/fomantic/Fomantic-UI/commit/70d538c2527263f50dedab5d4ebf60e258cc279f)
- docs(contributors): add LolHens as a contributor [`d285f16`](https://github.com/fomantic/Fomantic-UI/commit/d285f16fe3981a53602dedd6735a797a2f2cf8da)
- fix(dimmer): borders on partial segment dimmers are incorrect [`10b59be`](https://github.com/fomantic/Fomantic-UI/commit/10b59be18003e8ff0f49cef1222c93d4aa55bf11)
- build(deps): bump @octokit/rest from 16.35.0 to 16.35.2 [`6e7104c`](https://github.com/fomantic/Fomantic-UI/commit/6e7104c2820ae354519dbffdff1431a037fdd608)
- fix(popup): tooltips don't work on safari &lt;= 12.1 [`dde63c4`](https://github.com/fomantic/Fomantic-UI/commit/dde63c4475acd56c33a49a532d88706bf0ac46e7)
- chore(readme): update readme contents [`9c6142f`](https://github.com/fomantic/Fomantic-UI/commit/9c6142f5158b61e35d4d2b8770aeb554a18fa1bb)
- build(deps-dev): bump all-contributors-cli from 6.11.1 to 6.11.2 [`330562f`](https://github.com/fomantic/Fomantic-UI/commit/330562fb1baf544cecb38a283b872cce0a4a4c72)
- feat(modal): allow close icon to be inside header for small modals [`de0e2b8`](https://github.com/fomantic/Fomantic-UI/commit/de0e2b895f027ddf257097abffcf694442c60c91)
- feat(dropdown): add unfilterable item class for search input [`8b5625a`](https://github.com/fomantic/Fomantic-UI/commit/8b5625ad4d6df9188a280e800a2e61f9208d3a03)
- build(deps): bump gulp-git from 2.9.0 to 2.10.0 [`091befd`](https://github.com/fomantic/Fomantic-UI/commit/091befdeba25b102f330281e49e6af1442f255dc)
- chore(release): bump version [`d0cb855`](https://github.com/fomantic/Fomantic-UI/commit/d0cb85511e9cab05d0636a1c4c10e3ef7a60c978)
- build(actions): stop nightly error on forks [`87ad7fc`](https://github.com/fomantic/Fomantic-UI/commit/87ad7fcd4c5624defc6b12d122dac8fe459db0e9)
- chore(release): update changelog [`037a040`](https://github.com/fomantic/Fomantic-UI/commit/037a0402362fa2ffa44e434fe7e362c8cb753bb8)
- fix(checkbox): ie11 support for non existing event [`e93abbe`](https://github.com/fomantic/Fomantic-UI/commit/e93abbe3c0a9cae037cf0e1d3dd44a20150dd6aa)
- fix(globals): duplicate variable declaration [`5c15f90`](https://github.com/fomantic/Fomantic-UI/commit/5c15f90ff01032bba1721e203f66669765137440)
- docs(readme): add snyk badge [`2e6e1aa`](https://github.com/fomantic/Fomantic-UI/commit/2e6e1aad055caa39e11c7237a774da0e64a1d7de)

#### [2.8.2](https://github.com/fomantic/Fomantic-UI/compare/2.8.1...2.8.2)

> 18 November 2019

- fix(engines): make npm version more or equal to [`#1186`](https://github.com/fomantic/Fomantic-UI/issues/1186)
- build(actions): correct nightly build version [`#1171`](https://github.com/fomantic/Fomantic-UI/issues/1171)
- chore(release): update dist [`7142103`](https://github.com/fomantic/Fomantic-UI/commit/714210352a7f86a74017734ff772ac230eae7bb9)
- fix(emoji): make emoji inherit font-size so they don't get cropped [`66c45d8`](https://github.com/fomantic/Fomantic-UI/commit/66c45d8a1adbbe31abd552ea33962647e6e54543)
- chore(release): update changelog [`2f3312f`](https://github.com/fomantic/Fomantic-UI/commit/2f3312f0f075e3a570dc96725be17e965b3b0964)
- chore(release): bump version [`c95d70d`](https://github.com/fomantic/Fomantic-UI/commit/c95d70df0b8f61394c0c7bcdfe2bca0c39cde77a)

#### [2.8.1](https://github.com/fomantic/Fomantic-UI/compare/2.7.8...2.8.1)

> 13 November 2019

- build(deps-dev): bump all-contributors-cli from 6.10.0 to 6.11.0 [`#1160`](https://github.com/fomantic/Fomantic-UI/pull/1160)
- build(deps): bump @octokit/rest from 16.34.1 to 16.35.0 [`#1154`](https://github.com/fomantic/Fomantic-UI/pull/1154)
- build(deps-dev): bump auto-changelog from 1.16.1 to 1.16.2 [`#1133`](https://github.com/fomantic/Fomantic-UI/pull/1133)
- build(deps): bump @octokit/rest from 16.33.1 to 16.34.0 [`#1117`](https://github.com/fomantic/Fomantic-UI/pull/1117)
- build(deps): bump gulp-json-editor from 2.5.3 to 2.5.4 [`#1115`](https://github.com/fomantic/Fomantic-UI/pull/1115)
- feat(toast): add actions, behaviors and other variations [`#160`](https://github.com/fomantic/Fomantic-UI/issues/160)
- fix(calendar): no word length limit for months [`#1026`](https://github.com/fomantic/Fomantic-UI/issues/1026)
- feat(calendar): add onBeforeChange callback and fix a date value issue [`#417`](https://github.com/fomantic/Fomantic-UI/issues/417)
- feat(dropdown): optional skip focus when calling 'show' behavior [`#1040`](https://github.com/fomantic/Fomantic-UI/issues/1040)
- fix(dropdown): remove searchterm if nothing matches & opts are disabled [`#992`](https://github.com/fomantic/Fomantic-UI/issues/992)
- feat(form): generalize state variations for field [`#1097`](https://github.com/fomantic/Fomantic-UI/issues/1097)
- fix(slider): offset for reversed vertical slider [`#1142`](https://github.com/fomantic/Fomantic-UI/issues/1142)
- fix(slider): add fireOnInit parameter to prevent events being triggered [`#1000`](https://github.com/fomantic/Fomantic-UI/issues/1000)
- fix(dropdown): dont adjustment dropdown icon when inside a label button [`#1058`](https://github.com/fomantic/Fomantic-UI/issues/1058)
- fix(form): trigger correct dirty handlers to fix function of checkboxes [`#1053`](https://github.com/fomantic/Fomantic-UI/issues/1053)
- fix(list): behavior of grouped icons in list [`#1038`](https://github.com/fomantic/Fomantic-UI/issues/1038)
- fix(dropdown): action button has incorrect border radius with dropdown [`#1072`](https://github.com/fomantic/Fomantic-UI/issues/1072)
- fix(table): add td support in tfoot tag [`#840`](https://github.com/fomantic/Fomantic-UI/issues/840)
- fix(form): dont trigger change for dropdown when form is cleared [`#778`](https://github.com/fomantic/Fomantic-UI/issues/778)
- feat(form): accept 1 in addition to true as checked value for checkboxes [`#987`](https://github.com/fomantic/Fomantic-UI/issues/987)
- fix(dropdown): prevent blur when hiding dropdown directly after search [`#1089`](https://github.com/fomantic/Fomantic-UI/issues/1089)
- fix(dropdown): use regular event handler for allowAdditions input blur [`#997`](https://github.com/fomantic/Fomantic-UI/issues/997)
- feat(dropdown): add case sensitivity setting for search [`#932`](https://github.com/fomantic/Fomantic-UI/issues/932)
- fix(modal): correct undetached positioning when large modal is used [`#1079`](https://github.com/fomantic/Fomantic-UI/issues/1079)
- fix(modal): make bottom margin scrolling modals work in firefox & edge [`#1075`](https://github.com/fomantic/Fomantic-UI/issues/1075)
- fix(calendar): prevent toggle range class at today button [`#901`](https://github.com/fomantic/Fomantic-UI/issues/901)
- fix(grid): fix padding on stackable compact grid on mob devices [`#652`](https://github.com/fomantic/Fomantic-UI/issues/652)
- fix(tab): do not auto activate tabs more than once [`#1014`](https://github.com/fomantic/Fomantic-UI/issues/1014)
- fix(modal): vertical alignment on detachable modal was incorrect [`#1009`](https://github.com/fomantic/Fomantic-UI/issues/1009)
- fix(calendar): cross browser support for dateparsing using dots [`#829`](https://github.com/fomantic/Fomantic-UI/issues/829)
- fix(calendar): date formatting when entered via keyboard [`#829`](https://github.com/fomantic/Fomantic-UI/issues/829)
- chore(release): update dist [`662c43f`](https://github.com/fomantic/Fomantic-UI/commit/662c43f82de2b11677c1a7dd7fa5052181b4cdc5)
- feat(*): add dynamic LESS compilation of component variations [`c048399`](https://github.com/fomantic/Fomantic-UI/commit/c0483997eaf3e378abcaef1cf6b25bdfd1d33ffb)
- chore(release): update changelog [`dc250f3`](https://github.com/fomantic/Fomantic-UI/commit/dc250f3fddf7c40ba6aa4ae649682d80b8e9c01b)
- chore: merge branch add-contributors into develop [`a260b0b`](https://github.com/fomantic/Fomantic-UI/commit/a260b0b538bc851745642d17e4546ba21838108e)
- feat(emoji): add emoji component using tweemoji & joypixels [`4c1d67c`](https://github.com/fomantic/Fomantic-UI/commit/4c1d67c1877546386f1f79894c8b11a36f483cfe)
- feat(icons): update icons to FA 5.11.2 [`764ed35`](https://github.com/fomantic/Fomantic-UI/commit/764ed35710f3f895be103d97485f4fe956771526)
- fix(modal): support rtl left scrollbar behaviors [`3313552`](https://github.com/fomantic/Fomantic-UI/commit/3313552771e0e633a3fba388ae9e47b13a42aa64)
- feat(rating): float value ratings [`0583dcc`](https://github.com/fomantic/Fomantic-UI/commit/0583dcc1b5e10e9c89d4958487446b54347d6d2a)
- fix(slider): handle touchevent on devices using jquery2 [`3ecaec0`](https://github.com/fomantic/Fomantic-UI/commit/3ecaec0c5fc901342c07ef2c8716fc71b32cb1f9)
- build(deps): bump @octokit/rest from 16.34.0 to 16.34.1 [`e6fe26d`](https://github.com/fomantic/Fomantic-UI/commit/e6fe26d382a6ad50476631d22cdd13274a7870e4)
- fix(grid): override grid container widths [`f0ba553`](https://github.com/fomantic/Fomantic-UI/commit/f0ba5531959e82cda9ad9e4ffea86febc83ba493)
- fix(dropdown): value on empty selects [`3d329c2`](https://github.com/fomantic/Fomantic-UI/commit/3d329c2721cfd2c03f470b6b78532da1cddffae5)
- docs: add zombietfk as a contributor [`7eae660`](https://github.com/fomantic/Fomantic-UI/commit/7eae660e0b8e467030d6a8491ad0b71463aafb80)
- fix(slider): hidden sliders cause browser freeze [`669c3b3`](https://github.com/fomantic/Fomantic-UI/commit/669c3b324751ab74e135067c4c3747fb11ba6beb)
- docs: add rmarchiori as a contributor [`8df2185`](https://github.com/fomantic/Fomantic-UI/commit/8df2185104b36c053d23fb7ca497b7dc6db876e3)
- fix(popup): avoid detection of wrong existing popup [`4473b66`](https://github.com/fomantic/Fomantic-UI/commit/4473b66f71e8ba8ea6d7d1c3d93cc4f3053c9a56)
- docs: add josejbarneto as a contributor [`9f4f857`](https://github.com/fomantic/Fomantic-UI/commit/9f4f857115e867813feb419695835026db2b9c71)
- docs: add aexvir as a contributor [`ffe203a`](https://github.com/fomantic/Fomantic-UI/commit/ffe203ab6bb6fce8c485238c83df20264a11a8fd)
- build(deps-dev): bump all-contributors-cli from 6.9.3 to 6.10.0 [`7870214`](https://github.com/fomantic/Fomantic-UI/commit/78702149ee01a0410652630d0648a4eb0c8a1eff)
- docs: add HypertextPP as a contributor [`078d978`](https://github.com/fomantic/Fomantic-UI/commit/078d9780c8c6dec0daa2a13154f67283b3424bce)
- docs: add aardbol as a contributor [`15279f1`](https://github.com/fomantic/Fomantic-UI/commit/15279f1ff2139a11595bd8b7b1dbb8208d594678)
- docs: add RenonDis as a contributor [`301cbdc`](https://github.com/fomantic/Fomantic-UI/commit/301cbdce3bcc07957814e4ea75bdc73fa9188422)
- docs(readme): add nightly build info [`272b92a`](https://github.com/fomantic/Fomantic-UI/commit/272b92a396cf5e985212d83d7f0239cd23a78e62)
- feat(table): color marked cells [`8d08ea2`](https://github.com/fomantic/Fomantic-UI/commit/8d08ea23e7db62f26656a04a5eb65d51d4ccdbe9)
- fix(modal): fetch dimmer click if not detached [`49fddb1`](https://github.com/fomantic/Fomantic-UI/commit/49fddb19aa7b5dfc5c695c89a6b3ad38a5109857)
- docs: add cruzdanilo as a contributor [`0e95ebd`](https://github.com/fomantic/Fomantic-UI/commit/0e95ebd8b9b65270e182994cd76688205ce237f4)
- docs: add justkey007 as a contributor [`62978dd`](https://github.com/fomantic/Fomantic-UI/commit/62978dd97f498fc16f86ae6897247731b81db417)
- docs: add ryamaguchi0220 as a contributor [`4b6034a`](https://github.com/fomantic/Fomantic-UI/commit/4b6034a8cf240a80d19e96497d977d37d20d0196)
- fix(emoji): change emoji path to use svg [`9855d54`](https://github.com/fomantic/Fomantic-UI/commit/9855d54a1fa280baeeb4032b538a30527a8e43d5)
- chore(release): bump version [`dadbcd7`](https://github.com/fomantic/Fomantic-UI/commit/dadbcd728662122ff0a54c8c2062a997e5351ae0)
- docs(security): add 2.8 info [`723c3ba`](https://github.com/fomantic/Fomantic-UI/commit/723c3badb404698e48cacce232c6a27fa9d2c5b4)
- chore: add lubber-de to github funding file [`5d27f88`](https://github.com/fomantic/Fomantic-UI/commit/5d27f8849a39a61368be7dc8642af650606fb1b7)
- docs: add simondarke as a contributor [`ef7f454`](https://github.com/fomantic/Fomantic-UI/commit/ef7f45497ae0a8cb4f0fb96c37b951c24b92261e)
- docs: add iwgx as a contributor [`42ce1ed`](https://github.com/fomantic/Fomantic-UI/commit/42ce1edafbe86192807ab9d083c4eebd8146d908)
- docs: add RShalman as a contributor [`cb8ec2d`](https://github.com/fomantic/Fomantic-UI/commit/cb8ec2d561e1816b65eababd812d7ebb1932313b)
- docs: add shui91 as a contributor [`ee8a3d3`](https://github.com/fomantic/Fomantic-UI/commit/ee8a3d31fde2c281b7235963be13b93d1777504c)
- docs: add aexvir as a contributor [`d272066`](https://github.com/fomantic/Fomantic-UI/commit/d272066c463513bc80d8cbbdb1640c9d3ef31b0d)
- docs: update .all-contributorsrc [`9af52c7`](https://github.com/fomantic/Fomantic-UI/commit/9af52c753a11ed13d9b51182fe478cda5217a9ed)
- fix(build): variables in @site.variables were ignored [`4d3f3e4`](https://github.com/fomantic/Fomantic-UI/commit/4d3f3e46ff19ca1395e480ad8f4862826d6eb907)
- fix(dropdown): multiselect removing wasn't working [`327003f`](https://github.com/fomantic/Fomantic-UI/commit/327003fc68e00917176f51b797f26952eaa75cfd)
- fix(card): right image border in horizontal cards [`74d15b5`](https://github.com/fomantic/Fomantic-UI/commit/74d15b56cd3583d602c66b05f2f292d5501fca8c)
- fix(chore): permission value should transform into octal [`2563aa6`](https://github.com/fomantic/Fomantic-UI/commit/2563aa67a5604066fdcb6490dfb538a8535fa1ea)
- feat(docs): add lubber-de to funding info as suggested [`3573f61`](https://github.com/fomantic/Fomantic-UI/commit/3573f61fc1949c4c6d45613f50c4523cba821296)
- fix(dimmer): remove page dimmer border radius [`d5b66eb`](https://github.com/fomantic/Fomantic-UI/commit/d5b66eb242b8d0c5239956f9ba7a754a54911b78)
- fix(api): set context in beforesend to match docs [`e2b8a06`](https://github.com/fomantic/Fomantic-UI/commit/e2b8a060aa21c401e2bef7b10de0fbf13419109c)
- fix(card): horizontal cards on mobile got cut [`7d07c8c`](https://github.com/fomantic/Fomantic-UI/commit/7d07c8ca982ee2878b205d78f80890e862a3b9aa)
- build(theme): allow null for @site [`3983a7e`](https://github.com/fomantic/Fomantic-UI/commit/3983a7ebd6187838db20a44745870675e0ded659)
- fix(dropdown): parameter count resulted in wrong data for onchange [`bce515b`](https://github.com/fomantic/Fomantic-UI/commit/bce515b8f662d7d261b05993f9a9a122ff050c3d)
- fix(dropdown): remove required attribute from select [`00a87d2`](https://github.com/fomantic/Fomantic-UI/commit/00a87d28bb9f1ee2ddd4ec76e177fa0d39d6d486)
- docs: update README.md [`a8a870a`](https://github.com/fomantic/Fomantic-UI/commit/a8a870ad72cea4f118c895a0ea7bd5f5b2df9348)
- build(deps-dev): bump all-contributors-cli from 6.8.2 to 6.9.0 [`b37e3fd`](https://github.com/fomantic/Fomantic-UI/commit/b37e3fdfaaa3acad781d96fd3db491e0205022bc)
- build(deps-dev): bump all-contributors-cli from 6.8.1 to 6.8.2 [`00eea96`](https://github.com/fomantic/Fomantic-UI/commit/00eea96f6f87c088d967a1809f87d9cffd32b077)
- feat(table): add colored left & right row border [`ca7d653`](https://github.com/fomantic/Fomantic-UI/commit/ca7d653e1748e19eba04e94f92aa083df4623b57)
- feat(slider): add preventCrossover setting for range sliders [`4b1d548`](https://github.com/fomantic/Fomantic-UI/commit/4b1d54894c640896e6554358140e4578159a9bf4)
- build(deps): bump @octokit/rest from 16.28.8 to 16.28.9 [`531d1e4`](https://github.com/fomantic/Fomantic-UI/commit/531d1e4d10ec58020d44e0658a44b9dbdcdb377f)
- build(deps-dev): bump all-contributors-cli from 6.9.1 to 6.9.2 [`c6e6438`](https://github.com/fomantic/Fomantic-UI/commit/c6e6438672106bde260aa08c0992906eba5ea316)
- build(deps-dev): bump auto-changelog from 1.15.0 to 1.16.1 [`d9e7f2d`](https://github.com/fomantic/Fomantic-UI/commit/d9e7f2d9e2f4e8a9b8a76adf5090ba3096898d90)
- build(deps): bump @octokit/rest from 16.28.7 to 16.28.8 [`100e848`](https://github.com/fomantic/Fomantic-UI/commit/100e8484376206c4dbcb32709ee36565a430678a)
- feat(progress): made setting to 100% optional when set error/warning [`c2646f1`](https://github.com/fomantic/Fomantic-UI/commit/c2646f176e6cd0f3931e4c330000c3afd78094ba)
- build(deps): bump @octokit/rest from 16.33.0 to 16.33.1 [`e0634b3`](https://github.com/fomantic/Fomantic-UI/commit/e0634b3682a1c11589c0af593d091907d84fb4b5)
- fix(input): icon inputs have wrong padding when inside menus [`fdae269`](https://github.com/fomantic/Fomantic-UI/commit/fdae2697b319b5c06e2ab45d6dfa67b24e9537bc)
- build(deps): bump @octokit/rest from 16.30.2 to 16.32.0 [`b99726d`](https://github.com/fomantic/Fomantic-UI/commit/b99726dff6d06fd31d0a82716fa0c41db13b5eff)
- build(deps): bump @octokit/rest from 16.30.1 to 16.30.2 [`c484748`](https://github.com/fomantic/Fomantic-UI/commit/c4847486de6389c7f316d53688c298531684fb1b)
- docs: update .all-contributorsrc [`f2414ec`](https://github.com/fomantic/Fomantic-UI/commit/f2414ec12e1a91627fab15c6d7356025f480b4e0)
- docs: update .all-contributorsrc [`e977374`](https://github.com/fomantic/Fomantic-UI/commit/e977374b7d057a839c9cc4b81a43ed55ec0b6dd5)
- docs: update .all-contributorsrc [`70eed86`](https://github.com/fomantic/Fomantic-UI/commit/70eed865a6357d4799f27d619673061c7a932bb1)
- docs: update CONTRIBUTORS.md [`960c0ec`](https://github.com/fomantic/Fomantic-UI/commit/960c0ec66fbaf3845d6fd7dcc6744ed31261f578)
- docs: update README.md [`eae8901`](https://github.com/fomantic/Fomantic-UI/commit/eae8901185c5b0b0ff35ca87ea8074ea5cd82751)
- docs: update CONTRIBUTORS.md [`2423776`](https://github.com/fomantic/Fomantic-UI/commit/2423776144b6513b392b5e94d6d5761dc12dbb9b)
- docs: update README.md [`52ae150`](https://github.com/fomantic/Fomantic-UI/commit/52ae150c32dd163385cfb8fe2f5045960ca539a2)
- build(actions): add nightly build action [`fb9ec33`](https://github.com/fomantic/Fomantic-UI/commit/fb9ec3372674509e668110a670de59c6471145d4)
- feat(calendar): support type setting as metadata & initialize without JS [`c4221e4`](https://github.com/fomantic/Fomantic-UI/commit/c4221e4fb8a52790c51728fc40975a451b5c45dc)
- build(deps-dev): bump all-contributors-cli from 6.9.0 to 6.9.1 [`fa4adee`](https://github.com/fomantic/Fomantic-UI/commit/fa4adeecda13deb2b19ea3c4ff614977321a04d5)
- docs: update .all-contributorsrc [`755435d`](https://github.com/fomantic/Fomantic-UI/commit/755435d63a09db9ecf1b2adba79c9a006e8b093b)
- docs: update CONTRIBUTORS.md [`8630943`](https://github.com/fomantic/Fomantic-UI/commit/86309435fa14ccf74e81275f9a6ea84006c294e9)
- docs: update README.md [`ba6a7cb`](https://github.com/fomantic/Fomantic-UI/commit/ba6a7cbaa2c878f9e3b971f4c02b55aa4596ee9b)
- docs: update CONTRIBUTORS.md [`b4ce7eb`](https://github.com/fomantic/Fomantic-UI/commit/b4ce7eb2e578c9b961a5e80288efcc6bb79b1c60)
- docs: update README.md [`9d9c327`](https://github.com/fomantic/Fomantic-UI/commit/9d9c327ae8279e266d0ae6123988f80ddeced5be)
- build(actions): add nightly build action [`8eb1705`](https://github.com/fomantic/Fomantic-UI/commit/8eb1705041e7e24134cbf6b3798894788e30b85c)
- build(actions): fix nightly build [`00f68a8`](https://github.com/fomantic/Fomantic-UI/commit/00f68a8a2173f5d8aef3a55760e189d1be8ad638)
- docs: update CONTRIBUTORS.md [`ed0ce58`](https://github.com/fomantic/Fomantic-UI/commit/ed0ce5817276c179a4dc7ddc80a194c772364b9f)
- chore(*): merge master into develop [`0d0dcbf`](https://github.com/fomantic/Fomantic-UI/commit/0d0dcbf16e10a3cb45558f1948f12fcdae64c1e5)
- chore(*): merge master into develop [`85f9466`](https://github.com/fomantic/Fomantic-UI/commit/85f9466633039dd4708c7e18744e7759fe6fd545)
- build(actions): add nightly build action [`e14db9d`](https://github.com/fomantic/Fomantic-UI/commit/e14db9dea761fcdef461e1b1cf0124dd4684bece)
- build(deps-dev): bump all-contributors-cli from 6.9.2 to 6.9.3 [`0304c0a`](https://github.com/fomantic/Fomantic-UI/commit/0304c0a09218899c6265892c67a3f2d7b0971007)
- build(deps): bump @octokit/rest from 16.32.0 to 16.33.0 [`647850f`](https://github.com/fomantic/Fomantic-UI/commit/647850fe0d3399cc95fc421173dc85d2d6485ba5)
- build(deps): bump @octokit/rest from 16.29.0 to 16.30.1 [`29b5325`](https://github.com/fomantic/Fomantic-UI/commit/29b53253797358057981308eba9eb8a872a276e3)
- build(deps): bump @octokit/rest from 16.28.9 to 16.29.0 [`49d4788`](https://github.com/fomantic/Fomantic-UI/commit/49d4788a5619521628705d474f23b7b4d064ab79)
- chore(templates): add labels to new issue to reduce triage effort [`7521889`](https://github.com/fomantic/Fomantic-UI/commit/7521889a33a0165430fdc53f06e81eb17787e517)
- fix(modal): clicking on scrollbar with rtl enabled should not close the modal [`dd14fba`](https://github.com/fomantic/Fomantic-UI/commit/dd14fbafc3aec10345cc4178edc258f59bc7993d)
- Merge pull request #1091 from fomantic/dependabot/npm_and_yarn/develop/octokit/rest-16.33.1 [`fb7b98c`](https://github.com/fomantic/Fomantic-UI/commit/fb7b98c23c55e6cd0b20360fabe6e0e1baed3006)
- fix(dropdown): setting value of dropdown did not remove search [`093b901`](https://github.com/fomantic/Fomantic-UI/commit/093b90164589a23304a84caa9612cf3e1a3e5233)
- fix(modal): dont close modal when scrollbar is clicked in rtl environment [`2d894f1`](https://github.com/fomantic/Fomantic-UI/commit/2d894f1ae20b86612965fd17962171d85afd81a5)
- fix(list): use hex for unicode character to avoid encoding errors [`6187bae`](https://github.com/fomantic/Fomantic-UI/commit/6187bae41c3e15cc01a80465878539ac9101dc73)
- build(actions): remove push event [`ff32126`](https://github.com/fomantic/Fomantic-UI/commit/ff32126a049a82a81740bbe7c2c3ebada3180bee)

#### [2.7.8](https://github.com/fomantic/Fomantic-UI/compare/2.7.7...2.7.8)

> 1 September 2019

- fix(form): 'set values' behavior had no proper calendar support [`#980`](https://github.com/fomantic/Fomantic-UI/issues/980)
- feat(slider): add auto adjusted label display [`#913`](https://github.com/fomantic/Fomantic-UI/issues/913)
- feat(site): add font-display variable [`#262`](https://github.com/fomantic/Fomantic-UI/issues/262)
- fix(label): top attached labels omitted margin for content [`#925`](https://github.com/fomantic/Fomantic-UI/issues/925)
- fix(progress): wrong error on validating sum of rounded percents [`#953`](https://github.com/fomantic/Fomantic-UI/issues/953)
- feat(dropdown): add select optgroup and horizontal divider support [`#956`](https://github.com/fomantic/Fomantic-UI/issues/956)
- chore(release): update changelog [`4b5cd6b`](https://github.com/fomantic/Fomantic-UI/commit/4b5cd6bc0dd17cf2645d3a5f1564cfe20691b7a3)
- build(deps): replace conventional-changelog [`c7ed685`](https://github.com/fomantic/Fomantic-UI/commit/c7ed685c4ce9f04904f97ed095643e8a8741c65c)
- chore(release): update dist [`fd8a83c`](https://github.com/fomantic/Fomantic-UI/commit/fd8a83c4a79789c6d492da3e673129790308c718)
- build(deps): bump inquirer from 6.5.1 to 6.5.2 [`e5468c7`](https://github.com/fomantic/Fomantic-UI/commit/e5468c71ccdfc4d27e672d11d2b22fb2a157a9c7)
- build(deps): bump inquirer from 6.5.0 to 6.5.1 [`e04f4b1`](https://github.com/fomantic/Fomantic-UI/commit/e04f4b1aafa50c586df137533d03266be1a8d2f3)
- build(deps-dev): bump conventional-changelog-cli from 2.0.21 to… [`ddbaf51`](https://github.com/fomantic/Fomantic-UI/commit/ddbaf5143fb2aa561e4f5c1a87fafbcd7cf91e29)
- build(ci): change from travis to github actions [`c621e5d`](https://github.com/fomantic/Fomantic-UI/commit/c621e5da7166c541f625cc9ce7c0f7e94c169c9b)
- feat(form): check for existing calendar, dropdown or checkbox modules [`d0aecbe`](https://github.com/fomantic/Fomantic-UI/commit/d0aecbe3918d5ecff1d5f8ae08dd596b7003585d)
- feat(tab): auto activate first tab if no active specified [`3e129a0`](https://github.com/fomantic/Fomantic-UI/commit/3e129a0de2acdf9142d5ec12ce8bfa5cf345f898)
-  docs: fix contributors layout [`9b882bb`](https://github.com/fomantic/Fomantic-UI/commit/9b882bb91a874646dc0a0e316411978c7723cab3)
- docs: add egoisticalgoat as a contributor [`2510762`](https://github.com/fomantic/Fomantic-UI/commit/251076267cf5dcb8d738bfed3aa221faa01d6b60)
- build: emit errors instead of logging only [`b530cfc`](https://github.com/fomantic/Fomantic-UI/commit/b530cfcc66503e4a603f7d60e1ce9c5e9e24efa4)
- docs: add douglasg14b as a contributor [`3cd7e8c`](https://github.com/fomantic/Fomantic-UI/commit/3cd7e8cef18572db534f9a3cdec5cf8776749221)
- docs: add ryamaguchi0220 as a contributor [`24abc18`](https://github.com/fomantic/Fomantic-UI/commit/24abc187e69bbcae942df584e6a3b42e404c6a14)
- docs: add bartocc as a contributor [`a3cf0ae`](https://github.com/fomantic/Fomantic-UI/commit/a3cf0ae702d2e7db46101824ded8d87e65e1b0ca)
- docs: add 0xflotus as a contributor [`1375310`](https://github.com/fomantic/Fomantic-UI/commit/13753100ea2a73d1f6014c77a60b0f371142616f)
- docs: add rubenhbaca as a contributor [`b554539`](https://github.com/fomantic/Fomantic-UI/commit/b55453913b037a959dfd9a27d766bf6488c6f314)
- docs: add ventura-eesc as a contributor [`bdbe099`](https://github.com/fomantic/Fomantic-UI/commit/bdbe099addfbddc002f497e17c13de0708ca72a9)
- docs: add bborn as a contributor [`f405b9b`](https://github.com/fomantic/Fomantic-UI/commit/f405b9b88ed92c52ce42edd314886145e0f8e7e6)
- docs: add MikeyFriedChicken as a contributor [`42bba19`](https://github.com/fomantic/Fomantic-UI/commit/42bba199f7dcc666192384b1ac2fcd08a7e4ae22)
- docs: add GammaGames as a contributor [`608a036`](https://github.com/fomantic/Fomantic-UI/commit/608a0363784f3396b379818bda4574176bc063d9)
- docs: add euangoddard as a contributor [`c3e4d9e`](https://github.com/fomantic/Fomantic-UI/commit/c3e4d9e62d1a121ad3213d6a63a78b02e11942e0)
- docs: add danthedeckie as a contributor [`3c6bdf8`](https://github.com/fomantic/Fomantic-UI/commit/3c6bdf833f531678ffd0f2fc993197d7fe9a8ae8)
- docs: add iarspider as a contributor [`e1debec`](https://github.com/fomantic/Fomantic-UI/commit/e1debec30d57bb86ad1906a394fcbc7c42984f13)
- docs: add patilkiranm as a contributor [`0b14613`](https://github.com/fomantic/Fomantic-UI/commit/0b14613641cf5e89847170813afe3b9f2cbd1620)
- docs: add ko2in as a contributor [`7fe7f2c`](https://github.com/fomantic/Fomantic-UI/commit/7fe7f2c31f1fe46efa0a74a9507a565ddf26b14f)
- docs: add dutrieux as a contributor [`704490c`](https://github.com/fomantic/Fomantic-UI/commit/704490ccc4f5516d80ffccb052ee4b059f193d56)
- docs: add globophobe as a contributor [`2268039`](https://github.com/fomantic/Fomantic-UI/commit/2268039367dcff38013d123f63819ada7463c685)
- build(deps): bump less from 3.9.0 to 3.10.3 [`13dcab1`](https://github.com/fomantic/Fomantic-UI/commit/13dcab19f13bb1f01ecd0ff04afd7205da3e02f6)
- build(ci): fix ci process [`9fbfb7e`](https://github.com/fomantic/Fomantic-UI/commit/9fbfb7e92b18d164a0647c00a4200c5a3184b977)
- build(ci): correct ci and throw errors instead of logging [`df5c7b2`](https://github.com/fomantic/Fomantic-UI/commit/df5c7b2e6aa5f6230ae5f8340c561c03bd63e9b2)
- chore(release): bump version [`8016e8a`](https://github.com/fomantic/Fomantic-UI/commit/8016e8a9af8f3cca761bae024b736272857a5a24)
- docs(readme): replace build badge with GHA [`495dd56`](https://github.com/fomantic/Fomantic-UI/commit/495dd56c2ea836bd89a49d82d4065600c3983c22)
- fix(dropdown): keep input field focus if it's an menu item [`1df7676`](https://github.com/fomantic/Fomantic-UI/commit/1df767622b25040fba2da65d675c4029c66536f8)
- fix(dropdown): sanitize initial values to prevent xss on firefox & ie [`f7c24ac`](https://github.com/fomantic/Fomantic-UI/commit/f7c24ace480ef0f98350d8192caff44f42adf0a9)
- docs(src readme): correct typo in example code [`a3974d1`](https://github.com/fomantic/Fomantic-UI/commit/a3974d1fba6532c7c8a4ba3438cf0487ab54f86f)

#### [2.7.7](https://github.com/fomantic/Fomantic-UI/compare/2.7.6...2.7.7)

> 28 July 2019

- feat(icons): update icons to FA 5.9.0 [`#887`](https://github.com/fomantic/Fomantic-UI/issues/887)
- fix(container): respect fluid container on mobile screen [`#900`](https://github.com/fomantic/Fomantic-UI/issues/900)
- fix(accordion): remove transition class after animation so loaders work [`#865`](https://github.com/fomantic/Fomantic-UI/issues/865)
- fix(dropdown): only preventdefault on hide for associating labels [`#861`](https://github.com/fomantic/Fomantic-UI/issues/861)
- fix(dropdown): corrected initial clearable icon when '&lt;select&gt;' is used [`#839`](https://github.com/fomantic/Fomantic-UI/issues/839)
- feat(checkbox): add sizes and form size inheritance [`#666`](https://github.com/fomantic/Fomantic-UI/issues/666)
- fix(table): colored definition table top cell border overlap [`#883`](https://github.com/fomantic/Fomantic-UI/issues/883)
- feat(popup): add optional setting 'forcePosition' to disable calculation [`#684`](https://github.com/fomantic/Fomantic-UI/issues/684)
- fix(search): 'get result' on numerical or user defined fields didnt work [`#897`](https://github.com/fomantic/Fomantic-UI/issues/897)
- fix(dropdown): dont toggle on "set selected" when no labels are used [`#670`](https://github.com/fomantic/Fomantic-UI/issues/670)
- feat(dropdown): add support for images/icons in api response param [`#872`](https://github.com/fomantic/Fomantic-UI/issues/872)
- ci(build): verify build process [`#876`](https://github.com/fomantic/Fomantic-UI/issues/876)
- fix(form): correct inline checkbox label padding [`#823`](https://github.com/fomantic/Fomantic-UI/issues/823)
- fix(flag): rtl build changed background-position values [`#859`](https://github.com/fomantic/Fomantic-UI/issues/859)
- fix(form): inline field label doesn't respect error styles [`#818`](https://github.com/fomantic/Fomantic-UI/issues/818)
- fix(dropdown): correct clear icon alignment [`#837`](https://github.com/fomantic/Fomantic-UI/issues/837)
- fix(step): step visualization also on non active [`#830`](https://github.com/fomantic/Fomantic-UI/issues/830)
- feat(checkbox): add toggle on ENTER-key option [`#819`](https://github.com/fomantic/Fomantic-UI/issues/819)
- chore(release): update dist [`b0508f4`](https://github.com/fomantic/Fomantic-UI/commit/b0508f441e662dcb278c62037ecea5ac2870f2cd)
- docs(contributors): add all-contributors [`b006c54`](https://github.com/fomantic/Fomantic-UI/commit/b006c5498e7f9e3230c8cafcd50bdcb6c09542b6)
- build(deps-dev): bump all-contributors-cli from 6.7.0 to 6.8.1 [`d772e55`](https://github.com/fomantic/Fomantic-UI/commit/d772e55991661f45ad740903b53fc2089b1834a4)
- build(deps): bump @octokit/rest from 16.16.0 to 16.28.2 [`20e9cde`](https://github.com/fomantic/Fomantic-UI/commit/20e9cde16212c17e7e0716dc6800c2c3aa5742b7)
- build(deps): bump gulp-autoprefixer from 6.0.0 to 6.1.0 [`fdea8ff`](https://github.com/fomantic/Fomantic-UI/commit/fdea8ffd091a6f07e49246383c9f2d01491e0431)
- docs(faq): update info [`adcfe60`](https://github.com/fomantic/Fomantic-UI/commit/adcfe601e7c474415692efcb7027156582633a38)
- build(deps): bump gulp-json-editor from 2.5.0 to 2.5.2 [`75342c6`](https://github.com/fomantic/Fomantic-UI/commit/75342c67d542b02982a4ae750495542566673901)
- docs(readme): update badges and add other packages [`489e801`](https://github.com/fomantic/Fomantic-UI/commit/489e801f10410bb0d622ea6b658ffdb6b56a110f)
- build(deps): bump @octokit/rest from 16.28.3 to 16.28.4 [`56d5ef7`](https://github.com/fomantic/Fomantic-UI/commit/56d5ef7bfdba8dede974d5807b61349a639d79d4)
- build(deps): bump @octokit/rest from 16.28.2 to 16.28.3 [`447c28f`](https://github.com/fomantic/Fomantic-UI/commit/447c28f8f563e20107e6d1f9a7e9e2a6ae2c0514)
- chore(release): update changelog [`44acd64`](https://github.com/fomantic/Fomantic-UI/commit/44acd6436498e7caaa10a36119f9cc245cdcbd19)
- build(deps): bump inquirer from 6.2.2 to 6.4.1 [`d481b8f`](https://github.com/fomantic/Fomantic-UI/commit/d481b8f8d1d1ee48f180d0dac7f6f3cce6b14230)
- build(deps): bump @octokit/rest from 16.28.6 to 16.28.7 [`846b06f`](https://github.com/fomantic/Fomantic-UI/commit/846b06f322e52111cf91ec01423cf195823df44f)
- build(deps): bump gulp-header from 2.0.7 to 2.0.9 [`f71993c`](https://github.com/fomantic/Fomantic-UI/commit/f71993cec91e914f510f62445662e7a5be7f2fc7)
- build(deps): bump gulp-uglify from 3.0.1 to 3.0.2 [`f599033`](https://github.com/fomantic/Fomantic-UI/commit/f599033eaa132ad1b4932f35bba1bfebae84602e)
- build(deps): bump gulp-json-editor from 2.5.2 to 2.5.3 [`7d0715d`](https://github.com/fomantic/Fomantic-UI/commit/7d0715d0a7a4d7e6a6de6abe025f208d3dba290e)
- build(deps): bump merge-stream from 1.0.1 to 2.0.0 [`b3501f9`](https://github.com/fomantic/Fomantic-UI/commit/b3501f92cedf4407e9198dd931223b97d2159813)
- fix(form): prompt template function [`cc97a30`](https://github.com/fomantic/Fomantic-UI/commit/cc97a304f16875dd9ba8157cf00d4ef0d5bd7c13)
- build(deps): bump gulp-print from 5.0.0 to 5.0.2 [`da41952`](https://github.com/fomantic/Fomantic-UI/commit/da4195203bd3573a857a4c147ab75bc1677eded9)
- fix(site): revert size variable declaration [`1f1c6f0`](https://github.com/fomantic/Fomantic-UI/commit/1f1c6f0f833c0c41cd808a834c9596bd47dc9211)
- build(deps): bump inquirer from 6.4.1 to 6.5.0 [`92414f0`](https://github.com/fomantic/Fomantic-UI/commit/92414f00f8690377d9e7d9d9a61ffca60afc0517)
- build(deps): bump @octokit/rest from 16.28.5 to 16.28.6 [`313a9fd`](https://github.com/fomantic/Fomantic-UI/commit/313a9fde74804d1b43931a22900b55129d4060d0)
- build(deps): bump @octokit/rest from 16.28.4 to 16.28.5 [`c272d43`](https://github.com/fomantic/Fomantic-UI/commit/c272d435644a83bc7057b787c09a56c7561299ca)
- build(deps): bump gulp-rtlcss from 1.3.0 to 1.4.0 [`31b3bcf`](https://github.com/fomantic/Fomantic-UI/commit/31b3bcf21d137540c12781cf11c48d7f7f9bf5f2)
- fix(label): content margin after two attached labels [`2510ea9`](https://github.com/fomantic/Fomantic-UI/commit/2510ea90840e9208262df79c137ec61fb99ddb21)
- build(deps): [security] bump lodash.merge from 4.6.1 to 4.6.2 [`cc19442`](https://github.com/fomantic/Fomantic-UI/commit/cc19442222b2b0006c201cd013376e8f46c59754)
- build(deps): [security] bump lodash from 4.17.11 to 4.17.14 [`265a206`](https://github.com/fomantic/Fomantic-UI/commit/265a2069c2c2ec5d3dddddde98ca166aaf9b1f68)
- build(deps): bump jquery from 3.4.0 to 3.4.1 [`28a6cd6`](https://github.com/fomantic/Fomantic-UI/commit/28a6cd6d8690a293e61aea39ff59b514b4d7265d)
- chore(release): bump version [`8bbc022`](https://github.com/fomantic/Fomantic-UI/commit/8bbc022ed58eb7d0534eac7480aed430ece78a56)
- docs(changelog): fix formatting issue [`cb7b652`](https://github.com/fomantic/Fomantic-UI/commit/cb7b6522c178abd16e3c504fb824979d08d94473)
- build(deps): bump lodash from 4.17.11 to 4.17.14 [`98bdde6`](https://github.com/fomantic/Fomantic-UI/commit/98bdde63b9da992c03e61d7ebb3c31b6305a6534)
- style(modal): remove whitespace [`cf440f4`](https://github.com/fomantic/Fomantic-UI/commit/cf440f4856ab7163914a8768a3e9cc1ed90e7341)
- build(deps): bump lodash.merge from 4.6.1 to 4.6.2 [`669eb24`](https://github.com/fomantic/Fomantic-UI/commit/669eb2401931e0d781d3813f47f012082f81baff)
- feat(modal): destroy should tear down mutation observer [`d880d35`](https://github.com/fomantic/Fomantic-UI/commit/d880d35664832786e59da027543bb240607133fa)
- fix(image): hidden images were still visible when used in image groups [`a0bf2b3`](https://github.com/fomantic/Fomantic-UI/commit/a0bf2b3ba72c1f15e13e889c9b38c2dbdf14a860)
- docs(contributing): fix repository typo [`9611bf0`](https://github.com/fomantic/Fomantic-UI/commit/9611bf03304cf09eb8f484374a62b2581dad5489)

#### [2.7.6](https://github.com/fomantic/Fomantic-UI/compare/2.7.5...2.7.6)

> 16 June 2019

- fix(menu): hover & active state colors on inverted secondary pointing [`#777`](https://github.com/fomantic/Fomantic-UI/issues/777)
- fix(button,table): move LESS functions out of LESS file and into variables [`#736`](https://github.com/fomantic/Fomantic-UI/issues/736)
- fix(calendar): support dynamic way to append popup instead of prepending to the parent [`#699`](https://github.com/fomantic/Fomantic-UI/issues/699)
- fix(progress): wrong error on validating total on multiple progress [`#757`](https://github.com/fomantic/Fomantic-UI/issues/757)
- fix(form): stop propagation only when dirty event was triggered and prevent default action [`#746`](https://github.com/fomantic/Fomantic-UI/issues/746)
- fix(dropdown): check for existing observer before accessing it [`#784`](https://github.com/fomantic/Fomantic-UI/issues/784)
- fix(table): table header on mobile [`#787`](https://github.com/fomantic/Fomantic-UI/issues/787)
- fix(icon): improve default theme overrides import [`#763`](https://github.com/fomantic/Fomantic-UI/issues/763)
- fix(icon): don't import default theme overrides [`#763`](https://github.com/fomantic/Fomantic-UI/issues/763)
- fix(slider): non reachable max value and rounding issues [`#716`](https://github.com/fomantic/Fomantic-UI/issues/716)
- fix(calendar): support JSON dates [`#741`](https://github.com/fomantic/Fomantic-UI/issues/741)
- fix(transition): not checking for event object lead to TypeError [`#745`](https://github.com/fomantic/Fomantic-UI/issues/745)
- chore(release): update dist files [`1fd94d2`](https://github.com/fomantic/Fomantic-UI/commit/1fd94d2479f297c906bed557f0567d1d3f0a4d2c)
- feat(progress): add indeterminate states [`816fbbd`](https://github.com/fomantic/Fomantic-UI/commit/816fbbd257ba30a4c2b95299f12aac125268fb0b)
- docs(roadmap): update with more detail [`d95b0c7`](https://github.com/fomantic/Fomantic-UI/commit/d95b0c79956d9eb01233023fe2938250d95b9e54)
- fix(form): transparent input padding and texarea support [`dd561b5`](https://github.com/fomantic/Fomantic-UI/commit/dd561b5e7bb953f8c08ca27d58df798ae117c201)
- chore(release): update changelog [`8f44264`](https://github.com/fomantic/Fomantic-UI/commit/8f442646c101de7093eed559da730e92b2a881af)
- docs(security): add security policy [`2545595`](https://github.com/fomantic/Fomantic-UI/commit/2545595804f3c4b6c230ea04e952208a30c31190)
- refactor(*): clean up deprecated symbols [`601f504`](https://github.com/fomantic/Fomantic-UI/commit/601f50452c304adf03f4e2f55a7ae375e6806b30)
- build(composer): fix typo, add web property & changed domain to FUI [`9ba689a`](https://github.com/fomantic/Fomantic-UI/commit/9ba689aca00bf44b23feba65b048cee3cc067faa)
- chore(release): bump version number [`66c9340`](https://github.com/fomantic/Fomantic-UI/commit/66c9340fdd0a832fa4b4841ae43f3f3d2671dbb6)
- chore(release): merge develop branch [`441a7d3`](https://github.com/fomantic/Fomantic-UI/commit/441a7d31837cd9bdd5eeca6af339d3ced5ecb2d1)
- build(theme.less): adjust line numbers for error messages [`6b0fd0d`](https://github.com/fomantic/Fomantic-UI/commit/6b0fd0d49b0553947d90c1d0693a5e2bf7fa75b9)
- chore(github): add FUNDING file [`b132715`](https://github.com/fomantic/Fomantic-UI/commit/b1327153b6f227cd0abd3cec7f0168db150ab537)
- build(autoprefixer): change 'browsers' setting to 'overrideBrowserslist' [`1652597`](https://github.com/fomantic/Fomantic-UI/commit/16525972c2a4cd907663929a0c5bacde6cd0a4bf)
- fix(form): remove rule function lead to TypeError [`752827e`](https://github.com/fomantic/Fomantic-UI/commit/752827e5895e50d36a7c88202d85b138ea4c9ead)
- fix(button): center text in fluid & vertically aligned button group [`bfd7c84`](https://github.com/fomantic/Fomantic-UI/commit/bfd7c8496e89158e63bcc93f46288733caa3c2b0)

#### [2.7.5](https://github.com/fomantic/Fomantic-UI/compare/2.7.4...2.7.5)

> 9 May 2019

- feat(icons): update to FA 5.8.2 [`#572`](https://github.com/fomantic/Fomantic-UI/issues/572)
- fix(menu): correct floating label position in pointing menu [`#668`](https://github.com/fomantic/Fomantic-UI/issues/668)
- fix(progess): all percents are shown while animation [`#707`](https://github.com/fomantic/Fomantic-UI/issues/707)
- fix(label): adjust basic ribbon label size and position [`#708`](https://github.com/fomantic/Fomantic-UI/issues/708)
- fix(list): align text in lists with icons [`#597`](https://github.com/fomantic/Fomantic-UI/issues/597)
- feat(segment): add fitted variant [`#701`](https://github.com/fomantic/Fomantic-UI/issues/701)
- fix(tab): position issue with fixed item size [`#671`](https://github.com/fomantic/Fomantic-UI/issues/671)
- feat(calendar): add eventDates support and onSelect handler [`#674`](https://github.com/fomantic/Fomantic-UI/issues/674)
- fix(calendar): string selectors for start/endCalendar did not work [`#685`](https://github.com/fomantic/Fomantic-UI/issues/685)
- fix(*): breakpoints ignoring next breakpoint in some cases [`#681`](https://github.com/fomantic/Fomantic-UI/issues/681) [`#681`](https://github.com/fomantic/Fomantic-UI/issues/681)
- fix(modal): open animation broken on first open [`#542`](https://github.com/fomantic/Fomantic-UI/issues/542)
- fix(menu): additional specificity for secondary inverted menu no longer needed [`#672`](https://github.com/fomantic/Fomantic-UI/issues/672)
- fix(button): group of basic disabled buttons had incorrect styles [`#643`](https://github.com/fomantic/Fomantic-UI/issues/643)
- fix(dropdown): hide open menus on destroy for correct state reset [`#653`](https://github.com/fomantic/Fomantic-UI/issues/653)
- fix(card): force horizontal cards meta, extra content and actions to align properly [`#159`](https://github.com/fomantic/Fomantic-UI/issues/159)
- fix(form): remove unnecessary property '-webkit-appearance: none' with :focus from error field [`#576`](https://github.com/fomantic/Fomantic-UI/issues/576)
- build(css): watch task didn't update files that depends on site.variable [`#631`](https://github.com/fomantic/Fomantic-UI/issues/631)
- fix(form): corrects border radius variable reference [`#628`](https://github.com/fomantic/Fomantic-UI/issues/628)
- fix(menu): right dropdown sub-menu not being vertical [`#382`](https://github.com/fomantic/Fomantic-UI/issues/382)
- fix(button): fix padding for compact labeled icon button [`#598`](https://github.com/fomantic/Fomantic-UI/issues/598)
- fix(dropdown): click-event was locked when single selection had allowAdditions enabled [`#591`](https://github.com/fomantic/Fomantic-UI/issues/591)
- chore(release): update dist [`6cc22db`](https://github.com/fomantic/Fomantic-UI/commit/6cc22db14bdfcf79c941aeb0604a400f09877b58)
- refactor: remove old release notes [`b982951`](https://github.com/fomantic/Fomantic-UI/commit/b982951fc35112760f9af63e5bcf41f26c2774ba)
- build(deps): add conventional-changelog-cli [`6cb4a67`](https://github.com/fomantic/Fomantic-UI/commit/6cb4a675e621c3a91bc486d503a40a9bf8334bd2)
- chore(*): clean up files and correct spelling and links [`25738d5`](https://github.com/fomantic/Fomantic-UI/commit/25738d5268a3488dc1f55b36dc4ef0deb8eae395)
- feat(form): add dirty and clean states, and ability to cancel submit [`adf5937`](https://github.com/fomantic/Fomantic-UI/commit/adf593733e0ed463dcb18b697f651a5df91143e5)
- fix(dropdown): inverted pointing menu had white arrow [`124625c`](https://github.com/fomantic/Fomantic-UI/commit/124625c50d255a0ada3e2ba851055a854cc67c3c)
- chore(*): switched comment blocks to Fomantic UI references [`72e5a24`](https://github.com/fomantic/Fomantic-UI/commit/72e5a247017a7f567d53c0ae007691379f2184ec)
- fix(table): don't break style when nested tables [`9760d91`](https://github.com/fomantic/Fomantic-UI/commit/9760d917a2275461a373ab5d1b86143084876999)
- feat(form): add calendar input field [`8152b38`](https://github.com/fomantic/Fomantic-UI/commit/8152b38e4d7c85cfc3bbd27bafb45d1e63b110df)
- fix(chore): moved some core css to less files from default overrides and always include default overrides first [`2bfe9a5`](https://github.com/fomantic/Fomantic-UI/commit/2bfe9a5c78a0434ce0a6eb1425d6b31ad1a8177e)
- chore(release): update changelog [`c7511c7`](https://github.com/fomantic/Fomantic-UI/commit/c7511c7a333f73f9664e52dce11464c6f755214d)
- fix(form validation): make sure rules are selecting within the same form [`313012d`](https://github.com/fomantic/Fomantic-UI/commit/313012da48dc1fed692ba776631b50323552b91c)
- chore(package): refactor field positions and add info [`bfa7873`](https://github.com/fomantic/Fomantic-UI/commit/bfa7873c2c95823c7fd4c69fe96eb83aa48a483e)
- feat(checkbox): vertically align checkbox in fields [`dcf3976`](https://github.com/fomantic/Fomantic-UI/commit/dcf3976db08b338635340c6e5742a5aef9635a0c)
- feat(divider): add horizontal divider alignment variation [`1981277`](https://github.com/fomantic/Fomantic-UI/commit/1981277500d62863a6aed1afddeca0b2e707b011)
- chore(probot): modify probot configs [`5aa461e`](https://github.com/fomantic/Fomantic-UI/commit/5aa461e27b115674af985180b8c45e482c4c3ea7)
- fix(progess): fix timing issue of updating value/percent [`fe97fc4`](https://github.com/fomantic/Fomantic-UI/commit/fe97fc40a3f270d03d1bfad471752fbee3efd080)
- feat(breadcrumb): add inverted variant [`ff6ba2d`](https://github.com/fomantic/Fomantic-UI/commit/ff6ba2d0ab95c7f6d3c8b08ac5a4fd2b106a8245)
- build(deps): update jquery [`8cc8edd`](https://github.com/fomantic/Fomantic-UI/commit/8cc8edd6ad259c8b603ab038d1a76a44de3e78ba)
- fix(menu): correct submenu fix which broke right menus [`af98873`](https://github.com/fomantic/Fomantic-UI/commit/af988735dfbc3d73fc2749feb499a5670eedbf4a)
- fix(modal): use direct sibling for content selector [`e4fbb61`](https://github.com/fomantic/Fomantic-UI/commit/e4fbb6155f82220d4ccba8d3eeab74690a6ad017)
- fix(modal): support fixed menu, toast and sidebar to also not move when a modal is shown [`aeb3274`](https://github.com/fomantic/Fomantic-UI/commit/aeb32742b9a2fc116dd2ac29edd6c43ef700c4c2)
- fix(progress): display 0 valued progress bars [`a92b8ac`](https://github.com/fomantic/Fomantic-UI/commit/a92b8acec3e0e1219bae4b90fc19b3c6f0d5878a)
- fix(dropdown): correct alignment of image and icons within items [`72d3420`](https://github.com/fomantic/Fomantic-UI/commit/72d342091a1d6a98ecef185171fba78527480c2b)
- fix(popup): support iOS to recognize popup close on touch [`c978917`](https://github.com/fomantic/Fomantic-UI/commit/c978917310b8350330872c9aeaae69781e146e00)
- fix(input): error border didn't change input action border [`0aab16f`](https://github.com/fomantic/Fomantic-UI/commit/0aab16f34438ab957f2c9b2656ddb7ddf79cec9d)
- feat(dropdown): add scrolling support for simple variant [`9c8f18f`](https://github.com/fomantic/Fomantic-UI/commit/9c8f18f09b3dcd9f04afc25379a039d895bb0999)
- fix(dropdown): margin missing on upward dropdown [`024f5d4`](https://github.com/fomantic/Fomantic-UI/commit/024f5d4516605cbe8aa4e6aee515c8605c5bc1e2)
- fix(api): module callback function typo [`43c2c8b`](https://github.com/fomantic/Fomantic-UI/commit/43c2c8b3b3eb8ba051abe0d7fd9fbb8c7799c80a)
- fix(table): selectable rows/cells should have pointing cursor [`7742fa3`](https://github.com/fomantic/Fomantic-UI/commit/7742fa319f24ceba1f23ff5b4f9541448efbad52)
- docs(readme): add jetbrains logo [`769c370`](https://github.com/fomantic/Fomantic-UI/commit/769c370d99a84cb3a1e65e407bf604dc33996850)
- chore(release): bump version [`74b0860`](https://github.com/fomantic/Fomantic-UI/commit/74b08605f8d094512ed19c7824b118483ca611fe)
- fix(modal): `autofocus` shouldn’t focus disabled inputs [`fadbc30`](https://github.com/fomantic/Fomantic-UI/commit/fadbc30b570b46dc69ec7316c134f5fa3a6c1313)
- fix(calendar): support dateobject given for parse.date as for initialDate setting [`1a4938a`](https://github.com/fomantic/Fomantic-UI/commit/1a4938a02a0746fe9dc05413f82a3ab001698959)
- docs(readme): fix "submitting" typo [`d75e851`](https://github.com/fomantic/Fomantic-UI/commit/d75e8511f14c3016997f2bbbe4ae3891575f9d5b)
- fix(search): undefined internal variable [`7b89336`](https://github.com/fomantic/Fomantic-UI/commit/7b893367050b43790e8a14226c10e46c16821f51)
- fix(breadcrumb): increase line height for readability on wrapped content [`c7ca707`](https://github.com/fomantic/Fomantic-UI/commit/c7ca707233d352aefef9e0a6492ba458a5dab3e5)
- fix(form validation): error when calling "validate form" with API attached [`58dafe0`](https://github.com/fomantic/Fomantic-UI/commit/58dafe0897fcf0ab6bb69620f820cc1cbee306e0)
- chore(probot): add all reviewers and add exoego as reviewer [`12858b5`](https://github.com/fomantic/Fomantic-UI/commit/12858b50efc5e00fa722e4438d0c83593b8bf29e)
- fix(dimmer): disable blur on popups [`f10dd0b`](https://github.com/fomantic/Fomantic-UI/commit/f10dd0b63b80824398f9400998bec21e08d1fb02)
- revert(api): set context in beforesend to $module instead of possible stateContext to match docs [`57718ce`](https://github.com/fomantic/Fomantic-UI/commit/57718cee7998893703b1a4b492645d7f496f6054)
- fix(api): set context in beforesend to $module instead of possible stateContext to match docs [`004616f`](https://github.com/fomantic/Fomantic-UI/commit/004616ffabbefeab75818667d2f2e5d9f005433b)
- fix(table): definition table footer had wrong box-shadow to the left [`96b97f3`](https://github.com/fomantic/Fomantic-UI/commit/96b97f3b77e09132b3fbdc10ae42dc49d0b5a832)
- fix(dropdown): prevent submenu vanish for simple dropdowns [`6998edd`](https://github.com/fomantic/Fomantic-UI/commit/6998edd536baf1b6f1aa938e0a1cce6b13449ef1)
- fix(modal): dont close dimmer when another modal is still animating [`58cf41a`](https://github.com/fomantic/Fomantic-UI/commit/58cf41ae3732b4fe2846df56c6e28f32b66f2b37)
- chore(release): remove reverted fix note [`7be57fc`](https://github.com/fomantic/Fomantic-UI/commit/7be57fcaaccf7b88f7e85e70ede8c3d5259eed61)
- fix(card): word-wrap overflowing with long strings [`8b75f0f`](https://github.com/fomantic/Fomantic-UI/commit/8b75f0f44a865cfd2be5060a3e4d194e73eb76f9)
- fix(modal): dont wrap image content direct images [`5a59ae3`](https://github.com/fomantic/Fomantic-UI/commit/5a59ae3e5cb35f0021ecc835ecfd7ac8c7a1c7ef)

#### [2.7.4](https://github.com/fomantic/Fomantic-UI/compare/2.7.3...2.7.4)

> 2 April 2019

- build(deps): fix install issue caused by dev deps [`#607`](https://github.com/fomantic/Fomantic-UI/issues/607)
- chore(release): 2.7.4 [`e66b9e9`](https://github.com/fomantic/Fomantic-UI/commit/e66b9e98bcba1b121467889ff9b01b2514da1452)
- chore(release): update release notes [`b0a3831`](https://github.com/fomantic/Fomantic-UI/commit/b0a383146742617fd70d1060e99c7af1d491b167)
- chore(release): update version [`63bcfb2`](https://github.com/fomantic/Fomantic-UI/commit/63bcfb2135b1524a9d21c2a3f82ce28932f55b46)
- chore(release): update version [`9daec1e`](https://github.com/fomantic/Fomantic-UI/commit/9daec1e1127c6453be5f49ebb44859c6f588ef2e)

#### [2.7.3](https://github.com/fomantic/Fomantic-UI/compare/2.7.2...2.7.3)

> 2 April 2019

- fix(site): support dpi &gt; 100% for media queries [`#567`](https://github.com/fomantic/Fomantic-UI/pull/567)
- fix(menu): increased specificity to keep grey color for disabled items in tabular menus [`#490`](https://github.com/fomantic/Fomantic-UI/pull/490)
- feat(dropdown): add height variation [`#545`](https://github.com/fomantic/Fomantic-UI/issues/545)
- feat(dropdown): add column support for dropdowns [`#545`](https://github.com/fomantic/Fomantic-UI/issues/545)
- fix(site): support dpi &gt; 100% for media queries (#567) [`#385`](https://github.com/fomantic/Fomantic-UI/issues/385)
- fix(checkbox): proper check for non existent event object in firefox [`#543`](https://github.com/fomantic/Fomantic-UI/issues/543)
- fix(dropdown): missing event property in focus event raises JS error in firefox [`#533`](https://github.com/fomantic/Fomantic-UI/issues/533)
- feat(modal): add top and bottom aligned modal which fixes multiple modal positions bug [`#530`](https://github.com/fomantic/Fomantic-UI/issues/530)
- feat(calendar): adjustable shortyear to century calculation [`#514`](https://github.com/fomantic/Fomantic-UI/issues/514)
- feat(modal): add overlay fullscreen modal [`#522`](https://github.com/fomantic/Fomantic-UI/issues/522)
- feat(calendar): add disable all dates but some [`#484`](https://github.com/fomantic/Fomantic-UI/issues/484)
- feat(label): absolute corner icon position for other tags support [`#518`](https://github.com/fomantic/Fomantic-UI/issues/518)
- fix(dropdown): catch a possible null value for preselected values [`#505`](https://github.com/fomantic/Fomantic-UI/issues/505)
- fix(dropdown): show list on icon click regardless of minCharacter [`#496`](https://github.com/fomantic/Fomantic-UI/issues/496)
- fix(build): incorrect format of file permission [`#502`](https://github.com/fomantic/Fomantic-UI/issues/502)
- fix(segment): keep flex setting for compact segment in horizontal segments group [`#477`](https://github.com/fomantic/Fomantic-UI/issues/477)
- fix(header): sub header color in inverted segment [`#486`](https://github.com/fomantic/Fomantic-UI/issues/486)
- fix(button): basic colored buttons box shadow [`#495`](https://github.com/fomantic/Fomantic-UI/issues/495)
- fix(sidebar): make closable only work in clickaway event as stated in the docs [`#467`](https://github.com/fomantic/Fomantic-UI/issues/467)
- chore(release): 2.7.3 [`d287f00`](https://github.com/fomantic/Fomantic-UI/commit/d287f00d955c7c15e3ecf4fd979bf9ba5999ac20)
- chore(release): 2.7.3 dist [`cf51d5a`](https://github.com/fomantic/Fomantic-UI/commit/cf51d5aca339ad261a5d097f41c741432d8153ce)
- build(deps): refactor package dependencies [`a8351fe`](https://github.com/fomantic/Fomantic-UI/commit/a8351fe91743f7f10287c37054d1bfe48cd0063d)
- feat(progress): add multiple bars support [`c384e83`](https://github.com/fomantic/Fomantic-UI/commit/c384e8356181371804d8ad475e4a20a19d127ca6)
- fix(shape): fix 3D flip starting zoom, nested shapes, ignore child elements with class 'active' [`f5f3f2c`](https://github.com/fomantic/Fomantic-UI/commit/f5f3f2c2b4c08c2153ffd4bf3c778a9fd6c26b66)
- chore(release): update release notes [`0062727`](https://github.com/fomantic/Fomantic-UI/commit/0062727719385b128211753c42857068a301fa6f)
- refactor: remove unused local variables [`6a7360e`](https://github.com/fomantic/Fomantic-UI/commit/6a7360e75be910a875ffc512a5939305f8158af1)
- chore(release): update release notes [`990363f`](https://github.com/fomantic/Fomantic-UI/commit/990363fc195ac0f632f52ab2ed627573be0a86fc)
- fix(card): add missing inverted colors [`23b9594`](https://github.com/fomantic/Fomantic-UI/commit/23b9594ab78f97d6e79f4a8aa3831647364f0fe5)
- feat(modal): don't move content and modal on dimmer when scrollbar hides [`63ddcdd`](https://github.com/fomantic/Fomantic-UI/commit/63ddcdd33764e1cb5188d9206405a5481b0e5203)
- fix(transition): transitions made of hidden inline elements were not working anymore [`0a05e9f`](https://github.com/fomantic/Fomantic-UI/commit/0a05e9f97e1cad8ef3a3e14ddb595839fdcbc137)
- fix(tab): should escape meta characters [`08f24a4`](https://github.com/fomantic/Fomantic-UI/commit/08f24a4c34f88e1ae55445db4cd648536a9d0b3f)
- feat(step): add arrows in stacked steps [`3f913df`](https://github.com/fomantic/Fomantic-UI/commit/3f913dfdcf57f324d9826427435a1538c4fa86f1)
- fix(table): inverted variation styles [`7bd4adb`](https://github.com/fomantic/Fomantic-UI/commit/7bd4adb25dd994e710f6ea6e87624eff0dff9586)
- feat(calendar): ability to select adjacent month dates [`e21a158`](https://github.com/fomantic/Fomantic-UI/commit/e21a1580ca43a73cc49af122d3c45fcb0e49136f)
- fix(calendar): initialDate now update input [`7e30c28`](https://github.com/fomantic/Fomantic-UI/commit/7e30c280b334861b1d6ae219f976c9623ea2e38f)
- fix(shape): focused checkbox inside shape breaks animation [`1b4aa99`](https://github.com/fomantic/Fomantic-UI/commit/1b4aa99537485d35208d52cb1eb802de2b95b0e1)
- feat(checkbox): visual support for indeterminate toggle [`07524f0`](https://github.com/fomantic/Fomantic-UI/commit/07524f077a4853cfae104c61d5c640d2fe88a13c)
- fix(checkbox): prevent default events to avoid IE11/Edge resetting the checkbox [`00191d2`](https://github.com/fomantic/Fomantic-UI/commit/00191d266509575389f52f91875567039578fe06)
- fix(slider): don't conflict with checkbox [`9c3ee37`](https://github.com/fomantic/Fomantic-UI/commit/9c3ee376fb594537e35277db61fb59f49790ea5c)
- fix(button): fluid labeled icon button padding [`c88cbb3`](https://github.com/fomantic/Fomantic-UI/commit/c88cbb318ae95859ca75813f0491f6d3dcb7e802)
- chore(release): update version [`f469145`](https://github.com/fomantic/Fomantic-UI/commit/f469145898e11e813c47ef184c91d7ef31e52048)
- fix(segment): fix clearing for stacked and piled segments [`c14e3f6`](https://github.com/fomantic/Fomantic-UI/commit/c14e3f67cb07ca590ed41b11f0d0c0b4fb792696)
- docs(readme): add link to merge intention comment [`783786b`](https://github.com/fomantic/Fomantic-UI/commit/783786b5c27bf0252dc47c0277746b4a695210ca)
- fix(input): add missing tiny size variant [`dc4bf77`](https://github.com/fomantic/Fomantic-UI/commit/dc4bf77b66e8420fefd5b43b4383225944565778)
- chore(release): update release notes [`1c1d9dd`](https://github.com/fomantic/Fomantic-UI/commit/1c1d9dd445769e95b0316afaf620f9a493b8b582)
- chore(release): sync with master [`47bad19`](https://github.com/fomantic/Fomantic-UI/commit/47bad19f3f0d25534d2b3e9bc5e1af8ec7919a8a)
- fix(formvalidation): check if field is undefined before accessing [`f7c21e9`](https://github.com/fomantic/Fomantic-UI/commit/f7c21e9d23de6706ec6225c13612580eb2f5e5b9)
- fix(form validation): support checkbox groups for checked rule like radio groups [`878b69a`](https://github.com/fomantic/Fomantic-UI/commit/878b69ad3e79e98a966e403db2064908989c47e0)
- fix(progress): inverted progress bars color [`90057fa`](https://github.com/fomantic/Fomantic-UI/commit/90057fa4fdfb6e8ae4132e321febc845c96d1f4e)
- feat(calendar): expose week cell class setting [`85c0db2`](https://github.com/fomantic/Fomantic-UI/commit/85c0db28391fa4e660b679bde87c763416c92442)
- fix(menu): correct right item border in containers [`ab2a277`](https://github.com/fomantic/Fomantic-UI/commit/ab2a277380fca27815a9956a31c9554fd41918d2)
- fix(popup): onHide was called twice [`794a8b8`](https://github.com/fomantic/Fomantic-UI/commit/794a8b8d762716c0ae85116d48fc9dc9596c60f5)
- fix(shape): shape transition did not work when child also has a transition set [`76d10d3`](https://github.com/fomantic/Fomantic-UI/commit/76d10d3e658e78dc3b4cc1be090a563de7cf8d64)
- fix(progress): fix 0 percent bars on colored progress [`b817ea7`](https://github.com/fomantic/Fomantic-UI/commit/b817ea737b91c8f328c9253b3353c71d77e97a50)
- feat(site): remove font-smoothing property [`4a2ed3f`](https://github.com/fomantic/Fomantic-UI/commit/4a2ed3f0593e59db8a9a965365060473a7e8460a)
- fix(formvalidation): safari didn't show errors [`c177443`](https://github.com/fomantic/Fomantic-UI/commit/c17744359b3438ce6be51166616306a9daefc0ce)
- fix(calendar): fix day calculation if year had 2-digit notation [`2ebca94`](https://github.com/fomantic/Fomantic-UI/commit/2ebca94e27c8fa66bc6f715df2e2bc23da8fb4c3)
- fix(build): write metadata.json for docs [`6216d5f`](https://github.com/fomantic/Fomantic-UI/commit/6216d5f406c57fd7de2f5af1fd821bce84d31ba2)
- build(deps): update bower jQuery dependency [`5958171`](https://github.com/fomantic/Fomantic-UI/commit/595817147f6d638b77191cc6b451521f360d1caf)
- fix(dimmer): loader was still visible in dimmed dimmer [`549b75c`](https://github.com/fomantic/Fomantic-UI/commit/549b75c8f2cd7de9f7c73ee0b8a68eac22883f69)
- fix(form): fields is undefined [`90be786`](https://github.com/fomantic/Fomantic-UI/commit/90be786b7230942564dbafe971e24112e56d82e6)
- fix(button): basic button loop always used primary for margin [`c44b09b`](https://github.com/fomantic/Fomantic-UI/commit/c44b09b6ca4225505c19412443cc64f0e814d91e)
- fix(dropdown): allow a label to be clickable inside a dropdown button [`4707fa1`](https://github.com/fomantic/Fomantic-UI/commit/4707fa16e89688fc71bdfae9606ba30592687ca8)
- fix(label): adjusted position of ribbon label used in tables [`9373ca9`](https://github.com/fomantic/Fomantic-UI/commit/9373ca918f8b68b8391b5b891436d292911a968f)
- feat(api): don't throw error on all 2xx status codes [`407446e`](https://github.com/fomantic/Fomantic-UI/commit/407446e3781fc7ddf55f75ba0e64bb22c6d12b82)
- fix(modal): modal was not closable if opened by another modal for a second time [`ff454ad`](https://github.com/fomantic/Fomantic-UI/commit/ff454adc8f8797e6a6f8e738d809a808ea7b0de9)
- fix(segment): fix background for inverter,secondary,tertiary in horizontal group [`9f6ffb0`](https://github.com/fomantic/Fomantic-UI/commit/9f6ffb0d1026be9aaf530cf0a2594b23f492fb5e)

#### [2.7.2](https://github.com/fomantic/Fomantic-UI/compare/2.7.1...2.7.2)

> 5 February 2019

- feat(label): support 'bottom' for all floating label variants [`#430`](https://github.com/fomantic/Fomantic-UI/pull/430)
- fix(table): increase specificity to make colors work over striped or stacked columns [`#332`](https://github.com/fomantic/Fomantic-UI/pull/332)
- fix(card): bottom attached colored buttons left blurry grey bottom line [`#454`](https://github.com/fomantic/Fomantic-UI/issues/454)
- feat(icons): update icons to FontAwesome 5.7 [`#236`](https://github.com/fomantic/Fomantic-UI/issues/236)
- fix(icon): increase color specificity [`#436`](https://github.com/fomantic/Fomantic-UI/issues/436)
- build(deps): remove gulp-help dependency [`#439`](https://github.com/fomantic/Fomantic-UI/issues/439)
- fix(checkbox): call onChange only once and dont on "set checked" [`#295`](https://github.com/fomantic/Fomantic-UI/issues/295) [`#399`](https://github.com/fomantic/Fomantic-UI/issues/399)
- fix(progress): don't show min-width progress bar when not initialized [`#424`](https://github.com/fomantic/Fomantic-UI/issues/424)
- feat(text): add sizes identically to icon [`#413`](https://github.com/fomantic/Fomantic-UI/issues/413)
- fix(menu): secondary menu colors not being applied [`#406`](https://github.com/fomantic/Fomantic-UI/issues/406)
- fix(popup): correct tooltip z-index value [`#394`](https://github.com/fomantic/Fomantic-UI/issues/394)
- fix(dropdown): cast to string before rendering if value is an integer [`#379`](https://github.com/fomantic/Fomantic-UI/issues/379)
- fix(segment, menu): "secondary segment" or "secondary menu" have a different meaning [`#364`](https://github.com/fomantic/Fomantic-UI/issues/364)
- chore(release): 2.7.2 [`7128a93`](https://github.com/fomantic/Fomantic-UI/commit/7128a9324a835796d625b77507a7c8881ba913a9)
- chore(release): 2.7.2 dist files [`4ddb76f`](https://github.com/fomantic/Fomantic-UI/commit/4ddb76f5d015471bfe309bf6a8f71baa39603afb)
- feat(reset): updated normalize.css to 8.0.1 [`f7f00d3`](https://github.com/fomantic/Fomantic-UI/commit/f7f00d3a3aa82b474991d992b7e08b3960e4d4dc)
- fix(transition): remember inline display value and don't show default hidden tags [`73cd274`](https://github.com/fomantic/Fomantic-UI/commit/73cd27440bb366c5cabf856ef9351bb1d725bfb3)
- fix(progress): fix 0% display and "inverted indicating" label color [`bad67cb`](https://github.com/fomantic/Fomantic-UI/commit/bad67cb8b4a0be882723909dcf3b0d9761a999fc)
- docs(coc): add code of conduct [`4ce3c33`](https://github.com/fomantic/Fomantic-UI/commit/4ce3c3349838f56b83b2fa580a8458eea4da52bb)
- fix(form validation): array validations should respect each single field [`5be7315`](https://github.com/fomantic/Fomantic-UI/commit/5be731507a622e879f9e986a319773658431a7fa)
- feat(loader,modal): default loader color settings in dimmers affected loaders in modals [`cdfc878`](https://github.com/fomantic/Fomantic-UI/commit/cdfc878a4506e954850be7433a6d5efac776126a)
- docs(CONTRIBUTING): add env setup and change some sentences [`a98a32a`](https://github.com/fomantic/Fomantic-UI/commit/a98a32a9f6ad7bba24ab98c39c631d1894b6be14)
- fix(step): increase specificity of icon size [`23cafb3`](https://github.com/fomantic/Fomantic-UI/commit/23cafb3e7fc4fe5744313b74a2aa2341778c85e6)
- fix(search): don't increase categoryindex if result was empty [`1d8c7ac`](https://github.com/fomantic/Fomantic-UI/commit/1d8c7ac8f4e56a0964ab0ee01e4ab07f99ca868b)
- feat(label): remove hardcoded color exception "not()" for menu item labels [`207e40e`](https://github.com/fomantic/Fomantic-UI/commit/207e40e167c08c3856f365fcd77c8e7b26c7dfac)
- feat(label): right icon will be given correct margin when placed after text [`20d6389`](https://github.com/fomantic/Fomantic-UI/commit/20d638998e66dc784581169c6139c8e77669b0f3)
- fix(loader): elastic loader was not working in Firefox [`62fe856`](https://github.com/fomantic/Fomantic-UI/commit/62fe85672c5cc5ec5323104910db900d36056782)
- fix(menu): corrected support for disabled items in inverted menus [`5318605`](https://github.com/fomantic/Fomantic-UI/commit/53186050fed066de80f7f32ac7b03eee545f9eeb)
- fix(menu): wrong styles applied to secondary menu [`1372242`](https://github.com/fomantic/Fomantic-UI/commit/1372242f51f3d14e5fbc06c2f078620834cb736b)
- fix(button, icon): loading icon position in button was not rotating around center [`1f71602`](https://github.com/fomantic/Fomantic-UI/commit/1f7160203ee8a4c7c42dad2815113967571e97b9)
- fix(icon): make link and disabled work together correctly, also support icon groups [`cef454e`](https://github.com/fomantic/Fomantic-UI/commit/cef454ea37a812d3bbc7e1de18f24a2d02e75e93)
- fix(dropdown): templates should also use dynamic classnames from settings [`26d6689`](https://github.com/fomantic/Fomantic-UI/commit/26d66892cbee2c9cd952815e85fdf23bce91439b)
- fix(form,segment): inverted variants should get inverted loader properly [`6b091f8`](https://github.com/fomantic/Fomantic-UI/commit/6b091f8460b2dedcfa2c5b7c3188de92f9e7231b)
- fix(dropdown): multi dropdown deletes last item when removing input/search text [`b84b814`](https://github.com/fomantic/Fomantic-UI/commit/b84b814f6d4d2c9577c1318e578792405257cabf)
- feat(label): add left and right aligned floating label [`e1550b4`](https://github.com/fomantic/Fomantic-UI/commit/e1550b43d40da02bad6b5403f163dd31349f3a22)
- fix(list): horizontal lists wrap nicely on small screens [`dbb489c`](https://github.com/fomantic/Fomantic-UI/commit/dbb489ca8d36e356b8513cc7379576734671db28)
- fix(form validation): radio buttons do not validate if the first is disabled [`b5a4d54`](https://github.com/fomantic/Fomantic-UI/commit/b5a4d540ffe444cd3d7136e1fbe291e6bfeeee3b)
- fix(menu): keep auto width for icon menu sizes [`7a204d4`](https://github.com/fomantic/Fomantic-UI/commit/7a204d4bc563b5a524c922d7cd944ce8f0c4e21a)
- fix(button): increased size specificity to work with menu item buttons [`1489756`](https://github.com/fomantic/Fomantic-UI/commit/1489756270205e2832ff082f686fb826486f43f3)
- feat(list): add suffixed ordered list variation [`6a7352b`](https://github.com/fomantic/Fomantic-UI/commit/6a7352bf1f772e45fac841cc7309d2c910308c0b)
- fix(sidebar): respect a change of closable setting [`4de7c51`](https://github.com/fomantic/Fomantic-UI/commit/4de7c5197b6cdd9bfc5e0582eedeb9737ad367ba)
- fix(label): adjust image height of image labels in menu items [`7ac1cb3`](https://github.com/fomantic/Fomantic-UI/commit/7ac1cb3cf93b368cc5de0f0d81d9271853d89f89)
- feat(probot): add welcome bot config [`11e9d04`](https://github.com/fomantic/Fomantic-UI/commit/11e9d043492dd015e12327d3ffab5986b5e0c7d4)
- fix(form): checkbox and radio (with errors) were only reset if the first option was selected [`6e41efe`](https://github.com/fomantic/Fomantic-UI/commit/6e41efe893f9dd95f0d13d0bdd6b26daaca10396)
- fix(menu): labels in secondary pointing menu items were misaligned [`5d9f93a`](https://github.com/fomantic/Fomantic-UI/commit/5d9f93a7090c78c911aef756a8e399f3bbfce223)
- fix(dropdown): fix simple dropdown positioning in vertical menus [`ba49f8f`](https://github.com/fomantic/Fomantic-UI/commit/ba49f8f0dbcf161343de989e0bb6ab1472c1e9d9)
- fix(list,icon): adjust position when icon has loading class [`80df182`](https://github.com/fomantic/Fomantic-UI/commit/80df1820327456dbd85c48cc4ac6b46e11b51bf5)
- chore(release): update release notes [`5d3efb7`](https://github.com/fomantic/Fomantic-UI/commit/5d3efb72883febc08dc4294aa953e90eb7f0cdb4)
- fix(input): support error class on input action buttons [`3cbc515`](https://github.com/fomantic/Fomantic-UI/commit/3cbc5154768d7ba1ab1706c883522836190d0b7e)
- chore(release): update release notes [`e50e021`](https://github.com/fomantic/Fomantic-UI/commit/e50e02114e60b20049d9f479c6192530b9589298)
- chore(release): 2.7.2 [`0d537d6`](https://github.com/fomantic/Fomantic-UI/commit/0d537d6d7a63944c405a6ca0de885cedad688acd)
- chore(release): update release notes [`606ac7c`](https://github.com/fomantic/Fomantic-UI/commit/606ac7cf749b451a5bb77d2bca13d062c760becc)
- feat(dropdown, search): support to ignore diacritics on search [`63a0855`](https://github.com/fomantic/Fomantic-UI/commit/63a08554dd30a49e95de40c12abaebba55895cd0)
- docs(roadmap): add roadmap [`ecddf01`](https://github.com/fomantic/Fomantic-UI/commit/ecddf01cd28b5df123c04901cf75754b8e818a78)
- fix(modal): prevent closing the modal when webkit scrollbar has been dragged [`bdf30a8`](https://github.com/fomantic/Fomantic-UI/commit/bdf30a81b64044a1890f5e5976ec1407f8fdb8a7)
- feat(dropdown): add delete icon classname to settings instead of having it hardcoded [`bb32ee8`](https://github.com/fomantic/Fomantic-UI/commit/bb32ee89267e1e5f8a78e2f15925ffdb6a8e2a9a)
- fix(dimmer): show proper webkit scrollbar on inverted variant [`249dfee`](https://github.com/fomantic/Fomantic-UI/commit/249dfeeadb5b049f1ba0d10bcb96c5efbb77a323)
- docs(readme): add v3 development message [`a8e7eee`](https://github.com/fomantic/Fomantic-UI/commit/a8e7eee7279d688a227f07473a829e8d96b3a738)
- style(search): removed wrong markup and added missing semicolons [`280cad9`](https://github.com/fomantic/Fomantic-UI/commit/280cad9f7623e7fc303d6ef29c95a7cb183fe213)
- chore(release): update version number [`a011585`](https://github.com/fomantic/Fomantic-UI/commit/a01158580b901e6330b55a125bb310d083f3bec8)
- chore(release): rebase with master [`983384f`](https://github.com/fomantic/Fomantic-UI/commit/983384fcd4121a82ae6612df9045b46f69dc27a2)
- feat(probot): add auto-assign config [`49cba77`](https://github.com/fomantic/Fomantic-UI/commit/49cba77057a8282fa8a5dc0f70cb651ebe91f68e)
- feat(probot): add probot config [`c2e2938`](https://github.com/fomantic/Fomantic-UI/commit/c2e2938e0c800f2c0aa4c11d835565432ecd6759)
- fix(segment): add stackable horizontal segments [`c391574`](https://github.com/fomantic/Fomantic-UI/commit/c3915748f7f612dd2fa6b98e391b75ac020b8ad5)
- fix(form validation): supply checked radio value to custom rule [`5aca68b`](https://github.com/fomantic/Fomantic-UI/commit/5aca68b8c667528c4a5f6577b5011eadca92f0fa)
- feat(label): content in floating labels should not wrap whitespace [`12be9b1`](https://github.com/fomantic/Fomantic-UI/commit/12be9b150958d682a576d3c8a07294cb75cc2410)
- fix(input): make inverted transparent input in forms appear white [`3c0e6b7`](https://github.com/fomantic/Fomantic-UI/commit/3c0e6b7f6eb0a4de54190dd09f6285354134a57b)
- fix(popup): display a popup over a checkbox slider completely [`6be2082`](https://github.com/fomantic/Fomantic-UI/commit/6be208202d80515777b6cf21df31b6b71c27bbd7)
- feat(modal): on modal hide focus the last focused element before the modal was opened [`be9e4c3`](https://github.com/fomantic/Fomantic-UI/commit/be9e4c37de0d019c04a4a672d4576bdf5e75f1cf)
- feat(step): steps will wrap by default unless specified as unstackable [`f04011b`](https://github.com/fomantic/Fomantic-UI/commit/f04011b40b0669a74f02d8208479c41f394ab62a)
- docs(readme) add travis badge & change last commit branch [`4c9da88`](https://github.com/fomantic/Fomantic-UI/commit/4c9da88f38ba0bae2913b5d667b615c069709351)
- fix(dropdown): sanitize possible given text values [`8608a4d`](https://github.com/fomantic/Fomantic-UI/commit/8608a4df7f6758f1979edfa0a996c88056e757ef)
- fix(label): link icon cursors in corner labels did not work [`f719689`](https://github.com/fomantic/Fomantic-UI/commit/f719689d9995f5f8b867225d04e575a3ce6f2d50)
- fix(dropdown): allow a real zero to be a selectable value [`dfa1ea1`](https://github.com/fomantic/Fomantic-UI/commit/dfa1ea14a35c179dc3eb1efff0a3951913cb0f42)
- fix(dimmer): z-index impact when using blurring dimmer filter [`dbb7ad3`](https://github.com/fomantic/Fomantic-UI/commit/dbb7ad36507932777a1ab76241d68af4b8bc59db)
- fix(button): z-index on attached buttons was shown above dropdown menu [`08e6406`](https://github.com/fomantic/Fomantic-UI/commit/08e6406da11f61875ce7bb244b3a09388e2bb181)
- fix(list): missing pseudo-class leads to invisible list item [`e1d2098`](https://github.com/fomantic/Fomantic-UI/commit/e1d2098fce501a97cab2a469fca4cfb66cdb2868)
- fix(menu): last item in secondary compact menu lost left top/bottom border radius [`b97bd06`](https://github.com/fomantic/Fomantic-UI/commit/b97bd06435ad4df2c43e37912ee6d52eac28053f)
- fix(header): should have same background color as other inverted components [`25f417e`](https://github.com/fomantic/Fomantic-UI/commit/25f417e4628c9cff1a478e33dc29025496d4b834)
- fix(colors): missing "globals" subpath in optional theme [`e347e20`](https://github.com/fomantic/Fomantic-UI/commit/e347e20de4981b3cca2e43bdd90c206a98f37a78)
- fix(modal): reactivate approve/deny event handling if onHide returned false [`3bd454c`](https://github.com/fomantic/Fomantic-UI/commit/3bd454c96a8972f1a813f6cf62e2c8bcd1162b82)

#### [2.7.1](https://github.com/fomantic/Fomantic-UI/compare/2.7.0...2.7.1)

> 24 December 2018

- chore(release): 2.7.1 [`7f6bd29`](https://github.com/fomantic/Fomantic-UI/commit/7f6bd29db53f17a2c4e2c47e2dc0e81568d1ea5f)
- chore(release): 2.7.1 [`3d40656`](https://github.com/fomantic/Fomantic-UI/commit/3d406563696094289eb4e7c84dec5145437eab14)
- fix(loader): elastic style had wrong color applied [`b19c2d1`](https://github.com/fomantic/Fomantic-UI/commit/b19c2d145d4f3dd4a09cb03026425ffa9558e445)
- fix(loader): elastic style had wrong color applied [`df5701c`](https://github.com/fomantic/Fomantic-UI/commit/df5701c5f41a4a0e09a25ec9a2bb0e84962c9fd7)

#### [2.7.0](https://github.com/fomantic/Fomantic-UI/compare/2.6.4...2.7.0)

> 21 December 2018

- refactor(slider): turn range into slider and add new features [`#117`](https://github.com/fomantic/Fomantic-UI/issues/117)
- build(gulp): hangs on 'create install files' [`#307`](https://github.com/fomantic/Fomantic-UI/issues/307)
- fix(modal): fix top border radius when allowMultiple is true [`#308`](https://github.com/fomantic/Fomantic-UI/issues/308)
- fix(visibility): rename placeholder class to constraint [`#296`](https://github.com/fomantic/Fomantic-UI/issues/296)
- fix(modal): dimmer click closed modal when allowMultiple=true even if onHide()=false [`#284`](https://github.com/fomantic/Fomantic-UI/issues/284)
- fix(dropdown): fix select always showing remove icon [`#271`](https://github.com/fomantic/Fomantic-UI/issues/271)
- feat(input): add red border around `error labeled input` [`#257`](https://github.com/fomantic/Fomantic-UI/issues/257)
- fix(security): changed event-stream version [`#268`](https://github.com/fomantic/Fomantic-UI/issues/268)
- feat(search): wrap result into object when original result is an array [`#263`](https://github.com/fomantic/Fomantic-UI/issues/263)
- feat(label): add inverted variant, basic grouping and basic tag [`#116`](https://github.com/fomantic/Fomantic-UI/issues/116)
- fix(placeholder): append .loadUIOverrides() to the bottom [`#255`](https://github.com/fomantic/Fomantic-UI/issues/255)
- fix(table): images in tables did not display properly [`#227`](https://github.com/fomantic/Fomantic-UI/issues/227)
- build: update to gulp4 [`#112`](https://github.com/fomantic/Fomantic-UI/issues/112)
- chore(release): 2.7 [`c3ec205`](https://github.com/fomantic/Fomantic-UI/commit/c3ec205d237b1c18fd1d697646872557f8db86fe)
- feat(colors): add central dynamic color map for every component [`7338ad2`](https://github.com/fomantic/Fomantic-UI/commit/7338ad2a295c5460bdd97f261c36ee85032d5bd3)
- style: remove trailing CSS unit values & duplicate properties [`32ebf7e`](https://github.com/fomantic/Fomantic-UI/commit/32ebf7e1243dd80295df13bff5d2bd662d082bd3)
- build(travis): fix package-lock sha512 checksum error [`1f15e3b`](https://github.com/fomantic/Fomantic-UI/commit/1f15e3b50b2089c9826a09fc3f7c2ce21cdbef6c)
- feat(loader): add new variants, module support and refactor colors [`5bd8d2a`](https://github.com/fomantic/Fomantic-UI/commit/5bd8d2a52bb9a5d0a36c2083bcc7a8add1a60e03)
- feat(rating): add individual icons and colors instead of fixed star & heart only [`a341fd9`](https://github.com/fomantic/Fomantic-UI/commit/a341fd9a827efd7f29ad4fa4878b789c6b907348)
- refactor: remove deprecated jquery functions [`bc67749`](https://github.com/fomantic/Fomantic-UI/commit/bc677491eb2ff5115459011446766b0b99e5e7bd)
- security: prevent JS execution from manual entries or untrusted remote data [`11da1e3`](https://github.com/fomantic/Fomantic-UI/commit/11da1e329f0cf54207e0cce7d9a74a44ca56241f)
- chore(release): update dist files [`a5bc71c`](https://github.com/fomantic/Fomantic-UI/commit/a5bc71c00061ab029796cb7c58ec0d2afeba6844)
- style: fix some css errors [`3608cc6`](https://github.com/fomantic/Fomantic-UI/commit/3608cc6d5a5787e8969065c1e1e4eafd8af51924)
- fix(checkbox): support onChange for cursor keynav [`3fec1ec`](https://github.com/fomantic/Fomantic-UI/commit/3fec1ecd191ffb362eb22b02062c531d50617f6c)
- style(readme): improve consistency [`207e948`](https://github.com/fomantic/Fomantic-UI/commit/207e9483b36a384c0702e44609fde67905d8b50a)
- feat(calendar): add timegap setting to expand time selector [`cc639de`](https://github.com/fomantic/Fomantic-UI/commit/cc639de84ff835368ba4497b2d8420c6e16d4abd)
- docs(issue template): remove old template [`9f1cc00`](https://github.com/fomantic/Fomantic-UI/commit/9f1cc007ac4ed0ec7d03addf678fa1cc00710857)
- fix(form, dropdown): formvalidation broke when id had colon in it [`599ea12`](https://github.com/fomantic/Fomantic-UI/commit/599ea12c589b4d4ca2c3b8eb4582c16d592ffa90)
- fix(dropdown): show "no results" when filterRemoteData is false and response is empty [`b700b93`](https://github.com/fomantic/Fomantic-UI/commit/b700b93d4d9fbb67aeb116ccee720b2a0933ff0c)
- fix(list): make sure list settings are not applied to any "list icon" [`fd63cc9`](https://github.com/fomantic/Fomantic-UI/commit/fd63cc943ff127f6c4ab7c5e76bda419386920b5)
- fix(modal): touch scrolling (dropdown, content, focussed input) fixed [`f7cc7b5`](https://github.com/fomantic/Fomantic-UI/commit/f7cc7b538a1217b6930ceb3055ff0f593a118ede)
- feat(input,textarea): support corner label and icon for textarea [`d2aa74d`](https://github.com/fomantic/Fomantic-UI/commit/d2aa74d9c2a4c599e83b2e4e03f8df8b363610f6)
- fix(menu, loader): hotfixes for 2.7 [`6e72bcc`](https://github.com/fomantic/Fomantic-UI/commit/6e72bcc4aaec3082790292e91db81221301ae03b)
- fix(dropdown): fixes submenu positioning [`26dbfe7`](https://github.com/fomantic/Fomantic-UI/commit/26dbfe70691ac668f36bb5ae1bd0dbd7b053b783)
- fix(popup): fix correct usage for addTouchEvents=false [`24fcf68`](https://github.com/fomantic/Fomantic-UI/commit/24fcf6897101abb7480485b75d5b7be256659737)
- docs(release notes): add gulp4 upgrade notice [`6ff5a07`](https://github.com/fomantic/Fomantic-UI/commit/6ff5a07529e4667203b4602d44e7424cf400b623)
- fix(dropdown): preselected values are ignored when data has individual value-name [`9f34023`](https://github.com/fomantic/Fomantic-UI/commit/9f34023f0b3d4c27981695a695a063ab9fed0171)
- feat(toast): use the same color on every inverted toast [`deb1ec7`](https://github.com/fomantic/Fomantic-UI/commit/deb1ec7bf102d427c2744007764e759f98827a9f)
- docs(readme): add package quality badge & change jsDelivr to rounded style [`fec8ae9`](https://github.com/fomantic/Fomantic-UI/commit/fec8ae94731b93535b6d38fcbdf9cdc65c0b427d)
- fix(dropdown): filter preselected entries from #287 was not working for div-dropdowns [`fc000b7`](https://github.com/fomantic/Fomantic-UI/commit/fc000b74d038e13ff74bbef802d8ee02e2188a02)
- feat(api): add ability to handle array responses in onResponse handler [`d5ec1f8`](https://github.com/fomantic/Fomantic-UI/commit/d5ec1f8636346fc1cea543cc4ccfc2c25ec2155e)
- fix(dropdown): filter already selected items when using remote api [`fd3646a`](https://github.com/fomantic/Fomantic-UI/commit/fd3646ad05f0dd9e5630564002180463b6f59c78)
- fix(table): thead and tbody missed alignment inheritance [`18238f1`](https://github.com/fomantic/Fomantic-UI/commit/18238f1612f049689df236c87c927918b8209262)
- feat(toast): changed title class to header [`128769f`](https://github.com/fomantic/Fomantic-UI/commit/128769f6b145d14844cfa1fee3430fdde0672f35)
- fix(text): add text component to gulp tasks [`4ecfa02`](https://github.com/fomantic/Fomantic-UI/commit/4ecfa0251409ff586e38d9df7f497050469b3d53)
- fix(dropdown): stop event on enterkey and multiple allowadditions to prevent form submission [`53267ee`](https://github.com/fomantic/Fomantic-UI/commit/53267ee7434d69b9c96580cb726469d4307e8ff0)
- fix(table): restore default vertical alignment [`493fd7f`](https://github.com/fomantic/Fomantic-UI/commit/493fd7f149da83b365a57e628fbcf32f14797b1c)
- fix(placeholder): Respect a possible 'image icon' not occupying the same space as a real image should [`c053e23`](https://github.com/fomantic/Fomantic-UI/commit/c053e232e9a51c136d5ff0906439c471edf433eb)
- fix(message): fixed compact icon message width [`c6d9334`](https://github.com/fomantic/Fomantic-UI/commit/c6d9334069c521aab1c53ceabc0cdf0bb407b6b1)

#### [2.6.4](https://github.com/fomantic/Fomantic-UI/compare/2.6.3...2.6.4)

> 15 November 2018

- chore/2.6.4 release [`#247`](https://github.com/fomantic/Fomantic-UI/pull/247)
- fix(popup): old Fix was disturbing popup position calculations [`#148`](https://github.com/fomantic/Fomantic-UI/issues/148)
- fix(form): dropdown width in forms [`#228`](https://github.com/fomantic/Fomantic-UI/issues/228)
- fix(segment): increase specificity of raised segment [`#205`](https://github.com/fomantic/Fomantic-UI/issues/205)
- chore(release): 2.6.4 [`11150d4`](https://github.com/fomantic/Fomantic-UI/commit/11150d464dde3b99fad161117bc71ad015b7ae93)
- style: fixes some CSS lint issues [`0fa3831`](https://github.com/fomantic/Fomantic-UI/commit/0fa3831be06c04ea6d7a85ca728c8aabbd07d18a)
- feat(dimmer): add support for using dimmers only partially on top,center,bottom [`e85b8e5`](https://github.com/fomantic/Fomantic-UI/commit/e85b8e556b8bb38e4d70fd9b879dcf9a723bf26f)
- feat(item): add inverted variant [`a52c665`](https://github.com/fomantic/Fomantic-UI/commit/a52c665425860fae10e4df45ad38f1df9f1e1dab)
- feat(site): update and add brand colors [`92af851`](https://github.com/fomantic/Fomantic-UI/commit/92af8517463f9adc96b0f08681fde9930827a683)
- feat(calendar): add `disabledDaysOfWeek` setting [`dd957bc`](https://github.com/fomantic/Fomantic-UI/commit/dd957bc5763eee3301697427195134e49b8c410c)
- feat(calendar): add ability to disable specific date(s) [`3f7bc5d`](https://github.com/fomantic/Fomantic-UI/commit/3f7bc5d8aa7e604be3822e472fc6ab66bae0d727)
- fix(menu): make the pointing tips in inverted menu reflecting menu background color [`ad2f57e`](https://github.com/fomantic/Fomantic-UI/commit/ad2f57e6ffdd3ccdb5a61c429938b10c7ad31e07)
- feat(popup): add size modifiers to none javascript popup [`c284ecd`](https://github.com/fomantic/Fomantic-UI/commit/c284ecdc80dade7a3b95b4e8cf604d29ba7de5f8)
- revert: add timegap setting to expand time selector [`108c1ec`](https://github.com/fomantic/Fomantic-UI/commit/108c1ec48ffb1eb40e1e5b8688f973b51af871fa)
- feat(calendar): add timegap setting to expand time selector [`2f05013`](https://github.com/fomantic/Fomantic-UI/commit/2f05013a12376fcd31e4cbc7197183ea2fcdf5b2)
- fix(modal): basic modal and inverted modal on inverted dimmer had wrong close icon color [`c4c8037`](https://github.com/fomantic/Fomantic-UI/commit/c4c80374a7ec90e0cf05d7fdd26866f23030736f)
- feat(statistic): add stackable variation [`dd04a90`](https://github.com/fomantic/Fomantic-UI/commit/dd04a90a6a64d70f97e66342ec74a8214098deed)
- build: implement travis [`e466d37`](https://github.com/fomantic/Fomantic-UI/commit/e466d3777e73b11f0dd0365318e6aa97f552a3e0)
- fix(dropdown): prevents close/open bubbling [`6ed8db1`](https://github.com/fomantic/Fomantic-UI/commit/6ed8db152e3ef678cfcb31a8cfb6d89722af0654)
- fix(dropdown): showOnFocus will not prevent dropdown opening [`22a25fa`](https://github.com/fomantic/Fomantic-UI/commit/22a25fa41b3a2ee216441954b06423bc91a4863c)
- fix(menu): dropdown inside menu should not reflect menu styling [`216f03f`](https://github.com/fomantic/Fomantic-UI/commit/216f03f42722e054be2491f67fc27cc0a86c0a3c)
- fix(list): icon and wrapped image were not inline and wrapped or wrongly aligned [`5b7ebae`](https://github.com/fomantic/Fomantic-UI/commit/5b7ebae9d999b453d70d31ac59a775c5dd9ed1d6)
- fix(dropdown): fix for menu bubbling [`0620309`](https://github.com/fomantic/Fomantic-UI/commit/062030902c4eb3968e735063b2f933bbdcac107a)
- fix(list): data-value on &lt;div&gt; list items is ignored [`6af1487`](https://github.com/fomantic/Fomantic-UI/commit/6af14871370b5ecbc6af3a29acad7b7b05353d19)
- fix(icon): corner icon size in header icon [`f812030`](https://github.com/fomantic/Fomantic-UI/commit/f812030dc38675437d85c4dbec4179ded5b22feb)
- fix(dropdown): IE11 got focus on submenu selection again [`63bc9a8`](https://github.com/fomantic/Fomantic-UI/commit/63bc9a80cdf867675337bd39f1c75d27c301ebe2)
- fix(dimmer): stop events when outside scope [`b9551d8`](https://github.com/fomantic/Fomantic-UI/commit/b9551d889f5a579e01c8679223fc0f3a03c917a4)
- fix(dropdown): remove top margin from simple dropdown items to prevent submenu vanishing [`627e808`](https://github.com/fomantic/Fomantic-UI/commit/627e808a5cf3a841803c63bae05d5717d51b2c77)
- fix(dimmer): make dimmer text more readable [`81e3934`](https://github.com/fomantic/Fomantic-UI/commit/81e3934a15e8929be3974579db86ed9cd6fef8a3)
- fix(dropdown): prevent user selection [`40374b8`](https://github.com/fomantic/Fomantic-UI/commit/40374b8914333084f60d57c937a4f3eb1cd5b27f)
- fix(modal): image and content does not wrap [`83aa9e2`](https://github.com/fomantic/Fomantic-UI/commit/83aa9e2354612210004cc798fa3ded93711bd82d)
- feat(progress): inverted colors text will black instead of white [`78dece2`](https://github.com/fomantic/Fomantic-UI/commit/78dece20e5a0ce7d6bd25ceffe8e6ff3b6a98949)
- fix(popup): correct module.supports.svg method [`7828b2f`](https://github.com/fomantic/Fomantic-UI/commit/7828b2f7596e3eb63f4e03db4f4b8762e2197a99)
- fix(dropdown): make sure to also clear filtered items when clearing [`6b39072`](https://github.com/fomantic/Fomantic-UI/commit/6b39072baa6dc805d5acc127ca8f23968ee3732a)
- fix(icon): icon group alignment [`91ea667`](https://github.com/fomantic/Fomantic-UI/commit/91ea6678bad309753cf1b6aac72c4819bbfbd28a)
- fix(dropdown): prevent multiselection dropdown being pushed down [`de7134d`](https://github.com/fomantic/Fomantic-UI/commit/de7134dbf42011931b34d0a31fc68b658d179cf3)
- chore: add vscode folder into .gitignore [`38a95b1`](https://github.com/fomantic/Fomantic-UI/commit/38a95b151a15d7509d1a77ff5bb8737d8fe05268)

#### [2.6.3](https://github.com/fomantic/Fomantic-UI/compare/2.6.2...2.6.3)

> 18 October 2018

- 2.6.3 Release [`#184`](https://github.com/fomantic/Fomantic-UI/pull/184)
- toast: fix position for top and bottom centered container on scrolling body [`#167`](https://github.com/fomantic/Fomantic-UI/pull/167)
- [Form] Transparent Input/Textarea Error [`#163`](https://github.com/fomantic/Fomantic-UI/pull/163)
- [Form] Support inverted transparent textarea [`#161`](https://github.com/fomantic/Fomantic-UI/pull/161)
- [Dimmer] Additional intensity states very light, light, medium [`#162`](https://github.com/fomantic/Fomantic-UI/pull/162)
- [Toast] Progressbar, closeEasing, Bugfixing, message support [`#139`](https://github.com/fomantic/Fomantic-UI/pull/139)
- [Progress] Remove unused code [`#156`](https://github.com/fomantic/Fomantic-UI/pull/156)
- [Dropdown] Fix the clearable setting that does'nt init a clearable dropdown [`#155`](https://github.com/fomantic/Fomantic-UI/pull/155)
- [Dropdown] Single Selection via keyboard gained focus again Fixes #153 [`#154`](https://github.com/fomantic/Fomantic-UI/pull/154)
- force display:none on .placeholder.hidden.transition [`#148`](https://github.com/fomantic/Fomantic-UI/pull/148)
- Add missing changes in release notes [`#147`](https://github.com/fomantic/Fomantic-UI/pull/147)
- fix(header): simplify css rules for top/bottom attached headers [`#181`](https://github.com/fomantic/Fomantic-UI/issues/181)
- fix(dropdown): clean-up some of leftover sui clear logic [`#171`](https://github.com/fomantic/Fomantic-UI/issues/171)
- feat(icons): add new FA 5.4 icons [`#166`](https://github.com/fomantic/Fomantic-UI/issues/166)
- feat(modal): add inverted variant [`#108`](https://github.com/fomantic/Fomantic-UI/issues/108)
- Merge pull request #154 from lubber-de/fix/153 [`#153`](https://github.com/fomantic/Fomantic-UI/issues/153)
- Don't focus on single selection . Fixes #153 [`#153`](https://github.com/fomantic/Fomantic-UI/issues/153)
- chore: 2.6.3 build [`2e8ea84`](https://github.com/fomantic/Fomantic-UI/commit/2e8ea847327e5fb5e9b9948a5a79163bba2db49f)
- feat(calendar): add ability to set `minDate` and `maxDate` with HTML attributes [`a6a3323`](https://github.com/fomantic/Fomantic-UI/commit/a6a332308d08be5264e24aae1b4c3ed47274bdc8)
- fix(button): support less 2.7 [`cc624fd`](https://github.com/fomantic/Fomantic-UI/commit/cc624fd0076f1e41867ce45c4d040f700cd7348c)
- chore: release tasks [`453ec46`](https://github.com/fomantic/Fomantic-UI/commit/453ec46568998054489a637836f1cd437e712a30)
- Fixed full progressbar support for mixed toasts/messages/compact/top attached, made compact an option, fixed alignments, fixed responsiveness margins, removed unused variables [`7266b63`](https://github.com/fomantic/Fomantic-UI/commit/7266b63c523a76965f2c95b1dae51b2809cd25d5)
- feat(toast): add color variants [`36228f0`](https://github.com/fomantic/Fomantic-UI/commit/36228f0c1b8f830909bd0ed3bbf7ec4af09958d9)
- Added closeIcon option, changed showProgress to allow false|'top'|'bottom' only [`aaac23e`](https://github.com/fomantic/Fomantic-UI/commit/aaac23e4b8ece2184caa02594e4eecd5098366cb)
- moved to proper places. Increased specificity of medium and light to still work with "simple" [`e8d6058`](https://github.com/fomantic/Fomantic-UI/commit/e8d605882aa9d160223474b88e5d59223718c392)
- feat(calendar): add disabled state [`ab3532d`](https://github.com/fomantic/Fomantic-UI/commit/ab3532d55fc81fece1e11286f78cd5526c858d79)
- Additional dimmer intensity states [`01e2683`](https://github.com/fomantic/Fomantic-UI/commit/01e268340593d6f94905d2ba9a64062e83751745)
- - Display error background for transparent input & textarea [`e0f54ea`](https://github.com/fomantic/Fomantic-UI/commit/e0f54eaeb6af8ca7fc33821e2c960748ba3b86fb)
- chore: merge SUI release [`c2ee301`](https://github.com/fomantic/Fomantic-UI/commit/c2ee301d4e1baf2394070b04fea70650a8404fda)
- moved declaration to proper position in less file [`6cce552`](https://github.com/fomantic/Fomantic-UI/commit/6cce552efe645631731fb5380723479fe798108d)
- Support inverted transparent textarea [`31ed000`](https://github.com/fomantic/Fomantic-UI/commit/31ed0007b7133967b7ef2ad2d52cc8328acf4299)
- fix(icon): fix corner position when using some icons in group [`aeed770`](https://github.com/fomantic/Fomantic-UI/commit/aeed7705a78cb7e5757954255547229f7219db22)
- simplified again to existing transparent definition [`7f8fff2`](https://github.com/fomantic/Fomantic-UI/commit/7f8fff2f60cea0b674561e61dc6ca1c939550bbc)
- fixed syntax... [`91dff06`](https://github.com/fomantic/Fomantic-UI/commit/91dff06b0b6bb2db475f0b223302147f2a9bbc54)
- support true/false/'top'/'bottom' for showProgress parameter. No need to set the proper className for progress anymore [`f7bc317`](https://github.com/fomantic/Fomantic-UI/commit/f7bc317213bab165736f99a38e6ae581052f8f03)
- Support string for showIcon to use individual icons [`c4c35c6`](https://github.com/fomantic/Fomantic-UI/commit/c4c35c6e385ed418b96c68fa2dd131bbc638dcc2)
- chore: update release notes [`043fce6`](https://github.com/fomantic/Fomantic-UI/commit/043fce66b79b8747db6f43a12f07ce074e793a77)
- perf(progress): animate scale instead of width [`dc2c5c8`](https://github.com/fomantic/Fomantic-UI/commit/dc2c5c829656c4ec31339cf4a056bba067975c65)
- removed unnecessary whitespace [`74872b7`](https://github.com/fomantic/Fomantic-UI/commit/74872b72f04bfb1910dbcc506ec40ce9185c3f96)
- better approach without using !important, thanks @ColinFrick [`05655ef`](https://github.com/fomantic/Fomantic-UI/commit/05655ef9f0311d64a166ffff44432733cf09d35b)
- less variables instead of fixed values [`ae61e96`](https://github.com/fomantic/Fomantic-UI/commit/ae61e96ed7f444d86dcbd271cde6d9751914fff8)
- force display:none, fixes SUI #6608 where placeholder was overriding display:none [`1566bfb`](https://github.com/fomantic/Fomantic-UI/commit/1566bfb784daa8a4f299344b9353cd9fd6df1b85)
- style: fix `From` typo [`820bee4`](https://github.com/fomantic/Fomantic-UI/commit/820bee4ad238ad4d979654f2003a8698588de987)
- finally simplified now... [`09140ba`](https://github.com/fomantic/Fomantic-UI/commit/09140ba939c1a7585e42c185dccbe535dfee00dd)
- chore: update release notes [`792a951`](https://github.com/fomantic/Fomantic-UI/commit/792a951688597c8ab986c472174bf68bfabe19d6)

#### [2.6.2](https://github.com/fomantic/Fomantic-UI/compare/2.6.1...2.6.2)

> 2 October 2018

- 2.6.2 [`#146`](https://github.com/fomantic/Fomantic-UI/pull/146)
- Revert "Merge branch 'acc-upgrade-gulp4' of github.com:acconrad/Semantic-UI into beta" [`8ddac35`](https://github.com/fomantic/Fomantic-UI/commit/8ddac35878503f7c0e8e8c311ce47307fa86834b)
- chore: update dependencies [`5b4b777`](https://github.com/fomantic/Fomantic-UI/commit/5b4b777bc996c3f5448156c3986c1c6e9bccb1ae)
- chore: 2.6.2 build [`cc2ff4a`](https://github.com/fomantic/Fomantic-UI/commit/cc2ff4a0c9bb9eb18c8f4cc819e9bfbf54b01866)
- chore: update release notes [`57b3f6c`](https://github.com/fomantic/Fomantic-UI/commit/57b3f6c10932a7cef5d68febcfaada0543d3e693)
- chore: update version [`b559afd`](https://github.com/fomantic/Fomantic-UI/commit/b559afdd8801535f356a4f07b110905f6968f475)
- fix: gulp install process [`194e0f0`](https://github.com/fomantic/Fomantic-UI/commit/194e0f0b92655b1402954d9864f8dff5a7a73755)
- revert: gulp install process [`d73955c`](https://github.com/fomantic/Fomantic-UI/commit/d73955ccbb4151fd0ca070c7105732cf96381581)

#### [2.6.1](https://github.com/fomantic/Fomantic-UI/compare/2.6.0...2.6.1)

> 2 October 2018

- 2.6.1 [`#144`](https://github.com/fomantic/Fomantic-UI/pull/144)
- [Modal] Fullscreen modals are not working in IE11 [`#136`](https://github.com/fomantic/Fomantic-UI/pull/136)
- [Icon] Comments icon inside "comment" component is not well aligned [`#133`](https://github.com/fomantic/Fomantic-UI/pull/133)
- fixing both Bower and Composer package names [`#140`](https://github.com/fomantic/Fomantic-UI/pull/140)
- [Modal] Fullscreen modal stuck to left edge of page [`#135`](https://github.com/fomantic/Fomantic-UI/pull/135)
- feat(button): move colors / primary / secondary to mixin [`#128`](https://github.com/fomantic/Fomantic-UI/issues/128)
- fix(modal): increase importance of legacy modal class definition [`#134`](https://github.com/fomantic/Fomantic-UI/issues/134)
- fix(modal): set @fullScreenOffset to correct offset [`#130`](https://github.com/fomantic/Fomantic-UI/issues/130)
- fix(comment): enforce dom structure for sub-comments [`#131`](https://github.com/fomantic/Fomantic-UI/issues/131)
- Toast progressbar, closeEasing, Bugfixing, message support [`0653860`](https://github.com/fomantic/Fomantic-UI/commit/0653860976be03bbb8ebebf8a44c6846b6357174)
- feat(button): move consequence variations to mixin [`be22acd`](https://github.com/fomantic/Fomantic-UI/commit/be22acd8725af95ed36178adb19e2d3454cafdf4)
- chore: 2.6.1 build [`77c60a5`](https://github.com/fomantic/Fomantic-UI/commit/77c60a5a0a4533980b52f36ceeda2348df74cf5e)
- Always render parent 'text-box', support 'top attached progress', show icon only, if class exists [`ccf7ad0`](https://github.com/fomantic/Fomantic-UI/commit/ccf7ad077c0cd1fd5e178acec49ac7b04b940eaf)
- Make opacity an option (default 1), removed flat class [`00eb26a`](https://github.com/fomantic/Fomantic-UI/commit/00eb26a96a612ae36b2571f44065b8cb09cfd06f)
- [DropDown] Fix icon position over searchentry, stay focussed on keyboard entries [`7d0276f`](https://github.com/fomantic/Fomantic-UI/commit/7d0276f5de3270b13781e73c570dae17e088714e)
- Fixed floating shadow, added hoverfloating [`f49a63c`](https://github.com/fomantic/Fomantic-UI/commit/f49a63cf3100149835360a7ecaef4e6d4c07b9ee)
- chore: update release notes [`ebc5969`](https://github.com/fomantic/Fomantic-UI/commit/ebc59691630412ba7028bac314d0c8a60ca35e2b)
- fix(modal): increase importance of legacy modal class definition (scrolling) [`c4eed66`](https://github.com/fomantic/Fomantic-UI/commit/c4eed662b0f1df038e8f1042f7ec4931db08f8c1)
- Support hoverfloating for message aswell [`6a22d11`](https://github.com/fomantic/Fomantic-UI/commit/6a22d11c462c99c190b8df69abdcf0501d2c46bf)
- changing Composer package's name to Fomantic UI [`919ffd3`](https://github.com/fomantic/Fomantic-UI/commit/919ffd35dd7d42b505449e5235102bc96f697609)
- chore: update version [`a1ec555`](https://github.com/fomantic/Fomantic-UI/commit/a1ec5555d5166df47cdbc1891283ff125d9ade76)
- chaning Bower's package name [`7f50759`](https://github.com/fomantic/Fomantic-UI/commit/7f507591481f0a2f26540e0759c0cd52d523983b)
- chore: update date [`ed26d84`](https://github.com/fomantic/Fomantic-UI/commit/ed26d84d2661bf97912fd8457290e0b71d852daf)
- chore: update release notes [`fa736c8`](https://github.com/fomantic/Fomantic-UI/commit/fa736c8861bea879a7f12b21a8a5f8dd849e99b5)
- Missing src file [`4ea71e5`](https://github.com/fomantic/Fomantic-UI/commit/4ea71e5ce7e48cd8a2c8891795dae00e5acef5a4)

#### [2.6.0](https://github.com/fomantic/Fomantic-UI/compare/2.5.0...2.6.0)

> 21 September 2018

- 2.6 Release [`#127`](https://github.com/fomantic/Fomantic-UI/pull/127)
- [Toast] Small fixes [`#125`](https://github.com/fomantic/Fomantic-UI/pull/125)
- [Message] Add floating variation to colored messages [`#124`](https://github.com/fomantic/Fomantic-UI/pull/124)
- Fixed some typos in the CONTRIBUTING guide [`#120`](https://github.com/fomantic/Fomantic-UI/pull/120)
- Lower modals are not accessible anymore in multiple modals [`#119`](https://github.com/fomantic/Fomantic-UI/pull/119)
- [Modal] Pressing the ESC key won't close all open modals anymore [`#118`](https://github.com/fomantic/Fomantic-UI/pull/118)
- [Checkbox] since 2.5.0 'before[Un]Checked' fires already on init [`#115`](https://github.com/fomantic/Fomantic-UI/pull/115)
- [Calendar] Adds support for WeekNumbers in Day View [`#113`](https://github.com/fomantic/Fomantic-UI/pull/113)
-  [Menu] Fix the inconsistent icon-text spacing in labeled icon menu dropdown [`#111`](https://github.com/fomantic/Fomantic-UI/pull/111)
- [Accordion][Header] Header with content has display:none when in an accordion element [`#103`](https://github.com/fomantic/Fomantic-UI/pull/103)
- Legacy modals [`#6562`](https://github.com/fomantic/Fomantic-UI/pull/6562)
- fix(message): add floating to colored messages [`#123`](https://github.com/fomantic/Fomantic-UI/issues/123)
- Fix #6439, basic colored labels do not have correct background [`#6439`](https://github.com/fomantic/Fomantic-UI/issues/6439)
- fix(checkbox): prevent before callbacks on init if fireOnInit is false [`#114`](https://github.com/fomantic/Fomantic-UI/issues/114)
- Fix #6557, specifity issue with dropdown in some menu types [`#6557`](https://github.com/fomantic/Fomantic-UI/issues/6557)
- Fix #6555 onChange is missing final param when used with action: 'hide' [`#6555`](https://github.com/fomantic/Fomantic-UI/issues/6555)
- fix(accordion): Modify "not active" rule to only hide siblings of the title inside the accordion [`#102`](https://github.com/fomantic/Fomantic-UI/issues/102)
- chore: 2.6 build [`a1d1491`](https://github.com/fomantic/Fomantic-UI/commit/a1d1491e93502cecdaa34a04a9f56a5730f25b1d)
- Build 2.4.0 [`4f6fe8e`](https://github.com/fomantic/Fomantic-UI/commit/4f6fe8ef44e088657ea6a5d1ed4bbea1100ca840)
- Move content loader to new component, placeholder. Modify placeholder segment to be 'empty segment' [`e83855c`](https://github.com/fomantic/Fomantic-UI/commit/e83855cdd351b752c988b5e608471ac6ae1882e7)
- [Toast] :tada: Initial commit [`4229acb`](https://github.com/fomantic/Fomantic-UI/commit/4229acb5657e8234ef4b4459905bff244eef17b4)
- chore: 2.6 build [`14b438a`](https://github.com/fomantic/Fomantic-UI/commit/14b438aac3cc846ecdc614fdcd83d8a577a79a49)
- chore: 2.6 build [`a13a9e7`](https://github.com/fomantic/Fomantic-UI/commit/a13a9e777a04279f358ced05afc3bb52adeda8ad)
- Finish content loader [`d382de6`](https://github.com/fomantic/Fomantic-UI/commit/d382de69fc34f0e805a38551b8d65eff0b447b22)
- Work on content loader [`0a560d8`](https://github.com/fomantic/Fomantic-UI/commit/0a560d8285a3256243c7c02b8336700b15bc9c97)
- Rename components to placeholder [`eedb182`](https://github.com/fomantic/Fomantic-UI/commit/eedb1829132395a73b2a2c561cd03b121249ccad)
- Support optional Weeknumbers in Calendar Day View [`b44e647`](https://github.com/fomantic/Fomantic-UI/commit/b44e647422f7df14ef5d58746eeeb676da9ed868)
- Add rlsnotes and placeholder segment [`bb0b9b9`](https://github.com/fomantic/Fomantic-UI/commit/bb0b9b90886a661456d17f90a36ed39d807becdd)
- Spacing on theme config [`e0c03dd`](https://github.com/fomantic/Fomantic-UI/commit/e0c03ddbf54d6e9c65e2319d1d96528910562e45)
- refactor: redesign the README [`effcf62`](https://github.com/fomantic/Fomantic-UI/commit/effcf62ef3aa214218072356a1b05ebd810351d7)
- Fix Week calculation display (needs to start with monday at least), moved calculation inside of get methods [`74f5d47`](https://github.com/fomantic/Fomantic-UI/commit/74f5d47e25bfa448908e78116ae4991ae5ca8f87)
- refactor: rewrite the contributing guide [`f6ed145`](https://github.com/fomantic/Fomantic-UI/commit/f6ed145d7f23853cd6cc617e9e63f6d85767d6ff)
- Finish refactor of modal to support legacy positioning for IE11 [`bbad430`](https://github.com/fomantic/Fomantic-UI/commit/bbad43026d0d0c6f52a62d2d1260039f4657b397)
- chore: update release notes [`f683ddc`](https://github.com/fomantic/Fomantic-UI/commit/f683ddc87b940d8306341beef84f91b4d9a6a089)
- Fix legacy modals to support top aligned, fix bug in ie11 for swapping between top/middle aligned [`e35ce81`](https://github.com/fomantic/Fomantic-UI/commit/e35ce81e2777b37712982c4297866ef35ffb9a3c)
- Finish content loader images [`a036608`](https://github.com/fomantic/Fomantic-UI/commit/a0366085fc4910eb304af6155dfefc2bf4200fc3)
- feat(ISSUE_TEMPLATE): create bug report [`fabd1fd`](https://github.com/fomantic/Fomantic-UI/commit/fabd1fd29732bba8e25ff87ffdeef88f6c547887)
- #6449 #6495 - Adapt fix for dimmer scroll. Move to modal from dimmer. Blocking scroll requires determining content height which only modal can do [`d6ebab1`](https://github.com/fomantic/Fomantic-UI/commit/d6ebab1e6c171cd8870d903c7761ed4cc9b525f1)
- Simplest implementation of clearable dropdown [`33d08ec`](https://github.com/fomantic/Fomantic-UI/commit/33d08ec920c95b0ef9ee84bc31fbdb304916c212)
- Make content loaders support image aspect ratios [`9a3079b`](https://github.com/fomantic/Fomantic-UI/commit/9a3079ba58ea54534160cabfc7b6227a77e2665e)
- refactor: rewrite pull request template [`802b755`](https://github.com/fomantic/Fomantic-UI/commit/802b7555496a3dc151d7437adf173124f538eaba)
- Re-subset dropdown to include close [`35c583f`](https://github.com/fomantic/Fomantic-UI/commit/35c583f10ba8c82ddddfb998af3a5c7daebb37fa)
- #6218 - Reuse closable pattern from dimmer [`588ef9b`](https://github.com/fomantic/Fomantic-UI/commit/588ef9b4cf0614c7caf4879003073f58473eb602)
- Finalize release notes for 2.4.0 [`33ed598`](https://github.com/fomantic/Fomantic-UI/commit/33ed598e75c7bcbb906d46b1b724c2c9ee184aad)
- Make values relative [`2882706`](https://github.com/fomantic/Fomantic-UI/commit/288270661431f4abda0280acc7f3480d84d0e6a2)
- #6520 - remove blurring on dimmer hide. Remove console logs. [`8a1ad49`](https://github.com/fomantic/Fomantic-UI/commit/8a1ad49be101a99987f4818eb4d37f967ccfac11)
- feat(ISSUE_TEMPLATE): create feature request [`4efd13a`](https://github.com/fomantic/Fomantic-UI/commit/4efd13ac6c56a8a6fb5802860294a9364d558817)
- Add styling for clear icon [`a4688f1`](https://github.com/fomantic/Fomantic-UI/commit/a4688f101caa4b0bbdb4bbb02237673f0245aa8d)
- Pressing the ESC key won't close all open modals anymore [`41180a7`](https://github.com/fomantic/Fomantic-UI/commit/41180a760436b2fa93f12b702f8250690298ddd3)
- Rlsnotes [`079dc7d`](https://github.com/fomantic/Fomantic-UI/commit/079dc7d9a7ad92f7eea6f40138bf01315f44696d)
- Fix interval on animation for placeholder [`b308c28`](https://github.com/fomantic/Fomantic-UI/commit/b308c282b741cf4053519b10f70a67ffce79a874)
- docs(contributing): Fixed some typos [`c18f98a`](https://github.com/fomantic/Fomantic-UI/commit/c18f98a5ccfec1d0501597cdcee9a29efac6a9a4)
- refactor: rearranged headers [`5d7a46d`](https://github.com/fomantic/Fomantic-UI/commit/5d7a46d0760222a981243d3f577cc8d079716ed6)
- Final release notes [`df1681c`](https://github.com/fomantic/Fomantic-UI/commit/df1681c688f515a743cddbc7065ee86472fa4d3d)
- Small fixes [`5f64787`](https://github.com/fomantic/Fomantic-UI/commit/5f64787ce4875b517cce764d771f1c713b6acf55)
- feat(ISSUE_TEMPLATE): create help wanted template [`dbfb347`](https://github.com/fomantic/Fomantic-UI/commit/dbfb347d931dd8d3bc797ff714f9745b802f443d)
- Rlsnote editing [`bf7e06f`](https://github.com/fomantic/Fomantic-UI/commit/bf7e06f2d838dd8c1b36bd53bf8053f3b21df491)
- chore: 2.6 build [`7bb54c3`](https://github.com/fomantic/Fomantic-UI/commit/7bb54c329a97bf5f69c14ad90d036f5efacb2b24)
- #6218 - Allow popup to use settings.closable without onclick [`06f2213`](https://github.com/fomantic/Fomantic-UI/commit/06f2213d4cff0e3d4396f31892a0b98b0b62e165)
- chore: 2.6 build [`e764530`](https://github.com/fomantic/Fomantic-UI/commit/e764530f0cb49c92e8b16a617cf1c1da0ec2366c)
- Force auto width/height for content loaders [`bd47451`](https://github.com/fomantic/Fomantic-UI/commit/bd47451f254ec84f3c89f18f21357a36c0d72c5b)
- Fix Multimonth display. table does not need/support to have semantic amount of column names to be specified [`3f98521`](https://github.com/fomantic/Fomantic-UI/commit/3f9852142e61ef1f051ce1411c12d74803dda4e8)
- chore: update release notes [`7e2f143`](https://github.com/fomantic/Fomantic-UI/commit/7e2f14359feb9a14b8df32d4dca4ebb6361ed1fd)
- Fix dropdown opening leftward inside menu [`56366b9`](https://github.com/fomantic/Fomantic-UI/commit/56366b96d31af4253eb8c4bfc37b6f2b376cec65)
- fix: add placeholder to tasks [`93c054c`](https://github.com/fomantic/Fomantic-UI/commit/93c054cccefb656265ebf543dea3b89c265d843a)
- style: fix $title typo [`4199d85`](https://github.com/fomantic/Fomantic-UI/commit/4199d850b9bb3f10fa7d3dd3cffb79bc8db0adad)
- feat: add note about version jump [`2da5b24`](https://github.com/fomantic/Fomantic-UI/commit/2da5b243885042b81077b992b468ec7b8c025fa1)
- fix: version number [`19fc86a`](https://github.com/fomantic/Fomantic-UI/commit/19fc86a9ce07145c9142a2bfa838cfa2e67b0155)
- chore: update version [`37d155f`](https://github.com/fomantic/Fomantic-UI/commit/37d155f317f16c838ab2df9d30f62074d130ae5d)
- Update README.md [`0c96ad3`](https://github.com/fomantic/Fomantic-UI/commit/0c96ad36aee30930fdffe4a6a4852a8d162e2e52)
- Fix component order [`e7e1c68`](https://github.com/fomantic/Fomantic-UI/commit/e7e1c6815aa1a7acfae31c9c7306b0efd006e674)
- #6363 Fixes IE11 placeholder color [`b81abbd`](https://github.com/fomantic/Fomantic-UI/commit/b81abbdf01f2a72718683c3c5f18d281bde2763e)
- feat(PULL_REQUEST_TEMP): add screenshot section [`9875ef8`](https://github.com/fomantic/Fomantic-UI/commit/9875ef80ab8d5fb4ac4ae18987c30c189097309f)
- docs: remove trello link [`c2f61d7`](https://github.com/fomantic/Fomantic-UI/commit/c2f61d7ff397454bb5b2fc3eb5745b69b3f4a0f3)
- Fix alias for disk outline icon #6556 [`39a4348`](https://github.com/fomantic/Fomantic-UI/commit/39a4348d541ec6060d07bc72ae58a03c7d5999db)
- Rlsnotes #6449 #6495 [`3b452ee`](https://github.com/fomantic/Fomantic-UI/commit/3b452eebc111e71b014e507d0043e191c6ab128d)
- Release notes [`bed86ba`](https://github.com/fomantic/Fomantic-UI/commit/bed86bad9a4c387421fb9cd6900451d9d8cd82a7)
- Set dimmer variation at run-time [`b4861d1`](https://github.com/fomantic/Fomantic-UI/commit/b4861d1e492d9b1f7cba61cb7a16575a6ab8adb5)
- fix(Modal): fix multiple modal display issue [`c2526c7`](https://github.com/fomantic/Fomantic-UI/commit/c2526c7438105dd87d9679ef5bb95a594f1bee19)
- Fix for UI image in placeholder segment [`0e80d09`](https://github.com/fomantic/Fomantic-UI/commit/0e80d097d78d1799bad42bb4914ce49c924faba6)
- Thanks #6531 [`14dc917`](https://github.com/fomantic/Fomantic-UI/commit/14dc9179c15b390fcd3644d0a6d68341565c0191)
- #6531 - Add UK alias for united kingdom [`1626dc1`](https://github.com/fomantic/Fomantic-UI/commit/1626dc1a0808e72661ec863382ef9fffa8e8f645)
- hex case for disk #6556 [`4326ad8`](https://github.com/fomantic/Fomantic-UI/commit/4326ad8a060008207acfce1af0af4a507dd58157)
- Work on release notes [`4944e52`](https://github.com/fomantic/Fomantic-UI/commit/4944e523672056d64b9bdc964f4775f4874e506f)
- Slightly modify inline dropdown icon right margin [`824fc8e`](https://github.com/fomantic/Fomantic-UI/commit/824fc8ed1a4d88523d90d91c007f083e117fc27c)
- Fix list issue where table-cell on content would cause content to collapse inappropriately [`6f2e1a8`](https://github.com/fomantic/Fomantic-UI/commit/6f2e1a85a07c198d13866dd1135677aa64583d07)
- Disable clearable by default [`e468419`](https://github.com/fomantic/Fomantic-UI/commit/e468419074f8c7f21ae9b2aa1c90494b22149d4a)
- [Menu] Fix the inconsistent icon-text spacing in labeled icon menu dropdown [`47406ec`](https://github.com/fomantic/Fomantic-UI/commit/47406ecdc8852dab2d34cf3615c71d220f6cc3ad)
- chore: update release notes [`1beeae0`](https://github.com/fomantic/Fomantic-UI/commit/1beeae01ee2eb4e86e623592b324df6c556e73b1)
- Update README.md [`c4e307c`](https://github.com/fomantic/Fomantic-UI/commit/c4e307c6c1a0b8c10f71b3c1b923d5e05253030c)
- Tick version [`564d28b`](https://github.com/fomantic/Fomantic-UI/commit/564d28bb16e508b5bf3876fabf381964cfa1b7d4)
- Remove dupe in theme.config [`e95f0fb`](https://github.com/fomantic/Fomantic-UI/commit/e95f0fb16641fad5b37dc832f3fc14506762ec9a)
- Add placeholder to example config [`36f6e93`](https://github.com/fomantic/Fomantic-UI/commit/36f6e93d9ae7e7c0f769a9b57882ed4d0f1a9360)
- Remove comment [`0c61a7e`](https://github.com/fomantic/Fomantic-UI/commit/0c61a7e72c61751a97bc694f47e1f920e386329b)

#### [2.5.0](https://github.com/fomantic/Fomantic-UI/compare/2.4.4...2.5.0)

> 3 September 2018

- 2.5 Release [`#101`](https://github.com/fomantic/Fomantic-UI/pull/101)
- [Icons] Add new icons from FA 5.3 [`#100`](https://github.com/fomantic/Fomantic-UI/pull/100)
- Implements dropdown different sizes (standalone and in forms) [`#57`](https://github.com/fomantic/Fomantic-UI/pull/57)
- [Grid] Add `compact` and `very compact` variations [`#99`](https://github.com/fomantic/Fomantic-UI/pull/99)
- [Card] Add `inverted` variation [`#98`](https://github.com/fomantic/Fomantic-UI/pull/98)
- [Cards] add horizontal variation [`#94`](https://github.com/fomantic/Fomantic-UI/pull/94)
- [Dependency] Fix compatibility issue with less &gt;= 3.5 due to math changes [`#97`](https://github.com/fomantic/Fomantic-UI/pull/97)
- [Dropdown] Add ability to clear multiple selection dropdowns [`#95`](https://github.com/fomantic/Fomantic-UI/pull/95)
- [Checkbox] Implements inverted mode for standalone checkboxes [`#65`](https://github.com/fomantic/Fomantic-UI/pull/65)
- Range slider component [`#78`](https://github.com/fomantic/Fomantic-UI/pull/78)
- [Step] Add `inverted` variation [`#93`](https://github.com/fomantic/Fomantic-UI/pull/93)
- [Step] Fix the bad step count in a segment [`#92`](https://github.com/fomantic/Fomantic-UI/pull/92)
- [Form] Added a transparent textarea option [`#91`](https://github.com/fomantic/Fomantic-UI/pull/91)
- fix(accordion): Invert active condition [`#90`](https://github.com/fomantic/Fomantic-UI/pull/90)
- [Feed] Add `inverted` variation [`#89`](https://github.com/fomantic/Fomantic-UI/pull/89)
- [Comment] Add `inverted` variation [`#88`](https://github.com/fomantic/Fomantic-UI/pull/88)
- [Checkbox] toggle don't have the "checked" class when initialized in a 'checked' state [`#85`](https://github.com/fomantic/Fomantic-UI/pull/85)
- [Build Tools] changed from SUI repo to FUI [`#86`](https://github.com/fomantic/Fomantic-UI/pull/86)
- [Flag] added uk as gb flag alias [`#87`](https://github.com/fomantic/Fomantic-UI/pull/87)
-  [Tab] Allow centered tab menu  [`#45`](https://github.com/fomantic/Fomantic-UI/pull/45)
- [Search] set value inside onSelect callback [`#83`](https://github.com/fomantic/Fomantic-UI/pull/83)
- Calendar [`#71`](https://github.com/fomantic/Fomantic-UI/pull/71)
- Updated icons to FontAwesome 5.2.0 [`#79`](https://github.com/fomantic/Fomantic-UI/pull/79)
- [Label] fixed incorrect label background color [`#81`](https://github.com/fomantic/Fomantic-UI/pull/81)
- [Loader] Add color variants [`#80`](https://github.com/fomantic/Fomantic-UI/pull/80)
- [Search] added ability to disable link action [`#82`](https://github.com/fomantic/Fomantic-UI/pull/82)
- Changed to fui repo [`#84`](https://github.com/fomantic/Fomantic-UI/issues/84)
- feat(loader): add colored loader variants [`#73`](https://github.com/fomantic/Fomantic-UI/issues/73)
- chore: 2.5 build [`298bd06`](https://github.com/fomantic/Fomantic-UI/commit/298bd061dffe0360947aca5499cef958c4a80273)
- Added range component [`c04e273`](https://github.com/fomantic/Fomantic-UI/commit/c04e273658033205d49b97c231ed912eeae04f1d)
- feat(docs): added profile links to contributors [`9973de0`](https://github.com/fomantic/Fomantic-UI/commit/9973de04a05eb254c7df381bdca66aaee3a65c6e)
- feat(icons): add new icons [`2aaf0db`](https://github.com/fomantic/Fomantic-UI/commit/2aaf0db9207aeece5f32c46aef9bead91fc33e93)
- chore(docs): made release dates consistent [`c1a1371`](https://github.com/fomantic/Fomantic-UI/commit/c1a13712107bc839a3952f281c7294676930d04e)
- fix(less): Use string escaping (e) and string formatting (%) functions for calc [`463f063`](https://github.com/fomantic/Fomantic-UI/commit/463f0636ff97c33e8163eadb28cd3fb25e36a710)
- fix(label): incorrect ribbon background on some labels [`a1aa3ba`](https://github.com/fomantic/Fomantic-UI/commit/a1aa3baecde436f1f8b77a60a3ddcffa704d9a84)
- refactor: update to fomantic org [`ec2d6d4`](https://github.com/fomantic/Fomantic-UI/commit/ec2d6d462072092e2fe5a824143291e92acc25f0)
- Finish adding useFlex setting for dimmer/modal [`e609212`](https://github.com/fomantic/Fomantic-UI/commit/e60921288810a60870f0676b9e65e8e4e06d9576)
- Add sized buttons group coupled dropdowns [`ffb826f`](https://github.com/fomantic/Fomantic-UI/commit/ffb826f1429c547aeabe7de28491e804bd18f248)
- Tweaking some mouse events [`4d1c0dd`](https://github.com/fomantic/Fomantic-UI/commit/4d1c0dd142d443c1ee7e31624854f41aec274513)
- Add sized menu coupled dropdowns [`ecf9cfd`](https://github.com/fomantic/Fomantic-UI/commit/ecf9cfdfb2d345728ca2b8fc5fde951419cd3b9f)
- Working on legacy setting for modals [`9707e40`](https://github.com/fomantic/Fomantic-UI/commit/9707e40448212aa24ed74a58b838c14dceca4120)
- Finish adding legacy settings [`fa55d1f`](https://github.com/fomantic/Fomantic-UI/commit/fa55d1f1081bc499dec9ceba39da8a5c931c6949)
- feat(cards): add horizontal variation [`60f10d5`](https://github.com/fomantic/Fomantic-UI/commit/60f10d5aa990e5eaeddfe18875aad41b0d89fa63)
- feat(search): add ability to disable link action [`5260a86`](https://github.com/fomantic/Fomantic-UI/commit/5260a86a909844283a7b4c048bc1d220bc3c0032)
- feat(menu): Add center modifier for menu [`272827f`](https://github.com/fomantic/Fomantic-UI/commit/272827fb3cff8e84116048f3f3888a011a3a8816)
- Created faq [`42137d0`](https://github.com/fomantic/Fomantic-UI/commit/42137d064f85618cf7e27a285d2afdd9b96cbc95)
- Added new 2.5 changes [`2ee4983`](https://github.com/fomantic/Fomantic-UI/commit/2ee4983bc299f241ef66fe895b69c8faadd113a7)
- Remove weird colored css rules (seem to be useless) [`07d119b`](https://github.com/fomantic/Fomantic-UI/commit/07d119b7c546be40a53f146727924ae8ae05422a)
- Add ability to clear multiple selection dropdowns [`ccc99e1`](https://github.com/fomantic/Fomantic-UI/commit/ccc99e1aab32ee65d9a5761b8cf0fcee55e3b143)
- Added a transparent textarea options on forms [`ebeee9e`](https://github.com/fomantic/Fomantic-UI/commit/ebeee9e6e823693cc746606b7f09c8e7c6d8da02)
- fix(checkbox): Set checked style class correctly on initial load [`85df5f6`](https://github.com/fomantic/Fomantic-UI/commit/85df5f6a448927ee4bd36c1d0bd06e611fc714a6)
- chore(docs): update release notes [`92f0c3e`](https://github.com/fomantic/Fomantic-UI/commit/92f0c3ee06dd8304b8dd00f452b185d255a0930f)
- Added new horizontal variables [`66baabf`](https://github.com/fomantic/Fomantic-UI/commit/66baabf31278e5ce412a2f2f0f0d57dd6773943b)
- Added header comment [`704b1e1`](https://github.com/fomantic/Fomantic-UI/commit/704b1e168f784deb40dcad92573af60c18d5c34c)
- fix(search): set value inside onSelect callback [`d24d070`](https://github.com/fomantic/Fomantic-UI/commit/d24d070a07a032b86bf1c9bec05a05d81d362c3b)
- Added shields [`a2b6251`](https://github.com/fomantic/Fomantic-UI/commit/a2b6251677f4f21244fa08b3350f9714c51bc4a2)
- Respect useFlex settinng if its a boolean [`cddcc36`](https://github.com/fomantic/Fomantic-UI/commit/cddcc364c35c4d66f5e8e7a299562b68af1ea803)
- Added release note [`f4e1073`](https://github.com/fomantic/Fomantic-UI/commit/f4e1073166cd1c14410a30c85d260bebfdc9ca27)
- chore: update version [`05e7c16`](https://github.com/fomantic/Fomantic-UI/commit/05e7c165bf5c36bbbbce5e860caa7a8984cf9a11)
- Added new horizontal variables [`3145ca5`](https://github.com/fomantic/Fomantic-UI/commit/3145ca56767f9dfa96af7dc73b12b85866329c77)
- fix(cards): add border radius to left side [`e277095`](https://github.com/fomantic/Fomantic-UI/commit/e2770950ad7038a14ba5e1dfa315622169a82c79)
- chore: update release date [`dfeb03e`](https://github.com/fomantic/Fomantic-UI/commit/dfeb03e48c5418bcbe4ca7e922b7d7e124188a38)
- chore: update release notes [`435171b`](https://github.com/fomantic/Fomantic-UI/commit/435171b7302cab9227a72724a9ac08dc3c596f0b)
- chore: updated release notes [`5ac3071`](https://github.com/fomantic/Fomantic-UI/commit/5ac3071529f6ca1bc58e4c4a2122154c7f34ba1a)
- chore: update release notes [`cc278af`](https://github.com/fomantic/Fomantic-UI/commit/cc278aff928b193ce916439511dfa54f2c6eea89)
- chore: update release notes [`8845691`](https://github.com/fomantic/Fomantic-UI/commit/8845691f762976b85f21d6a65d0e32be5eeb7593)
- chore: release notes [`473ebf0`](https://github.com/fomantic/Fomantic-UI/commit/473ebf04ef80e534d198a03ab168ba4e201b2927)
- chore: release notes [`9ac429d`](https://github.com/fomantic/Fomantic-UI/commit/9ac429dd5353bb4407ab780edebc801ac59fd06b)
- docs: updated release notes [`4ff83d9`](https://github.com/fomantic/Fomantic-UI/commit/4ff83d947061b5feb847f3cb209271c64bcc7c47)
- chore(docs): updated release notes [`b9c559a`](https://github.com/fomantic/Fomantic-UI/commit/b9c559a9c318b52e3c5bc04f0476a1d92e88fab4)
- Updated release notes [`6ccbfdb`](https://github.com/fomantic/Fomantic-UI/commit/6ccbfdbc42d14149e91ea364a65c9ac5b1664080)
- Updated release notes [`8f081c1`](https://github.com/fomantic/Fomantic-UI/commit/8f081c1c68cba829fa8d32966a47cf5450d8fb7f)
- Update flag.overrides [`dfbdd97`](https://github.com/fomantic/Fomantic-UI/commit/dfbdd9720f29065c8c351fd87a2e581626145861)
- Add the calendar variable to the config file [`96e2e5e`](https://github.com/fomantic/Fomantic-UI/commit/96e2e5eed6cbcdaafa0a348bb184f267a6449675)
- Added range component to theme.config.example [`c671f21`](https://github.com/fomantic/Fomantic-UI/commit/c671f21c789ddcda2ae3c5657fdd7414eddb3333)

#### [2.4.4](https://github.com/fomantic/Fomantic-UI/compare/2.4.3...2.4.4)

> 26 July 2018

- 2.4.4 Release [`#77`](https://github.com/fomantic/Fomantic-UI/pull/77)
- Disabled rating [`#76`](https://github.com/fomantic/Fomantic-UI/pull/76)
- Fixed textarea having wrong font family [`#75`](https://github.com/fomantic/Fomantic-UI/pull/75)
- Fix incorrect top attached header top margin [`#74`](https://github.com/fomantic/Fomantic-UI/pull/74)
- [Loader] Added loader speed variants [`#72`](https://github.com/fomantic/Fomantic-UI/pull/72)
- Fix the dropdown pointer that still remains after dropdown menu is collapsed [`#70`](https://github.com/fomantic/Fomantic-UI/pull/70)
- Fix for icon group inside button missing margin [`#68`](https://github.com/fomantic/Fomantic-UI/pull/68)
- Fix for bad positionned icon group in a menu item [`#69`](https://github.com/fomantic/Fomantic-UI/pull/69)
- Fix clearable dropdown margin [`#67`](https://github.com/fomantic/Fomantic-UI/pull/67)
- Initial calendar implementation [`d183143`](https://github.com/fomantic/Fomantic-UI/commit/d183143c994bfc0589851dceddc989078859e5f8)
- 2.4.4 build [`4a6674f`](https://github.com/fomantic/Fomantic-UI/commit/4a6674f5584e5a7374031d8c3816714c0e029fe6)
- Implements inverted mode for standalone checkboxes [`1c80396`](https://github.com/fomantic/Fomantic-UI/commit/1c80396dd2f705e1963930e56aa92afee3472091)
- Fixed scrolling for mobile devices while using dimmer [`e49faf0`](https://github.com/fomantic/Fomantic-UI/commit/e49faf0c01dd1f19017edcfae8bae139fa5413f2)
- Fix incorrect attached top header top margin [`aa2591f`](https://github.com/fomantic/Fomantic-UI/commit/aa2591f44edf5ff9a30aaeac5f84cff5c8a4f50d)
- Added release notes [`67792aa`](https://github.com/fomantic/Fomantic-UI/commit/67792aa1fea2ce7c620e73d00184cf4eb5adf670)
- Added loader speed variants [`c01a285`](https://github.com/fomantic/Fomantic-UI/commit/c01a28597f15bfcabf65b29c73aa82fbc994aca9)
- Add disabled class and logic [`6ee88eb`](https://github.com/fomantic/Fomantic-UI/commit/6ee88ebf49163c66f2a2120a1614bee5be93925f)
- Bumped version [`661f24e`](https://github.com/fomantic/Fomantic-UI/commit/661f24eb96835bcb79e36861e49aa5685f436ad7)
- Fix the bad text margin when selected item text is very long [`c1407c3`](https://github.com/fomantic/Fomantic-UI/commit/c1407c3f74f95983449a0707fbc0c1f9e324b0af)
- Update release notes [`3c5de03`](https://github.com/fomantic/Fomantic-UI/commit/3c5de0305e96fbc9899c0a8345253d96c4cf7a5e)
- Fix icons position in a menu item when there's a group icon [`6ff8452`](https://github.com/fomantic/Fomantic-UI/commit/6ff84525fd673dd69c8469c2cafa406ed06d2937)
- Fix right margin inside button when there's an icon group [`342d7f9`](https://github.com/fomantic/Fomantic-UI/commit/342d7f9aef4dd4c19c957730c9ec5497adcec3dc)
- Add a line in the release notes [`ac2e335`](https://github.com/fomantic/Fomantic-UI/commit/ac2e3358600b4f8017a29ae46c146871c271b5fd)

#### [2.4.3](https://github.com/fomantic/Fomantic-UI/compare/2.4.2...2.4.3)

> 9 July 2018

- 2.4.3 Release [`#63`](https://github.com/fomantic/Fomantic-UI/pull/63)
- [Docs] build error on new node version [`#61`](https://github.com/fomantic/Fomantic-UI/pull/61)
- [Button] tertiary buttons have @basicDownBackground when :active [`#62`](https://github.com/fomantic/Fomantic-UI/pull/62)
- Invalid inverted message [`#58`](https://github.com/fomantic/Fomantic-UI/pull/58)
- Fixes #60 [`#60`](https://github.com/fomantic/Fomantic-UI/issues/60)
- Fixes #54 [`#54`](https://github.com/fomantic/Fomantic-UI/issues/54)
- Build 2.3.3 [`09e2ccd`](https://github.com/fomantic/Fomantic-UI/commit/09e2ccd59d9407055f78e78d53fca7d71cbc6e1e)
- 2.4.3 Build [`650b6ff`](https://github.com/fomantic/Fomantic-UI/commit/650b6ffb68db668a701547eed635c84939e6ea55)
- Implements dropdown different sizes (standalone and in forms) [`43e56f6`](https://github.com/fomantic/Fomantic-UI/commit/43e56f6d7b02d280f8851bdccfdf729441604c72)
- #6428 Deprecate several icons using in and out class [`ef77e8d`](https://github.com/fomantic/Fomantic-UI/commit/ef77e8dafa5065fbcdbe9f02898695a2e8ff5274)
- Build 2.3.3 [`ef8bc2e`](https://github.com/fomantic/Fomantic-UI/commit/ef8bc2e2ca10f97e3188c90e135a846aa33915ae)
- Move deprecated icons before normal rules to prevent improper inheritance [`403a377`](https://github.com/fomantic/Fomantic-UI/commit/403a37799030c246db46aa45302f0c915c17b610)
- 2.4.3 release notes [`765bde7`](https://github.com/fomantic/Fomantic-UI/commit/765bde7f02752187c25d11591378760fa19255f1)
- Sign in/out alternate are actually duplicates [`363f283`](https://github.com/fomantic/Fomantic-UI/commit/363f283915619170366e41ad6dad70e1fce5fee2)
- Bumped version [`aaa7e44`](https://github.com/fomantic/Fomantic-UI/commit/aaa7e44aa4d487067c6e3bb7fbe3b8474294c89d)
- Add rlsnote date [`146d960`](https://github.com/fomantic/Fomantic-UI/commit/146d960a249d43d68ce78dffb3e1abf3b00b1f1d)
- Fix api settings to pull cache from cache settings by default [`b45aafd`](https://github.com/fomantic/Fomantic-UI/commit/b45aafd441793361eafcc4e5a0461b54a56722b6)
- Version tick [`6a0e2f6`](https://github.com/fomantic/Fomantic-UI/commit/6a0e2f612f1415d30d7ee4cdaf6fddc1cd51ab67)
- Added .inverted to inverted message class [`7f095e7`](https://github.com/fomantic/Fomantic-UI/commit/7f095e72787c75b7c8956936532959fee5528acf)

#### [2.4.2](https://github.com/fomantic/Fomantic-UI/compare/2.4.1...2.4.2)

> 4 July 2018

- 2.4.2 Release [`#56`](https://github.com/fomantic/Fomantic-UI/pull/56)
- 2.4.2 Release [`#55`](https://github.com/fomantic/Fomantic-UI/pull/55)
- [Dropdown] Add clear icon in single selection mode [`#46`](https://github.com/fomantic/Fomantic-UI/pull/46)
- [Dropdown] Fix searchable dropdown that doesn't get focus on show [`#39`](https://github.com/fomantic/Fomantic-UI/pull/39)
- [Modal] Fullscreen Modals since 2.3.0 regression in Safari [`#50`](https://github.com/fomantic/Fomantic-UI/pull/50)
- [Dropdown] Clean select mutation code [`#44`](https://github.com/fomantic/Fomantic-UI/pull/44)
- [Dropdown] Add possibility to add header items during js initialization [`#43`](https://github.com/fomantic/Fomantic-UI/pull/43)
- [Search] Add setting for error header in search results (Fix #6442) [`#41`](https://github.com/fomantic/Fomantic-UI/pull/41)
- [Modal] Revert "Add solve for dimmer to prevent modal scrolling in bg" [`#42`](https://github.com/fomantic/Fomantic-UI/pull/42)
- [Modal] In Chrome, Modals close on Mouse up outside the Modal [`#47`](https://github.com/fomantic/Fomantic-UI/pull/47)
-  [Tab] Last tab should still have a bottom margin [`#48`](https://github.com/fomantic/Fomantic-UI/pull/48)
- [Icon] Allow both rotated and flipped icons [`#49`](https://github.com/fomantic/Fomantic-UI/pull/49)
- [Label] :ActiveHover is not a valid selector error #5908 [`#51`](https://github.com/fomantic/Fomantic-UI/pull/51)
- [Dependency] Add compatibility with Less 3.x #6447  [`#52`](https://github.com/fomantic/Fomantic-UI/pull/52)
- Next to beta [`#53`](https://github.com/fomantic/Fomantic-UI/pull/53)
- [Dependency] Add compatibility with Less 3.x [`#6447`](https://github.com/fomantic/Fomantic-UI/pull/6447)
- Merge pull request #41 from prudho/next [`#6442`](https://github.com/fomantic/Fomantic-UI/issues/6442)
- Fix #6442 [`#6442`](https://github.com/fomantic/Fomantic-UI/issues/6442)
- 2.4.2 Build [`b1a661e`](https://github.com/fomantic/Fomantic-UI/commit/b1a661e3fc65a2f5f383c40c778b33ad1c89e7a3)
- feat(icon): Add halfway rotated and both flipped/rotated icon variations [`edfee96`](https://github.com/fomantic/Fomantic-UI/commit/edfee96cf04d620d1c9409955359ee1258883eae)
- fix(modal): Split click event listener into mousedown / up [`fecb698`](https://github.com/fomantic/Fomantic-UI/commit/fecb698f81961315c8785d8162d9d4322fcc45b3)
- Added 2.4.2 release notes [`8344333`](https://github.com/fomantic/Fomantic-UI/commit/834433349f781c127a4305f2a27744cc6bcab833)
- Update CONTRIBUTING.md [`5eb20d6`](https://github.com/fomantic/Fomantic-UI/commit/5eb20d649a38668777069c5cee92236d17be16b9)
- Clean dropdown mutation code [`eae5001`](https://github.com/fomantic/Fomantic-UI/commit/eae5001ea2a65adb076749019334d2965e487f1c)
- revert: "Add solve for dimmer to prevent modal scrolling in bg" [`96e8747`](https://github.com/fomantic/Fomantic-UI/commit/96e8747a855bc65a0eb52eeb1cbf2565361ff4ce)
- [Tab] Allow centered tab menu [`583989d`](https://github.com/fomantic/Fomantic-UI/commit/583989ddf6ca37dc824108ab4ac58ca2e05579a9)
- Fix searchable dropdown that doesn't get focus on show [`d948892`](https://github.com/fomantic/Fomantic-UI/commit/d948892b9751729ed97f60525b3aa739ac57dd40)
- Revert "Fix searchable dropdown that doesn't get focus on show" [`b460ba9`](https://github.com/fomantic/Fomantic-UI/commit/b460ba9e7bebc86be9762f8d8ac4ad67827f745a)
- Add compatibility with Less 3.x [`1ec2d04`](https://github.com/fomantic/Fomantic-UI/commit/1ec2d04b79136ddff854b84e30f4f7689645679d)
- Fix searchable dropdown that doesn't get focus on show [`dff098f`](https://github.com/fomantic/Fomantic-UI/commit/dff098f8cd4532f33ee106616f045851a2f05df0)
- Add compatibility with Less 3.x [`9226167`](https://github.com/fomantic/Fomantic-UI/commit/92261675c25bfce8b1cf96aa5d70f6b07d2b93a6)
- Bumped version [`ddec4ca`](https://github.com/fomantic/Fomantic-UI/commit/ddec4ca81556e8f69b6a4b6089a54094bef1210f)
- fix(label): Replace :ActiveHover with :hover [`1d8d82d`](https://github.com/fomantic/Fomantic-UI/commit/1d8d82dc72e54f5fc6561dcfc1fe4de55de3306f)
- fix(tab/segment): Add margin-bottom to last tab segment [`530b7b4`](https://github.com/fomantic/Fomantic-UI/commit/530b7b44dce186c0bfdb43d5bdc26a70a9f675dd)
- Fixes the ugly secondary tabular centered menu [`cc8d5cf`](https://github.com/fomantic/Fomantic-UI/commit/cc8d5cf720872007041cd56d14eac80f2609e2d5)
- Updated next branch to beta [`0be37db`](https://github.com/fomantic/Fomantic-UI/commit/0be37db5d4bbede6ac0353b9ff74f447bf0f085e)
- fix(modal): Set position of modal element to relative [`446ea69`](https://github.com/fomantic/Fomantic-UI/commit/446ea69070a528667172ebae571e596f02b5c961)

#### [2.4.1](https://github.com/fomantic/Fomantic-UI/compare/2.4.0...2.4.1)

> 20 June 2018

- 2.4.1 hotfix [`#37`](https://github.com/fomantic/Fomantic-UI/pull/37)
- 2.4.1 Build [`daeaa7a`](https://github.com/fomantic/Fomantic-UI/commit/daeaa7a86f095f20fe8aba174b3657c2f4e05d18)
- perf(dropdown): Update divider selector [`9b598cb`](https://github.com/fomantic/Fomantic-UI/commit/9b598cb1df24aa617a0c20cf40affc71e5787118)
- perf(dropdown): Only select dividers if hideDividers option is true [`9b4e30f`](https://github.com/fomantic/Fomantic-UI/commit/9b4e30fb0bd08616a9b548f085b7bbfcc09d61a9)
- 2.4.1 Release notes [`6c13e54`](https://github.com/fomantic/Fomantic-UI/commit/6c13e543a4849901c3afe91a00bba908d59a0386)
- Added mentions [`baa852f`](https://github.com/fomantic/Fomantic-UI/commit/baa852fc08af3b61cd9c74789c3957febc76bf56)
- Bumped version [`8f87c09`](https://github.com/fomantic/Fomantic-UI/commit/8f87c09296447e4af3ba12dafe19f9f01ee1c452)
- fix(list): Typo in selection list item:hover selector [`80730e0`](https://github.com/fomantic/Fomantic-UI/commit/80730e0647032b4636b947b1ee3d701180e52abc)

#### 2.4.0

> 19 June 2018

- 2.4 Release [`#33`](https://github.com/fomantic/Fomantic-UI/pull/33)
- 2.4 Release [`#32`](https://github.com/fomantic/Fomantic-UI/pull/32)
- Fixed some formatting [`#6396`](https://github.com/fomantic/Fomantic-UI/pull/6396)
- Fix #6429: [Icon] Wechat icon doesn't display [`#6431`](https://github.com/fomantic/Fomantic-UI/pull/6431)
- [Site] fix @inputLineHeight comment spelling error [`#6405`](https://github.com/fomantic/Fomantic-UI/pull/6405)
- [Label] Use basicBackground in all basic rules [`#6220`](https://github.com/fomantic/Fomantic-UI/pull/6220)
- Dimmer build [`#15`](https://github.com/fomantic/Fomantic-UI/pull/15)
- 2.3.2 Update [`#14`](https://github.com/fomantic/Fomantic-UI/pull/14)
- Update package.json & package-lock.json [`#6`](https://github.com/fomantic/Fomantic-UI/pull/6)
- Updated package.json & package-lock.json [`#5`](https://github.com/fomantic/Fomantic-UI/pull/5)
- Update to new logos [`#4`](https://github.com/fomantic/Fomantic-UI/pull/4)
- Added fomantic logos [`#3`](https://github.com/fomantic/Fomantic-UI/pull/3)
- Update to fomantic [`#2`](https://github.com/fomantic/Fomantic-UI/pull/2)
- Fomantic convert [`#1`](https://github.com/fomantic/Fomantic-UI/pull/1)
- [Menu] Disabled menu items still changing state on hover [`#6268`](https://github.com/fomantic/Fomantic-UI/pull/6268)
- [Search] add disabled style [`#6225`](https://github.com/fomantic/Fomantic-UI/pull/6225)
- Fix for #4183 [`#4510`](https://github.com/fomantic/Fomantic-UI/pull/4510)
- Fix #3486: [Search] add exactResults on duplicate check [`#6223`](https://github.com/fomantic/Fomantic-UI/pull/6223)
- Created issue template [`#6205`](https://github.com/fomantic/Fomantic-UI/pull/6205)
- Fixed the icon bugs raised in the issues [`#6181`](https://github.com/fomantic/Fomantic-UI/pull/6181)
- Setup stalebot for stale issue management [`#6182`](https://github.com/fomantic/Fomantic-UI/pull/6182)
- Added onChanging callback to accordion [`#5892`](https://github.com/fomantic/Fomantic-UI/pull/5892)
- [Icon Input] Fix for issue #4057 [`#4157`](https://github.com/fomantic/Fomantic-UI/pull/4157)
- [Modal] Support modification of 'closable' setting while modal is open [`#3396`](https://github.com/fomantic/Fomantic-UI/pull/3396)
- Fix inverted dimmer text color [`#4631`](https://github.com/fomantic/Fomantic-UI/pull/4631)
- Revert "'on: change' causes error prompts to appear when blurring field " [`#6172`](https://github.com/fomantic/Fomantic-UI/pull/6172)
- 'on: change' causes error prompts to appear when blurring field  [`#4423`](https://github.com/fomantic/Fomantic-UI/pull/4423)
- Take content settings before attr title [`#4614`](https://github.com/fomantic/Fomantic-UI/pull/4614)
- Swap huge and big in menu.variables #5899 [`#5902`](https://github.com/fomantic/Fomantic-UI/pull/5902)
- Add font weight global variables [`#6171`](https://github.com/fomantic/Fomantic-UI/pull/6171)
- [Popup] Use @background value for arrow background color [`#6059`](https://github.com/fomantic/Fomantic-UI/pull/6059)
- Cleanup documentation HTML structure [`#6127`](https://github.com/fomantic/Fomantic-UI/pull/6127)
- Add missing comma: makes 9 global vars local [`#6136`](https://github.com/fomantic/Fomantic-UI/pull/6136)
- Centered modal [`#6170`](https://github.com/fomantic/Fomantic-UI/pull/6170)
- Revert "[Dropdown] Allow ignoring of case when getting an item" [`#6121`](https://github.com/fomantic/Fomantic-UI/pull/6121)
- [Dropdown] Allow ignoring of case when getting an item [`#3432`](https://github.com/fomantic/Fomantic-UI/pull/3432)
- [Checkbox] Added `box-shadow` to the checkbox component’s `.toggle` variation [`#5096`](https://github.com/fomantic/Fomantic-UI/pull/5096)
- default 'prompt' message has mistakes in writing [`#5530`](https://github.com/fomantic/Fomantic-UI/pull/5530)
- [Dropdown] The width of inputs that are inside of a dropdown’s `.menu` should never be overridden [`#5097`](https://github.com/fomantic/Fomantic-UI/pull/5097)
- Fix for [Form Validation] regression: get values with radio returns true or false #5713 [`#6043`](https://github.com/fomantic/Fomantic-UI/pull/6043)
- [Flag] Add England Flag and Alias [`#5944`](https://github.com/fomantic/Fomantic-UI/pull/5944)
- Fix horizontal scrollbar height, closes #5728 [`#5749`](https://github.com/fomantic/Fomantic-UI/pull/5749)
- Updated YouTube colour [`#6110`](https://github.com/fomantic/Fomantic-UI/pull/6110)
- [Buttons] fix for active basic button text color always having a lower specificity due to !important [`#5832`](https://github.com/fomantic/Fomantic-UI/pull/5832)
- Add link to webpage at top of README [`#5872`](https://github.com/fomantic/Fomantic-UI/pull/5872)
- Revert "[Build Tools] Default theme folder can be configured" [`#5635`](https://github.com/fomantic/Fomantic-UI/pull/5635)
- [Build Tools] Default theme folder can be configured [`#5543`](https://github.com/fomantic/Fomantic-UI/pull/5543)
- Updated font imports to use HTTPS [`#5602`](https://github.com/fomantic/Fomantic-UI/pull/5602)
- Correct check for undefined variable [`#4544`](https://github.com/fomantic/Fomantic-UI/pull/4544)
- Fix #3439 - Now steps can be .unstackable [`#3714`](https://github.com/fomantic/Fomantic-UI/pull/3714)
- [Docs] #5521 Update the JSFiddle to use HTTPS [`#5522`](https://github.com/fomantic/Fomantic-UI/pull/5522)
- [Table] #5227 Added missing rules for sortable/inverted headers [`#5303`](https://github.com/fomantic/Fomantic-UI/pull/5303)
- [Modal] #4196 Disable refreshing for non active/animated modals [`#5319`](https://github.com/fomantic/Fomantic-UI/pull/5319)
- Update Edge supported versions [`#5400`](https://github.com/fomantic/Fomantic-UI/pull/5400)
- Add missing .woff2 file to material theme [`#5405`](https://github.com/fomantic/Fomantic-UI/pull/5405)
- Added a `.tiny` modal size [`#5123`](https://github.com/fomantic/Fomantic-UI/pull/5123)
- Added 4 positions for corner icons [`#4653`](https://github.com/fomantic/Fomantic-UI/pull/4653)
- Fix typo [`#5228`](https://github.com/fomantic/Fomantic-UI/pull/5228)
- Fixed an issue with child `.card` elements inheriting their parents’ rules [`#5148`](https://github.com/fomantic/Fomantic-UI/pull/5148)
- Switched Project Talk to official forums in *md files [`#5004`](https://github.com/fomantic/Fomantic-UI/pull/5004)
- Fix #3424 [`#4651`](https://github.com/fomantic/Fomantic-UI/pull/4651)
- [Icons] Upgrading to FontAwesome v4.7.0 [`#4766`](https://github.com/fomantic/Fomantic-UI/pull/4766)
- Add CDNJS version badge in README.md [`#4680`](https://github.com/fomantic/Fomantic-UI/pull/4680)
- Fix fg-color on inverted forms in flat theme. [`#4550`](https://github.com/fomantic/Fomantic-UI/pull/4550)
- Added hover styling to icon group [`#4399`](https://github.com/fomantic/Fomantic-UI/pull/4399)
- Update material theme font URLs to be '//' instead of 'http://' [`#4051`](https://github.com/fomantic/Fomantic-UI/pull/4051)
- Sets border-radius when vertical buttons have a single child button [`#4107`](https://github.com/fomantic/Fomantic-UI/pull/4107)
- [Dropdown] Fix issue #4150 [`#4156`](https://github.com/fomantic/Fomantic-UI/pull/4156)
- [Input] ADD the same style for input[type="file"]. [`#4074`](https://github.com/fomantic/Fomantic-UI/pull/4074)
- [Icons] Removed duplicated 'talk' icon with incorrect content [`#4354`](https://github.com/fomantic/Fomantic-UI/pull/4354)
- [Dropdown] Disconnect.selectObserver bugfix [`#4316`](https://github.com/fomantic/Fomantic-UI/pull/4316)
- [Menu] @dividerSize cannot be changed since it is hard coded [`#4136`](https://github.com/fomantic/Fomantic-UI/pull/4136)
- Fix compact form messages [`#4144`](https://github.com/fomantic/Fomantic-UI/pull/4144)
- Update README.md [`#4118`](https://github.com/fomantic/Fomantic-UI/pull/4118)
- Remove duplicate selector [`#4081`](https://github.com/fomantic/Fomantic-UI/pull/4081)
- spelling fixes [`#4067`](https://github.com/fomantic/Fomantic-UI/pull/4067)
- Update Font Awesome item in release notes [`#4048`](https://github.com/fomantic/Fomantic-UI/pull/4048)
- [Card] Added raised style [`#2955`](https://github.com/fomantic/Fomantic-UI/pull/2955)
- [Dropdown] Add exact search - #3085 [`#3994`](https://github.com/fomantic/Fomantic-UI/pull/3994)
- [ref #4004] added inline fields to inverted form styling [`#4005`](https://github.com/fomantic/Fomantic-UI/pull/4005)
- Add a style option [`#3492`](https://github.com/fomantic/Fomantic-UI/pull/3492)
- Correct ProjectTalk Button link in Readme on NPM [`#3978`](https://github.com/fomantic/Fomantic-UI/pull/3978)
- Email fix for #3755 [`#3955`](https://github.com/fomantic/Fomantic-UI/pull/3955)
- let is not supported on Safari [`#3966`](https://github.com/fomantic/Fomantic-UI/pull/3966)
- Fix typo in placeholder styling for the Internet Explorer [`#3940`](https://github.com/fomantic/Fomantic-UI/pull/3940)
- Set Internet Explorer support to 11+ [`#3871`](https://github.com/fomantic/Fomantic-UI/pull/3871)
- Bake 'easeOutQuad' easing function into nag module. [`#3862`](https://github.com/fomantic/Fomantic-UI/pull/3862)
- Fixed punctuation and flow [`#3867`](https://github.com/fomantic/Fomantic-UI/pull/3867)
- Fix typo [`#3829`](https://github.com/fomantic/Fomantic-UI/pull/3829)
- [Icons] Upgrading to FontAwesome v4.5.0 [`#3311`](https://github.com/fomantic/Fomantic-UI/pull/3311)
- fix modal/dimmer inverted bug #3192 [`#3665`](https://github.com/fomantic/Fomantic-UI/pull/3665)
- Non developer readme contribution [`#3693`](https://github.com/fomantic/Fomantic-UI/pull/3693)
- Update README.md [`#1`](https://github.com/fomantic/Fomantic-UI/pull/1)
- #3514: the fix for issue: 'The checking for semantic.json always fail… [`#3515`](https://github.com/fomantic/Fomantic-UI/pull/3515)
- [Flag] Adding Scotland and Wales [`#3494`](https://github.com/fomantic/Fomantic-UI/pull/3494)
- Fix for flags with invalid country class [`#3333`](https://github.com/fomantic/Fomantic-UI/pull/3333)
- callback on correct timing [`#3405`](https://github.com/fomantic/Fomantic-UI/pull/3405)
- Fix typo [`#3401`](https://github.com/fomantic/Fomantic-UI/pull/3401)
- Fix for #3212 [`#3213`](https://github.com/fomantic/Fomantic-UI/pull/3213)
- [form] Fix integer validation [`#3053`](https://github.com/fomantic/Fomantic-UI/pull/3053)
- [Search] Fixed fields.url [`#3206`](https://github.com/fomantic/Fomantic-UI/pull/3206)
- Support for dimmer with zero opacity [`#3167`](https://github.com/fomantic/Fomantic-UI/pull/3167)
- Inconsistency with `widescreen only` class [`#3161`](https://github.com/fomantic/Fomantic-UI/pull/3161)
- Call onSearchQuery whether or not results are cached [`#3138`](https://github.com/fomantic/Fomantic-UI/pull/3138)
- Ability to cancel a modal hide from the onHide callback [`#3168`](https://github.com/fomantic/Fomantic-UI/pull/3168)
- Fixed inconsistent use of media query breakpoints [`#3180`](https://github.com/fomantic/Fomantic-UI/pull/3180)
- Update README.md [`#3140`](https://github.com/fomantic/Fomantic-UI/pull/3140)
- Fix Syntax Error in bower.json [`#3114`](https://github.com/fomantic/Fomantic-UI/pull/3114)
- Fix  #2652 [`#3061`](https://github.com/fomantic/Fomantic-UI/pull/3061)
- Revert "[Form] Remove Defunct Fluid Form" [`#3015`](https://github.com/fomantic/Fomantic-UI/pull/3015)
- [Form] Remove Defunct Fluid Form [`#2892`](https://github.com/fomantic/Fomantic-UI/pull/2892)
- Fix Add Errors Should Display Immediately #1172 [`#2887`](https://github.com/fomantic/Fomantic-UI/pull/2887)
- [dropdown] Preserve initial disabled state [`#2983`](https://github.com/fomantic/Fomantic-UI/pull/2983)
- [form] Get value of checkbox if its have [`#2979`](https://github.com/fomantic/Fomantic-UI/pull/2979)
- Typos [`#2984`](https://github.com/fomantic/Fomantic-UI/pull/2984)
- Fixed bad template url [`#2956`](https://github.com/fomantic/Fomantic-UI/pull/2956)
- add form data as onSuccess callback param [`#2944`](https://github.com/fomantic/Fomantic-UI/pull/2944)
- Remove duplicate icon aliases [`#2942`](https://github.com/fomantic/Fomantic-UI/pull/2942)
- Typo in HTML [`#2907`](https://github.com/fomantic/Fomantic-UI/pull/2907)
- [Nag] Fix issue with localstorage and add support for session storage [`#2929`](https://github.com/fomantic/Fomantic-UI/pull/2929)
- Remove old info [`#2927`](https://github.com/fomantic/Fomantic-UI/pull/2927)
- Add colored items on inverted menu. [`#2850`](https://github.com/fomantic/Fomantic-UI/pull/2850)
- Revert "Fix callback return from build task" [`#2840`](https://github.com/fomantic/Fomantic-UI/pull/2840)
- Fix callback return from build task [`#2836`](https://github.com/fomantic/Fomantic-UI/pull/2836)
- add projecttalk to readme [`#2832`](https://github.com/fomantic/Fomantic-UI/pull/2832)
- [Dropdown] Allow `onHide` callbacks to prevent Hiding [`#2769`](https://github.com/fomantic/Fomantic-UI/pull/2769)
- Sticky position fix for fluid menus [`#2710`](https://github.com/fomantic/Fomantic-UI/pull/2710)
- Set API.settings.debug to false as documented [`#2817`](https://github.com/fomantic/Fomantic-UI/pull/2817)
- Update RegExps in packaging for npm. [`#2816`](https://github.com/fomantic/Fomantic-UI/pull/2816)
- add missing @inputWidth var to form.less [`#2783`](https://github.com/fomantic/Fomantic-UI/pull/2783)
- [Popup] Look for inline popup in all siblings of target, not just immediate sibling [`#2772`](https://github.com/fomantic/Fomantic-UI/pull/2772)
- [Flag] Add England Alias [`#2770`](https://github.com/fomantic/Fomantic-UI/pull/2770)
- Add missing background-color variable for tabular menu [`#2734`](https://github.com/fomantic/Fomantic-UI/pull/2734)
- Update homepage.html [`#2728`](https://github.com/fomantic/Fomantic-UI/pull/2728)
- Updated browser prefix config [`#2717`](https://github.com/fomantic/Fomantic-UI/pull/2717)
- fix build/watch for people importing tasks into their own gulpfile [`#2668`](https://github.com/fomantic/Fomantic-UI/pull/2668)
- Properly set the dropdown value when dealing with remote loaded choices [`#2573`](https://github.com/fomantic/Fomantic-UI/pull/2573)
- Fix checkbox label font size variable name [`#2536`](https://github.com/fomantic/Fomantic-UI/pull/2536)
- remove popup position check [`#2519`](https://github.com/fomantic/Fomantic-UI/pull/2519)
- Fixes "SyntaxError: unreachable code after return statement" [`#2492`](https://github.com/fomantic/Fomantic-UI/pull/2492)
- Allow link underline and hover link underline to differ [`#2416`](https://github.com/fomantic/Fomantic-UI/pull/2416)
- add missing .loadUIOverrides() to definitions/elements/container.less [`#2390`](https://github.com/fomantic/Fomantic-UI/pull/2390)
- Update login.html [`#2369`](https://github.com/fomantic/Fomantic-UI/pull/2369)
- Fixes icon rendering problem in OSX + webkit [`#2347`](https://github.com/fomantic/Fomantic-UI/pull/2347)
- multiple spelling mistakes - second attempt [`#2346`](https://github.com/fomantic/Fomantic-UI/pull/2346)
- two spelling mistakes [`#2341`](https://github.com/fomantic/Fomantic-UI/pull/2341)
- CONTRIBUTING.md for `next` [`#2330`](https://github.com/fomantic/Fomantic-UI/pull/2330)
- fix font format [`#2331`](https://github.com/fomantic/Fomantic-UI/pull/2331)
- Update icon.less [`#2304`](https://github.com/fomantic/Fomantic-UI/pull/2304)
- Update progress.less [`#2305`](https://github.com/fomantic/Fomantic-UI/pull/2305)
- Update RELEASE-NOTES.md [`#2302`](https://github.com/fomantic/Fomantic-UI/pull/2302)
- #2280 Update statistic.less [`#2301`](https://github.com/fomantic/Fomantic-UI/pull/2301)
- bower.json: main: semantic.css =&gt; semantic.less [`#2244`](https://github.com/fomantic/Fomantic-UI/pull/2244)
- Update README.md [`#2237`](https://github.com/fomantic/Fomantic-UI/pull/2237)
- Update CONTRIBUTING.md [`#2238`](https://github.com/fomantic/Fomantic-UI/pull/2238)
- The wrong this [`#2225`](https://github.com/fomantic/Fomantic-UI/pull/2225)
- Make ordered list numbers in an inverted context be visible [`#2210`](https://github.com/fomantic/Fomantic-UI/pull/2210)
- "wrench" depencency as tarball [`#2183`](https://github.com/fomantic/Fomantic-UI/pull/2183)
- Corrected order of operations to enable precision (rounding). [`#2168`](https://github.com/fomantic/Fomantic-UI/pull/2168)
- Update build.js [`#2102`](https://github.com/fomantic/Fomantic-UI/pull/2102)
- Add onOpening callback to Accordion [`#2062`](https://github.com/fomantic/Fomantic-UI/pull/2062)
- add less plugin [`#2049`](https://github.com/fomantic/Fomantic-UI/pull/2049)
- Fix &lt;select&gt; inside form inline field [`#2034`](https://github.com/fomantic/Fomantic-UI/pull/2034)
- Moving required field indicator on grouped fields to group label [`#1989`](https://github.com/fomantic/Fomantic-UI/pull/1989)
- Fixed declared but unused variable [`#1955`](https://github.com/fomantic/Fomantic-UI/pull/1955)
- Fixed links in README.md [`#1944`](https://github.com/fomantic/Fomantic-UI/pull/1944)
- Fix image deformation when using fluid or size classes [`#1891`](https://github.com/fomantic/Fomantic-UI/pull/1891)
- [Popup] Doesn't remove Window Events on Destroy [`#1896`](https://github.com/fomantic/Fomantic-UI/pull/1896)
- Removed duplicate line [`#1890`](https://github.com/fomantic/Fomantic-UI/pull/1890)
- Treatment for name[] identifier [`#1806`](https://github.com/fomantic/Fomantic-UI/pull/1806)
- Correct IE9 support status [`#1781`](https://github.com/fomantic/Fomantic-UI/pull/1781)
- Update README.md [`#1742`](https://github.com/fomantic/Fomantic-UI/pull/1742)
- Update icons to support Font Awesome 4.3 [`#1729`](https://github.com/fomantic/Fomantic-UI/pull/1729)
- Show filtered menu if search input placed in menu. [`#1632`](https://github.com/fomantic/Fomantic-UI/pull/1632)
- Properly parse RTL question during gulp install [`#1640`](https://github.com/fomantic/Fomantic-UI/pull/1640)
- Update from original [`#1`](https://github.com/fomantic/Fomantic-UI/pull/1)
- Dropdown module (restore) [`#1627`](https://github.com/fomantic/Fomantic-UI/pull/1627)
- Fix i.icon selector with attribute [`#1602`](https://github.com/fomantic/Fomantic-UI/pull/1602)
- Fix relative paths on windows [`#1553`](https://github.com/fomantic/Fomantic-UI/pull/1553)
- Improve configuration comment [`#1500`](https://github.com/fomantic/Fomantic-UI/pull/1500)
- styles for inputs without type attribute [`#1481`](https://github.com/fomantic/Fomantic-UI/pull/1481)
- Switch SASS to Sass. :) [`#1466`](https://github.com/fomantic/Fomantic-UI/pull/1466)
- remove irc channel from readme [`#1443`](https://github.com/fomantic/Fomantic-UI/pull/1443)
- Add Support for &lt;input type="datetime-local"&gt; [`#1398`](https://github.com/fomantic/Fomantic-UI/pull/1398)
- Remove duplicated ignore property in bower.json. [`#1389`](https://github.com/fomantic/Fomantic-UI/pull/1389)
- fix variable Google Fonts Character Subset Param [`#1386`](https://github.com/fomantic/Fomantic-UI/pull/1386)
- Google Fonts Character Subset Param [`#1378`](https://github.com/fomantic/Fomantic-UI/pull/1378)
- Add 'vanilla' distribution section to readme. [`#1356`](https://github.com/fomantic/Fomantic-UI/pull/1356)
- This fixes #1331 [`#1348`](https://github.com/fomantic/Fomantic-UI/pull/1348)
- Fixes double border of pointing menu attached to segment [`#1349`](https://github.com/fomantic/Fomantic-UI/pull/1349)
- fix missing closing td in kitchensink [`#1338`](https://github.com/fomantic/Fomantic-UI/pull/1338)
- Fix typo in css selector for `.vertical.flip.transition.in` [`#1302`](https://github.com/fomantic/Fomantic-UI/pull/1302)
- Typo in Release Notes URL [`#1278`](https://github.com/fomantic/Fomantic-UI/pull/1278)
- fix: the enable/disable method does not act correctly [`#1257`](https://github.com/fomantic/Fomantic-UI/pull/1257)
- misspell in checkbox enable/disable method name [`#1255`](https://github.com/fomantic/Fomantic-UI/pull/1255)
- Fix button font-size units [`#1204`](https://github.com/fomantic/Fomantic-UI/pull/1204)
- Update search to accept a source that is an array. [`#1009`](https://github.com/fomantic/Fomantic-UI/pull/1009)
- Typo in semantic.config.example, css branch [`#912`](https://github.com/fomantic/Fomantic-UI/pull/912)
- fix single celled tfoot [`#696`](https://github.com/fomantic/Fomantic-UI/pull/696)
- RTL hints updates [`#688`](https://github.com/fomantic/Fomantic-UI/pull/688)
- Accessible reveal [`#692`](https://github.com/fomantic/Fomantic-UI/pull/692)
- Add a Bitdeli Badge to README [`#690`](https://github.com/fomantic/Fomantic-UI/pull/690)
- docs: fix broken accordion (form example) [`#666`](https://github.com/fomantic/Fomantic-UI/pull/666)
- Fixes bracket match in rule function [`#658`](https://github.com/fomantic/Fomantic-UI/pull/658)
- Closing a modal throws an error when the transitions module isn't available [`#627`](https://github.com/fomantic/Fomantic-UI/pull/627)
- first pass at generating specs [`#618`](https://github.com/fomantic/Fomantic-UI/pull/618)
- Possibly an old CSS leftover. [`#619`](https://github.com/fomantic/Fomantic-UI/pull/619)
- Very first sentence didn't end in a period! [`#617`](https://github.com/fomantic/Fomantic-UI/pull/617)
- RTL hints [`#598`](https://github.com/fomantic/Fomantic-UI/pull/598)
- Adds ability to change conditionals text [`#601`](https://github.com/fomantic/Fomantic-UI/pull/601)
- Typo: Horizontal items image missing comma [`#592`](https://github.com/fomantic/Fomantic-UI/pull/592)
- Remove extra label tag [`#583`](https://github.com/fomantic/Fomantic-UI/pull/583)
- Remove extra comma [`#582`](https://github.com/fomantic/Fomantic-UI/pull/582)
- Add missing punctuation [`#578`](https://github.com/fomantic/Fomantic-UI/pull/578)
- Fix typos in module.html.eco [`#579`](https://github.com/fomantic/Fomantic-UI/pull/579)
- Fixes bottom attached message bottom margin. [`#569`](https://github.com/fomantic/Fomantic-UI/pull/569)
- Fixed colors repeating in items.less [`#572`](https://github.com/fomantic/Fomantic-UI/pull/572)
- Fixes message attached between top and bottom. [`#568`](https://github.com/fomantic/Fomantic-UI/pull/568)
- Fix W3C CSS gradients syntax. [`#558`](https://github.com/fomantic/Fomantic-UI/pull/558)
- Forgot to change the year [`#561`](https://github.com/fomantic/Fomantic-UI/pull/561)
- Transition: Disable animationEnd callback on transition reset. [`#532`](https://github.com/fomantic/Fomantic-UI/pull/532)
- prevent close icon style override [`#556`](https://github.com/fomantic/Fomantic-UI/pull/556)
- Doc was missing forward icon in Media Actions [`#551`](https://github.com/fomantic/Fomantic-UI/pull/551)
- Docs: Remove unused sticky menu items [`#548`](https://github.com/fomantic/Fomantic-UI/pull/548)
- Removed semicolon that breaks LESS parser [`#539`](https://github.com/fomantic/Fomantic-UI/pull/539)
- Update package.json [`#534`](https://github.com/fomantic/Fomantic-UI/pull/534)
- Fixing typos [`#524`](https://github.com/fomantic/Fomantic-UI/pull/524)
- Update docs [`#522`](https://github.com/fomantic/Fomantic-UI/pull/522)
- Update README.md - small typo [`#515`](https://github.com/fomantic/Fomantic-UI/pull/515)
- A more consistent selector. [`#511`](https://github.com/fomantic/Fomantic-UI/pull/511)
- s/Everyday/Every day/ [`#496`](https://github.com/fomantic/Fomantic-UI/pull/496)
- Fix CONTRIBUTING.md: docpad now on top level [`#489`](https://github.com/fomantic/Fomantic-UI/pull/489)
- Added missing opening HTML tag [`#485`](https://github.com/fomantic/Fomantic-UI/pull/485)
- Update homepage.html [`#478`](https://github.com/fomantic/Fomantic-UI/pull/478)
- Fix JSFiddle link in documentation. [`#482`](https://github.com/fomantic/Fomantic-UI/pull/482)
- Fix release date for 0.11.0 [`#474`](https://github.com/fomantic/Fomantic-UI/pull/474)
- fix typo [`#471`](https://github.com/fomantic/Fomantic-UI/pull/471)
- Fix issue #409 [`#433`](https://github.com/fomantic/Fomantic-UI/pull/433)
- Issue #423 - right sidebar push not working [`#424`](https://github.com/fomantic/Fomantic-UI/pull/424)
- Fixed packaged version. [`#420`](https://github.com/fomantic/Fomantic-UI/pull/420)
- add karma-coverage and coveralls grunt task [`#418`](https://github.com/fomantic/Fomantic-UI/pull/418)
- allow grouped buttons in actions [`#417`](https://github.com/fomantic/Fomantic-UI/pull/417)
- Missing big icon variation in documentation [`#413`](https://github.com/fomantic/Fomantic-UI/pull/413)
- Add social button style for vk.com [`#410`](https://github.com/fomantic/Fomantic-UI/pull/410)
- use load-grunt-tasks [`#386`](https://github.com/fomantic/Fomantic-UI/pull/386)
- Reorder webfont urls to help prevent low quality icons in Chome on Windo... [`#385`](https://github.com/fomantic/Fomantic-UI/pull/385)
- Updated readme.md for new location (Semantic-Org) [`#388`](https://github.com/fomantic/Fomantic-UI/pull/388)
- Fixed width of .ui.attached.icon.message [`#381`](https://github.com/fomantic/Fomantic-UI/pull/381)
- Explicitly specify right aligned sidebar positions [`#374`](https://github.com/fomantic/Fomantic-UI/pull/374)
- Case insensitive e-mail validation [`#373`](https://github.com/fomantic/Fomantic-UI/pull/373)
- Update sidebar.html.eco [`#369`](https://github.com/fomantic/Fomantic-UI/pull/369)
- Update sidebar.js [`#368`](https://github.com/fomantic/Fomantic-UI/pull/368)
- missing closing tag on a &lt;p&gt; [`#367`](https://github.com/fomantic/Fomantic-UI/pull/367)
- Clean out trailing commas [`#345`](https://github.com/fomantic/Fomantic-UI/pull/345)
- #343 modal text can't be selected [`#344`](https://github.com/fomantic/Fomantic-UI/pull/344)
- Add a "context" setting to the popup module [`#335`](https://github.com/fomantic/Fomantic-UI/pull/335)
- version upfix [`#329`](https://github.com/fomantic/Fomantic-UI/pull/329)
- moved plugins and ports to a wiki page [`#318`](https://github.com/fomantic/Fomantic-UI/pull/318)
- Fix documentation errors in validation rules. [`#317`](https://github.com/fomantic/Fomantic-UI/pull/317)
- added irc channel to README [`#310`](https://github.com/fomantic/Fomantic-UI/pull/310)
- recommend forking the fiddle for bug reports [`#308`](https://github.com/fomantic/Fomantic-UI/pull/308)
- select was still receiving input styling; removed it [`#306`](https://github.com/fomantic/Fomantic-UI/pull/306)
- header.less color variables [`#301`](https://github.com/fomantic/Fomantic-UI/pull/301)
- Fix modal media typo [`#291`](https://github.com/fomantic/Fomantic-UI/pull/291)
- fixes #262 [`#263`](https://github.com/fomantic/Fomantic-UI/pull/263)
- fix some typos found in doc [`#264`](https://github.com/fomantic/Fomantic-UI/pull/264)
- Fixed '404 not found' link path in CONTRIBUTING.md file [`#258`](https://github.com/fomantic/Fomantic-UI/pull/258)
- fix typo [`#228`](https://github.com/fomantic/Fomantic-UI/pull/228)
- Remove FlipCSS from package.json [`#217`](https://github.com/fomantic/Fomantic-UI/pull/217)
- Remove FlipCSS from package.json [`#217`](https://github.com/fomantic/Fomantic-UI/pull/217)
- Doc typo: Correct the Checkbox link [`#200`](https://github.com/fomantic/Fomantic-UI/pull/200)
- fix some problems that are similar to #34 [`#193`](https://github.com/fomantic/Fomantic-UI/pull/193)
- Invalid json fix [`#196`](https://github.com/fomantic/Fomantic-UI/pull/196)
- Removed the incorrect required value. [`#185`](https://github.com/fomantic/Fomantic-UI/pull/185)
- Correct src & build files for previous pull-request [`#179`](https://github.com/fomantic/Fomantic-UI/pull/179)
- fixed the ":;" bug, which will cause rails assets pipeline compile error... [`#159`](https://github.com/fomantic/Fomantic-UI/pull/159)
- new Large size for icons [`#142`](https://github.com/fomantic/Fomantic-UI/pull/142)
- fix some issues with scrolling menu [`#143`](https://github.com/fomantic/Fomantic-UI/pull/143)
- add type='email' and some others [`#129`](https://github.com/fomantic/Fomantic-UI/pull/129)
- Add white colour for button background [`#111`](https://github.com/fomantic/Fomantic-UI/pull/111)
- remove menu item "Getting Started" [`#120`](https://github.com/fomantic/Fomantic-UI/pull/120)
- Added the input element of checkbox to the dom with 0 opacity. [`#115`](https://github.com/fomantic/Fomantic-UI/pull/115)
- fix type='email' fields rendering [`#110`](https://github.com/fomantic/Fomantic-UI/pull/110)
- Fixed bug when adding to angular projects [`#99`](https://github.com/fomantic/Fomantic-UI/pull/99)
- fix paths to the correct url [`#94`](https://github.com/fomantic/Fomantic-UI/pull/94)
- Created custom collections to hopefully avoid the performance issues you facing [`#80`](https://github.com/fomantic/Fomantic-UI/pull/80)
- Fixed #68: Add CONTRIBUTING.md file [`#69`](https://github.com/fomantic/Fomantic-UI/pull/69)
- Fixes height of image labels. [`#62`](https://github.com/fomantic/Fomantic-UI/pull/62)
- Added queue setting to transition module fixes #23 [`#29`](https://github.com/fomantic/Fomantic-UI/pull/29)
- fix invalid component.json [`#19`](https://github.com/fomantic/Fomantic-UI/pull/19)
- Merge pull request #6431 from alex-karo/fix-wechat-icon-1 [`#6429`](https://github.com/fomantic/Fomantic-UI/issues/6429)
- 'brand-icons' font-family to wechat icon [`#6429`](https://github.com/fomantic/Fomantic-UI/issues/6429)
- Added .inverted to dropdowns Closes #5276 [`#5276`](https://github.com/fomantic/Fomantic-UI/issues/5276)
- Merge pull request #6223 from prudho/master [`#3486`](https://github.com/fomantic/Fomantic-UI/issues/3486)
- Labels should check for label existence not value existence Fixes #6123 #6271 #6280 #6276 [`#6123`](https://github.com/fomantic/Fomantic-UI/issues/6123)
- Fix #6147 - Disabled menu items still changing state on hover [`#6147`](https://github.com/fomantic/Fomantic-UI/issues/6147)
- Close #6229. Basic tertiary button layout with var [`#6229`](https://github.com/fomantic/Fomantic-UI/issues/6229)
- Added primary & secondary inverted buttons Fixes #5643 [`#5643`](https://github.com/fomantic/Fomantic-UI/issues/5643)
- Fix #4476 [`#4476`](https://github.com/fomantic/Fomantic-UI/issues/4476)
- Fixes #6125 [`#6125`](https://github.com/fomantic/Fomantic-UI/issues/6125)
- Fixed exchange.alternate icon Fixes #6175 [`#6175`](https://github.com/fomantic/Fomantic-UI/issues/6175) [`#6176`](https://github.com/fomantic/Fomantic-UI/issues/6176) [`#6180`](https://github.com/fomantic/Fomantic-UI/issues/6180)
- Merge pull request #5749 from jayphelps/scrollbar [`#5728`](https://github.com/fomantic/Fomantic-UI/issues/5728)
- Fix #5366, #5975, taken from @dannyBies [`#5366`](https://github.com/fomantic/Fomantic-UI/issues/5366)
- Changed gulp-clone version (Fixes #6067) [`#6067`](https://github.com/fomantic/Fomantic-UI/issues/6067)
- Fix horizontal scrollbar height, closes #5728 [`#5728`](https://github.com/fomantic/Fomantic-UI/issues/5728)
- Really fix #5391 [`#5391`](https://github.com/fomantic/Fomantic-UI/issues/5391)
- Fixes #5578, absolute positioned modal items are now taken into scroll calculation [`#5578`](https://github.com/fomantic/Fomantic-UI/issues/5578)
- Merge pull request #3714 from TemaSM/master [`#3439`](https://github.com/fomantic/Fomantic-UI/issues/3439)
- Fixes #4579, compact icon message not appearing compact [`#4579`](https://github.com/fomantic/Fomantic-UI/issues/4579)
- Remove iOS html class name fix #3488 [`#3488`](https://github.com/fomantic/Fomantic-UI/issues/3488)
- Fixes #4707 position: relative on dimmer [`#4707`](https://github.com/fomantic/Fomantic-UI/issues/4707)
- Fixes #3604 #5116 Issue with left/right menu on stackable mobile [`#3604`](https://github.com/fomantic/Fomantic-UI/issues/3604)
- Fixes #5064 issue with radio in Onfailure callback [`#5064`](https://github.com/fomantic/Fomantic-UI/issues/5064)
- Fix #4237 IE11 dropdown issue with re-opening [`#4237`](https://github.com/fomantic/Fomantic-UI/issues/4237)
- Fixes #4479 - Approve/deny callbacks can occur multiple times if clicked quickly [`#4479`](https://github.com/fomantic/Fomantic-UI/issues/4479)
- Fix #5113 Dropdown blur issue [`#5113`](https://github.com/fomantic/Fomantic-UI/issues/5113)
- Fixes #4145 image icon causes issues in header [`#4145`](https://github.com/fomantic/Fomantic-UI/issues/4145)
- Fix #3012 padded vertical segments [`#3012`](https://github.com/fomantic/Fomantic-UI/issues/3012)
- Fix #4264 remove height requirements on iOS mode [`#4264`](https://github.com/fomantic/Fomantic-UI/issues/4264)
- Merge pull request #4651 from rminnett/next [`#3424`](https://github.com/fomantic/Fomantic-UI/issues/3424)
- Fixes #4490 - Dropdown with search inside menu should be tabbable. Fixes issue with selectOnKeydown and html text [`#4490`](https://github.com/fomantic/Fomantic-UI/issues/4490)
- Fixes #2534 for real, adds loadOnce setting [`#2534`](https://github.com/fomantic/Fomantic-UI/issues/2534)
- Fix #3424 [`#3424`](https://github.com/fomantic/Fomantic-UI/issues/3424)
- Fixes #4344 select on keydown now highlights partial selections when using search selection matching the first letters of matched result [`#4344`](https://github.com/fomantic/Fomantic-UI/issues/4344)
- Fixes #4183 Fixes  not working correctly since  due to incorrect use of new function signature. [`#4183`](https://github.com/fomantic/Fomantic-UI/issues/4183)
- Fixes #3998, dropdown icon should not use stopPropagation [`#3998`](https://github.com/fomantic/Fomantic-UI/issues/3998)
- Fix #4181 [`#4181`](https://github.com/fomantic/Fomantic-UI/issues/4181)
- Fix compact form messages [`#3343`](https://github.com/fomantic/Fomantic-UI/issues/3343)
- Fixes #3879, #3622 - mutation observers occur erroneously with internal updates, causing issues [`#3879`](https://github.com/fomantic/Fomantic-UI/issues/3879)
- Fixes #3887 element removed from DOM would cause popup to be closed [`#3887`](https://github.com/fomantic/Fomantic-UI/issues/3887)
- Fixes #3917, adds check for bubbled label event coming from surrounding label [`#3917`](https://github.com/fomantic/Fomantic-UI/issues/3917)
- Fixes #3887 issue with clicking element removed from DOM inside popup [`#3887`](https://github.com/fomantic/Fomantic-UI/issues/3887)
- Refix #3855 to fix scoping, allow for 'global' var without polluting global namespace [`#3855`](https://github.com/fomantic/Fomantic-UI/issues/3855)
- Fixes #3858 issue with gulp rtl tasks [`#3858`](https://github.com/fomantic/Fomantic-UI/issues/3858)
- Fix #2933 - Disabled button does not remove pointer events when loading [`#2933`](https://github.com/fomantic/Fomantic-UI/issues/2933)
- Add cursor spacing, fix #3790 issue with search losing focus on selection [`#3790`](https://github.com/fomantic/Fomantic-UI/issues/3790)
- Fixes #3790 - Multi select loses focus on item click [`#3790`](https://github.com/fomantic/Fomantic-UI/issues/3790)
- Fix #3781 - Variable not being used correctly in menu [`#3781`](https://github.com/fomantic/Fomantic-UI/issues/3781)
- Fixes #3606, field revalidation would cause whole form to be revalidated [`#3606`](https://github.com/fomantic/Fomantic-UI/issues/3606)
- Fixes #3653, refactors several lines to use expectsJSON [`#3653`](https://github.com/fomantic/Fomantic-UI/issues/3653)
- Fixes #3705 - Issue with normalize.css reset resetting some elements to content-box box sizing [`#3705`](https://github.com/fomantic/Fomantic-UI/issues/3705)
- Fix #3743 line break in multiple select dropdown [`#3743`](https://github.com/fomantic/Fomantic-UI/issues/3743)
- Fixes #3717 issue with margin collapse with form fields vs field [`#3717`](https://github.com/fomantic/Fomantic-UI/issues/3717)
- Fix #3439 - Now steps can be .unstackable [`#3439`](https://github.com/fomantic/Fomantic-UI/issues/3439)
- Fix #3496 - Justified grid inside centered grid now justified [`#3496`](https://github.com/fomantic/Fomantic-UI/issues/3496)
- Fixes #3676 form submit on dropdown selection [`#3676`](https://github.com/fomantic/Fomantic-UI/issues/3676)
- Fixes #3619 issue with attached message [`#3619`](https://github.com/fomantic/Fomantic-UI/issues/3619)
- Fixes #3183, mobile sub-menus will not select [`#3183`](https://github.com/fomantic/Fomantic-UI/issues/3183)
- Fixes #2781 issue with 'is visible' not returning correctly from popup [`#2781`](https://github.com/fomantic/Fomantic-UI/issues/2781)
- Fix #142, several pretty bad issues in fixed template [`#142`](https://github.com/fomantic/Fomantic-UI/issues/142)
- Fixes #3016, adds setting for keys [`#3016`](https://github.com/fomantic/Fomantic-UI/issues/3016)
- Fixes #3011 bottom attached cannot immediately jump to top attached [`#3011`](https://github.com/fomantic/Fomantic-UI/issues/3011)
- Fixes #3036, reset does not reset value [`#3036`](https://github.com/fomantic/Fomantic-UI/issues/3036)
- Fix #142, several pretty bad issues in fixed template [`#142`](https://github.com/fomantic/Fomantic-UI/issues/142)
- Fixes #3016, adds setting for keys [`#3016`](https://github.com/fomantic/Fomantic-UI/issues/3016)
- Fixes #3011 bottom attached cannot immediately jump to top attached [`#3011`](https://github.com/fomantic/Fomantic-UI/issues/3011)
- Call onSearchQuery whether or not results are cached [`#3106`](https://github.com/Semantic-Org/Semantic-UI/issues/3106)
- Fixes #3036, reset does not reset value [`#3036`](https://github.com/fomantic/Fomantic-UI/issues/3036)
- Call onSearchQuery whether or not results are cached [`#3106`](https://github.com/Semantic-Org/Semantic-UI/issues/3106)
- Fixes #2939 issue with placeholder color [`#2939`](https://github.com/fomantic/Fomantic-UI/issues/2939)
- Fixes #2953, issue with input width [`#2953`](https://github.com/fomantic/Fomantic-UI/issues/2953)
- Fixes #2923 issue with allow additions not implementing add results template [`#2923`](https://github.com/fomantic/Fomantic-UI/issues/2923)
- Typo in HTML [`#2906`](https://github.com/fomantic/Fomantic-UI/issues/2906)
- Fixes #2583 issue with menu disappearing using allowAdditions: true [`#2583`](https://github.com/fomantic/Fomantic-UI/issues/2583)
- Fix #2782 left icon corner labeled input [`#2782`](https://github.com/fomantic/Fomantic-UI/issues/2782)
- Fixes #2826, bottom aligned has incorrect flex value [`#2826`](https://github.com/fomantic/Fomantic-UI/issues/2826)
- Fixes #2818, action: hide now calls onChange #2818 [`#2818`](https://github.com/fomantic/Fomantic-UI/issues/2818)
- Fixes #2824, messages should always be removed on show unless message is max selection [`#2824`](https://github.com/fomantic/Fomantic-UI/issues/2824)
- Finally fixes #2058, forceSelection shouldnt occur on empty query. minor formatting [`#2058`](https://github.com/fomantic/Fomantic-UI/issues/2058)
- Fix #2733 pointing dropdown incorrectly overwrites upward rules [`#2733`](https://github.com/fomantic/Fomantic-UI/issues/2733)
- Fixes #2810 nested grid receives wrong flex-direction [`#2810`](https://github.com/fomantic/Fomantic-UI/issues/2810)
- Fixes #2806 issue with trim in dropdown [`#2806`](https://github.com/fomantic/Fomantic-UI/issues/2806)
- Fixes issue with modal close #2736 [`#2736`](https://github.com/fomantic/Fomantic-UI/issues/2736)
- Fixes #2715 Fixes touchstart event, removes delay from touchstart, fixes possibility of onShow occuring twice when touch events used. Fixes onHide not calling [`#2715`](https://github.com/fomantic/Fomantic-UI/issues/2715)
- Fixes #2700 circular labeled icon button [`#2700`](https://github.com/fomantic/Fomantic-UI/issues/2700)
- Fixes #2691 image removes padding on some other ui [`#2691`](https://github.com/fomantic/Fomantic-UI/issues/2691)
- Fixes #2665, message icon collapses [`#2665`](https://github.com/fomantic/Fomantic-UI/issues/2665)
- Fix #2657 action input inside form [`#2657`](https://github.com/fomantic/Fomantic-UI/issues/2657)
- Fixes #2649 Mixed line endings in source files [`#2649`](https://github.com/fomantic/Fomantic-UI/issues/2649)
- Fixes #2545, revisits #2552. Issues with arrow variables, github theme display with steps [`#2545`](https://github.com/fomantic/Fomantic-UI/issues/2545)
- Fixes #2552 issue with last step [`#2552`](https://github.com/fomantic/Fomantic-UI/issues/2552)
- Fixes #2466, limitValues was parsing values with total. Move getNumericValue to method [`#2466`](https://github.com/fomantic/Fomantic-UI/issues/2466)
- Fix #2477 Site.variable inheritance should precede all component inheritance [`#2477`](https://github.com/fomantic/Fomantic-UI/issues/2477)
- Fixes #2436 - onChange should use string equality since input will be stored as string [`#2436`](https://github.com/fomantic/Fomantic-UI/issues/2436)
- Fix #2435 Flex fields do not allow wrap on mobile [`#2435`](https://github.com/fomantic/Fomantic-UI/issues/2435)
- Fix #2415, mistakes in embed for vimeo source [`#2415`](https://github.com/fomantic/Fomantic-UI/issues/2415)
- Fix #2412, using form without validation rules causes errors [`#2412`](https://github.com/fomantic/Fomantic-UI/issues/2412)
- Fixes #2382 Issue with set selected not working with user values [`#2382`](https://github.com/fomantic/Fomantic-UI/issues/2382)
- Fixes #2359, attached menu should not remove margin unless no direction specified [`#2359`](https://github.com/fomantic/Fomantic-UI/issues/2359)
- Adds fireOnInit setting, and onAdd onRemove callbacks for multiple [`#2252`](https://github.com/fomantic/Fomantic-UI/issues/2252)
- Fix #2253, improper disabled form field rules [`#2253`](https://github.com/fomantic/Fomantic-UI/issues/2253)
- Fixes #2180, right offstage position does not take horizontal scrollbars into consideration [`#2180`](https://github.com/fomantic/Fomantic-UI/issues/2180)
- Fixes #2219, icon should not reset line height [`#2219`](https://github.com/fomantic/Fomantic-UI/issues/2219)
- #Fixes #2202, adds support for multiple button, dropdown in action input [`#2202`](https://github.com/fomantic/Fomantic-UI/issues/2202)
- Fixes #2157 #2158 Issue with link styles applying to UI inside ui list [`#2157`](https://github.com/fomantic/Fomantic-UI/issues/2157)
- Fixes #2187 hidden divider does not work with vertical divider [`#2187`](https://github.com/fomantic/Fomantic-UI/issues/2187)
- Fixes #2163 #2128 #2162 Search results are now stored in metadata for each result and retrieved from metadata. Results now have a unique id injected based on position which can also be used for lookup, i.e. A1 = first category first result. [`#2163`](https://github.com/fomantic/Fomantic-UI/issues/2163)
- Fix #2184 User error messages are confusing for missing themes [`#2184`](https://github.com/fomantic/Fomantic-UI/issues/2184)
- Fixes #2138 issue with matching to non string value [`#2138`](https://github.com/fomantic/Fomantic-UI/issues/2138)
- Fix #2121, woff2 declaration is incorrect [`#2121`](https://github.com/fomantic/Fomantic-UI/issues/2121)
- Fixes #2061, page no longer moves on modal show [`#2061`](https://github.com/fomantic/Fomantic-UI/issues/2061)
- Fixes #2122 Component array in semantic.json (or defualts) does not remove duplicates [`#2122`](https://github.com/fomantic/Fomantic-UI/issues/2122)
- Fixes #2059 #2070 rewrite object search used in search module to be much less obtuse [`#2059`](https://github.com/fomantic/Fomantic-UI/issues/2059)
- Fixes #2057 issue with labeled input in forms not fitting column width [`#2057`](https://github.com/fomantic/Fomantic-UI/issues/2057)
- Fixes #2021, resolves #2069. Fix image flex defaults in IE [`#2021`](https://github.com/fomantic/Fomantic-UI/issues/2021) [`#2069`](https://github.com/fomantic/Fomantic-UI/issues/2069)
- Fixes #2075, issue with placeholder on input [`#2075`](https://github.com/fomantic/Fomantic-UI/issues/2075)
- Fixes #2076 transparent left icon input [`#2076`](https://github.com/fomantic/Fomantic-UI/issues/2076)
- Fix #2052 typo in site.variables [`#2052`](https://github.com/fomantic/Fomantic-UI/issues/2052)
- Fixes #2042 bind events with delegation in general [`#2042`](https://github.com/fomantic/Fomantic-UI/issues/2042)
- Fix #2040 package is a reserved word in some backends [`#2040`](https://github.com/fomantic/Fomantic-UI/issues/2040)
- Fixes #2024, simplifies padding logic for selection item [`#2024`](https://github.com/fomantic/Fomantic-UI/issues/2024)
- Fixes #2017, onSelect uses startsWith matching to find selected value [`#2017`](https://github.com/fomantic/Fomantic-UI/issues/2017)
- Fixes #2001 Table sort positioning, ascending/descending icons reversed [`#2001`](https://github.com/fomantic/Fomantic-UI/issues/2001)
- Fixes #1990, tab affected by casing [`#1990`](https://github.com/fomantic/Fomantic-UI/issues/1990)
- Fixes #1961, kitchen sink display issue with h4 [`#1961`](https://github.com/fomantic/Fomantic-UI/issues/1961)
- Fixes #1931, adds in page overflowX, nested grid rule, fixes several additional grid issues with align [`#1931`](https://github.com/fomantic/Fomantic-UI/issues/1931)
- Fixes #1929, radio checkboxes remove checked class from other radios on checked [`#1929`](https://github.com/fomantic/Fomantic-UI/issues/1929)
- Fixes #1964, use more standardized table-cell solution for horizontal dividers [`#1964`](https://github.com/fomantic/Fomantic-UI/issues/1964)
- Fixes #1962, bookish styles reversed [`#1962`](https://github.com/fomantic/Fomantic-UI/issues/1962)
- Fixes #1954, input selector not specific enough [`#1954`](https://github.com/fomantic/Fomantic-UI/issues/1954)
- Fixes #1941, disabled checkbox shows hand cursor [`#1941`](https://github.com/fomantic/Fomantic-UI/issues/1941)
- Fixes #1916, onChange fires even when selected value is current value [`#1916`](https://github.com/fomantic/Fomantic-UI/issues/1916)
- Fixes #1925, missing z-index causes animated button to fail inside fixed content [`#1925`](https://github.com/fomantic/Fomantic-UI/issues/1925)
- Fixes #1924 Transparent input styles are overwritten by form stylings [`#1924`](https://github.com/fomantic/Fomantic-UI/issues/1924)
- Fixes #1920, mobile actions evaluates to negative padding causing rule to be omitted [`#1920`](https://github.com/fomantic/Fomantic-UI/issues/1920)
- Fixes #1922 Adds zindex to dimmer inside cardA [`#1922`](https://github.com/fomantic/Fomantic-UI/issues/1922)
- Fixes #1903, local search now escapes special chars [`#1903`](https://github.com/fomantic/Fomantic-UI/issues/1903)
- Fixes #1852 Popup hide all does not call onHidden [`#1852`](https://github.com/fomantic/Fomantic-UI/issues/1852)
- Fix #1881 Clockwise rotation was being overwritten by icon alias [`#1881`](https://github.com/fomantic/Fomantic-UI/issues/1881)
- Fixes #1895 issue with popup not reopening on mobile [`#1895`](https://github.com/fomantic/Fomantic-UI/issues/1895)
- Removed duplicate line [`#2`](https://github.com/Semantic-Org/Semantic-UI-CSS/issues/2)
- Fixes #1886, &lt;button&gt; in group does not take full width [`#1886`](https://github.com/fomantic/Fomantic-UI/issues/1886)
- Fixes #1850 search category results sometimes fails [`#1850`](https://github.com/fomantic/Fomantic-UI/issues/1850)
- Fixes #1827, list inside accordion [`#1827`](https://github.com/fomantic/Fomantic-UI/issues/1827)
- Fixes #1867, issue with forceSelection not clearing filter [`#1867`](https://github.com/fomantic/Fomantic-UI/issues/1867)
- Fixed #1831 [`#1831`](https://github.com/fomantic/Fomantic-UI/issues/1831)
- Fixes #898, disabled &lt;button&gt; missing disabled styles [`#898`](https://github.com/fomantic/Fomantic-UI/issues/898)
- Fixes #1800 Sidebar now queues animation when exclusive and not overlay [`#1800`](https://github.com/fomantic/Fomantic-UI/issues/1800)
- Fixes #1825, API now has 'was cancelled' method, add method to state to detect api request cancellation [`#1825`](https://github.com/fomantic/Fomantic-UI/issues/1825)
- Fixes #1854 chrome pointing menu is off by 1px [`#1854`](https://github.com/fomantic/Fomantic-UI/issues/1854)
- Fixes #1844 pointing menu arrow is under dropdown menu [`#1844`](https://github.com/fomantic/Fomantic-UI/issues/1844)
- Fixes #1842, small typo caused rtl tasks not to run [`#1842`](https://github.com/fomantic/Fomantic-UI/issues/1842)
- Fixes #1840, tab with ajax does not hide content correctly [`#1840`](https://github.com/fomantic/Fomantic-UI/issues/1840)
- Fixes #1832, typo in modal middle aligned [`#1832`](https://github.com/fomantic/Fomantic-UI/issues/1832)
- Fixes #793 #1506 #1693 - Adds flex to labeled input [`#793`](https://github.com/fomantic/Fomantic-UI/issues/793)
- Fixes #793 #1506 #1693 - Fixes fluid flex [`#793`](https://github.com/fomantic/Fomantic-UI/issues/793)
- Fixes #793 #1506 #1693 - Fixes button margin on last commit [`#793`](https://github.com/fomantic/Fomantic-UI/issues/793)
- Fixes #793 #1506 #1693, &lt;button&gt; supports flex. Added flex to ui action input [`#793`](https://github.com/fomantic/Fomantic-UI/issues/793)
- Fixes #1787 Evenly divided steps was not 100% width [`#1787`](https://github.com/fomantic/Fomantic-UI/issues/1787)
- Fixes #1734, floats disappear in stackable grid on mobile [`#1734`](https://github.com/fomantic/Fomantic-UI/issues/1734)
- Fixes #1766, external link [`#1766`](https://github.com/fomantic/Fomantic-UI/issues/1766)
- Fixes #1750, destroy not called on previous instance when doubline initialized [`#1750`](https://github.com/fomantic/Fomantic-UI/issues/1750)
- Fixes #1631. Issue with grid resetting inline-block spacing fix [`#1631`](https://github.com/fomantic/Fomantic-UI/issues/1631)
- Fix #1630 reset now clears prompts [`#1630`](https://github.com/fomantic/Fomantic-UI/issues/1630)
- Fix #1630, Checkbox must have error removed before reset to avoid revalidating [`#1630`](https://github.com/fomantic/Fomantic-UI/issues/1630)
- Fixes #1656. is occurring would not return correct value. Add repeat detection when queue: false [`#1656`](https://github.com/fomantic/Fomantic-UI/issues/1656)
- Fix #1638, bubbled click event on item now only blocks callback not other events [`#1638`](https://github.com/fomantic/Fomantic-UI/issues/1638)
- Actually fixes #1680, issue with ribbon sizing [`#1680`](https://github.com/fomantic/Fomantic-UI/issues/1680)
- Fix #1680, Issue with ribbons and sizing [`#1680`](https://github.com/fomantic/Fomantic-UI/issues/1680)
- Fixes #1667 mistake with relative sizes in sized lists. Removes padding from child lists of relaxed lists [`#1667`](https://github.com/fomantic/Fomantic-UI/issues/1667)
- Fix #1658, focused button styles now override [`#1658`](https://github.com/fomantic/Fomantic-UI/issues/1658)
- Fix #1677 disabled button inside basic button group, add global disabled border color [`#1677`](https://github.com/fomantic/Fomantic-UI/issues/1677)
- Fixes #1660 issue with transform causing stacking context on dropdown icon [`#1660`](https://github.com/fomantic/Fomantic-UI/issues/1660)
- Fix #1651 Missing responsive width variables in form [`#1651`](https://github.com/fomantic/Fomantic-UI/issues/1651)
- Fixes #1637, Progress bar does not include overrides [`#1637`](https://github.com/fomantic/Fomantic-UI/issues/1637)
- FIxes #1628 (Once and for all) [`#1628`](https://github.com/fomantic/Fomantic-UI/issues/1628)
- Fix #1604, Checkbox toggles on spacebar [`#1604`](https://github.com/fomantic/Fomantic-UI/issues/1604)
- Fix #1601 Search Selection RegExp Escapes Search Values [`#1601`](https://github.com/fomantic/Fomantic-UI/issues/1601)
- Fixes #1611 Issue with incorrect conditional making percent appear as value for value progress [`#1611`](https://github.com/fomantic/Fomantic-UI/issues/1611)
- Fix #1619 Issue with equal height grid resizing due to table-cell [`#1619`](https://github.com/fomantic/Fomantic-UI/issues/1619)
- Fix #1600 Sidebar not immediately available after init when wrong html [`#1600`](https://github.com/fomantic/Fomantic-UI/issues/1600)
- Fix #1613 Release notes [`#1613`](https://github.com/fomantic/Fomantic-UI/issues/1613)
- Fix #1613 https issue with video component [`#1613`](https://github.com/fomantic/Fomantic-UI/issues/1613)
- Fix #1590 Wide and very wide popups should not have defined width [`#1590`](https://github.com/fomantic/Fomantic-UI/issues/1590)
- Fixes #1578 vague selector for form validation prompt [`#1578`](https://github.com/fomantic/Fomantic-UI/issues/1578)
- Fix #1586, remove deprecated use of $.size() [`#1586`](https://github.com/fomantic/Fomantic-UI/issues/1586)
- Fixes #1581 material theme issue [`#1581`](https://github.com/fomantic/Fomantic-UI/issues/1581)
- Fixes #1538 Orange active color was set to wrong variable [`#1538`](https://github.com/fomantic/Fomantic-UI/issues/1538)
- Fixes #1546 1 pixel jump on first tab element segment [`#1546`](https://github.com/fomantic/Fomantic-UI/issues/1546)
- Fixes #1548, visible ui message not visible inside form [`#1548`](https://github.com/fomantic/Fomantic-UI/issues/1548)
- Fixes #1551 typo in accordion reset [`#1551`](https://github.com/fomantic/Fomantic-UI/issues/1551)
- Fix #1536 animated alignment [`#1536`](https://github.com/fomantic/Fomantic-UI/issues/1536)
- Fixes #1542, typo from cd9f4f9e58 fix caused fullTextRegexp to match all values in search [`#1542`](https://github.com/fomantic/Fomantic-UI/issues/1542)
- Fixes #1542, typo from cd9f4f9e58 fix caused fullTextRegexp to match all values in search [`#1542`](https://github.com/fomantic/Fomantic-UI/issues/1542)
- Fixes #1513, calls to $.tab were not correctly passing behavior arguments [`#1513`](https://github.com/fomantic/Fomantic-UI/issues/1513)
- Fixes #1470 Timers still exist after destroy is called [`#1470`](https://github.com/fomantic/Fomantic-UI/issues/1470)
- Fixes #1477 Fixes issue with missing margin from (x) wide field on mobile [`#1477`](https://github.com/fomantic/Fomantic-UI/issues/1477)
- Fixes #1515 issue with ui action input with ui with icon variation [`#1515`](https://github.com/fomantic/Fomantic-UI/issues/1515)
- Fixes #1520 Issue when using named popup in different offset container [`#1520`](https://github.com/fomantic/Fomantic-UI/issues/1520)
- Fixes #1532 Regexp restarts search from middle of string on multiple iterations, breaking search [`#1532`](https://github.com/fomantic/Fomantic-UI/issues/1532)
- Fix #1510 image display inside ui table [`#1510`](https://github.com/fomantic/Fomantic-UI/issues/1510)
- Better fix #1518, add default components to tasks/default.js, load instead of specified components if none specified [`#1518`](https://github.com/fomantic/Fomantic-UI/issues/1518)
- Rebuild dist with fixes #1518 [`#1518`](https://github.com/fomantic/Fomantic-UI/issues/1518)
- Fixes #1518, duplicates in dist/ [`#1518`](https://github.com/fomantic/Fomantic-UI/issues/1518)
- Fixes #1512, inline fields rules apply to input but not ui input. Pointing labeled variation needs additional horizontal padding to compensate for triangle size [`#1512`](https://github.com/fomantic/Fomantic-UI/issues/1512)
- Fixes #1501 issue with gulp install not obeying component choices [`#1501`](https://github.com/fomantic/Fomantic-UI/issues/1501)
- Fixes #1330, indicating progress does not update correctly in webkit, adds data-percent value to module [`#1330`](https://github.com/fomantic/Fomantic-UI/issues/1330)
- Fixes #1479 vertical segment border does not appear correctly with background [`#1479`](https://github.com/fomantic/Fomantic-UI/issues/1479)
- Fixes #1483, issues with repaint on buttons [`#1483`](https://github.com/fomantic/Fomantic-UI/issues/1483)
- Fixes #1491, double padding on padded stackable grid [`#1491`](https://github.com/fomantic/Fomantic-UI/issues/1491)
- Add structured table variation, fixes #1293 and #1359 [`#1293`](https://github.com/fomantic/Fomantic-UI/issues/1293)
- Fixes #1393 Dropdown shows/hides on window focus/blur. Adds window blur detection to element blur [`#1393`](https://github.com/fomantic/Fomantic-UI/issues/1393)
- Fixes #1458 Improvements to Dropdown [`#1458`](https://github.com/fomantic/Fomantic-UI/issues/1458)
- Fixes #1412, nested stackable grid display issues [`#1412`](https://github.com/fomantic/Fomantic-UI/issues/1412)
- Fixes #1413, Vertical segment shouldnt remove padding on first-last child [`#1413`](https://github.com/fomantic/Fomantic-UI/issues/1413)
- Adds sidebar IoS detection for overflow. Fixes #1442, modal losing scroll position on mobile when package includes sidebar. #1320 issue with mobile scroll in docs [`#1442`](https://github.com/fomantic/Fomantic-UI/issues/1442)
- Fixes #1433 Issue with bottom left attached label border radius [`#1433`](https://github.com/fomantic/Fomantic-UI/issues/1433)
- Fixes #1422, #1423- form layout issues [`#1422`](https://github.com/fomantic/Fomantic-UI/issues/1422)
- Fixes #1395, Progress poorly handles undefined/false/0 values evaluating as false [`#1395`](https://github.com/fomantic/Fomantic-UI/issues/1395)
- Fixes #1367, scrolling is not removed if modals already visible [`#1367`](https://github.com/fomantic/Fomantic-UI/issues/1367)
- Fixes #1371 Checkbox can now have labels anywhere [`#1371`](https://github.com/fomantic/Fomantic-UI/issues/1371)
- Fixes #1383 issue when using select with values that include capital letters [`#1383`](https://github.com/fomantic/Fomantic-UI/issues/1383)
- Fixes #1374 inconsistent behavior naming for sidebar [`#1374`](https://github.com/fomantic/Fomantic-UI/issues/1374)
- Fixes #1377 Item link color rules too broad [`#1377`](https://github.com/fomantic/Fomantic-UI/issues/1377)
- Fix #1303 Dropdown does not update with form validation [`#1303`](https://github.com/fomantic/Fomantic-UI/issues/1303)
- Fixes #1355, #1289, action input inside dropdown [`#1355`](https://github.com/fomantic/Fomantic-UI/issues/1355)
- Fixes #1352, 'remove link' alias causing issues with linking remove icon [`#1352`](https://github.com/fomantic/Fomantic-UI/issues/1352)
- Fixes #1353, fix many em values to be exact pixel calcs to avoid rounding errors [`#1353`](https://github.com/fomantic/Fomantic-UI/issues/1353)
- Fixes #1291 Fixes issue with nested dropdown menus appearing. [`#1291`](https://github.com/fomantic/Fomantic-UI/issues/1291)
- Merge pull request #1348 from ordepdev/master [`#1331`](https://github.com/fomantic/Fomantic-UI/issues/1331)
- Fixes #1288, Add failsafe for chrome animations, debug issues with dropdown child-menus [`#1288`](https://github.com/fomantic/Fomantic-UI/issues/1288)
- This fixes #1331 [`#1331`](https://github.com/fomantic/Fomantic-UI/issues/1331)
- Fix #1306 popup remove typo causing error. [`#1306`](https://github.com/fomantic/Fomantic-UI/issues/1306)
- Fixes #1290 issue with card/item links [`#1290`](https://github.com/fomantic/Fomantic-UI/issues/1290)
- Fixes #1272, popup refresh was removing popup inappropriately [`#1272`](https://github.com/fomantic/Fomantic-UI/issues/1272)
- Fixes #1266 issue with right menu dropdown item direction [`#1266`](https://github.com/fomantic/Fomantic-UI/issues/1266)
- Fixes #1267, bad selector for search in dropdown [`#1267`](https://github.com/fomantic/Fomantic-UI/issues/1267)
- Maybe fix #1259 [`#1259`](https://github.com/fomantic/Fomantic-UI/issues/1259)
- Fixes #1256, adds better handling of settings.popup, and fluid [`#1256`](https://github.com/fomantic/Fomantic-UI/issues/1256)
- Refix #1256, adds new setting for adjusting fluid width on display [`#1256`](https://github.com/fomantic/Fomantic-UI/issues/1256)
- Fixes #1256, issues with offsetParent as 'html', should account for padding added to  'body' [`#1256`](https://github.com/fomantic/Fomantic-UI/issues/1256)
- Fixes #1188 animated lists do not animate children at all [`#1188`](https://github.com/fomantic/Fomantic-UI/issues/1188)
- Fixes #1248, body height not removed on refresh [`#1248`](https://github.com/fomantic/Fomantic-UI/issues/1248)
- Fixes #1245, scrolling large/small modal not working correctly [`#1245`](https://github.com/fomantic/Fomantic-UI/issues/1245)
- Fixes #1238, Modal classnames are removed by .transition() when set in onStart [`#1238`](https://github.com/fomantic/Fomantic-UI/issues/1238)
- Fixes #1219 Inverted segments do not have any border [`#1219`](https://github.com/fomantic/Fomantic-UI/issues/1219)
- Fixes #1219 colored attached segment formatting [`#1219`](https://github.com/fomantic/Fomantic-UI/issues/1219)
- Fixes #1223 disabled does not work with link icon [`#1223`](https://github.com/fomantic/Fomantic-UI/issues/1223)
- Fixes #1226, makes variables simpler for label/image/icon/flag inside item. Fixes lineheight offset [`#1226`](https://github.com/fomantic/Fomantic-UI/issues/1226)
- Fixes #885, default animation does not support multiple, multiple now always does not push canvas [`#885`](https://github.com/fomantic/Fomantic-UI/issues/885)
- Fixes #1222 Handling touchstart as special case no longer necessary [`#1222`](https://github.com/fomantic/Fomantic-UI/issues/1222)
- Fix #1203 icon alignment variable [`#1203`](https://github.com/fomantic/Fomantic-UI/issues/1203)
- Fixes #1191 in 1.0, issue with first stackable card margin [`#1191`](https://github.com/fomantic/Fomantic-UI/issues/1191)
- Rebuild dist from source Fixes #1201 [`#1201`](https://github.com/fomantic/Fomantic-UI/issues/1201)
- Fix #1193, site/reset missing from install [`#1193`](https://github.com/fomantic/Fomantic-UI/issues/1193)
- Fixes #1019 UI list does not allow for some nested content types [`#1019`](https://github.com/fomantic/Fomantic-UI/issues/1019)
- Fixes #1173 doubling grid wasnt doubling for some sizes [`#1173`](https://github.com/fomantic/Fomantic-UI/issues/1173)
- Fixes #1181 issue with horizontal segment specificity [`#1181`](https://github.com/fomantic/Fomantic-UI/issues/1181)
- Fixes #765, moves loading state to css only [`#765`](https://github.com/fomantic/Fomantic-UI/issues/765)
- Fixes #968 and #1138, Transition can now correctly cancel callbacks when interrupted mid animation [`#968`](https://github.com/fomantic/Fomantic-UI/issues/968)
- Fixes #766 #671 Fixes bug in finding modal with dimmer name [`#766`](https://github.com/fomantic/Fomantic-UI/issues/766)
- Fixes #766 #671 issues with multiple dimmers in same context. Added new 'dimmerName' setting, allowing you to specify which dimmer inside a context should be used. [`#766`](https://github.com/fomantic/Fomantic-UI/issues/766)
- Fixes #1140, bad CLA link [`#1140`](https://github.com/fomantic/Fomantic-UI/issues/1140)
- Fixes #1137 minwidth on fluid dropdown [`#1137`](https://github.com/fomantic/Fomantic-UI/issues/1137)
- Fixes #1120, adds correct conditions to toggle as well [`#1120`](https://github.com/fomantic/Fomantic-UI/issues/1120)
- Fixes #1120, sidebar can now hide/show during animation [`#1120`](https://github.com/fomantic/Fomantic-UI/issues/1120)
- Fixes #1123 Issue with 0 value not using strict matching [`#1123`](https://github.com/fomantic/Fomantic-UI/issues/1123)
- Fixes #949 popup and dropdown on sam element causes dropdown to show on popup visible [`#949`](https://github.com/fomantic/Fomantic-UI/issues/949)
- Fixes #1105, arbitrary specificity increase, due to loss from multi-word classes [`#1105`](https://github.com/fomantic/Fomantic-UI/issues/1105)
- Fixes #1100. Word order [`#1100`](https://github.com/fomantic/Fomantic-UI/issues/1100)
- Fixes #1091 Missing ui overrides on form [`#1091`](https://github.com/fomantic/Fomantic-UI/issues/1091)
- Fixes #1080 issue with computer and tablet only grid [`#1080`](https://github.com/fomantic/Fomantic-UI/issues/1080)
- Fixes #1023 issue with text icons in dropdown [`#1023`](https://github.com/fomantic/Fomantic-UI/issues/1023)
- Fixes #326, vertical divider now swaps to horizontal inside stackable grid [`#326`](https://github.com/fomantic/Fomantic-UI/issues/326)
- Fixes #1065 adds missing flags asset [`#1065`](https://github.com/fomantic/Fomantic-UI/issues/1065)
- Move lists to elements (this may cause issues if you are using an early beta release, be sure to rename), fixes #1017, modifications/fixes to undocumented sticky component in prep for release [`#1017`](https://github.com/fomantic/Fomantic-UI/issues/1017)
- Fixes #1052, full screen modal missing font size [`#1052`](https://github.com/fomantic/Fomantic-UI/issues/1052)
- Fixes #1054, issue with inheritance of link styles in menus [`#1054`](https://github.com/fomantic/Fomantic-UI/issues/1054)
- Fixes #1044, removes stub for tab definition [`#1044`](https://github.com/fomantic/Fomantic-UI/issues/1044)
- Fixes modal to remove scroll bars when modal is visible, fixes #787 [`#787`](https://github.com/fomantic/Fomantic-UI/issues/787)
- Fix #1038 in 1.0 [`#1038`](https://github.com/fomantic/Fomantic-UI/issues/1038)
- Fixes #1033 issue with XSS in popup [`#1033`](https://github.com/fomantic/Fomantic-UI/issues/1033)
- Fixes #357, Horizontal Dividers now adjust to text size automatically. [`#357`](https://github.com/fomantic/Fomantic-UI/issues/357)
- Add back in (x) wide fields fixes #982 [`#982`](https://github.com/fomantic/Fomantic-UI/issues/982)
- Fix #941, add manual popup trigger option [`#941`](https://github.com/fomantic/Fomantic-UI/issues/941)
- Fixes #977, wrong behavior on form success [`#977`](https://github.com/fomantic/Fomantic-UI/issues/977)
- Fixes #929 Adds centered ui grid variation alongside center aligned [`#929`](https://github.com/fomantic/Fomantic-UI/issues/929)
- Fixes #681, multi line steps, adds two line variation for vertical steps. Fixes all steps to use transform rotote  arrows instead of border arrows for consistency [`#681`](https://github.com/fomantic/Fomantic-UI/issues/681)
- Fixes #704, Fixes #421. onShow, onHide callback moved to before transition starts, added new callbacks onVisible and noHidden for after animation completes [`#704`](https://github.com/fomantic/Fomantic-UI/issues/704) [`#421`](https://github.com/fomantic/Fomantic-UI/issues/421)
- Fixes #336 iOS doesn't render:active classes [`#336`](https://github.com/fomantic/Fomantic-UI/issues/336)
- Fixes #662 inverted icon rendering in OSX [`#662`](https://github.com/fomantic/Fomantic-UI/issues/662)
- Fixes #542, use sibling selector instead of adjacent sibling on checkbox rules [`#542`](https://github.com/fomantic/Fomantic-UI/issues/542)
- Fixes #711 selection dropdown does not match input height. Also adds stricter dropdown error css selectors [`#711`](https://github.com/fomantic/Fomantic-UI/issues/711)
- Fixes #694 A dropdown with numeric content for data-text causes an error on toLowerCase [`#694`](https://github.com/fomantic/Fomantic-UI/issues/694)
- Fixes #712, Modal uses RequestAnimationFrame without doing browser normalization on the event [`#712`](https://github.com/fomantic/Fomantic-UI/issues/712)
- Fixes #669 Merge branch 'dropdown-error' of github.com:Semantic-Org/Semantic-UI [`#669`](https://github.com/fomantic/Fomantic-UI/issues/669)
- Fixes #687, removes docpad as a dependency, moves to dev depencies [`#687`](https://github.com/fomantic/Fomantic-UI/issues/687)
- Fixes #680 Issue with horizontal lists alignment in IE [`#680`](https://github.com/fomantic/Fomantic-UI/issues/680)
- Fixes #660 issue with ui input styling inside forms [`#660`](https://github.com/fomantic/Fomantic-UI/issues/660)
- Fixes #614, issue with modal vertical position on multiple shows [`#614`](https://github.com/fomantic/Fomantic-UI/issues/614)
- Fixes #614, issue with modal vertical position on multiple shows [`#614`](https://github.com/fomantic/Fomantic-UI/issues/614)
- Fixes #528 Fixes modal to resize page if not enough room to fit modal [`#528`](https://github.com/fomantic/Fomantic-UI/issues/528)
- Fixes #633 broken url on docs page [`#633`](https://github.com/fomantic/Fomantic-UI/issues/633)
- Fixes #644 form validation does not trigger validation check on checkbox change [`#644`](https://github.com/fomantic/Fomantic-UI/issues/644)
- Fixes #646 issue with z-index on modal close [`#646`](https://github.com/fomantic/Fomantic-UI/issues/646)
- Fixes #584 dimmers now use JS animations for on hover to avoid callback issues [`#584`](https://github.com/fomantic/Fomantic-UI/issues/584)
- Fixes #616 accordion removes inline styles [`#616`](https://github.com/fomantic/Fomantic-UI/issues/616)
- Fixes #630 Moves menu border to left side, removes on first-child [`#630`](https://github.com/fomantic/Fomantic-UI/issues/630)
- Fixes #632 Border radius on corner label does not match some UI elements [`#632`](https://github.com/fomantic/Fomantic-UI/issues/632)
- Fixes #622, added as a separate commit to avoid addition committed files. Thanks GianlucaGuarini [`#622`](https://github.com/fomantic/Fomantic-UI/issues/622)
- Fixes #625 Popup using title attribute would not restore its attribute properly with on click. Hide All is invoked on popup not the element causing it to popup, making cached data lost. [`#625`](https://github.com/fomantic/Fomantic-UI/issues/625)
- Fixes #541, onSuccess does not return value of callback [`#541`](https://github.com/fomantic/Fomantic-UI/issues/541)
- Fixes #573, checkbox on grid docs page is broken [`#573`](https://github.com/fomantic/Fomantic-UI/issues/573)
- Fixes #552 Generic ascending/descending icon was overriding some other sort icons. Fixes #552 [`#552`](https://github.com/fomantic/Fomantic-UI/issues/552) [`#552`](https://github.com/fomantic/Fomantic-UI/issues/552)
- Fixes exact matches to breakpoints returning both devices, i.e 768px screens showing both mobile and tablet. Fixes #527 [`#527`](https://github.com/fomantic/Fomantic-UI/issues/527)
- Fixes form add prompt to be more comprehensive, easier to work with, Fixes #567 #541 [`#567`](https://github.com/fomantic/Fomantic-UI/issues/567)
- Fixes #559 issue with homepage wording [`#559`](https://github.com/fomantic/Fomantic-UI/issues/559)
- Fixes #526, callout to divided grid in divider page [`#526`](https://github.com/fomantic/Fomantic-UI/issues/526)
- Dropdown: Fixes #498, dropdown item links not clickable from touch events. Fixes issue with touchmove event not being cremoved after menu hide [`#498`](https://github.com/fomantic/Fomantic-UI/issues/498)
- Inputs: fixes #483 fixes display of fluid action inputs [`#483`](https://github.com/fomantic/Fomantic-UI/issues/483)
- Fixes #486 issue with progres bars in docs [`#486`](https://github.com/fomantic/Fomantic-UI/issues/486)
- Fixes #484 typo from regexp replace causing placeholder not to exist for input [`#484`](https://github.com/fomantic/Fomantic-UI/issues/484)
- Adds warning color to progress (fixes #444) [`#444`](https://github.com/fomantic/Fomantic-UI/issues/444)
- Fixes #473 issue with thumbs up/down receiving up/down arrow formatting [`#473`](https://github.com/fomantic/Fomantic-UI/issues/473)
- Fixes #445 popup using click can sometimes open/close, caused by document clickaway event being preserved [`#445`](https://github.com/fomantic/Fomantic-UI/issues/445)
- Fixes #465 issue with doc menu on definition page [`#465`](https://github.com/fomantic/Fomantic-UI/issues/465)
- Fixes #467 issue with accordion clipping content [`#467`](https://github.com/fomantic/Fomantic-UI/issues/467)
- Fixes #320 stackable grid is overwritten by (x) wide column [`#320`](https://github.com/fomantic/Fomantic-UI/issues/320)
- Input fixes #434, duplicate size in input [`#434`](https://github.com/fomantic/Fomantic-UI/issues/434)
- Fix #422 - Hide native browser tooltip [`#422`](https://github.com/fomantic/Fomantic-UI/issues/422)
- Fixes #409 dropdown does not contain easing definition for fallback js animation [`#409`](https://github.com/fomantic/Fomantic-UI/issues/409)
- Fixes #405, error in dimmer causing modals not to be showable unless active [`#405`](https://github.com/fomantic/Fomantic-UI/issues/405)
- Fixes #391, double closing body tag [`#391`](https://github.com/fomantic/Fomantic-UI/issues/391)
- Fixes #401 issue with stackable padding [`#401`](https://github.com/fomantic/Fomantic-UI/issues/401)
- Fixes #402 issue with revalidation of forms always occuring on change [`#402`](https://github.com/fomantic/Fomantic-UI/issues/402)
- Fixes #360 url missing from input types [`#360`](https://github.com/fomantic/Fomantic-UI/issues/360)
- Fixes #365, has transition does not call function [`#365`](https://github.com/fomantic/Fomantic-UI/issues/365)
- Fixes #359 again, selected item would not select a falsey value [`#359`](https://github.com/fomantic/Fomantic-UI/issues/359)
- Fixes #355 #359 #277 Issue with improper type check on dropdown default values [`#355`](https://github.com/fomantic/Fomantic-UI/issues/355)
- Fixes #338 regression, offstage position was calculated before content position was available. [`#338`](https://github.com/fomantic/Fomantic-UI/issues/338)
- Fixes #330 issue with nested accordion. Adds nested accordion example [`#330`](https://github.com/fomantic/Fomantic-UI/issues/330)
- Fixes #315 typo in icon docs [`#315`](https://github.com/fomantic/Fomantic-UI/issues/315)
- Fixes #315 typo in icon docs [`#315`](https://github.com/fomantic/Fomantic-UI/issues/315)
- Fixes #285 Adds CSS transition support detection to usage of CSS transitions in other modules [`#285`](https://github.com/fomantic/Fomantic-UI/issues/285)
- Fixes #283 issue with regexp not escaping on validation [`#283`](https://github.com/fomantic/Fomantic-UI/issues/283)
- Fixes #251 formatting of links inside labels, adds doc example [`#251`](https://github.com/fomantic/Fomantic-UI/issues/251)
- Fixes #293. Fixes issue with modal queuing, multiple modals. adds new behaviors for controlling modal groups [`#293`](https://github.com/fomantic/Fomantic-UI/issues/293)
- Fixes #289 issue with ie and modals [`#289`](https://github.com/fomantic/Fomantic-UI/issues/289)
- Fixes #275 adds numerical class support for fluid buttons [`#275`](https://github.com/fomantic/Fomantic-UI/issues/275)
- Fixes #277 falsey values are treated as undefined [`#277`](https://github.com/fomantic/Fomantic-UI/issues/277)
- Fixes #273 issue with dropdown icons breaking layout [`#273`](https://github.com/fomantic/Fomantic-UI/issues/273)
- Fixes #268 icon spacing issue [`#268`](https://github.com/fomantic/Fomantic-UI/issues/268)
- Fixes #261 issues with vertical alignment of checkboxes [`#261`](https://github.com/fomantic/Fomantic-UI/issues/261)
- Merge pull request #263 from luisrudge/master [`#262`](https://github.com/fomantic/Fomantic-UI/issues/262)
- Fixes #256, issue with prevent default on click [`#256`](https://github.com/fomantic/Fomantic-UI/issues/256)
- fixes #262 [`#262`](https://github.com/fomantic/Fomantic-UI/issues/262)
- Fixes #61. Touch respones now 0ms responsive, "clickaway" event now [`#61`](https://github.com/fomantic/Fomantic-UI/issues/61)
- fixes #250 adds orange segment and label [`#250`](https://github.com/fomantic/Fomantic-UI/issues/250)
- Fixes #242, adds overflow on item corner labels, there is still an odd rounding error that sometimes appears on dark bgs for corner label, but at least border-radius is obeyed [`#242`](https://github.com/fomantic/Fomantic-UI/issues/242)
- Fixes #247 right menu formatting when used with a secondary menu. adds search formatting for secondary menu and updates docs with a more complex example [`#247`](https://github.com/fomantic/Fomantic-UI/issues/247)
- Fixes #240 adds small/large sizing for modals, adds example of callbacks [`#240`](https://github.com/fomantic/Fomantic-UI/issues/240)
- Fixes #249 issue with rotated icon naming [`#249`](https://github.com/fomantic/Fomantic-UI/issues/249)
- Fixes #239 issue with changes to modal, dimmer close event not destroyed on dimmer on hide [`#239`](https://github.com/fomantic/Fomantic-UI/issues/239)
- fixes #237 docs issue with field label [`#237`](https://github.com/fomantic/Fomantic-UI/issues/237)
- Rewrites modal and dimmer fixes #233, no longer dependencies between closing dimmer and closing modal, each can close separately. Disables transition logging by default [`#233`](https://github.com/fomantic/Fomantic-UI/issues/233)
- Fixes #238 specificty of css rules for overriding 100% column with a 'x wide column' [`#238`](https://github.com/fomantic/Fomantic-UI/issues/238)
- Fixes #197 adds browserstack callout [`#197`](https://github.com/fomantic/Fomantic-UI/issues/197)
- fixes #227 issue with dropdown, build and version uptick [`#227`](https://github.com/fomantic/Fomantic-UI/issues/227)
- Updates development docs to be more thorough fixes #202 [`#202`](https://github.com/fomantic/Fomantic-UI/issues/202)
- Fixes #195 issue with icon mobile display [`#195`](https://github.com/fomantic/Fomantic-UI/issues/195)
- Fixes #172 popup side being inverted, also fixes bug with offstage position not being calculated correctly on multiple refreshes of a popup, showing an offstage popup. Also removes inline styles after popup hide [`#172`](https://github.com/fomantic/Fomantic-UI/issues/172)
- dropdown menu typo caused button dropdown menus to appear on wrong side, fixes #177 [`#177`](https://github.com/fomantic/Fomantic-UI/issues/177)
- fixes #166, heaven knows where the previous commit went [`#166`](https://github.com/fomantic/Fomantic-UI/issues/166)
- Fixes #108 issue with accordion in safari [`#108`](https://github.com/fomantic/Fomantic-UI/issues/108)
- fixes #133 zoom on docs for accessibility [`#133`](https://github.com/fomantic/Fomantic-UI/issues/133)
- fixes #128 popup issue [`#128`](https://github.com/fomantic/Fomantic-UI/issues/128)
- Adds remove to dimmer destroy fixes #151, removes right margin changes [`#151`](https://github.com/fomantic/Fomantic-UI/issues/151)
- Fixes #149, issue with dropdown formatting in menus and dropdown icons [`#149`](https://github.com/fomantic/Fomantic-UI/issues/149)
- fixes #134 issue with menu icon inheritance [`#134`](https://github.com/fomantic/Fomantic-UI/issues/134)
- Modal: Adds attach events method and focus/blur on field on show/hide, fixes #124 [`#124`](https://github.com/fomantic/Fomantic-UI/issues/124)
- fixes #127 page grid issues [`#127`](https://github.com/fomantic/Fomantic-UI/issues/127)
- fixes #116, issue with checkbox input not being selected properly [`#116`](https://github.com/fomantic/Fomantic-UI/issues/116)
- fixes #109 issue with modal centering being forced at 50% [`#109`](https://github.com/fomantic/Fomantic-UI/issues/109)
- fixes #71 and #83, issue is caused by rendering with optimizelegibility [`#71`](https://github.com/fomantic/Fomantic-UI/issues/71)
- fixes #76 jump in icon with input button [`#76`](https://github.com/fomantic/Fomantic-UI/issues/76)
- updates bower json from component json fixes #91 [`#91`](https://github.com/fomantic/Fomantic-UI/issues/91)
- fixes #77 language issue [`#77`](https://github.com/fomantic/Fomantic-UI/issues/77)
- fixes menu from being too large on mobile devices causing formatting issues. Fixes #86 [`#86`](https://github.com/fomantic/Fomantic-UI/issues/86)
- fixes #58, adds close menu item to sidebar when on mobile [`#58`](https://github.com/fomantic/Fomantic-UI/issues/58)
- fixes #89 heinous text shadow still on buttons [`#89`](https://github.com/fomantic/Fomantic-UI/issues/89)
- Fixes #45 label positioning issue [`#45`](https://github.com/fomantic/Fomantic-UI/issues/45)
- Fixes #70 issue with multiline dropdown content [`#70`](https://github.com/fomantic/Fomantic-UI/issues/70)
- Merge pull request #69 from caitp/issue-68 [`#68`](https://github.com/fomantic/Fomantic-UI/issues/68)
- Fixes #63, sizes for inputs. Fixes issues with input icon sometimes not [`#63`](https://github.com/fomantic/Fomantic-UI/issues/63)
- fixes #55 mispelling [`#55`](https://github.com/fomantic/Fomantic-UI/issues/55)
- fixes #52 issue with loading input clearing other icons [`#52`](https://github.com/fomantic/Fomantic-UI/issues/52)
- fixes #41  paragraph margin on demos [`#41`](https://github.com/fomantic/Fomantic-UI/issues/41)
- fixes #44 issue with celled borders. Additionally fixes inverted celled tables [`#44`](https://github.com/fomantic/Fomantic-UI/issues/44)
- fixes #42 labeled icon attaches margin right to other icons [`#42`](https://github.com/fomantic/Fomantic-UI/issues/42)
- fixes #43, neutraface on menus [`#43`](https://github.com/fomantic/Fomantic-UI/issues/43)
- fixes #40 rss feed example float issue [`#40`](https://github.com/fomantic/Fomantic-UI/issues/40)
- fixes #37 input fields inside menus are not centered correctly [`#37`](https://github.com/fomantic/Fomantic-UI/issues/37)
- fixes #39, inheritance issue from menu dropdown [`#39`](https://github.com/fomantic/Fomantic-UI/issues/39)
- fixes #36, chrome causes stuttering (subpixel antialiasing change?)  on animating opacity [`#36`](https://github.com/fomantic/Fomantic-UI/issues/36)
- fixes #35, cursor on toggle in chrome [`#35`](https://github.com/fomantic/Fomantic-UI/issues/35)
- Fixes #34 issues with scrolling menu on definition page [`#34`](https://github.com/fomantic/Fomantic-UI/issues/34)
- Merge pull request #29 from jonhkr/master [`#23`](https://github.com/fomantic/Fomantic-UI/issues/23)
- Fixes #23 issue with queued animations in dropdown and modal [`#23`](https://github.com/fomantic/Fomantic-UI/issues/23)
- Fixes #7 Issue with modal example [`#7`](https://github.com/fomantic/Fomantic-UI/issues/7)
- Adds form validation on all errors on input change regardless of on setting. Fixes #5 [`#5`](https://github.com/fomantic/Fomantic-UI/issues/5)
- Build 2.3.1 [`789d020`](https://github.com/fomantic/Fomantic-UI/commit/789d020a3996e3d52fdb5206b159fc88762b3dac)
- Build 2.3.0 [`72d2235`](https://github.com/fomantic/Fomantic-UI/commit/72d223511a86cb6cd792fe52e1a3da6b2fce2248)
- Rebuild dist files for demo #3724 [`10a3ba6`](https://github.com/fomantic/Fomantic-UI/commit/10a3ba6ed994df9949f1dfbef9f6849c4fc41746)
- Update dist to 2.2.14 [`bef9b46`](https://github.com/fomantic/Fomantic-UI/commit/bef9b4632b91304d39d6d2ef0b2e0eea7c92790b)
- Made a complete port of FA5 with all new icons [`ae37d28`](https://github.com/fomantic/Fomantic-UI/commit/ae37d28b6071677f51cfb67899f1cd3c691b23e9)
- Regen package-lock [`5d4260e`](https://github.com/fomantic/Fomantic-UI/commit/5d4260eddc209ee2e10bb7888f509923cf2e2a1f)
- Reported FA5 using a new method [`b9b2e63`](https://github.com/fomantic/Fomantic-UI/commit/b9b2e63f25ee9f3a89aa7a8ae23f7a3694023c1f)
- Build 2.1.5 [`f2b82bd`](https://github.com/fomantic/Fomantic-UI/commit/f2b82bd1b6e24ca9d5af7d0d3f284ff70c0a5ab0)
- Build 2.1.5 [`1bf0f89`](https://github.com/fomantic/Fomantic-UI/commit/1bf0f89ae785cb562ac8fad3548d6c65a92586a0)
- Build 2.1.8 [`ee3fe51`](https://github.com/fomantic/Fomantic-UI/commit/ee3fe514070cf5d23c6a40bda042664d6f8128f6)
- Build next dist [`b848ce9`](https://github.com/fomantic/Fomantic-UI/commit/b848ce9a3821bc3ff62d0cf1876c113dde1033af)
- Update all NPM deps [`324e538`](https://github.com/fomantic/Fomantic-UI/commit/324e53876dd76b0386b3799c3d6f7d6baed5676a)
- Upgrades FontAwesome to v4.7.0 [`ca893b6`](https://github.com/fomantic/Fomantic-UI/commit/ca893b6160d70125bf0d024acdf03367f9197996)
- Added Material Design Icons to Semantic UI material theme. [`9640218`](https://github.com/fomantic/Fomantic-UI/commit/9640218813bee54ded2b90179147c359ab4a8153)
- Remove undocumented components [`88ea864`](https://github.com/fomantic/Fomantic-UI/commit/88ea864a462e48680f172f448198f640f1431ab8)
- Build 2.2.3 [`8b8a27b`](https://github.com/fomantic/Fomantic-UI/commit/8b8a27bdc93b148d9acc832a21770ca027ea2081)
- Rebuild dist for test case #2626 [`d1bd78a`](https://github.com/fomantic/Fomantic-UI/commit/d1bd78a33e82eff4bb695b70fa060123430b35a6)
- Package lockfile [`dcadce0`](https://github.com/fomantic/Fomantic-UI/commit/dcadce079272bd069b7aab5b83e375a9dccc65f6)
- Fixed a bug with the chart line icon [`de9c9aa`](https://github.com/fomantic/Fomantic-UI/commit/de9c9aac95069cca03ff64ec932e62035e6231dc)
- #6269 Actually do update for iframeresizer.js [`27ff17b`](https://github.com/fomantic/Fomantic-UI/commit/27ff17b55b2c3af03bf3c1fa7449a44a40f7bafe)
- Build 2.3.2 [`3cf595a`](https://github.com/fomantic/Fomantic-UI/commit/3cf595a855bbd65c15d56d23597449a37825823d)
- 2.4 Build [`a119f02`](https://github.com/fomantic/Fomantic-UI/commit/a119f028f695a2b9fdb9d2e823c55fa78866b813)
- Corrected for missing &lt;i&gt; selector [`3554462`](https://github.com/fomantic/Fomantic-UI/commit/355446213969bf2f829fa9b9b042e1ceb1d633da)
- Rebuild dist [`1b48f52`](https://github.com/fomantic/Fomantic-UI/commit/1b48f527eb73d6bc4b1af2e94d52f51c32cec3c3)
- Build 2.2.10 [`dfc323e`](https://github.com/fomantic/Fomantic-UI/commit/dfc323e608ff15e36a336c17ef925ffc27b5bb2e)
- Rebuild dist [`ecfe69c`](https://github.com/fomantic/Fomantic-UI/commit/ecfe69c87f18965768e1e84cf54c3644e7e105e3)
- Build 2.2.11 [`9f1f6ab`](https://github.com/fomantic/Fomantic-UI/commit/9f1f6ab4cda3742e472a809dae71a2555a2ce354)
- Build 2.2.8 [`6bc1c5e`](https://github.com/fomantic/Fomantic-UI/commit/6bc1c5ec4bdaf349e8ac5877f9fee0139a138d9d)
- Package 2.1.7 [`74fea12`](https://github.com/fomantic/Fomantic-UI/commit/74fea12e1fd548cb870872ba5ed59f5acdcc57ba)
- build dist [`d092842`](https://github.com/fomantic/Fomantic-UI/commit/d092842e4548499990db60f1c5fddae91179f4a3)
- Add colors + minor changes [`342451a`](https://github.com/fomantic/Fomantic-UI/commit/342451a417361b5fa9723172264210d14e10612f)
- Removed unneeded files & 2.4 build [`ca81e97`](https://github.com/fomantic/Fomantic-UI/commit/ca81e9796111ce846654c22b50b1498dc54df384)
- Rework outline and brand icons to load from overrides, not define icons if not loaded (except brand which would require a refactor) #6226 [`7fab797`](https://github.com/fomantic/Fomantic-UI/commit/7fab7974a7ffa3a4c74ed760c41ae21d7407dc4e)
- Build 2.3.2 [`e485882`](https://github.com/fomantic/Fomantic-UI/commit/e485882ef375c6873e8e758c7952ab72131636aa)
- Rebuild dist [`da2bfe1`](https://github.com/fomantic/Fomantic-UI/commit/da2bfe1f935ca58e48b300a6edb2aac7e400551c)
- Build 2.0.3 [`616c99c`](https://github.com/fomantic/Fomantic-UI/commit/616c99cdc8fec7f4b1166b852099ad971bef9e3c)
- Rebuild dist [`1af9b61`](https://github.com/fomantic/Fomantic-UI/commit/1af9b61dfc4700cb5dbb51d2faa470957f9fdd0c)
- #6085 dedupe icons from FA5 port [`1587c0b`](https://github.com/fomantic/Fomantic-UI/commit/1587c0be7e71193f6ec054fc6e6d026f1ce58939)
- Rebuild dist [`2d13bd7`](https://github.com/fomantic/Fomantic-UI/commit/2d13bd732f12d6e1e3841c400a9e537c57a4e4dc)
- Revert wrong deletion of the state module [`392854e`](https://github.com/fomantic/Fomantic-UI/commit/392854e2e5dff8850a052ba2f5ea972b9557772a)
- Build 2.0.5 [`ff74fb8`](https://github.com/fomantic/Fomantic-UI/commit/ff74fb8e8ce02e01eff6328607623d2b3cf583cf)
- Build 2.0.3 [`cb01f9f`](https://github.com/fomantic/Fomantic-UI/commit/cb01f9f4629ba9cb521f96d74debddef04871878)
- Build 2.0.2 [`9c1a967`](https://github.com/fomantic/Fomantic-UI/commit/9c1a96738ce40792697163696b1befbdb847360e)
- Build 2.0.6 [`e78514b`](https://github.com/fomantic/Fomantic-UI/commit/e78514b5fc7dc0b161ca7585cc7336dfca19843a)
- Rebuild dist [`5946f9e`](https://github.com/fomantic/Fomantic-UI/commit/5946f9e1803343dbcbaac1b582bafaf086dac925)
- Restructure install steps [`7816f55`](https://github.com/fomantic/Fomantic-UI/commit/7816f55d49625e243e79c027a7b964c02acd95a0)
- Build 2.2.12 [`7864436`](https://github.com/fomantic/Fomantic-UI/commit/78644361cb7ea690707c01ba81aad1c1eb8dd9f9)
- Implement inverted / inverted basic primary / secondary button [`16e4942`](https://github.com/fomantic/Fomantic-UI/commit/16e49424180363bbec3c6aa2994848daf83d483b)
- Build 2.2.8 [`a0fc599`](https://github.com/fomantic/Fomantic-UI/commit/a0fc599c164ec05987beb6fa88fb6763395281a5)
- #2599 Fixes double borders in some attached cases, consolidates attached logic, adds attached examples [`62110fc`](https://github.com/fomantic/Fomantic-UI/commit/62110fc51fd8416fecdfe1ed08a5db76259bdee1)
- Build 2.4 [`89afc72`](https://github.com/fomantic/Fomantic-UI/commit/89afc72aa93a01e3e5a0accc9d7a2dbdf3982d2b)
- Upgrad to normalize 7.0 #4647 [`bd08e15`](https://github.com/fomantic/Fomantic-UI/commit/bd08e15b31c0e2d227d63380d5400e7523e25fa1)
- Rebuild 2.2.11 for release [`7e37d4a`](https://github.com/fomantic/Fomantic-UI/commit/7e37d4a098a51c0a888ca273b07d1423e21eef7c)
- Build 2.0.7 [`068d761`](https://github.com/fomantic/Fomantic-UI/commit/068d76138e5dd2bc3ae8fc757e16e179d21ff8a8)
- Fixed all broken icons, changed some names and updated to 5.0.6 [`58aac93`](https://github.com/fomantic/Fomantic-UI/commit/58aac93a23f3e65a33d0b2224b4dae73c4ded36d)
- Build next ver [`15160d6`](https://github.com/fomantic/Fomantic-UI/commit/15160d6229af95cf6b878768c7440c6e3e86f9f0)
- Rebuild dist [`386384f`](https://github.com/fomantic/Fomantic-UI/commit/386384f6e341acd99f68424daba2bc2c28780f01)
- Adds primary/secondary/positive/negative basic variations #3756 [`7140349`](https://github.com/fomantic/Fomantic-UI/commit/7140349bdf39a01955c1d6265a3a84bdda1f4fd4)
- Updated to 2.2.14 file which fixes the gulp-clone bug [`8b47dd6`](https://github.com/fomantic/Fomantic-UI/commit/8b47dd6ce72a7380cd8c4d8ac51271a8a8e63b2d)
- Re-order rules in form [`a5a7326`](https://github.com/fomantic/Fomantic-UI/commit/a5a7326c0808479f108dcbbe905ea663a374b4ae)
- Revert "Move code and build JS from source" [`9cc1646`](https://github.com/fomantic/Fomantic-UI/commit/9cc1646d93bdb452af6fe07960191752a324b9ac)
- Move code and build JS from source [`2ec1a2a`](https://github.com/fomantic/Fomantic-UI/commit/2ec1a2aeb04e853a3b666c83388e3a81eac42047)
- Finish working on basic label [`0f83ba0`](https://github.com/fomantic/Fomantic-UI/commit/0f83ba085cf3d5e95a27209671fd7594ffe1a4b4)
- Fixing many unexpected regressions #4506, release will wait till morning [`2c26746`](https://github.com/fomantic/Fomantic-UI/commit/2c26746dcedcc1610ab2c4ce0b64c218ab324547)
- Build #2713 [`5639244`](https://github.com/fomantic/Fomantic-UI/commit/56392443ff15fa76263c74560dc92e23684b72d7)
- #2610 partial work on checkbox focus variables [`082a350`](https://github.com/fomantic/Fomantic-UI/commit/082a35065f963889cf15a3127f4fa9131882a663)
- #4267 #5253 Adds new behaviors for form validation - Add rule, Add field, remove field, remove rule [`bd6e37c`](https://github.com/fomantic/Fomantic-UI/commit/bd6e37c5d0b1384e60ba552c9e517a1e938d26b6)
- Updates to ui search to allow local category search, and responsive name width [`95ae3bf`](https://github.com/fomantic/Fomantic-UI/commit/95ae3bf5fc98e2be09dd0656ccf0994baf0573ca)
- Add centered dimmers and modals [`3766a33`](https://github.com/fomantic/Fomantic-UI/commit/3766a338e7cc62d9265f7ab9163a0f8cd0f32cfb)
- Real 2.2.11 build [`4c0c5ca`](https://github.com/fomantic/Fomantic-UI/commit/4c0c5caaec4353777bcb01c30d0447a73d3854a8)
- Rebuild dist [`6b70683`](https://github.com/fomantic/Fomantic-UI/commit/6b70683d922d470d828ddcd644008b8b5586e48a)
- Revert "Build JS files" [`d5c009e`](https://github.com/fomantic/Fomantic-UI/commit/d5c009eaa4da9ac65a83be4756604ff300991078)
- Build JS files [`69cba7f`](https://github.com/fomantic/Fomantic-UI/commit/69cba7f7f3695aa4dddf7fac8b9c2dc1540a464e)
- Wrap more async into tasks [`a0887bb`](https://github.com/fomantic/Fomantic-UI/commit/a0887bbad729c2a7772937744375de8f0f159e36)
- #2526 - Redo methods for determining boundaries exceeded to be more coherent [`d692dbc`](https://github.com/fomantic/Fomantic-UI/commit/d692dbc342890a0e72fd835c96e918ff32983f55)
- Update template [`563e92b`](https://github.com/fomantic/Fomantic-UI/commit/563e92bc950aae6c22fc79e43726008d32004dff)
- Fixes JSONP conditions and rebuilds next #2713 [`25b5e71`](https://github.com/fomantic/Fomantic-UI/commit/25b5e716debe0e42ebde33f901b2e9870a95eef1)
- #2638 - Add doesntContain, doesntContainExactly rules [`750e9f1`](https://github.com/fomantic/Fomantic-UI/commit/750e9f1048f99bc8127f0289e70332065627a4fd)
- Fix popup to use observeChanges instead of autoremove [`b7e317a`](https://github.com/fomantic/Fomantic-UI/commit/b7e317a5de5895b2bac2acb2590e31b7a039c746)
- Finishes #2610 and #2607 issues with checkbox focus styles [`36bab3e`](https://github.com/fomantic/Fomantic-UI/commit/36bab3ec9654afb74154f2de3cbe1fc6158cdf16)
- Format final rlsnotes [`be9b3d6`](https://github.com/fomantic/Fomantic-UI/commit/be9b3d6abcadc2f89464e18441bc8c10af375926)
- #2866 - Add unstackable fields, unstackable form variations [`1a1c3b4`](https://github.com/fomantic/Fomantic-UI/commit/1a1c3b4abb08c8ae44d4696d4c3b6d6daedb58dc)
- #4211 Change is.fitWidth to can.openRightward, fix logic to work after setting leftward [`3b802c3`](https://github.com/fomantic/Fomantic-UI/commit/3b802c33c1aeb7473637e0362f26670c53158d3f)
- Build dropdown module [`1251caf`](https://github.com/fomantic/Fomantic-UI/commit/1251caf0cb6be8c616faff83077996dee20277d1)
- Add labeled button variation, basic label variation [`098d9fc`](https://github.com/fomantic/Fomantic-UI/commit/098d9fc02c1c441c3bd6da69a89c4b14a56c6723)
- Fix possible memory leak in popup/sticky/visibility [`34988c7`](https://github.com/fomantic/Fomantic-UI/commit/34988c7c4fd7adeb7688eb89829f1469572fb702)
- #4368 - Dimmer will now reset settings before each modal show making it simpler to work with multiple modal types in same page [`28bf34e`](https://github.com/fomantic/Fomantic-UI/commit/28bf34ed8a9af485ed0673f6e90d4468c5fab20f)
- #4616 - fixes bug with results displaying when using showNoResults. Adds callbacks to many internal methods for better hooks [`9fa01f6`](https://github.com/fomantic/Fomantic-UI/commit/9fa01f607d4d4718c076f9d0d6a986f1a5ea2c14)
- CSS indenting #3714 [`7ab6597`](https://github.com/fomantic/Fomantic-UI/commit/7ab65977e1577719270edad1a328c9ff9334a06f)
- Update escape key for search [`bfea105`](https://github.com/fomantic/Fomantic-UI/commit/bfea105b12f710a01d56e9c048c5fee906f6489f)
- Input selectors now require child selector to avoid inheritance issues #4157 [`282bdb9`](https://github.com/fomantic/Fomantic-UI/commit/282bdb984e5cfa5df1e14346c3075d2ae97cb7b0)
- Add #1032 tabular variations for all directions [`fa179f7`](https://github.com/fomantic/Fomantic-UI/commit/fa179f766c734953528a5d6ba8c1c471a049517e)
- #2573, refactoring add option value. Adds remove option value when deselected. Consolidated checks into has conditions [`54918e9`](https://github.com/fomantic/Fomantic-UI/commit/54918e9deb670b2d279a10c95aa19ae7e11c16fd)
- #2610 and #2607 iterating on checkbox variable additions [`1e6e843`](https://github.com/fomantic/Fomantic-UI/commit/1e6e843919f58128e2c510fd61f0833792cf598f)
- #703 #4093, is valid no longer triggers UI updates, adds ability to validate individual fields [`ad03335`](https://github.com/fomantic/Fomantic-UI/commit/ad03335509ed7083a908c1b705f07109db5651b3)
- Dont do anything with outline/brand inside definition (this is part of override). Use existing names to avoid backwards compatability issues #6226 [`cf70177`](https://github.com/fomantic/Fomantic-UI/commit/cf70177a378746b202df30745638865b32c90b39)
- Adds tiny size modal #5123 [`66cc709`](https://github.com/fomantic/Fomantic-UI/commit/66cc7098eedf32a6529019c0b71338d9fbbc7a39)
- Last minute regression fixes from leftward changes #4506 [`2c3511b`](https://github.com/fomantic/Fomantic-UI/commit/2c3511b99c420ae16ff844b9f2b1094a01568b96)
- Reset dist/components/dropdown.js [`587a702`](https://github.com/fomantic/Fomantic-UI/commit/587a702713d66e6e7811b33de6d89a83d840dd72)
- Reset dist/semantic.js [`95ec084`](https://github.com/fomantic/Fomantic-UI/commit/95ec084c3ae73bc338480153049677586bdbf813)
- Move code to source file [`36ba0fe`](https://github.com/fomantic/Fomantic-UI/commit/36ba0fe8a545e02600e157c17ccb043e46710338)
- Add custom scrollbar styles [`ede9f98`](https://github.com/fomantic/Fomantic-UI/commit/ede9f9839cd94a30457d3d80ebf7cd35908e12bb)
- Updated/Fixed buttons after SUI patch [`19aa345`](https://github.com/fomantic/Fomantic-UI/commit/19aa345934b2d360c58d182709ba344357a6353f)
- Add issue templates [`20361f2`](https://github.com/fomantic/Fomantic-UI/commit/20361f20d1c5d9bc21433b48f03817b5261751f7)
- Release notes and build 2.0.4 [`b22a40e`](https://github.com/fomantic/Fomantic-UI/commit/b22a40ee7065f2fe8342795dcd0a8f87ed89a214)
- Fixes alignment of dimmer [`fc60ec0`](https://github.com/fomantic/Fomantic-UI/commit/fc60ec009c46590372594ba3e0d975a7717b2b9b)
- Adds many new tabular variables [`8cd1d30`](https://github.com/fomantic/Fomantic-UI/commit/8cd1d304fce4979f9733d865e61f0bd6e5daf512)
- #2648 - Fix issue when build/watch tasks are imported without sub-tasks defined [`021da85`](https://github.com/fomantic/Fomantic-UI/commit/021da85e3cfd90fa9ac8b2bc0172da4443de538b)
- Rlsnotes, links and warnings [`cb9e3c8`](https://github.com/fomantic/Fomantic-UI/commit/cb9e3c8e942d988e836fe58aac6e9326bda79ccd)
- Adjust appearance of labeled icon menu [`c0f3c4f`](https://github.com/fomantic/Fomantic-UI/commit/c0f3c4ff01d8163c14a345d02de37f44011ef40a)
- #4029 Fixes issue with dropdown mutation observer not handling case where entire &lt;select&gt; is replaced. Update placeholder text usage. Add new values option for initialized dropdowns from js [`ef94ea8`](https://github.com/fomantic/Fomantic-UI/commit/ef94ea8e65ddd8639fd5c2aa30fd6ff8ad8d06af)
- Undo unnecessary formatting [`3705e96`](https://github.com/fomantic/Fomantic-UI/commit/3705e960b984b55bda8fa913bf4bb5ac78e419e0)
- Break out close events into separate methods [`775df0e`](https://github.com/fomantic/Fomantic-UI/commit/775df0e06179e5330a684379eb8b604718e41ed5)
- Fix isssues when using messages instead of labels, with max selection and display count [`4c1d7d0`](https://github.com/fomantic/Fomantic-UI/commit/4c1d7d0456f1187440a81f05fd02ca4cb5127b99)
- Rebuild 2.0.3 [`53ff84e`](https://github.com/fomantic/Fomantic-UI/commit/53ff84e1655e4ba00bb6d02c155c33f3ef50b494)
- fix(dropdown): Only update text if action is activate or combo [`c296538`](https://github.com/fomantic/Fomantic-UI/commit/c296538616b4d1d8522dd81bbccb9df84bc71cb6)
- Use single quotes for string literals [`ab535ba`](https://github.com/fomantic/Fomantic-UI/commit/ab535ba375e71e27aa41026e45b7aa4857d8c060)
- #2713 Possible fix for complete returning XHR and not response [`039b549`](https://github.com/fomantic/Fomantic-UI/commit/039b5490ac51b9be906a7ad42ed9bf06dbc33cf2)
- #2689 #2690 Fixes issues with restore defaults. Fixes issues with confusion over set selected [`46b5d53`](https://github.com/fomantic/Fomantic-UI/commit/46b5d53cc5cc2ce0a70efa2332659ae544956e72)
- #2636 Tests & Fixes 0, 1, and 2 conditions for minLength, maxLength and exactLength [`93a92d2`](https://github.com/fomantic/Fomantic-UI/commit/93a92d2bf067b4670d2eb7a389e348f8c75b24ff)
- Added a primary and secondary colored card [`6588b79`](https://github.com/fomantic/Fomantic-UI/commit/6588b7970ea749b9a15d2b096cc0b34847b8ec0d)
- Added a primary and secondary colored card [`c3b08b7`](https://github.com/fomantic/Fomantic-UI/commit/c3b08b732253950769bd203b0813685d84d2568f)
- Fix relaxed/veryrelaxed grid container [`ffd2a73`](https://github.com/fomantic/Fomantic-UI/commit/ffd2a73c1dad674888607ea94b2c217fc2962032)
- feat(dropdown): Add new hideDivider option [`5112bdd`](https://github.com/fomantic/Fomantic-UI/commit/5112bddb92571c3620e9892745644181f7c4694d)
- Added primary and secondary colored headers [`f77256b`](https://github.com/fomantic/Fomantic-UI/commit/f77256bc1f5cfeb1879fd240e66f34be4c0538d3)
- #3432 implement matching user addition case [`0fa5821`](https://github.com/fomantic/Fomantic-UI/commit/0fa58217adef109e22faa3722d2d4f30bef71ac5)
- Fixed an issue whith child `.card` elements incorrectly inheriting their parents’ rules [`c5ede18`](https://github.com/fomantic/Fomantic-UI/commit/c5ede1822209822141bd2681083ef5b1cc316945)
- #4506 leftward now only checks on rightward, so predefined leftward menus are not touched. Fixes spacing on left dropdown icon [`56865fd`](https://github.com/fomantic/Fomantic-UI/commit/56865fd40379843a2ed558c09c0e5297d383224d)
- Add arrow centering on small popups [`0f464a6`](https://github.com/fomantic/Fomantic-UI/commit/0f464a6ca1acef0723d7a81533a27e09f26946a9)
- Spelling and link fixes [`3d49954`](https://github.com/fomantic/Fomantic-UI/commit/3d499541e8ad23a8d6e4875309f057e87f13a26f)
- rebuild dist [`2b41fda`](https://github.com/fomantic/Fomantic-UI/commit/2b41fda2a9c07831658e67fcf709120665f81d18)
- Rebuild dist [`7849999`](https://github.com/fomantic/Fomantic-UI/commit/784999926cd2a131d14aeb2968c4a4ef7caeefae)
- Removal observer always should use document to teardown [`250a465`](https://github.com/fomantic/Fomantic-UI/commit/250a465263232d89ac540bf3e68b62196ee5e5ae)
- Adds raised card varaition, darkens floating shadow slightly [`fc518a3`](https://github.com/fomantic/Fomantic-UI/commit/fc518a3e34f4b71c6ef0be5e843cecc12eb33988)
- Add zoom transition [`d32b2eb`](https://github.com/fomantic/Fomantic-UI/commit/d32b2eba169fdc3b61bff5b962d2f07d1adea1e5)
- Adds unstackable variation to items #2901 [`cec0772`](https://github.com/fomantic/Fomantic-UI/commit/cec077273fcc5f7e3b0a66eeedda4490f5fd45b4)
- Update readme [`971b7d0`](https://github.com/fomantic/Fomantic-UI/commit/971b7d0fcb0044ff4e6b8479a953d5336db41fc8)
- rlsnotes [`e63201e`](https://github.com/fomantic/Fomantic-UI/commit/e63201ef9ae9661b243cdac7a3c64ed88fbf2644)
- Release notes [`e198bdf`](https://github.com/fomantic/Fomantic-UI/commit/e198bdf5ecd7334988f1c429d6e82427ef92ee05)
- Adds additional segment variables, background variables should allow for images, fixes github segment margin [`5f701c1`](https://github.com/fomantic/Fomantic-UI/commit/5f701c1fbef6ec5ff50bf633899793cd5bb4d03e)
- Updated dependencies [`1555c7d`](https://github.com/fomantic/Fomantic-UI/commit/1555c7d54a2376da33e702e21863c0ed9dcde6e4)
- Add PR template [`c153656`](https://github.com/fomantic/Fomantic-UI/commit/c1536561f4cf366b270927fdab853d96242f87a9)
- #3396 modal close [`aa33138`](https://github.com/fomantic/Fomantic-UI/commit/aa331386d0b8bd7234d68485c1ae0b8fc4a96269)
- #4267 #5253 Fix some mistaken logic [`8f1409a`](https://github.com/fomantic/Fomantic-UI/commit/8f1409aeb5e540ae647670bca556996abbadbcfb)
- Undo unnecessary formatting [`0493cad`](https://github.com/fomantic/Fomantic-UI/commit/0493cad4177622896072674a84743ddb9ed4abd6)
- #2599 Finish attached logic [`b5b1374`](https://github.com/fomantic/Fomantic-UI/commit/b5b137408f9285933f0dee59bee14089e9e8f374)
- Adds #3744 - Calling dropdown() on select initialized as dropdown now works [`313f8f4`](https://github.com/fomantic/Fomantic-UI/commit/313f8f4a4a7f7bee581ca0af415aa9e82cf02bbb)
- Fix inheritance issue with segments #4013 [`f8e295f`](https://github.com/fomantic/Fomantic-UI/commit/f8e295fcffa77504896ffecf8fee0a82f56347c6)
- #4688 #4692 Fixes issue where backslash and other spcial characters may cause dropdown to fail [`152482a`](https://github.com/fomantic/Fomantic-UI/commit/152482a9e2298608eb81bdd517b53720cd473183)
- Fixes dropdown arrow on left/right pointing #4896 [`9642bda`](https://github.com/fomantic/Fomantic-UI/commit/9642bdaef8cf6258b1179410d3e04a3a23693d86)
- Enable error message for offstage position, adjust lastResort to also allow true instead of specified position [`9b2b159`](https://github.com/fomantic/Fomantic-UI/commit/9b2b1590ed4fc35f37b55c687a0410d4f69cd73d)
- [Label] Use basicBackground with background [`2bbd880`](https://github.com/fomantic/Fomantic-UI/commit/2bbd88060e30c3791e1b2c182b8071758761595c)
- Fix links in release notes [`8c0d3ab`](https://github.com/fomantic/Fomantic-UI/commit/8c0d3abc81bee5557594ad42c511a1c54df5839f)
- Adds glow transition [`0141f6e`](https://github.com/fomantic/Fomantic-UI/commit/0141f6ed25aa44559bfdd200de5ac2bc8e075882)
- Add additional weight to link list states #5603 [`e43e7ac`](https://github.com/fomantic/Fomantic-UI/commit/e43e7ac25664c5866a40c69d7f5d73fcfa31340c)
- Added primary and secondary colored icons [`0b8f73a`](https://github.com/fomantic/Fomantic-UI/commit/0b8f73ad001d2d52a09c4152d11c19e1d887dd5e)
- Fix input to work with basic label, fix basic label hover, add left labeled button [`c2cfd76`](https://github.com/fomantic/Fomantic-UI/commit/c2cfd765f4e4d4d7cf5a28f41713e3072033f45b)
- Adds JSON decode to onFailure #2713 [`03e4965`](https://github.com/fomantic/Fomantic-UI/commit/03e4965571c19da29f6952de3b99ac52a468453a)
- #2655 Fixes vertical basic buttons not aligned correctly [`79ca738`](https://github.com/fomantic/Fomantic-UI/commit/79ca738d05973ef4ea63424c1a14687dae775e30)
- Update stale.yml [`185b320`](https://github.com/fomantic/Fomantic-UI/commit/185b3208cb6f248781d89b3df63b5f43c6b95d1c)
- Add issue links [`e211f49`](https://github.com/fomantic/Fomantic-UI/commit/e211f49e9535d23dd65f3266915304c144e67cff)
- Add popupVisible className setting [`55508be`](https://github.com/fomantic/Fomantic-UI/commit/55508be387d726f3d6b356a9cea37d6544b559ca)
- #2737 fix improper selector for autofocus setting, move setting check to outside function so it can be called manually [`a1ca414`](https://github.com/fomantic/Fomantic-UI/commit/a1ca41407647c13897142dd57b4b31a7413cc43b)
- feat(dropdown): Extend sortSelect with 'natural' and custom function [`a1aff81`](https://github.com/fomantic/Fomantic-UI/commit/a1aff812a78788bd0be3b3d06859c236ba3614ab)
- Fix issue in implementation of closable on dimmer, fix issue with not namespacing dimmer in modal [`fa08398`](https://github.com/fomantic/Fomantic-UI/commit/fa08398aad20f7764aa99afdea1e123a178b80a9)
- Add inverted scrollbar styles [`9ef8f0e`](https://github.com/fomantic/Fomantic-UI/commit/9ef8f0e8551131e74cfc3e7e28945c4483e2c741)
- #2681 return length to functioning as minLength, add exact length [`208c9d6`](https://github.com/fomantic/Fomantic-UI/commit/208c9d6c59725911f1fee43a63fdcd0e274679a9)
- #2666 - remove label does not correctly use get.values() internally, causing a type error with multiple [`14dea43`](https://github.com/fomantic/Fomantic-UI/commit/14dea43662f6302c4581e5d0917c6362d49b942e)
- Removed stale.yml [`d64524c`](https://github.com/fomantic/Fomantic-UI/commit/d64524cc41f367b381cd9fbd39c285a4ad677062)
- Create stale.yml [`8c8ed1f`](https://github.com/fomantic/Fomantic-UI/commit/8c8ed1f76c55cb9d4e27be0f4a642a9429b959b0)
- Adds new setSize setting to sticky, fixes issue with percentage based containers #4360 [`bea2c71`](https://github.com/fomantic/Fomantic-UI/commit/bea2c71af8178faca8d9f38a386817ab3b292067)
- Fix basic step theme [`260e15d`](https://github.com/fomantic/Fomantic-UI/commit/260e15dc6eb706a41d6c685296e58e74d30be4ca)
- #2576 Modal will remove body style after hiding [`6fbabf4`](https://github.com/fomantic/Fomantic-UI/commit/6fbabf4c2bc996341c13995d220c47f4d20bce22)
- Add mobile styles for search [`0727e5e`](https://github.com/fomantic/Fomantic-UI/commit/0727e5e5ad08169be4da9ee0d16c6200046a82b7)
- Correctly calculate offset when popup is in a different positioning context [`5e9535e`](https://github.com/fomantic/Fomantic-UI/commit/5e9535e1f0a041a1fcd923685548c09d2a486253)
- Only reposition the current menu element [`06aaeb0`](https://github.com/fomantic/Fomantic-UI/commit/06aaeb007a81553539def3dcae4ce6b4d8d8456a)
- #2583 rlsnotes [`95542ce`](https://github.com/fomantic/Fomantic-UI/commit/95542cea87c8ac7dc59544feb23e1300d66024bd)
- #2526 Popup fluid width is now set by its parent DOM element, not its offsetContext (i.e. thing with position: relative) [`5d113c0`](https://github.com/fomantic/Fomantic-UI/commit/5d113c01a513a660896c4d0f800d48ee442f391f)
- Add solve for dimmer to prevent modal scrolling in bg [`75dcaa2`](https://github.com/fomantic/Fomantic-UI/commit/75dcaa2694da2aaa681aff1be74b2c0f3fab4028)
- #6192 centering/bordered icons [`59be6ec`](https://github.com/fomantic/Fomantic-UI/commit/59be6ec5a15ca3ed920b7a3e5e47d1795e024386)
- Final rlsnotes [`cb0f940`](https://github.com/fomantic/Fomantic-UI/commit/cb0f940dd22486b604c3c0e96132e972972284a3)
- Rlsnotes add links [`2915862`](https://github.com/fomantic/Fomantic-UI/commit/2915862167dc7941b6886b6a2a43b8263499d87e)
- #4163 #4164 More general fix that properly escapes string values for selectors [`6f19675`](https://github.com/fomantic/Fomantic-UI/commit/6f19675c526f2df31a676dcc22676554f2959e1b)
- Visibility type: fixed now properly tears down on destroy #3548 [`ad8fb89`](https://github.com/fomantic/Fomantic-UI/commit/ad8fb89ec3ae21b59a474e57d72115f7d65b260c)
- Related #2713 add XHR to all callbacks [`44bf836`](https://github.com/fomantic/Fomantic-UI/commit/44bf836651761e0e7c993df922f081bb2afba981)
- linkify rlsnotes [`b660d70`](https://github.com/fomantic/Fomantic-UI/commit/b660d70c1a91c89770ffc2112ec4f06f3fa70b3d)
- Add PR links to rlsnotes [`54491f4`](https://github.com/fomantic/Fomantic-UI/commit/54491f49252fc5d6e6027d794d73e0ddb1950789)
- Fix inverted scrollbars in inverted ui [`a528f20`](https://github.com/fomantic/Fomantic-UI/commit/a528f207387c4390e84326f9da1d2ddc301786a3)
- Wow i suck [`d481304`](https://github.com/fomantic/Fomantic-UI/commit/d48130406f4d2b9bb370fc8d9be6aee8e6c197a5)
- Fix visibility inside scroll context [`b962d89`](https://github.com/fomantic/Fomantic-UI/commit/b962d899f1587fd8b4a84fa198b2c38e897911a7)
- #2676 Checkbox now correctly prevent default event on keyup not keydown [`8f6bc3d`](https://github.com/fomantic/Fomantic-UI/commit/8f6bc3df803385dfb4c460a8a0129e6fcdf21727)
- Start of 2.4 release notes [`135246a`](https://github.com/fomantic/Fomantic-UI/commit/135246af911d74e43ea168b443be5132f1c05d2a)
- #5231 #5809 Recursion in remote search when results are success but return no results on show [`b4edc1b`](https://github.com/fomantic/Fomantic-UI/commit/b4edc1b380fb630314bcdea8584b64569084618c)
- Fix issue with bottom margin on stats [`18ecf15`](https://github.com/fomantic/Fomantic-UI/commit/18ecf158a355eaf8da8ff4844f0030aa72159d48)
- Adds @normal usage for non default themes #6227 [`87c62ff`](https://github.com/fomantic/Fomantic-UI/commit/87c62ffcc74b11c9cc5c78961ed1076d31a87ea8)
- Fix searchdelay could make results appear even after search has lost focus [`2a53a9f`](https://github.com/fomantic/Fomantic-UI/commit/2a53a9fbd02ff40074fbefcdf03e23ee57f693c3)
- Related #2605, sticky no longer uses bottomPadding for determining bottom edge of context. This is counterintuitive and in most cases wrong [`253bdc5`](https://github.com/fomantic/Fomantic-UI/commit/253bdc5c53aae3132715c103abc2a48461b11eae)
- fix(dropdown): Check if search is active and focus/blur the search field when toggling the dropdown with the icon [`ba8aae5`](https://github.com/fomantic/Fomantic-UI/commit/ba8aae52bec367d2035f781bb6bdf9008d6333e1)
- Changed @solidFontName to @fontName [`75db2ed`](https://github.com/fomantic/Fomantic-UI/commit/75db2edc75abbccf02eec4f511e03a7767bb6bad)
- Rlsnotes  2.0.5 [`072e6bc`](https://github.com/fomantic/Fomantic-UI/commit/072e6bc595eb4dac059dca6d4e6c61d8e8e29d22)
- Fix issue with overflow: scroll [`bcdc1f0`](https://github.com/fomantic/Fomantic-UI/commit/bcdc1f018cd88634bb022e2ffd54fe74848a6593)
- Clean up logic in onComplete for cogency  #2713 [`66c89ad`](https://github.com/fomantic/Fomantic-UI/commit/66c89add39b8b0a2db6a44fed5fb7211f9f9d614)
- #2394 URL values will now encode while avoiding double encoding [`fc6df94`](https://github.com/fomantic/Fomantic-UI/commit/fc6df94ea36435a582c63dc5aa2f9e90ce09b22a)
- #2556 Adds back black icons [`4b7a8fe`](https://github.com/fomantic/Fomantic-UI/commit/4b7a8fe19138c31893a8dfbe48b5a872eac92ae8)
- Fix dropdowns inside overflow containers [`619386e`](https://github.com/fomantic/Fomantic-UI/commit/619386ebbc714447e9c2ca4d50c7460ffcf98239)
- #4279, preserve em units for math, fix h1-h5 to use exact decimals as well [`00b7d08`](https://github.com/fomantic/Fomantic-UI/commit/00b7d089525ac5af6a15fa5075d8377489d1fc35)
- Fix typo in icon menu [`96502c3`](https://github.com/fomantic/Fomantic-UI/commit/96502c31348c9905ff204339e6c71f7229877e71)
- Fix admin tasks failing to create npm repos for single components [`82159da`](https://github.com/fomantic/Fomantic-UI/commit/82159dafeb4d6dbc6f2347a0d9fc7bd20f66f6d2)
- #6192 few missing aliases for outline #6232 [`3f5ca5a`](https://github.com/fomantic/Fomantic-UI/commit/3f5ca5a6954c8f4291794c80c4a9d243a24c2bb8)
- Fix bug with autofocus modifying focus of modal fields [`dcf6a93`](https://github.com/fomantic/Fomantic-UI/commit/dcf6a933956a3cbc82a63a99fbf84ea84ce4b779)
- #5391 - Fixes issue with deprecated uglify setting in build tools [`cd3a639`](https://github.com/fomantic/Fomantic-UI/commit/cd3a639a5461c896d7c6a09792ca96377cf98a33)
- #4211 - Fix left pointing menu to swap sides with leftward [`9425380`](https://github.com/fomantic/Fomantic-UI/commit/942538047ed0a2028e7dd8f67f79821bf06b9afa)
- #4163 #4164 Fixes associative array name values not working correctly [`6e88af1`](https://github.com/fomantic/Fomantic-UI/commit/6e88af15b7cf356ca46f744d6de47fe592650860)
- Allow `onHide` callbacks for dropdown prevent hiding [`4dfeaab`](https://github.com/fomantic/Fomantic-UI/commit/4dfeaabe9b63772dd72ec1a9d8058dcc07c8c0e2)
- #2526 Add jitter to deal with rounding issues when popup is adjacent to edge [`5b2b198`](https://github.com/fomantic/Fomantic-UI/commit/5b2b1981018722cdb3aab047011f1be94f97c178)
- Build 2.3.2 [`8a25358`](https://github.com/fomantic/Fomantic-UI/commit/8a25358ae52cbbfb9f07760789b5632e39f71707)
-  Fix icon inside label inside a.item wrongly colored [`c0bdf53`](https://github.com/fomantic/Fomantic-UI/commit/c0bdf5300a980ff5db862d6fc1f1b38e76eca904)
- Adds coupling for ribbon label with reveal #5681 [`c423611`](https://github.com/fomantic/Fomantic-UI/commit/c4236115ade83b45c2d234f73a3b9ab2688b7f1d)
- Fix issue where dropdowns might animate outward two times on blur [`2c5cc6f`](https://github.com/fomantic/Fomantic-UI/commit/2c5cc6fc1c06130500db17cac948a6dd0c388d0c)
- Add scrolling content style [`784c0a1`](https://github.com/fomantic/Fomantic-UI/commit/784c0a191ab4b86655d100345359728334e3800a)
- #2615 re-order settings [`c091f50`](https://github.com/fomantic/Fomantic-UI/commit/c091f50aa7bef2371eda7c5f5cf9e5b3370e70f6)
- Fix eventNamespace in #3396 [`3827fd0`](https://github.com/fomantic/Fomantic-UI/commit/3827fd0a82ec4303874faf16439ffaa3a806540b)
- Fix issue with bottomPassed and topPassed [`3bbaf13`](https://github.com/fomantic/Fomantic-UI/commit/3bbaf137b575c660af12cc89d6b811a8ae15cb8c)
- Rlsnotes [`58a5fb5`](https://github.com/fomantic/Fomantic-UI/commit/58a5fb5e96365d7327780ed7c136b1b4f4f98039)
- Rlsnotes #2700 [`d334b7f`](https://github.com/fomantic/Fomantic-UI/commit/d334b7f14c3647fc7f71b7fa7045fa25bca13c15)
- Rlsnotes [`c82c668`](https://github.com/fomantic/Fomantic-UI/commit/c82c66851079b806a941764ea8da3d65e64c44fc)
- #2629 Throw error when identifier is a non-string value [`b756bb5`](https://github.com/fomantic/Fomantic-UI/commit/b756bb52fe378fc95fb05b3a454aadb00ae12dcf)
- #2526 adjust comments [`bc736b2`](https://github.com/fomantic/Fomantic-UI/commit/bc736b2e5f55eae1269cd752d3a06d0f47194f2c)
- Metadata can now be used to parse content links in docs [`c7e16ef`](https://github.com/fomantic/Fomantic-UI/commit/c7e16efe3db9342ee29a6f7fd5655406bf56547a)
- Fix double margin on nested images #6224 [`b93737e`](https://github.com/fomantic/Fomantic-UI/commit/b93737e07189aa61b5326304d5e72448f6df2f16)
- Better implementation of #6016 passing value to callback [`e137ee1`](https://github.com/fomantic/Fomantic-UI/commit/e137ee1bfd5b89ac699efd9a1d56f9e27c16d93d)
- http -&gt; https [`c325005`](https://github.com/fomantic/Fomantic-UI/commit/c325005722094571d62a97500b42e0a5e92918a6)
- Update rlsnotes [`df2b59a`](https://github.com/fomantic/Fomantic-UI/commit/df2b59a3122588a9a8bac22794867ced8e58ae58)
- #5522 update jsfiddle link to canonical [`073db05`](https://github.com/fomantic/Fomantic-UI/commit/073db057a98ac9237fc4b7e73f0dc2b4a4e8371a)
- Update the JSFiddle. [`8eeb3ad`](https://github.com/fomantic/Fomantic-UI/commit/8eeb3ad70f5402aa1a4086d69340acaee2ab98ac)
- Rlsnote lang [`7491b94`](https://github.com/fomantic/Fomantic-UI/commit/7491b9455f116a5508e2d4caf40726ef843779a9)
- Fixes issue with visibility type image re-animating when reinitialized [`b9d402d`](https://github.com/fomantic/Fomantic-UI/commit/b9d402d62bd988281c6705856c36d8ceffaac22c)
- Search remote data before showing if necessary #4041, fix typo in remote search setting [`6b759b7`](https://github.com/fomantic/Fomantic-UI/commit/6b759b74c0470164abd614e0a89bcfccbc8363b1)
- Fix needs docs rlsnotes [`5ab6b1d`](https://github.com/fomantic/Fomantic-UI/commit/5ab6b1d04fcb2190d77fbbc4bd40b1d6180d4f43)
- Text menu now uses padding for larger hitboxes [`f585d4c`](https://github.com/fomantic/Fomantic-UI/commit/f585d4cf16230456431c0258f9932e155aba29c4)
- Update rlsnotes [`5bca2d9`](https://github.com/fomantic/Fomantic-UI/commit/5bca2d9fbb9809b3b0eef19a456c55a8e170160f)
- #2649 additional style pruning, remove two unnecessary scope uses from less [`db968a4`](https://github.com/fomantic/Fomantic-UI/commit/db968a4e05cd16bdae927468f87f3c12faad1382)
- Update search.js to allow custom display fields [`0119240`](https://github.com/fomantic/Fomantic-UI/commit/0119240944459081fc2a2e00fb6c78cab9e37af0)
- #2573 Fixes &lt;select&gt; will not add option values with remote data. [`e61b39c`](https://github.com/fomantic/Fomantic-UI/commit/e61b39c16b73160d03165a185433b074a4be693f)
- Thanks #4614 [`1ce9e1c`](https://github.com/fomantic/Fomantic-UI/commit/1ce9e1cc29779b5b4635e0b4e5df728d7398ca65)
- Add coupling for lists inside menus, fix box shadow showing as border #5603 [`66df031`](https://github.com/fomantic/Fomantic-UI/commit/66df031f4b950dc32c230fd2a5a7d3fa6f6bb14f)
- Attempting to fix install message [`7e21869`](https://github.com/fomantic/Fomantic-UI/commit/7e218698920307453a5fd3f572a28bc766cc9d5b)
- Match formatting #3085 [`f87ae3d`](https://github.com/fomantic/Fomantic-UI/commit/f87ae3d6f61ad6850a017fade0ddd6c6f8792256)
- Fix unchecked checkboxes not being accessible with get value [`688c645`](https://github.com/fomantic/Fomantic-UI/commit/688c64551a0bbedf602d9641e0ba8452bdbd4332)
- #2505 #2501 radio checkbox regression during fixes to #2610 [`7d5ea33`](https://github.com/fomantic/Fomantic-UI/commit/7d5ea33a0a21cd42d37c87e4e402b98dff23fba5)
- Fix issue with credential caching in publish script due to https git urls [`3838710`](https://github.com/fomantic/Fomantic-UI/commit/383871090cda527df916e1751279b3de79b07480)
- Release notes 2.3.2 [`d8b8461`](https://github.com/fomantic/Fomantic-UI/commit/d8b8461f1b472dafe5090a824c1e11498dcd26a3)
- Update PULL_REQUEST_TEMPLATE.md [`c272475`](https://github.com/fomantic/Fomantic-UI/commit/c272475f314ab21b1f3a253aed28318cfd43e912)
- Minor button theme change [`faa5e3b`](https://github.com/fomantic/Fomantic-UI/commit/faa5e3bfccd9f576e75a7fe4d3925cab96929403)
- Fix element structure [`6175d52`](https://github.com/fomantic/Fomantic-UI/commit/6175d523c19ac0da65554849832c484214160259)
- Typos in release notes [`1d63034`](https://github.com/fomantic/Fomantic-UI/commit/1d630340bcc48b742c4a80882a61c25e058d56e9)
- #5366, #5975 - Fixes issue with offset not available on window [`18ac909`](https://github.com/fomantic/Fomantic-UI/commit/18ac909518276804e998cf7d92be79f3e66c6647)
- Fix error which could cause popup to use wrong offset context when specifying popup manually [`8df7f2f`](https://github.com/fomantic/Fomantic-UI/commit/8df7f2f2c75cbdf68cc5134dd2357895c66fdd5c)
- Setup forked prompt package [`f89dc9c`](https://github.com/fomantic/Fomantic-UI/commit/f89dc9c36c084605e787c77fc99290170b8f7b38)
- Default theme folder can be configured [`dedec07`](https://github.com/fomantic/Fomantic-UI/commit/dedec07aaa135f7b4ab557d7eb8e77da9cb7ff3d)
- Fix positioning with loading/dropdown icon [`635a0ee`](https://github.com/fomantic/Fomantic-UI/commit/635a0eed735fb45370e08a4216b6d9d8ea0ef519)
- 5122 allow dashed cc values [`31b28a1`](https://github.com/fomantic/Fomantic-UI/commit/31b28a1950364a56b8c08e4e715743cc288bbc48)
- #2534 - Add cacheType setting, response or html. Response caches original response so that execution occurs in same way each load. HTML caches final html content after callbacks [`6b5c383`](https://github.com/fomantic/Fomantic-UI/commit/6b5c383dabfda853e6862a59a5b4edf9dda1c01e)
- Add right/left floated lists [`d0d42c4`](https://github.com/fomantic/Fomantic-UI/commit/d0d42c4941d0baf3ba2928cf9705cd9cfa566873)
- Finish notes [`9dd18d4`](https://github.com/fomantic/Fomantic-UI/commit/9dd18d41f883bd1e1e11bbcd480134bccc71a7cf)
- Hoist install folder [`fc0e03d`](https://github.com/fomantic/Fomantic-UI/commit/fc0e03d98b5a62176e6e228c2f30d8df4feb573a)
- #2605 last scroll value should only be saved if element scroll position changes [`b61fef3`](https://github.com/fomantic/Fomantic-UI/commit/b61fef3205dfefe5a4832841dbeb625a968603fe)
- #2617 Fixes unnecesssary use of flex with fluid button [`e5eca74`](https://github.com/fomantic/Fomantic-UI/commit/e5eca744d025c76afda58e1e0acf5b355828b3a4)
- Fixed typo in README.md [`d6dace4`](https://github.com/fomantic/Fomantic-UI/commit/d6dace4824b3b1eea5263699b49e008d9f9d84b3)
- #2573 Fix derp conditions of else [`4be9213`](https://github.com/fomantic/Fomantic-UI/commit/4be921336a3ce9695d856151d8b24d8e28ed1f4a)
- Rlsnotes #6242g [`a6e8c0b`](https://github.com/fomantic/Fomantic-UI/commit/a6e8c0bd73715f55616adcf03888ad44bc44fe7b)
- #5892 - Add onChanging callback [`d168eab`](https://github.com/fomantic/Fomantic-UI/commit/d168eab1710affc262d5c56312fd2cdc993b0e95)
- Rlsnotes #6043, #5713, 6067 [`3c72588`](https://github.com/fomantic/Fomantic-UI/commit/3c72588bd54f8e43a5c4cb7bc1a87f1236625f92)
- #6043 #5713 code formatting [`8b21e93`](https://github.com/fomantic/Fomantic-UI/commit/8b21e930fc33853dff911b3ab0420789f5ac8054)
- Update rlsnotes [`d1f5ea3`](https://github.com/fomantic/Fomantic-UI/commit/d1f5ea3e111ed5155525a5fddbf4193ab9519757)
- Fix for #5713 [`afff7b2`](https://github.com/fomantic/Fomantic-UI/commit/afff7b2535b497132acdd5150f8c2327b8d2ca6e)
- Fix top right pointing dropdown to move arrow when leftward #4211 [`b13bef1`](https://github.com/fomantic/Fomantic-UI/commit/b13bef17bca184d6b25525dead65ec27293b29ea)
- Fix issue with  not being passed to offsetContext when using predefined popup [`6e6c92a`](https://github.com/fomantic/Fomantic-UI/commit/6e6c92a4790516d7797997561ce50769e2546f4b)
- #3430 Fixes issue with page scroll flickering due to bug in sticky when container height is defined by static sticky height [`52dbc62`](https://github.com/fomantic/Fomantic-UI/commit/52dbc6288e327d1b671b0d86019a23ef6d601bcc)
- Fix bug with top passed bottom passed in visibility [`415a67d`](https://github.com/fomantic/Fomantic-UI/commit/415a67dedbd1c04da01f43fed3680fa4c35a9903)
- #4163 #4164 Forgot to rename one use [`6016da3`](https://github.com/fomantic/Fomantic-UI/commit/6016da337fc28ce0c0e4d30cd771992c3453254f)
- Modify multi-select dropdown behavior [`5f393f6`](https://github.com/fomantic/Fomantic-UI/commit/5f393f6c33a5365b927eba415bebc6071f871541)
- Adds searchOnFocus setting #4087 [`376d021`](https://github.com/fomantic/Fomantic-UI/commit/376d0211fcf9832de926f9dcb7f82b5edc7f7e6e)
- #2737 typo in code [`b6fa0b3`](https://github.com/fomantic/Fomantic-UI/commit/b6fa0b3020ce5f979cc7fe7a6d622eeaa2bd8f79)
- Fix margin on fields with only one field [`fe24d4b`](https://github.com/fomantic/Fomantic-UI/commit/fe24d4bcd675b4e48132c6fcc5d31922c0aae2a3)
- Fix wide and very wide popup appear offscreen on mobile [`1177c23`](https://github.com/fomantic/Fomantic-UI/commit/1177c237895875b0a76a415f00503713b8b4971a)
- [Form] Add * required marker from the label itself [`8836c39`](https://github.com/fomantic/Fomantic-UI/commit/8836c39b88710434f2e8786a91619bf3298f2399)
- fix(dropdown): Only check option value to determine if option is selected [`3a941ac`](https://github.com/fomantic/Fomantic-UI/commit/3a941ac09f4b892266625d3de9748557bcd3952d)
- Update ISSUE_TEMPLATE.md [`584fc1c`](https://github.com/fomantic/Fomantic-UI/commit/584fc1cd8e689918dfe55220b5867fb7052b97fe)
- Fix the 'ignoreCase' option when using multiselect to work with has.label #6123 [`6910893`](https://github.com/fomantic/Fomantic-UI/commit/691089301b0305168bdf9157515b3f13d771e77b)
- Added expected and result to bug template [`36f77a8`](https://github.com/fomantic/Fomantic-UI/commit/36f77a8791f0e7bb714cfd2ad27305fd83782325)
- Implements #4458 [`06e16f2`](https://github.com/fomantic/Fomantic-UI/commit/06e16f2ce540a94744e680ea711cce53ab1ff3a8)
- Rlsnotes on icons [`8b3f0f3`](https://github.com/fomantic/Fomantic-UI/commit/8b3f0f37b7a934bd7856c42c93ce4b71b19ca78a)
- Fix issue with scrolling modal and allowMultiple #2423 [`aa1d36b`](https://github.com/fomantic/Fomantic-UI/commit/aa1d36b232ef2cdf7f80f090f95e76d803bc4d07)
- Rlsnotes [`1a43f05`](https://github.com/fomantic/Fomantic-UI/commit/1a43f058e6032fb2f6bd1ca59275963913ff77b2)
- #4872 #4850 Fixes issue with icon offset in header and list [`48aaf9a`](https://github.com/fomantic/Fomantic-UI/commit/48aaf9a74a6bd414cf661048df071d098eed83bd)
- Fix spacing on image in dropdown [`aa6ecf9`](https://github.com/fomantic/Fomantic-UI/commit/aa6ecf951ce72d4cd8fbaa36e5d52c61e04d14f3)
- Corrected the previous commit [`2ec4b57`](https://github.com/fomantic/Fomantic-UI/commit/2ec4b573cfba14c27c1bb0bfdb2a1ab77c43cffb)
- Fix release note merge [`8448492`](https://github.com/fomantic/Fomantic-UI/commit/844849285d8f554c8abfadf602bf330a6f8e2dcd)
- Mind in the wrong place [`56c5664`](https://github.com/fomantic/Fomantic-UI/commit/56c56645d608eb141cf5ec3521db0c5d7e28ff69)
- spelling: fitted [`2b19534`](https://github.com/fomantic/Fomantic-UI/commit/2b1953420d69e33d18f6adfb29c5e1591d6e2c82)
- spelling: dribble [`b404ae5`](https://github.com/fomantic/Fomantic-UI/commit/b404ae54e5565bc5ea128d6473722a495e4ef026)
- spelling: context [`be209c1`](https://github.com/fomantic/Fomantic-UI/commit/be209c181d5318543605bba0bb4db535a5a427ac)
- spelling: content [`3cc4520`](https://github.com/fomantic/Fomantic-UI/commit/3cc452006fd8a446c4d2dde03987812b9b082b56)
- Finish iteration [`d1fe145`](https://github.com/fomantic/Fomantic-UI/commit/d1fe1455166a5c57225825977d52871945bff6f0)
- Removes label input padding, breaks valign with flex [`c713945`](https://github.com/fomantic/Fomantic-UI/commit/c7139458c6997c7aa741da51ff2cbff32f98c9be)
- Remove vertical spacing from breadcrumb [`77f1d7c`](https://github.com/fomantic/Fomantic-UI/commit/77f1d7c4dde0d6b5a995739d188a790401bc94c7)
- #2734 rlsnotes [`181cbcd`](https://github.com/fomantic/Fomantic-UI/commit/181cbcdf14a295b3d0b61ab98da1df1ff9ca46c9)
- Update deps [`7d0e7aa`](https://github.com/fomantic/Fomantic-UI/commit/7d0e7aa34a62455c03874a6472ff35e4354654aa)
- Allow text labeled dropdowns to continue to search after max selections [`3b952c3`](https://github.com/fomantic/Fomantic-UI/commit/3b952c34d2a7cc0d77c42cfc094f0912c30c7b8b)
- RLSnotes [`f395784`](https://github.com/fomantic/Fomantic-UI/commit/f39578424af8197605f29016257b606283a443c3)
- Remove verbose error message from popup, update rlsnotes [`a089192`](https://github.com/fomantic/Fomantic-UI/commit/a089192f47fa1c56bdda3d759195a2e4ad95c49d)
- Update rlsnotes [`3c91c57`](https://github.com/fomantic/Fomantic-UI/commit/3c91c57d98e21f362d19b00403b95decc18aa96e)
- Rlsnotes [`834d65d`](https://github.com/fomantic/Fomantic-UI/commit/834d65db59221fb4331c2219f13afe3af9694b7b)
- Implement prompt as a function #6016 [`9eb4ac3`](https://github.com/fomantic/Fomantic-UI/commit/9eb4ac3c20fd069034a9406bd3ea1e447c87c560)
- [Search] add exactResults on duplicate check [`8842983`](https://github.com/fomantic/Fomantic-UI/commit/884298381e0bb46d5641a2facbfa4508606d8822)
- Icon update rlsnotes #6181 [`2ce2767`](https://github.com/fomantic/Fomantic-UI/commit/2ce276792e1a0ffaf21aa28a4847f6d07ffc9790)
- Update ISSUE_TEMPLATE.md [`25b7b26`](https://github.com/fomantic/Fomantic-UI/commit/25b7b268b1cf8b3da4fd2bea999893aceeed12bc)
- #3432 Simplifies setting name (derp), adds default to false [`32d47d6`](https://github.com/fomantic/Fomantic-UI/commit/32d47d60ef9b6da6db9a3e19afe71c7a717fbe04)
- Another install msg attempt [`11ee2c5`](https://github.com/fomantic/Fomantic-UI/commit/11ee2c5050b59b23ea4273430660f7d8d535bbe5)
- #5284 - double disabled styling on inputs [`ae38450`](https://github.com/fomantic/Fomantic-UI/commit/ae3845032fd26c9b5652a49989aedbb8f32f0367)
- Rlsnotes 2.2.9 [`8f7ec07`](https://github.com/fomantic/Fomantic-UI/commit/8f7ec07ce640f2a38b7b2e800fba6ae9941cf1f1)
- Notice on form validation [`cd63ad8`](https://github.com/fomantic/Fomantic-UI/commit/cd63ad891ddb1afa167b0cb86591dfdf25efcd28)
- Fixes decimal regex to be more reasonable [`fb8bccd`](https://github.com/fomantic/Fomantic-UI/commit/fb8bccd1150c9374fcfa081e295a05f7d61eac22)
- Fixes outlined star being difficult to see #3730 [`b1fa7e2`](https://github.com/fomantic/Fomantic-UI/commit/b1fa7e21951b7b49a92ed50f9b89e5241b25996d)
- Rlsnotes and condense logic further #3085 [`2c44d66`](https://github.com/fomantic/Fomantic-UI/commit/2c44d667aa4151fdd719c4595a7666f5eb6b0d87)
- Adjust arrow variables to automatically resize [`c6e78ae`](https://github.com/fomantic/Fomantic-UI/commit/c6e78ae909a12713235d6bb15b857281de1fca3d)
- Rename pressedTextColor var [`5527ce6`](https://github.com/fomantic/Fomantic-UI/commit/5527ce6c9a48c7c917bd9633a075ec62ba328506)
- Adds flex-shrink value for menu item [`065524a`](https://github.com/fomantic/Fomantic-UI/commit/065524a170c441857d4eebf722b27b1270dd33df)
- Rlsnotes [`f82717f`](https://github.com/fomantic/Fomantic-UI/commit/f82717f6a28974943936a9cb4d5f8f229cedfa27)
- Fix issue where dropdown inside label wont open [`37ad56b`](https://github.com/fomantic/Fomantic-UI/commit/37ad56b62c71c4ce637a4a9fd6c1f28a11e330eb)
- #2469 Fix issue with get animation when cache is undefined [`a942a27`](https://github.com/fomantic/Fomantic-UI/commit/a942a27ad6b16d0b722c5f18786c9b779e708072)
- [Segment] A basic segment within .segments should be basic [`05d60e4`](https://github.com/fomantic/Fomantic-UI/commit/05d60e4efd1f60ced3731adf7459f7dcd074c11f)
- fix(form): Set color in ms input placeholder pseudo selector to important [`8742826`](https://github.com/fomantic/Fomantic-UI/commit/8742826cb2ee724f73c4bb14279d7557f436a96a)
- Fix dimmer with setting closable:false still closable [`e461c66`](https://github.com/fomantic/Fomantic-UI/commit/e461c66ec9a1d3bdcbc81450a39b786c93f0213a)
- chore(stale.yml): update exempt labels [`862955b`](https://github.com/fomantic/Fomantic-UI/commit/862955bd65fa5ae79c2b648569a7dea4b5b1c09b)
- Fix transitions on ui images &gt; .image [`e31ff0a`](https://github.com/fomantic/Fomantic-UI/commit/e31ff0a16c384ba18973f235a04b0e8006fd8968)
- Swap bigWidth with hugeWidth in sizes #5899 [`b9d5690`](https://github.com/fomantic/Fomantic-UI/commit/b9d5690df2361507a79e29fdf03f5df4116150e5)
- Fix issue with install question requiring down arrow to select [`b6504ba`](https://github.com/fomantic/Fomantic-UI/commit/b6504ba1e02f7afd9c498227e55609943e28d7c1)
- #5549 - Fix regression from offsetTarget change [`44b8222`](https://github.com/fomantic/Fomantic-UI/commit/44b82222b0aa5c60a949681def6c02902c86585a)
- Fixes issue with dropdown positioning being incorrect inside menus #5542 [`a3b6fb6`](https://github.com/fomantic/Fomantic-UI/commit/a3b6fb62db8114b469b3ccfd4f342e2905dc6ed1)
- Fix default focused text rule to work with sizer #5633 [`f08a787`](https://github.com/fomantic/Fomantic-UI/commit/f08a78785d4c0d1333f48b7c3ebbb4f117556432)
- Revert the changes and increase the selector’s specificity. [`b13c972`](https://github.com/fomantic/Fomantic-UI/commit/b13c972c3d0b26d922dc642f3c73aff4d628fd3c)
- #4248 Fix issue with attached item menu #4248 [`bdb1928`](https://github.com/fomantic/Fomantic-UI/commit/bdb1928465bcaa8f2c1b0288d2ec309820c73d30)
- Fix issue where selection dropdown would modify search selection on tab before query [`238ac3c`](https://github.com/fomantic/Fomantic-UI/commit/238ac3c8906330e0fcc1980fefeea0ae2dfb2bda)
- Added missing rules for sortable inverted headers [`707ffd5`](https://github.com/fomantic/Fomantic-UI/commit/707ffd51471f15646428cafc589120d05971b90c)
- Rlsnotes 2.2.10 [`1323da9`](https://github.com/fomantic/Fomantic-UI/commit/1323da98e77917294c67aba2607e4b0c22e1b756)
- Fix math on scroll context [`064477c`](https://github.com/fomantic/Fomantic-UI/commit/064477c47d9f48a41b086e09811bed8e0b0a7dea)
- Added `box-shadow` to the checkbox component’s `.toggle` variation [`076cb9f`](https://github.com/fomantic/Fomantic-UI/commit/076cb9f8654241ffd8ac1a92a98d4f23eda58506)
- #703 #4093 callbacks should not occur when using is valid [`d163b57`](https://github.com/fomantic/Fomantic-UI/commit/d163b57745b5b51db087b37c0310d80825b819f3)
- Labels now use metadata setting [`aa0c9ce`](https://github.com/fomantic/Fomantic-UI/commit/aa0c9ce453519bd339ea9adfd61f8763a0336c82)
- #4163 rlsnotes and thanks [`9be5cf2`](https://github.com/fomantic/Fomantic-UI/commit/9be5cf27141accc203fa7e4a7f77de203a90c1b7)
- #4279 Fixes off by 1px errors in any UI with inputs [`e01309c`](https://github.com/fomantic/Fomantic-UI/commit/e01309c90a07b994d63faca6461bba7a14486ba5)
- Fix build scripts to work again [`d3e7455`](https://github.com/fomantic/Fomantic-UI/commit/d3e745524c554580675291051019afc921fd2881)
- #4815 change name for setting again to match other remote setting [`1f897b3`](https://github.com/fomantic/Fomantic-UI/commit/1f897b3bb17ef79a582231a17fd2143e94a6c088)
- spelling: falsy [`bb2e606`](https://github.com/fomantic/Fomantic-UI/commit/bb2e6063b1e660ebf2dd2e2ebe0b3be1b21eff23)
- spelling: compatibility [`a5efb15`](https://github.com/fomantic/Fomantic-UI/commit/a5efb15f262fb61cfb80e7bd2972ac83ac67a5d4)
- spelling: arguments [`dff05ab`](https://github.com/fomantic/Fomantic-UI/commit/dff05ab57b933fa20b21088dd2e891ab19f04cc7)
- Fix destroy never being called before init #3798 [`05652ab`](https://github.com/fomantic/Fomantic-UI/commit/05652ab7cdaf937ce5aaecdaabdf898ab4b78dff)
- Combine rules #2955 [`a514d0a`](https://github.com/fomantic/Fomantic-UI/commit/a514d0ae0f76242b920940933678a45db126d49b)
- Adding England flag: Issue #1549 removed the alias uk-england, but England was never added back. [`bb24dcf`](https://github.com/fomantic/Fomantic-UI/commit/bb24dcf75264ac87df6b6245e2a843ee280d305f)
- chore: Remove unnecessary variable [`bfb1408`](https://github.com/fomantic/Fomantic-UI/commit/bfb140850989ce144675dda5a2a2b918bc2aebe3)
- set @tabularBackgroundColor value to transparent [`e53401f`](https://github.com/fomantic/Fomantic-UI/commit/e53401f57e69940bac1a9e77d37782f8064ce59e)
- Rlsnotes [`40df964`](https://github.com/fomantic/Fomantic-UI/commit/40df9647c0ea9e8f81dd834f1258c9f17a5fab8d)
- Var typo [`03f38f8`](https://github.com/fomantic/Fomantic-UI/commit/03f38f8487a92a7b7bd85345576c1a6fda6d6367)
- Rlsnotes [`a747df2`](https://github.com/fomantic/Fomantic-UI/commit/a747df2e4b41c6c08fb18298fdd790737052914c)
- #2583 onHide/onShow should be last as well [`cba22a8`](https://github.com/fomantic/Fomantic-UI/commit/cba22a865fe7a5f57b443dee70702be47a332449)
- #2583 Fixes onComplete is not called at true 'end of animation' [`bb9bbad`](https://github.com/fomantic/Fomantic-UI/commit/bb9bbad825adf121ff7b8e3ddfbe1b6fafce2aea)
- Update URL again [`f32cc39`](https://github.com/fomantic/Fomantic-UI/commit/f32cc39b276c35188f72cfbee80acf0a7892b117)
- #1369 rlsnotes [`a99f26a`](https://github.com/fomantic/Fomantic-UI/commit/a99f26a288992b10585921128ec33ae57f1d8aaf)
- Added BrowserStack [`934fa03`](https://github.com/fomantic/Fomantic-UI/commit/934fa03b8f6624b30126a3f56dc6470a4891bb19)
- [Form Validation] Add an option that disallow trim before validation [`e6fcadd`](https://github.com/fomantic/Fomantic-UI/commit/e6fcadd0934385c35c90911b3dd5cbc874406bef)
- Fix issue with whitespace wrapping in reveal [`4231bb2`](https://github.com/fomantic/Fomantic-UI/commit/4231bb269f1f6000ca027b3c845fcbdddb5a1ad1)
- Rlsnotes #6193 [`6b31647`](https://github.com/fomantic/Fomantic-UI/commit/6b316474ae7ea27bda950a269ba44e2aa6311bc8)
- Fix visibility issue with onScreen calculations for long elements [`b78dc75`](https://github.com/fomantic/Fomantic-UI/commit/b78dc75fc17c93996dc2c1164b1c756f606fb4bc)
- Added icon updates [`11a4e49`](https://github.com/fomantic/Fomantic-UI/commit/11a4e49fa2679beee7bcd9a75a9679add5a82e2b)
- Update rlsnotes for 2.2.14 [`e890bd3`](https://github.com/fomantic/Fomantic-UI/commit/e890bd3809c23288d1e9fd5ab6026ba380079d6a)
- Rlsnotes #5530 [`7b4c507`](https://github.com/fomantic/Fomantic-UI/commit/7b4c5079d5bbef5e8c5cf6c35ad9f34d7b11879b)
- Update rlsnotes [`6547d62`](https://github.com/fomantic/Fomantic-UI/commit/6547d625afa373d8ce4ff1b50ca896a73f79f19a)
- #5366, #5975 - Fixes open rightward/leftward incorrectly adjusting to scroll context [`c598892`](https://github.com/fomantic/Fomantic-UI/commit/c5988929973156915e797f76b13a714ffbda4ae9)
- Fix issue where multiple modal init order matters #5559 [`4ccf825`](https://github.com/fomantic/Fomantic-UI/commit/4ccf825e07c6fabe96b61dc5debb0cc7f068d8fb)
- Release notes on dropdown changes [`33137fb`](https://github.com/fomantic/Fomantic-UI/commit/33137fb5cebf59d0dd64649f1f35259cbad83ea5)
- #5633 rlsnotes [`1b87427`](https://github.com/fomantic/Fomantic-UI/commit/1b874274a448ac5fc960bb91e059430396eb85c2)
- Fix bug in sticky when using offset setting [`7d0621c`](https://github.com/fomantic/Fomantic-UI/commit/7d0621c1c059c08cb48866a0bdc1c5027fa57fd9)
- Adds rlsnotes #5123 [`eb17ab8`](https://github.com/fomantic/Fomantic-UI/commit/eb17ab82f95f52a6baf89cf66d53ea9f8775eb4c)
- Fix mistaken use of variable [`a3a1763`](https://github.com/fomantic/Fomantic-UI/commit/a3a1763c8d2a9ad3ae4671c56d9f9f93929eb389)
- Add build tools notes [`868bacd`](https://github.com/fomantic/Fomantic-UI/commit/868bacdee7fb50a6006d8a0d24f810ea1e3d73e9)
- Fix unfinished release note [`32dd5d4`](https://github.com/fomantic/Fomantic-UI/commit/32dd5d4b97c9abd13bff777f4e5eccc9156e0b9a)
- Fixes issues with theme changes not generating files on win platform [`78ca7c5`](https://github.com/fomantic/Fomantic-UI/commit/78ca7c56f26f0be8f4b084e0a945cfee62dc678f)
- #2744 Fixes issue with fluid container overflow [`7b2a696`](https://github.com/fomantic/Fomantic-UI/commit/7b2a696caeee6f4b607a86bfe906da87a79e34f8)
- Update input [`e6c5780`](https://github.com/fomantic/Fomantic-UI/commit/e6c57803d767f2c8361420e9c40994513d33204b)
- Here goes  nothing [`908a16d`](https://github.com/fomantic/Fomantic-UI/commit/908a16ddffc4991d3426a6f56613287887a685b9)
- #2624 rlsnotes [`dc6ef06`](https://github.com/fomantic/Fomantic-UI/commit/dc6ef06fe7ddb3e7c23be54b3bd19c977206d175)
- #2599 rlsnotes [`c2062e8`](https://github.com/fomantic/Fomantic-UI/commit/c2062e8c86fdb2c63c3eab370bff787e2e130fd2)
- #2659 fix comments inside modal [`21139bd`](https://github.com/fomantic/Fomantic-UI/commit/21139bde54649fc7ec7870e6cc176d9c3066adf6)
- #2629 Fixes duck typing in form validation to check rules and id [`d2c4547`](https://github.com/fomantic/Fomantic-UI/commit/d2c4547dc04b79b274e6033d86ff076b34d52d6e)
- #2605 rlsnotes [`14c2b3d`](https://github.com/fomantic/Fomantic-UI/commit/14c2b3dcfe61f46a0e41f3c8d8d1b4a87ae86497)
- #2526 rlsnotes [`3864604`](https://github.com/fomantic/Fomantic-UI/commit/386460464ba353a5e0424e53a39e908eafd6ce59)
- #2615 Adds missing default value for refreshOnResize [`2219ea8`](https://github.com/fomantic/Fomantic-UI/commit/2219ea88f2e7e0a8406685f8c0e06ba108141b8b)
- Rlsnotes [`d881d66`](https://github.com/fomantic/Fomantic-UI/commit/d881d6611ad10b20c600093cfad1de4cd986f0f9)
- Fix errored input border radius [`a39cf66`](https://github.com/fomantic/Fomantic-UI/commit/a39cf66afe8da22a262522c019ace80569abeca0)
- Fix URL validation isssue with form [`00f17f7`](https://github.com/fomantic/Fomantic-UI/commit/00f17f73459ae6dc9449f097d434b36b7ad55456)
- Midnight in a perfect world [`57aac1e`](https://github.com/fomantic/Fomantic-UI/commit/57aac1e6db954271231f99dca3434a96c5cd939a)
- Version tick [`44cf50b`](https://github.com/fomantic/Fomantic-UI/commit/44cf50b61ce2570190e56fc374beba2c68a9de33)
- [Form Validation] Avoid trim of values before validation [`0666053`](https://github.com/fomantic/Fomantic-UI/commit/0666053eb7f63d720d0b9fd5661e5238296413b5)
- [Dropdown] A fluid dropdown should be fluid [`7eb1b05`](https://github.com/fomantic/Fomantic-UI/commit/7eb1b058519566fb2d7bbc5948ab84a2c2af80bc)
- [Table] Fix priority for td .disabled class [`31959e8`](https://github.com/fomantic/Fomantic-UI/commit/31959e86b1f93628d9a2e23f391c6112662e1332)
- Fix last tab inside container which does not have correct bottom margin [`87c8e52`](https://github.com/fomantic/Fomantic-UI/commit/87c8e526a70ce282f1a06e9c1142a02f4628639c)
- Bumped version [`c18f4d0`](https://github.com/fomantic/Fomantic-UI/commit/c18f4d0499c2f6360564d1d7a274c6befcc5be76)
- [Card] Icon containing class "card" misbehaves [`49f9118`](https://github.com/fomantic/Fomantic-UI/commit/49f9118bb9cf7857ec34d94dc64e990a3d9d7a7f)
- fix(flags): Fix wrong flag position for Myanmar / Burma [`e892ca0`](https://github.com/fomantic/Fomantic-UI/commit/e892ca080a0649579f2ecb7f8cec2421c7fc3a65)
- Add trailing newline at the end of generated JSON [`62c4c1e`](https://github.com/fomantic/Fomantic-UI/commit/62c4c1e7c9490d8e1d33248c67abd805d9b418ae)
- Typo [`7d76dae`](https://github.com/fomantic/Fomantic-UI/commit/7d76dae78fc5c3bff4fbea6593d1ceb2bd52f10b)
- Updated logo [`8a4612c`](https://github.com/fomantic/Fomantic-UI/commit/8a4612c0ef763508afd88dc503590d9cc58f8606)
- Give Jack's @ a link [`f1f4987`](https://github.com/fomantic/Fomantic-UI/commit/f1f498750065c10222e75cc42001b71841045f7b)
- fix @inputLineHeight comment spelling error [`1f8d24e`](https://github.com/fomantic/Fomantic-UI/commit/1f8d24e7e4eaa84406e326295022c37029bbc684)
- Update build tool to publish meteor [`4566b50`](https://github.com/fomantic/Fomantic-UI/commit/4566b50512ff16f110ed8df6dbb3711660ad3c1d)
- Update iframe.js #6269 [`a6a73bf`](https://github.com/fomantic/Fomantic-UI/commit/a6a73bf08721f1b944f597dfa04e36cf0395b924)
- #6226 remove testing variable as false [`ca05ebb`](https://github.com/fomantic/Fomantic-UI/commit/ca05ebbdfb52205e9316188b1a8f36fa92ea85de)
- Fix build-docs task not requiring component name in filename #6226 [`295af5f`](https://github.com/fomantic/Fomantic-UI/commit/295af5f328c5072e779d6ad4a0caec24509d4294)
- Version [`23a7efa`](https://github.com/fomantic/Fomantic-UI/commit/23a7efa3719dbab4d97a7c87b5bdea75179cf9cd)
- Changed i.icon font-family to @fontName instead of @solidFontName [`82226e6`](https://github.com/fomantic/Fomantic-UI/commit/82226e6ee175d0ad617ee31c496c20dd846b6a2a)
- Small change, padding [`b4f5d54`](https://github.com/fomantic/Fomantic-UI/commit/b4f5d54545246721b242bb2b7031c91537eea592)
- Update ISSUE_TEMPLATE.md [`6819743`](https://github.com/fomantic/Fomantic-UI/commit/68197433d883a506472ab836788851bef0924788)
- Update ISSUE_TEMPLATE.md [`10ebc98`](https://github.com/fomantic/Fomantic-UI/commit/10ebc9815ab1b470182e7a1cf19dcaef6d3bec58)
- Update ISSUE_TEMPLATE.md [`411989c`](https://github.com/fomantic/Fomantic-UI/commit/411989c882ee51d17e7bd3efdd631c293a697828)
- Update ISSUE_TEMPLATE.md [`b987777`](https://github.com/fomantic/Fomantic-UI/commit/b98777755fba6b2bdca5afb58e1b88c7cbf0c713)
- Tighten scrolling margin [`a076374`](https://github.com/fomantic/Fomantic-UI/commit/a076374fd4d4d08bc4067ce459da893ef1c84383)
- Fix modal flex issue in IE11 [`92fa08f`](https://github.com/fomantic/Fomantic-UI/commit/92fa08f1f4006d02cb62a2bd8dea9d1f04018e21)
- #4423 in next [`4cacf56`](https://github.com/fomantic/Fomantic-UI/commit/4cacf5603126028520a4b3c3bab481bd511c77ef)
- Thanks #4614 [`453fe87`](https://github.com/fomantic/Fomantic-UI/commit/453fe87bb492140c7660c6462a3f4c9f95d66559)
- Thanks #6167 [`ac0f313`](https://github.com/fomantic/Fomantic-UI/commit/ac0f3130c601a323b938217e9e5318026df76543)
- Rlsnotes #6127 [`26a3b60`](https://github.com/fomantic/Fomantic-UI/commit/26a3b602473ec1d2245dc669d636d7aa556b6c47)
- Username typo [`5cc4070`](https://github.com/fomantic/Fomantic-UI/commit/5cc40709fce2aac69b99c115459ab670846e3508)
- Remove href attribute from div element [`ccaafae`](https://github.com/fomantic/Fomantic-UI/commit/ccaafae32ab816306f1c429d4bc49c364a1c0270)
- Update gulp-clone dep with issue #6067 #6089 [`84fc63f`](https://github.com/fomantic/Fomantic-UI/commit/84fc63f493ea86bb479653a28a32fa00d4749f81)
- Use @background value for arrow background color [`d807a54`](https://github.com/fomantic/Fomantic-UI/commit/d807a542d823d9905747d1c3106668bce19e64e5)
- Rlsnotes [`c64d012`](https://github.com/fomantic/Fomantic-UI/commit/c64d01272c42df52a091b0a61a43d832feca9fe3)
- Rlsnotes 2.2.13 [`5550bca`](https://github.com/fomantic/Fomantic-UI/commit/5550bca6afe30aa5ba4b1a5a853c91e358ab4a5d)
- Forked package typo [`0fb7242`](https://github.com/fomantic/Fomantic-UI/commit/0fb72422eccbc00eae1128772478ae4583480353)
- Fork inquirer [`c75f2e5`](https://github.com/fomantic/Fomantic-UI/commit/c75f2e57402d211311e78b92c41a366aabf7dcd4)
- Remove colored output from install [`ba38080`](https://github.com/fomantic/Fomantic-UI/commit/ba38080a51cab4f365a6565abeed6c6bf22fbc5c)
- Version bump to 2.2.13 [`976a31e`](https://github.com/fomantic/Fomantic-UI/commit/976a31e23c44619d60ac19789eaadfd92737fd44)
- Rlsnotes 2.1.12 [`577ae99`](https://github.com/fomantic/Fomantic-UI/commit/577ae996568e355cb0141a7cce9ba07bec2ceceb)
- Rlsnotes [`415e9bc`](https://github.com/fomantic/Fomantic-UI/commit/415e9bcf8f9e13e2849457f6b4ca9f3a0238c309)
- Update rlsnotes [`4466494`](https://github.com/fomantic/Fomantic-UI/commit/4466494d7f45db844fd596056a7328e1fd0c3558)
- Fixes issue with line height offset no longer being necessary #4780 [`97750b7`](https://github.com/fomantic/Fomantic-UI/commit/97750b700c1303f10cf93ed76ed5aa6e5f0871d9)
- Remove console log #3744 [`43f2174`](https://github.com/fomantic/Fomantic-UI/commit/43f21749eb5147a7255b4ef521886524da1ae94a)
- #4506 fix subtle overlap of leftward menu [`f584e12`](https://github.com/fomantic/Fomantic-UI/commit/f584e1234e58f4556c11d1bec873d067be0ee180)
- Final rlsnotes 2.2.11 [`d062467`](https://github.com/fomantic/Fomantic-UI/commit/d0624671628187ffe18e4f0224ef10cc6d101616)
- Release date 2.2.11 [`95dcc26`](https://github.com/fomantic/Fomantic-UI/commit/95dcc2666f93ea1c73ab051209130b05a371578c)
- Rlsnotes 2.2.11 [`c1690f9`](https://github.com/fomantic/Fomantic-UI/commit/c1690f9b0aa9591677b953bc28e65d3aefff62fa)
- Rlsnotes typo [`08c616f`](https://github.com/fomantic/Fomantic-UI/commit/08c616fade071feab616ba29926605d6d60b7155)
- Release notes #4574 [`e3757aa`](https://github.com/fomantic/Fomantic-UI/commit/e3757aa76bb950ce6bfc28d9ec3f6198347308a5)
- #5281 fix issue with descendors cut-off in transparent input [`3a7d36f`](https://github.com/fomantic/Fomantic-UI/commit/3a7d36f343f6070f15142e9dc6e0ee91013e64d3)
- Fix issue with down arrow shortcut in dropdown [`7a5fb9e`](https://github.com/fomantic/Fomantic-UI/commit/7a5fb9e12a60c361cfa8c102ac24c2e7d68b6db7)
- Disable refreshing for non active/animated modals [`7a17e70`](https://github.com/fomantic/Fomantic-UI/commit/7a17e70dd6c5c96294d204982c305d1e5eed63b8)
- Timer logic in wrong place [`3de60bc`](https://github.com/fomantic/Fomantic-UI/commit/3de60bc3adf3593587e523fe72fe9fc904487435)
- #4237 remove console.log [`a26ee40`](https://github.com/fomantic/Fomantic-UI/commit/a26ee40612bd36431035afb1554e933fc4b60cb1)
- The width of inputs that are inside of a dropdown’s `.menu` should never be overridden [`dfc7599`](https://github.com/fomantic/Fomantic-UI/commit/dfc7599f6b9c6c730d6f750fb17105775c6aad35)
- Fix rls [`6389e62`](https://github.com/fomantic/Fomantic-UI/commit/6389e62e204e1e6a792cdbb29cd23b65112947c1)
- Fix wrench require statement [`47c61a4`](https://github.com/fomantic/Fomantic-UI/commit/47c61a4e58661eb01d08e5199536eed28c4adcf5)
- Rlsnotes [`7f86c8a`](https://github.com/fomantic/Fomantic-UI/commit/7f86c8a3a76ae38d34d1768e848fd94d8be305af)
- Rlsnotes [`10d5d37`](https://github.com/fomantic/Fomantic-UI/commit/10d5d370349f544529af586c8104054ddb526846)
- Rlsnotes [`0e118d6`](https://github.com/fomantic/Fomantic-UI/commit/0e118d6166e9e735a0ffb4a38cb1f64c1fdd727c)
- Rlsnotes [`9d31357`](https://github.com/fomantic/Fomantic-UI/commit/9d31357130599fc49dd414a5831a842d69d8abb6)
- Update [`7459055`](https://github.com/fomantic/Fomantic-UI/commit/7459055bc515c0c0a35eda4aab1dddaa25465397)
- Add new npm release for forked wrench #3404 [`6fcbf43`](https://github.com/fomantic/Fomantic-UI/commit/6fcbf43bc58a945ce705631c6557dc05f2f44bb9)
- 2.2.8 build [`d027a59`](https://github.com/fomantic/Fomantic-UI/commit/d027a5996cdc36bca79f120d55bc6024e4fe2264)
- spelling: horizontal [`045e733`](https://github.com/fomantic/Fomantic-UI/commit/045e73390d47964b574637848d87983533ac085f)
- spelling: determines [`9207cac`](https://github.com/fomantic/Fomantic-UI/commit/9207cacdf9845c64e164670f3fb90c61cb942775)
- spelling: dependencies [`b8e239b`](https://github.com/fomantic/Fomantic-UI/commit/b8e239bd6df427c9661d2dbbbb3e7f13dd20fac3)
- spelling: contributors [`7b2b72a`](https://github.com/fomantic/Fomantic-UI/commit/7b2b72a9ba79b66dd2c773115ead24d55f16faf1)
- spelling: callback [`e229ec8`](https://github.com/fomantic/Fomantic-UI/commit/e229ec8ef397212a2ba4e55d35196356f9cb0910)
- spelling: bound [`1e67d94`](https://github.com/fomantic/Fomantic-UI/commit/1e67d94fc5729f353d53968bafae85e1b28734a5)
- spelling: bottom [`ac7c0c2`](https://github.com/fomantic/Fomantic-UI/commit/ac7c0c23d4b90133e63d27a9fd164e8e64333a7e)
- spelling: beginning [`3ce6bfc`](https://github.com/fomantic/Fomantic-UI/commit/3ce6bfc2a9b1a8f87cf80c248bbd4747234db1b9)
- spelling: assigned [`ad47dad`](https://github.com/fomantic/Fomantic-UI/commit/ad47dadb9e305705042810eb7c6c4c4e8ba3b8e6)
- spelling: appearance [`fb16e8a`](https://github.com/fomantic/Fomantic-UI/commit/fb16e8ac7edbcddf1a9be452643973bc21e2d68c)
- spelling: additional [`f34521d`](https://github.com/fomantic/Fomantic-UI/commit/f34521d7e9471ccd43d28c60330b6b1502f5e913)
- spelling: absolutely [`bafb778`](https://github.com/fomantic/Fomantic-UI/commit/bafb778c9c4c537b91845e7d5a03b0d1d86a788f)
- #2534 - rlsnotes wrong [`a0c8542`](https://github.com/fomantic/Fomantic-UI/commit/a0c854269bfaee27ac4c1a3cb442cd0d40770e7b)
- #2534 preserve original behavior [`7901e04`](https://github.com/fomantic/Fomantic-UI/commit/7901e04409b845171027de99d499e06ef2dd947f)
- Fix @yordis [`0b11360`](https://github.com/fomantic/Fomantic-UI/commit/0b11360752c3176bf0e9f1a7432cc566cb507798)
- No really final positioning for loading dropdown [`8755da7`](https://github.com/fomantic/Fomantic-UI/commit/8755da70cfda8d64c41de38e7a3d31096913d03b)
- Fix positioning [`50b8989`](https://github.com/fomantic/Fomantic-UI/commit/50b898910099d0bf0a23e051f1178dbf06c1881c)
- RLSnotes #2534 [`1b87763`](https://github.com/fomantic/Fomantic-UI/commit/1b87763a747e409e86591e6d8c4eeeb2aa4c0b8b)
- Fix loading dropdown spinner position [`2b2187c`](https://github.com/fomantic/Fomantic-UI/commit/2b2187c415d34ce586663fab1fe9455cfa171003)
- Rebuild dist [`4e0e576`](https://github.com/fomantic/Fomantic-UI/commit/4e0e576b253d0fa0f973ed06ac088d9c5bab7832)
- Rebuild dist [`edda7f8`](https://github.com/fomantic/Fomantic-UI/commit/edda7f888d6457d796b3c06a708355885698eb6f)
- Builds 2.2.7 [`44a6bfa`](https://github.com/fomantic/Fomantic-UI/commit/44a6bfa23b6e527bf50a353c209d3cbbfa58bcdb)
- Build 2.2.2 [`3f51237`](https://github.com/fomantic/Fomantic-UI/commit/3f5123783e28b364f8d7866f7d12db0e809f5b27)
- Rebuild dist for demo [`41b1d14`](https://github.com/fomantic/Fomantic-UI/commit/41b1d148101a4385a07efe1993dd4285ef774a79)
- Build 2.2.1 [`4659224`](https://github.com/fomantic/Fomantic-UI/commit/46592245406402c956ed7960629bc9f8364a9bf6)
- Build final dist [`7a28863`](https://github.com/fomantic/Fomantic-UI/commit/7a2886343639f503905649b3e52e9473c51150bd)
- Build dist [`8b38f91`](https://github.com/fomantic/Fomantic-UI/commit/8b38f91c51ab112897b2e4e63e5acd6f85cbdd8f)
- Build 2.2.4 [`4551219`](https://github.com/fomantic/Fomantic-UI/commit/4551219016680e206d64a45c168d48ea19eb077e)
- Build 2.2.5 [`a6c179a`](https://github.com/fomantic/Fomantic-UI/commit/a6c179a60df272c5e975a9b2502bdfec7d471fde)
- Build 2.2.6 [`0b1b59b`](https://github.com/fomantic/Fomantic-UI/commit/0b1b59b0e1c780e842820df5c1904a162034812c)
- Fix version [`94f9ced`](https://github.com/fomantic/Fomantic-UI/commit/94f9ced66e9713b998d853732eae27080f687e10)
- Add all sizing variations to loader, rail, segment, step [`675844d`](https://github.com/fomantic/Fomantic-UI/commit/675844d8dc2a9667c3e6ebe0024bc48f7c8d4004)
- Rebuild dist [`7bd90bb`](https://github.com/fomantic/Fomantic-UI/commit/7bd90bb4c4b3c18a9dbf3871032021cd9928570a)
- Rebuild dist [`3c93462`](https://github.com/fomantic/Fomantic-UI/commit/3c934621ba1ee4e35c4e92937f377d783b7f1b66)
- Adds popup tooltips [`c6c93fb`](https://github.com/fomantic/Fomantic-UI/commit/c6c93fbc5fa2f96e87d7afd6b8da249b5ec8a25e)
- Build dist for demo [`db79ded`](https://github.com/fomantic/Fomantic-UI/commit/db79dede36fe98a407cf6189feb5afa88185a82f)
- Allows modules to work in environment with global other than window #3855 [`4292ab5`](https://github.com/fomantic/Fomantic-UI/commit/4292ab5aa1411ae016f879c469322cc72629eb08)
- Add animations to css popups [`047f66c`](https://github.com/fomantic/Fomantic-UI/commit/047f66ca2a86759b73ef8d408a1fb91127cabfbd)
- Demo [`e44d6e8`](https://github.com/fomantic/Fomantic-UI/commit/e44d6e88f66f1d85b48f1bee21c6de75a46013a9)
- fix(dropdown): display sub menu on the left when if cannot fit screen [`4d52d37`](https://github.com/fomantic/Fomantic-UI/commit/4d52d37e0c08cdaf4d81aebc2c5b3cde60e0cadb)
- Build 2.2 for release [`ebb1cab`](https://github.com/fomantic/Fomantic-UI/commit/ebb1cab098cad4509d8b173bd1d185b7472711f6)
- Adds boundary setting for popup and scroll context setting [`4a15af3`](https://github.com/fomantic/Fomantic-UI/commit/4a15af37d256f4d5010413d996bc5dd6551e33ef)
- Updates FontAwesome to v4.6.1 [`681bc19`](https://github.com/fomantic/Fomantic-UI/commit/681bc19a36befc740f201cb0800e8f2d4a37e6f1)
- Fix input spacing rule on dropdown, add colored box shadows, add border colors to message [`22fc884`](https://github.com/fomantic/Fomantic-UI/commit/22fc88442ef2637b6016250bec1cd8dfbcf191b6)
- Removes all references to year from copyright notice (lets save some annoyance every january) [`e1e1a81`](https://github.com/fomantic/Fomantic-UI/commit/e1e1a81ab3187ec8ecefd2dc60bc078edf3e7ddc)
- Update rlsnotes [`14af321`](https://github.com/fomantic/Fomantic-UI/commit/14af3214854be376d165444707ff0f829dbe4382)
- rebuild dist [`589799c`](https://github.com/fomantic/Fomantic-UI/commit/589799c11243172dcb14ab036a8e15deb9b60a4a)
- Multiple select dropdown now uses a sizer element to determine current text width, instead of estimating based on character count [`664a9d9`](https://github.com/fomantic/Fomantic-UI/commit/664a9d9032aa199b541a6829a0948c3370782899)
- Add hideAdditions option, fix multiselect behavior #3791 [`6f344a5`](https://github.com/fomantic/Fomantic-UI/commit/6f344a5cc392b2c8447b4ccb280399a34bede3df)
- Fix most tooltip animations [`370cbdb`](https://github.com/fomantic/Fomantic-UI/commit/370cbdb62fad9da561f42255b39629bd4ef2035e)
- Fix quote encoding in dropdown [`f38237d`](https://github.com/fomantic/Fomantic-UI/commit/f38237d6f8d03bbfae26c1056b23aae99da24c00)
- Fixes issue with left keyboard arrow shortcut in dropdown #3596 [`8e48595`](https://github.com/fomantic/Fomantic-UI/commit/8e485954fdd5442cd975119c71d4a72f11bb7189)
- Finish width/height setting on shape [`6093973`](https://github.com/fomantic/Fomantic-UI/commit/6093973ec88c9b1917e46a598c4edf4abd4ab897)
- Fixes issue #2779 - Search component uses 'settings', instead of init. Causing Callbacks to be set on LAST request on new request [`803b894`](https://github.com/fomantic/Fomantic-UI/commit/803b8948a8be758acd697ada499ae1a42006e6c4)
- Finally add selection on keyboard shortcut [`1c8d229`](https://github.com/fomantic/Fomantic-UI/commit/1c8d229aeb5722d3952631905b2762a926d95f81)
- #3724 fix concat css to not mess with paths replaced with regexp [`d9247de`](https://github.com/fomantic/Fomantic-UI/commit/d9247de8600ed93b1cc66c75413035845ec115c5)
- Fix issue with progress when current value exceeds total [`3328e08`](https://github.com/fomantic/Fomantic-UI/commit/3328e0837a6523e3f0ea794451100303c98469c6)
- Fix typo in popup, add new search setting selectFirstResult [`900f082`](https://github.com/fomantic/Fomantic-UI/commit/900f082387ba0614060008cbc2459c161312f27d)
- #3116 - Fixes issue with inheritance of statistic font size in groups [`ff99741`](https://github.com/fomantic/Fomantic-UI/commit/ff9974102f0344e2696e42f6f5419e0b2029f714)
- Finish loader sizing [`285aeec`](https://github.com/fomantic/Fomantic-UI/commit/285aeec1e169c38f989247d4b42bccf3377be4c2)
- Rebuild dist [`8b94e93`](https://github.com/fomantic/Fomantic-UI/commit/8b94e938fdb0575cb6906dcd31fb55e153c71cc3)
- Fix issue with APIsettings not behaving correctly when restoring a value without session data, fixed some instances where empty message could appear with results when removing multiselect choice. Fixed forceSelection to work consistently with multiselect [`5a610c3`](https://github.com/fomantic/Fomantic-UI/commit/5a610c35f388af0000dcec488f47c901197dc93c)
- Add sizing to menu [`9faacf4`](https://github.com/fomantic/Fomantic-UI/commit/9faacf4402bfc4fc513cda10faeefd5fc972074c)
- #3788 Fixes issue with search selection closing and reopening immediately [`79b9557`](https://github.com/fomantic/Fomantic-UI/commit/79b9557070a9b97c0cb950dea59e90f55254b9ef)
- Transition can now read final display state from metadata [`bf49cf4`](https://github.com/fomantic/Fomantic-UI/commit/bf49cf44d89e12243f1d16d65d3cfb20effe64fe)
- Finalize release notes 2.2.3 [`eece06b`](https://github.com/fomantic/Fomantic-UI/commit/eece06b12817133131d87f5302bdb65c68e7e3ac)
- Finishes showNoResults setting [`68b0074`](https://github.com/fomantic/Fomantic-UI/commit/68b007461a257d301b6c606992c3bbec451451f4)
- Fix issue with dropdown menu not opening after select due to preserving focus, fix issue with one segment inside segments group [`fc8d3ef`](https://github.com/fomantic/Fomantic-UI/commit/fc8d3efdc6cf6b2a0ad48eea96ea34ab24d3297b)
- Migrates to clean-css #4125 [`51993cb`](https://github.com/fomantic/Fomantic-UI/commit/51993cba533ebcd4fe81ea0c9ae3b250408688fe)
- Rebuild dist [`a413857`](https://github.com/fomantic/Fomantic-UI/commit/a41385711fd006f10ee1c44cec569130d9409b32)
- More accurate arrow positioning in tooltips [`dfc0cff`](https://github.com/fomantic/Fomantic-UI/commit/dfc0cff5f90135fb97487f034a08dfe67c48429d)
- Update deps [`a1e6012`](https://github.com/fomantic/Fomantic-UI/commit/a1e601231186261fdd11b7dd7d2c0779b6985627)
- Add transition fallback to progress [`f725b16`](https://github.com/fomantic/Fomantic-UI/commit/f725b162e70896e38257965424ac7f9af486b927)
- Add width setting [`cf550fc`](https://github.com/fomantic/Fomantic-UI/commit/cf550fc28e77c7f35710f76b364f1ef8c1406c7f)
- Update versions [`1af9872`](https://github.com/fomantic/Fomantic-UI/commit/1af98725803b7d37c0fa640eea6e6903f9854ff1)
- Fix issues with refocus causing animation on tab blur [`c18c3db`](https://github.com/fomantic/Fomantic-UI/commit/c18c3db936c1667fb7784d8f3c725db1aa124052)
- Adds new visibility callbacks, and fixes hidden image [`7eeeeea`](https://github.com/fomantic/Fomantic-UI/commit/7eeeeea54905d81d38f0735840417b27dd485721)
- #2534 - adds new DOM caching, which preserves events and final rendered state [`d095ed1`](https://github.com/fomantic/Fomantic-UI/commit/d095ed18f1977ed907ad4ac3195a71c5eb90f5bf)
- Add sizing to form, fix link icon style [`cc891bd`](https://github.com/fomantic/Fomantic-UI/commit/cc891bd5af2382b1cc639e9d23ce115519abd922)
- #3311 - Fixes talk aliases [`fe2d3ef`](https://github.com/fomantic/Fomantic-UI/commit/fe2d3efe2089ffa52337a5a617ea1bd30081baa4)
- Fix change in video to work correctly [`8a1027d`](https://github.com/fomantic/Fomantic-UI/commit/8a1027d63a9534e0df4f5cac19c3497e307fd34b)
- Fix issue with not being able to press down to open dropdown with user additions [`7484df0`](https://github.com/fomantic/Fomantic-UI/commit/7484df0504c26d6b66960bfbb159e459d9badcb8)
- Updates FontAwesome to v4.6.3 [`c1915e2`](https://github.com/fomantic/Fomantic-UI/commit/c1915e2546e334e411f435c196cb0962d055dd7a)
- Build 2.2 for release [`6274465`](https://github.com/fomantic/Fomantic-UI/commit/627446512a9f2ac65ee449838b9fb52cd7ee40cd)
- Fix some variables in tooltip [`246aafe`](https://github.com/fomantic/Fomantic-UI/commit/246aafeec16d731077fa95bfc0325130324702a0)
- Form fields (grouped field) now use negative margins like columns, this prevents middle rows in even sized fields being slightly smaller than other rows [`4db2dd5`](https://github.com/fomantic/Fomantic-UI/commit/4db2dd5ba671f8420e53ecd352d8bbac5de9c86a)
- [ref #904] added 4 positions for corner icons [`002752e`](https://github.com/fomantic/Fomantic-UI/commit/002752eb12debe5912fbb28d17751392b655d16c)
- sets border-radius when vertical buttons have a single child button [`3fb72fe`](https://github.com/fomantic/Fomantic-UI/commit/3fb72fe93f8c4d6d78653b9a5f9ed284112a45fd)
- Adds autoRemove option for popup, removing it immediately if its triggering element is destroyed [`ddba1ea`](https://github.com/fomantic/Fomantic-UI/commit/ddba1eabbfdb0bf465898797ce6defb7f427974f)
- Fix keyboard shortcut bug in search [`80825b1`](https://github.com/fomantic/Fomantic-UI/commit/80825b1a681b270e99c612209d6b5cdac55bba0f)
- Finish popup animations on directional tooltips [`23ebac4`](https://github.com/fomantic/Fomantic-UI/commit/23ebac4cbb10599278ecc00b2a3ea6d4dc1202cd)
- Fix tooltip case when no data-position is specified [`50306f8`](https://github.com/fomantic/Fomantic-UI/commit/50306f8eaf37706d641c8b21be3b786965d7e6bc)
- #4412, redo paths to be more consistent with default theme [`2fd4846`](https://github.com/fomantic/Fomantic-UI/commit/2fd4846e999d6f54ce0054ef03afa2157bce8185)
- Fixes comment sizing #4408 [`b78df37`](https://github.com/fomantic/Fomantic-UI/commit/b78df3745d47796372eaa76c9da48d57b5e7c22f)
- Add placeholder input text global variables, fix dropdown placeholder consistency [`c0ef556`](https://github.com/fomantic/Fomantic-UI/commit/c0ef556e95869027ffe654530c0d14a71abffb8f)
- #4181 fix issue with jQ 3.0 width calculations causing shape to break [`2b955e0`](https://github.com/fomantic/Fomantic-UI/commit/2b955e0f81cc134fcc6a3dbb020ad82e012c7c80)
- Finish #3529 dependent fields [`b75d5f4`](https://github.com/fomantic/Fomantic-UI/commit/b75d5f44e348724fbdf7fc8a7d697fb68cb6605e)
- fix placeholder typo in vendor prefix for IE [`bffda0b`](https://github.com/fomantic/Fomantic-UI/commit/bffda0b46ca05e7882dfc3a6dab6c305c39f852c)
- Rebuild dist [`9b6f59c`](https://github.com/fomantic/Fomantic-UI/commit/9b6f59cbefe65118cb369be58583cf60c67f9d21)
- Fixes event namespace issues with modal/dimmer #3200 [`764e790`](https://github.com/fomantic/Fomantic-UI/commit/764e7905dee8d54ef2f4be4fb266d7cac70c2cac)
- Add #3886 min characters for dropdown [`544b205`](https://github.com/fomantic/Fomantic-UI/commit/544b20565ff68a634fd6af19be8babb92d1bd13d)
- Fixes to progress callbacks [`6f31ccb`](https://github.com/fomantic/Fomantic-UI/commit/6f31ccb2791f764a12198183d59760e0cd7b96df)
- Swap aliases on thermometer, fix issue with scrolling dropdown right padding [`01dbc26`](https://github.com/fomantic/Fomantic-UI/commit/01dbc261cac3a891278b2993a09ee34f091e2a5d)
- Fix dropdown icon spacing, fix issues with selectOnKeydown when using text that includes html (like images) [`33ea63e`](https://github.com/fomantic/Fomantic-UI/commit/33ea63ec9139ffd3cc49ae492aeffd1666f8db63)
- #4051 - Fixes paths to roboto in material theme [`dbafd8d`](https://github.com/fomantic/Fomantic-UI/commit/dbafd8d4f1a3eb3fc7c21925ba9b60ac870a0e9d)
- spelling: mobile [`e80a048`](https://github.com/fomantic/Fomantic-UI/commit/e80a048f3c301950f1b2c90401c6e6ee2c64b224)
- Fixes popups in menu not appearing due to css specificity [`baed862`](https://github.com/fomantic/Fomantic-UI/commit/baed86245f0e8003ff3809257ad11623a3815cd4)
- #3856 #3870 - Fixed issue where onSelect event would not prevent bubbled close event on blur. [`21d24a0`](https://github.com/fomantic/Fomantic-UI/commit/21d24a087cf4ee3ea4a01923514cbe47839ce6c1)
- Rlsnotes #4144 [`c4d6033`](https://github.com/fomantic/Fomantic-UI/commit/c4d6033d45bbb12bf86b7f509bc69326971e1e94)
- Fixes bug with normalize value returning 100 when total is &gt; 100 [`af06c7a`](https://github.com/fomantic/Fomantic-UI/commit/af06c7a93046f93f2237809ab86cb18a0d8d7430)
- Adds container option for sticky, adds checkbox vars [`b008a19`](https://github.com/fomantic/Fomantic-UI/commit/b008a19de8006a4378c4f232f372d6bf46ffb313)
- Rlsnotes noodling [`be95191`](https://github.com/fomantic/Fomantic-UI/commit/be95191f8abbbe7f651735d3a76ccdf6b361f2c1)
- feat(dropdown) add exact search - #3085 [`3e6a37f`](https://github.com/fomantic/Fomantic-UI/commit/3e6a37ffd7033e681fd0b9a0be61e8b7d6551193)
- Fix issue where refocusing search (to preserve position) could retrigger events [`2ebcc26`](https://github.com/fomantic/Fomantic-UI/commit/2ebcc2673444d371a3fa32e6ada1e0faf44d0236)
- #3779 - Fixes issue where dropdown with user addition would keep input after selecting a choice [`ccb1c7f`](https://github.com/fomantic/Fomantic-UI/commit/ccb1c7fde48e500edfef57282a92166d1dac5b1b)
- #3766 - Fixes issue with get value not returning proper value [`c4be1cb`](https://github.com/fomantic/Fomantic-UI/commit/c4be1cb694a31130f680f796006ba1c5ced595c6)
- Add thanks #4766 #4815 [`ec7c5ae`](https://github.com/fomantic/Fomantic-UI/commit/ec7c5ae9199bf0d6bc1c55d9c89e4ba97db926b5)
- #3879 fixes item cache not updating after addition [`9fa00b9`](https://github.com/fomantic/Fomantic-UI/commit/9fa00b937980dab2cb510e71eadb8eb50a9f226b)
- Add abiility to autofocus in menu search [`e3ad10f`](https://github.com/fomantic/Fomantic-UI/commit/e3ad10ffe43010dc0772a0981058374413b3f4e8)
- Update icon.variables [`4fc9f00`](https://github.com/fomantic/Fomantic-UI/commit/4fc9f00337b1688a8c56b836f3a02324f123d63e)
- Finish release notes, fix dimmer [`0a74209`](https://github.com/fomantic/Fomantic-UI/commit/0a74209b1e62796d76f0ce06aa4f5995f8467dcc)
- spelling: retrieve [`e982084`](https://github.com/fomantic/Fomantic-UI/commit/e982084621d45ccb93a8c91e496523d946d704f1)
- spelling: resetting [`3bb0773`](https://github.com/fomantic/Fomantic-UI/commit/3bb0773d6883c5a459bcca3c53e30a41736407c0)
- spelling: modifying [`ca8990d`](https://github.com/fomantic/Fomantic-UI/commit/ca8990df3f440d0f5cb9abc12f081d350707d08d)
- Rename selectonShortcut [`7c01d21`](https://github.com/fomantic/Fomantic-UI/commit/7c01d212b889dcbf7a7de8685cad16b3288593c8)
- Update visibility component to have callbacks onFixed,onUnfixed [`fbc5657`](https://github.com/fomantic/Fomantic-UI/commit/fbc56571ad19cb329ae59a4da986378a888ba5c1)
- Finishes @inputPlaceholderColor (was not applying global styles to dropdown). Remove missing variable #3975 [`a764af6`](https://github.com/fomantic/Fomantic-UI/commit/a764af62caa1fe0cced90676aa6edcdfd0858c16)
- #3789 - Fix issue with label click making menu appeaR [`2e5ad7c`](https://github.com/fomantic/Fomantic-UI/commit/2e5ad7c71c6d879a5b55d9efe840856f3b698c17)
- Modal- add setting for keyboard shortcuts [`bd92491`](https://github.com/fomantic/Fomantic-UI/commit/bd924919d2e471929372dc1eb6fd4e38781c1188)
- Adds new value prop to form validation #3313 [`cf4bab4`](https://github.com/fomantic/Fomantic-UI/commit/cf4bab4c3723b59726018afd022a172ff9960d54)
- Fix condition where progress could continue firing interval indefinitely if removed from DOM [`ef5913b`](https://github.com/fomantic/Fomantic-UI/commit/ef5913ba1d4699584616eb3d94f529cc312403d8)
- Adds first pass depends field #3529 [`313cfe8`](https://github.com/fomantic/Fomantic-UI/commit/313cfe8e3372216c29300687cd89ca8db3029bc2)
- #3724, fix relative paths to be prefixed with ./ [`0c3c410`](https://github.com/fomantic/Fomantic-UI/commit/0c3c41038c55d9cdb9fd1a114387ae6b63ba8a40)
- Fix autoinstall breaks when param used after git clone of repo (no package manager) [`7afba22`](https://github.com/fomantic/Fomantic-UI/commit/7afba22cc77c409332c070fcaca61f1b1535e877)
- Fix bug in search related to DOM fragment removed from document [`b8a14c2`](https://github.com/fomantic/Fomantic-UI/commit/b8a14c2917529f1343459a832a05c1920c7a87d1)
- Fixes hideAdditions accidentally on by default, fixes issue with when hideAdditions: true addition not appearing on 2nd edit [`90d9eaa`](https://github.com/fomantic/Fomantic-UI/commit/90d9eaa6e62a843972a232fe769393c511eef058)
- #3932 Fixes compatibility issues with jq 3.0 [`2afb4d9`](https://github.com/fomantic/Fomantic-UI/commit/2afb4d95d201f40fb7ea77cf5d580f1f82c4fb97)
- Force HTTPS URLs [`2006131`](https://github.com/fomantic/Fomantic-UI/commit/200613183c6597682e87c91253b6559099529b79)
- spelling: specifier [`635efd7`](https://github.com/fomantic/Fomantic-UI/commit/635efd7964d3daee93aa1b7bfdc169666d095ef6)
- Cleans up SVG logic #3774 [`ccfb0cd`](https://github.com/fomantic/Fomantic-UI/commit/ccfb0cda1053beeb0c7a7d08ed405a15cd8926bd)
- Fixes issue with checkbox onEnable/disable callback mispelling [`ed98c55`](https://github.com/fomantic/Fomantic-UI/commit/ed98c55e8471ce27a9c76305f5fb2448d05e11e3)
- Fix mobile form field spacing #3913 [`d8bdcaf`](https://github.com/fomantic/Fomantic-UI/commit/d8bdcafa8364aaa625beae4ddc60eca963a1f01e)
- API now adds real AJAXsettings to debug [`6ee12b2`](https://github.com/fomantic/Fomantic-UI/commit/6ee12b22605db059755aa14a7cdcfc1ed009d911)
- Fixes issue with bulleted list appearing as link color when list item is a link [`8ef074b`](https://github.com/fomantic/Fomantic-UI/commit/8ef074b0423f272b0c45b07c6fbb0fcad6a50c65)
- Add comment sizing [`0cd0126`](https://github.com/fomantic/Fomantic-UI/commit/0cd01269dca3a9037e0c27da85f329df375a7567)
- Hotfix for typo [`a9cd492`](https://github.com/fomantic/Fomantic-UI/commit/a9cd4922279326128726e081a7a2f1c4314a5ff3)
- #4284 - Fixes obvious brand colors.. tbd instagram [`faae37a`](https://github.com/fomantic/Fomantic-UI/commit/faae37a424eb5146d717d975c33a8d3bf22c4e2d)
- Fixes missing :before for television and grab icon #4178 [`47f0653`](https://github.com/fomantic/Fomantic-UI/commit/47f06538f323a2f438f2ce39e263fbb1273eae90)
- #4305 Fixes issue with grid alignment inheritance [`7076fbe`](https://github.com/fomantic/Fomantic-UI/commit/7076fbe14fcf1007beeaaaa702e39810a11341e6)
- spelling: setting [`4a6826e`](https://github.com/fomantic/Fomantic-UI/commit/4a6826e8bb1b97a775ad80276dedfc5be3a6d938)
- spelling: misspelled [`ea3c4aa`](https://github.com/fomantic/Fomantic-UI/commit/ea3c4aa832d88e9177bac3284f1d2a33e3c663ec)
- Fixes comment start. Fixes base class for `.envira.gallery`. Adds two more aliases for `.assistive.listening.systems`. [`5085742`](https://github.com/fomantic/Fomantic-UI/commit/5085742269d8728221606493d77d3bb539e507ad)
- Fix vertically divided grid spacing in top row [`aa9304e`](https://github.com/fomantic/Fomantic-UI/commit/aa9304ec42478ca76facba16fd30f4ee8a443df6)
- add !important to enable placeholder styling in IE [`764321a`](https://github.com/fomantic/Fomantic-UI/commit/764321a3d63ad64e777c83400f87c6c087dffb4b)
- #3703- Fixes issue with dropdowns/buttons on the left side of a ui input when using 'action input [`4879fe4`](https://github.com/fomantic/Fomantic-UI/commit/4879fe482b12212de46848fb9f1e022090681c01)
- Fixes let usage [`443e700`](https://github.com/fomantic/Fomantic-UI/commit/443e700a74dd71d361197bee35ecbade9da52285)
- Rebuild 2.2.4 [`83147b8`](https://github.com/fomantic/Fomantic-UI/commit/83147b82b412d4213e60824857af0931ab05505d)
- Implements #4224 - justified centered grid fix [`d65d2e3`](https://github.com/fomantic/Fomantic-UI/commit/d65d2e3775c7d860c22fc9a506706f18f51b649c)
- Fix selection issue with &lt;select&gt; and userAdditions [`79c3108`](https://github.com/fomantic/Fomantic-UI/commit/79c31082b76c300cd6540b56e3dda7ee68300ceb)
- Fixed dropdown menu item not opening upward [`7ba53c3`](https://github.com/fomantic/Fomantic-UI/commit/7ba53c302f9cf436a60db8a2ced873484f481b52)
- Adds #3370 zIndex with type fixed visibility api [`a4ef537`](https://github.com/fomantic/Fomantic-UI/commit/a4ef53777ca434c1e018c56395424cea1132965a)
- Fix double hide issue in dropdown from force selection [`b2c4134`](https://github.com/fomantic/Fomantic-UI/commit/b2c41344867020671db41b5ec32d0b9e5c87dc17)
- Revert "zone.js/issues/319 Loosen equality on undefined check for determining input event" [`1e8d01b`](https://github.com/fomantic/Fomantic-UI/commit/1e8d01b4a740973e31bdc3a78a6de6b5cbc1cc4e)
- Fix typos in rlsnotes 2.2.3 [`60642e1`](https://github.com/fomantic/Fomantic-UI/commit/60642e10c01be421847c019dad55297558e86235)
- zone.js/issues/319 Loosen equality on undefined check for determining input event [`d028ed1`](https://github.com/fomantic/Fomantic-UI/commit/d028ed19b06ec25ddb033476eff8cebf2338abd7)
- #3313 remove logging [`4d01914`](https://github.com/fomantic/Fomantic-UI/commit/4d01914783363c90260ee269c789a5d6017e1535)
- #4174, remove path.sep from paths [`961b4c9`](https://github.com/fomantic/Fomantic-UI/commit/961b4c90680e8d3c1e423fbf9c0fdaf20d1e87af)
- Add forum note [`4f7a347`](https://github.com/fomantic/Fomantic-UI/commit/4f7a347f222db87a38040ff1db7bf25e91588bd8)
- spelling: tolerance [`422777d`](https://github.com/fomantic/Fomantic-UI/commit/422777d3de20682e5eba6eecf2db894965009a02)
- spelling: programmatically [`d98662f`](https://github.com/fomantic/Fomantic-UI/commit/d98662f40ce09544593d3546a76b4c2acee3db94)
- spelling: paths [`22b1180`](https://github.com/fomantic/Fomantic-UI/commit/22b1180c98a5035a734b96e1a3db72648db24455)
- spelling: overridden [`5f18cca`](https://github.com/fomantic/Fomantic-UI/commit/5f18cca855bf812a7c7fc9a1892ee21ab1cf8253)
- spelling: occurring [`f31b64b`](https://github.com/fomantic/Fomantic-UI/commit/f31b64b130fe0314285475659c2960479a17d720)
- spelling: listener [`b197250`](https://github.com/fomantic/Fomantic-UI/commit/b19725007460f0263ae63c30e9416198165b6fc6)
- spelling: initialized [`89f0c70`](https://github.com/fomantic/Fomantic-UI/commit/89f0c704ce78d9844630504fd5195d8b265a1de1)
- Make casing consistent #3774 [`465358b`](https://github.com/fomantic/Fomantic-UI/commit/465358bb789643964b35f79f9b97b3578f8081d3)
- Fix rem sizing on icon #3782 [`6552df0`](https://github.com/fomantic/Fomantic-UI/commit/6552df01c835ff248856956cae7a614e5f23902d)
- Fix point-events typo #4408 [`a551335`](https://github.com/fomantic/Fomantic-UI/commit/a551335b854681ddf279ca2827ed157191cf0198)
- Fix observe changes not working correctly in popup [`549e61f`](https://github.com/fomantic/Fomantic-UI/commit/549e61f35e5b7bf5612ca1df7be7eb72014f82dd)
- #4167 - Tabular menu now has correct bottom margin in all cases [`39ef156`](https://github.com/fomantic/Fomantic-UI/commit/39ef156decdf8e1e46034594229cad9af044d9a5)
- Fix issue with hideAdditions where enter key would not select value when typing rapidly [`77980c1`](https://github.com/fomantic/Fomantic-UI/commit/77980c1864abecd50ca2a64eba564c42c136f294)
- #3960, provide hint on hiding error message in msg [`9f68638`](https://github.com/fomantic/Fomantic-UI/commit/9f686384007889805912ff28ecf83102b321b6f6)
- Fix margin when floated content after top attached label [`2ed268a`](https://github.com/fomantic/Fomantic-UI/commit/2ed268a732f5c38f8835b8b34f9a29122a33a7b5)
- Fix issue with not pulling href from result #3409 [`6867f48`](https://github.com/fomantic/Fomantic-UI/commit/6867f48a06439d5bd0d1ad971854b1d9fe96ca29)
- Finishes renames #3984 [`0749182`](https://github.com/fomantic/Fomantic-UI/commit/074918211e9306a9f5d132f47d4f7660ab6c9f32)
- Dropdown menu tpl disabled attribute fix [`6acfabf`](https://github.com/fomantic/Fomantic-UI/commit/6acfabf80fba3512c9b173b4adebd6eee94e9e17)
- Fix issue with selection refocus changes causing menu not to open with down arrow key [`c43d464`](https://github.com/fomantic/Fomantic-UI/commit/c43d464a82902fda70f9f32c5873a7f0f6e65882)
- Updating regex for email validation [`57e4f72`](https://github.com/fomantic/Fomantic-UI/commit/57e4f72b9e115b9f2447bb6fa24a8a7c7b25f38f)
- #3886 fix default [`4a8eef3`](https://github.com/fomantic/Fomantic-UI/commit/4a8eef36deedfafec3f488f93666ad9531ca2a79)
- Fix variable addition for close/very close rail #3835 [`b0ca662`](https://github.com/fomantic/Fomantic-UI/commit/b0ca6625c8ca396d09114b8eb89876cb21c26a88)
- Fixes secondary inverted style [`0ffa8f9`](https://github.com/fomantic/Fomantic-UI/commit/0ffa8f96d911ac3c7fb5b017036a31f0c7ba7800)
- Add restore placeholder text [`fc29e68`](https://github.com/fomantic/Fomantic-UI/commit/fc29e682efc5c12ee59a772d7a0b9e1ad1e279c3)
- Rename localSearch to filterAPIResults #4815 [`a8bdf7d`](https://github.com/fomantic/Fomantic-UI/commit/a8bdf7d1053514f5eb6d9dfddb5bd0d7dc234170)
- Fix burma flag not having right sprite location [`a7f0df9`](https://github.com/fomantic/Fomantic-UI/commit/a7f0df91c98a7c6f58587dcb4ac6f051a91dddaa)
- Adds missing checkbox variables [`46904f9`](https://github.com/fomantic/Fomantic-UI/commit/46904f93915ed249cdb5c80be61a162cbd98af83)
- add localsearch function for dropdown with api remote data [`9efa323`](https://github.com/fomantic/Fomantic-UI/commit/9efa3234880e6d1f7fd802a2872cf37e456fa24e)
- #4408 - adds cred [`d849264`](https://github.com/fomantic/Fomantic-UI/commit/d849264b0b7c821ce8ca7701c820ebba32b69a78)
- [ref #4398] added hover styling to icon group [`90d4229`](https://github.com/fomantic/Fomantic-UI/commit/90d422942bc7602decfdf7701b6bac5509c6cfa4)
- Fixes dribbble icon #4185 [`e19abd5`](https://github.com/fomantic/Fomantic-UI/commit/e19abd586b15a76b7722f853a256047e48912374)
- #4107 Fixes only one vertical button [`0f48652`](https://github.com/fomantic/Fomantic-UI/commit/0f48652ba8306fe285f76ede1475b9c1de1fa433)
- Fixes disabled radios #4366 [`0f6d161`](https://github.com/fomantic/Fomantic-UI/commit/0f6d1617ac4be4276695e51d7995d11e06adcc22)
- Rlsnotes [`a7578b2`](https://github.com/fomantic/Fomantic-UI/commit/a7578b24545c479975bf9bc2996b4c9d57439213)
- Fix rlsnotes [`5bdde32`](https://github.com/fomantic/Fomantic-UI/commit/5bdde32e424a891cdab18d6a209dbc864101e6b3)
- spelling: thanks [`ca05c38`](https://github.com/fomantic/Fomantic-UI/commit/ca05c38dd38675830cbcec6eaecac4ac9e28f00e)
- spelling: visibility [`30ba1b4`](https://github.com/fomantic/Fomantic-UI/commit/30ba1b40e318ab40a828eb10ff6830f49bf71032)
- spelling: shortcuts [`4602cf3`](https://github.com/fomantic/Fomantic-UI/commit/4602cf3c0704d5c6357d5fee2fd53761386ce5e8)
- spelling: receive [`cf7f518`](https://github.com/fomantic/Fomantic-UI/commit/cf7f51872165ab1f3ed9e138c3d74ce7e37abe1b)
- Rlsnotes formatting [`172b813`](https://github.com/fomantic/Fomantic-UI/commit/172b81346fa45e535e684fc2cc03ad4e1d854faf)
- Add allowReselection setting for dropdown [`83d0585`](https://github.com/fomantic/Fomantic-UI/commit/83d0585102044477d5124c8922a06650f0251172)
- Add new variables for disabled button [`26a8815`](https://github.com/fomantic/Fomantic-UI/commit/26a881596e6dcd8fca3dcfb5dc61bdf096c63bc0)
- Fixes issue with disabled input getting :active styles #3907 [`13b8aaf`](https://github.com/fomantic/Fomantic-UI/commit/13b8aaf8ce8a131207d48dcf6c88a00eb8491e1b)
- Fix progress to use update interval [`acf3cc5`](https://github.com/fomantic/Fomantic-UI/commit/acf3cc5a4fca56a7ada4d4c08907cba02b98297e)
- Fix icon button centering [`4a4fc9b`](https://github.com/fomantic/Fomantic-UI/commit/4a4fc9b2a0f43a3dcbe2a4d7f6b7354342df99c4)
- Fixes missing message var [`b564cc3`](https://github.com/fomantic/Fomantic-UI/commit/b564cc3985966336d80d678bdbc932330000880e)
- Fixes focus on modal to include tabindex #4370 [`5476580`](https://github.com/fomantic/Fomantic-UI/commit/54765808d3943d50a54e6d448c502396156b5ca2)
- Update jq version #4254 [`2092e07`](https://github.com/fomantic/Fomantic-UI/commit/2092e0715016c710a3a49e33779b6fdce9fa96d2)
- Rlsnotes #4051 [`aa587c6`](https://github.com/fomantic/Fomantic-UI/commit/aa587c63ef05a15082e97576426841c12587b84c)
- Fixes uselabels not clearing properly #4366 #4275 [`ca08f33`](https://github.com/fomantic/Fomantic-UI/commit/ca08f335b75af1a71614196577c823e2cf395e14)
- Fixes vertical text menu includes horizontal padding [`00587e1`](https://github.com/fomantic/Fomantic-UI/commit/00587e1e523e6d949a831da3252d91993502247d)
- Fixes duplicated class name. [`83f2a12`](https://github.com/fomantic/Fomantic-UI/commit/83f2a1252dc2976a853bf15a018984aad662cc59)
- Revert api change [`e54566b`](https://github.com/fomantic/Fomantic-UI/commit/e54566b8de59a6f4a84b91465a584faee237004e)
- fix: Correct ProjectTalk link [`5570a1f`](https://github.com/fomantic/Fomantic-UI/commit/5570a1f8a9c02e354fd23ef7a69dbdef028deca4)
- Fix disabled checkbox override, wrap on search [`aea6ae8`](https://github.com/fomantic/Fomantic-UI/commit/aea6ae8393fe34845d5f16aa781f2c793fc92f6b)
- Fix attached step spacing [`41cb709`](https://github.com/fomantic/Fomantic-UI/commit/41cb7095855fbb74cd662c8187fe5dd4938e1137)
- Adds is complete method [`7308c11`](https://github.com/fomantic/Fomantic-UI/commit/7308c1173495f3c84fa461bca486244c0fbcdd33)
- Date [`22acbc2`](https://github.com/fomantic/Fomantic-UI/commit/22acbc26714637a5f0e1248c22aea16622f9822e)
- dropdown localsearch default to false [`634d2e0`](https://github.com/fomantic/Fomantic-UI/commit/634d2e0a08d0f905be4b6d6f7c3f025f474eed1c)
- Fix &lt;body&gt; being set to position relative when dimmable class applied [`a74d21a`](https://github.com/fomantic/Fomantic-UI/commit/a74d21a2f32dbe7a5199fe3b089626afe28fb095)
- #2534 release notes [`284f517`](https://github.com/fomantic/Fomantic-UI/commit/284f517f15e8c23357a6926a2ad43bbc7f23dc47)
- Update checkbox.less [`a21cbce`](https://github.com/fomantic/Fomantic-UI/commit/a21cbcef7a1ed690986a2461e52733a21ca6ef83)
- #4497 check if validation rule is defined when revalidating [`9411e01`](https://github.com/fomantic/Fomantic-UI/commit/9411e0182e6803fd5bb8abd0ebea68ab336f48f9)
- Update dropdown.js [`77d2739`](https://github.com/fomantic/Fomantic-UI/commit/77d2739079519f65b7c2545b4334b8dd8684a895)
- FIX: build after autoInstall [`301b3ad`](https://github.com/fomantic/Fomantic-UI/commit/301b3ad5a7626da070034e2a8aa3a902de139c36)
- Fix: Testing whether semantic.json is present in the install path, not the source path - otherwise semantic.json was overwritten during npm install (autoInstall:true) [`b6f1bdd`](https://github.com/fomantic/Fomantic-UI/commit/b6f1bddea2195693872399dbfded1a26647d19e4)
- FIX: auto install did not copy build during npm install [`161f72c`](https://github.com/fomantic/Fomantic-UI/commit/161f72cb9d33f8452f24f2b8dc0bac6705b9e99b)
- Add iconPath duplication to avoid reqing material site theme [`f13c935`](https://github.com/fomantic/Fomantic-UI/commit/f13c935f1d5c45ad46cd4635296fc50e80ac614b)
- #4403 cred [`d450ef7`](https://github.com/fomantic/Fomantic-UI/commit/d450ef7552c335ca383656af932ead5d5ad41b99)
- Update form.js [`b85ae81`](https://github.com/fomantic/Fomantic-UI/commit/b85ae81de35cf61bd6a0a57bcf473dc4b79e54f2)
- Fix comments #4125 [`d38e863`](https://github.com/fomantic/Fomantic-UI/commit/d38e863afe5f35dfede31ec40b0e9c4ac5b7fb70)
- Fix dropdown labels [`cef9e74`](https://github.com/fomantic/Fomantic-UI/commit/cef9e74d3c35497e0b60637d983d33161c923b94)
- Fix cursor on search dropdown [`6962b7b`](https://github.com/fomantic/Fomantic-UI/commit/6962b7b859166e49995354e7f48ed3857a4e09c8)
- #4192 [`c9bbe21`](https://github.com/fomantic/Fomantic-UI/commit/c9bbe21ef704e13b37ee417fe731e2a08814bd42)
- Fix [`bbcde4b`](https://github.com/fomantic/Fomantic-UI/commit/bbcde4b6cfb23b8a42143711f1b591b2d196bc7f)
- Remove duplicate height definition [`31026d4`](https://github.com/fomantic/Fomantic-UI/commit/31026d4b0e9662d4b9ee73903200f4dd4f6d4a24)
- Reset some styles in tooltip [`6fea79b`](https://github.com/fomantic/Fomantic-UI/commit/6fea79b6698974e755e8cf450f1f9abe137c90bc)
- Fix issue where selection was borked for search inside menu [`4b6595d`](https://github.com/fomantic/Fomantic-UI/commit/4b6595dd9905df72befedf44b6cb920406f7ce29)
- Fix error in dropdown logic with hideAdditions, fix func call missing parens [`489588c`](https://github.com/fomantic/Fomantic-UI/commit/489588cfd59f3f0a9ba49ea6203a6e48cd80fb2c)
- Fix issue with using let [`4f4b6c1`](https://github.com/fomantic/Fomantic-UI/commit/4f4b6c1d5545a113a1901d857804e9fdd94c8c28)
- Ok now really [`85a69ae`](https://github.com/fomantic/Fomantic-UI/commit/85a69aeafb076b738356d9aeb39ed84ad7e14654)
- Fixed an issue where all child inputs of a icon input would recieve a right padding, not just the main input. This caused issues where a popup was attached to the icon input which caused all of the inputs inside of it to have an uneeded padding. [`4731246`](https://github.com/fomantic/Fomantic-UI/commit/4731246f285a2ebcdd8a511111bb62f3f3ac3271)
- Fixes issue where if context is removed visibilty observers will not properly remove events [`a6238f0`](https://github.com/fomantic/Fomantic-UI/commit/a6238f06c110bbe836f80af2f9cec7b8549698f8)
- spelling: women's [`a6e4d7c`](https://github.com/fomantic/Fomantic-UI/commit/a6e4d7c43e18e3a8f0e82a79f7c9d75612b9b254)
- spelling: men's [`0963d6b`](https://github.com/fomantic/Fomantic-UI/commit/0963d6b1b2b2f25195a3966f985d27ef95749825)
- spelling: variations [`4543690`](https://github.com/fomantic/Fomantic-UI/commit/4543690a9d3c3529de2a558b86f0c455dc6c04a9)
- spelling: transition [`a43c082`](https://github.com/fomantic/Fomantic-UI/commit/a43c0821abfade3b71201a02b45502c91760d0e3)
- spelling: synchronously [`20c1f28`](https://github.com/fomantic/Fomantic-UI/commit/20c1f289bea35c4ccee063873ebe533a8107c495)
- spelling: statistic [`8941507`](https://github.com/fomantic/Fomantic-UI/commit/8941507b1983a0cf01b4d3132d8b202ab9067531)
- spelling: sequitur [`3ad9246`](https://github.com/fomantic/Fomantic-UI/commit/3ad92468b389726385a3f86e2ef4432c3c935e7b)
- spelling: search [`4b230ab`](https://github.com/fomantic/Fomantic-UI/commit/4b230ab85d3a11408aab6183130d4467c8062ac0)
- spelling: rewrite [`ac66cd6`](https://github.com/fomantic/Fomantic-UI/commit/ac66cd60e9cd3277c9d61c6be4ce3cf8a9aa5cad)
- spelling: previous [`ed04eb7`](https://github.com/fomantic/Fomantic-UI/commit/ed04eb728a6d5a124cd95dcd9c2bb33f825d7d64)
- spelling: permissions [`0487625`](https://github.com/fomantic/Fomantic-UI/commit/04876253f4ba0cb107b5630f1cbff28a99a6e6bd)
- spelling: ordered [`cf905c2`](https://github.com/fomantic/Fomantic-UI/commit/cf905c211f7b8a0b5ac5a7b5f7c7396c2b2f5350)
- spelling: length [`39a7f49`](https://github.com/fomantic/Fomantic-UI/commit/39a7f49559bc686d274d3216dbde20120236d233)
- spelling: initializing [`7728c48`](https://github.com/fomantic/Fomantic-UI/commit/7728c4820107312d73b49549549acfc33c9d0dfe)
- Fix debug msg position #3879 [`ad9ccbf`](https://github.com/fomantic/Fomantic-UI/commit/ad9ccbfe8cafa851d3354035ceb0cf8d56e0a2b6)
- Fix accidental use of ES6 function type. (I gotta stop doing this) [`1c0a565`](https://github.com/fomantic/Fomantic-UI/commit/1c0a5658825672335c8c852b1d7ac3e5d824fca6)
- Updates version number in icon.overrides file. [`74d1a03`](https://github.com/fomantic/Fomantic-UI/commit/74d1a03ee16fbe29d3aab0b460ad2d9aa169869a)
- Update rlsnotes for new feature [`77c1e9c`](https://github.com/fomantic/Fomantic-UI/commit/77c1e9cd78b83c5c5440a131bd99ba2830991743)
- last time [`9ddf9da`](https://github.com/fomantic/Fomantic-UI/commit/9ddf9daf0259cba3bcf0b76503f2680bce1a6b97)
- Fix rlsnotes [`ebb5196`](https://github.com/fomantic/Fomantic-UI/commit/ebb5196ad76c2b11188df42cdd30db8a9e4c23d6)
- Fix boolean flag for allowReselection being flipped [`ffc99e5`](https://github.com/fomantic/Fomantic-UI/commit/ffc99e5b66a0b90dd9c29d54412980ccf8d3a2d1)
- Fixes delimiter no longer working [`c9e4d83`](https://github.com/fomantic/Fomantic-UI/commit/c9e4d83e5fe5195ed65aa429561272dba5cb4d3c)
- rlsnotes [`b6002f6`](https://github.com/fomantic/Fomantic-UI/commit/b6002f61621966018dd73f917c4efb58d7602768)
- API now passes response to error handler when successTest fails [`a977c33`](https://github.com/fomantic/Fomantic-UI/commit/a977c331ea7c03947e807a7cfb1288c5d58fbbca)
- #3370 default to 10 [`970dffb`](https://github.com/fomantic/Fomantic-UI/commit/970dffbb68ee4bd2814ad37782d12bdedaf30f43)
- Updating regex for email validation [`7762e4e`](https://github.com/fomantic/Fomantic-UI/commit/7762e4e53e915428bb4133696f34a0193ec2721e)
- Fixes use of document.contain (borked in IE11) [`42dd3c7`](https://github.com/fomantic/Fomantic-UI/commit/42dd3c771b46ac4a045a65aff51e1b1f599b1619)
- Fix 1px offset on search selection input [`f69995d`](https://github.com/fomantic/Fomantic-UI/commit/f69995d8c0116015854845adc26abfa88ec65996)
- Fix multi dropdown icon spacing [`a7cab11`](https://github.com/fomantic/Fomantic-UI/commit/a7cab11bba882aeb37c3f7b46a70d4e08a4304e1)
- Remove console.log [`9528c17`](https://github.com/fomantic/Fomantic-UI/commit/9528c1764f9551ac97a3ad44b662086b53c4fcbe)
- #3873- Fixes typo in green inverted button [`4426f5c`](https://github.com/fomantic/Fomantic-UI/commit/4426f5c861850c29b14f3a5c38ebf1754928125f)
- Rlsnotes [`169ade8`](https://github.com/fomantic/Fomantic-UI/commit/169ade8c9be8ce8b0262816a6ce20f8fd0580d76)
- Fix logic snafoo in API #3770 [`61e6d13`](https://github.com/fomantic/Fomantic-UI/commit/61e6d133c8251f5eeae5f4eac1cfd53b88318704)
- Re-enable normal debug for search [`1b341b2`](https://github.com/fomantic/Fomantic-UI/commit/1b341b2e99fdcdbb3eaee0c25a573bece2d80c94)
- #3596 rlsnotes [`a40e5c6`](https://github.com/fomantic/Fomantic-UI/commit/a40e5c64689e720a60a68a42570da9c80b66b9bc)
- Fix dropdown icon size (slightly smaller), add variables [`5c79d13`](https://github.com/fomantic/Fomantic-UI/commit/5c79d13e78daa7b30eefa2eb94f00b86105ee9ac)
- Fix arrow inheritance [`a1f4fe4`](https://github.com/fomantic/Fomantic-UI/commit/a1f4fe4ecc7c85b9ed70db90e356b05ac39c820b)
- Fix text align of dropdown in icon menu [`61cf566`](https://github.com/fomantic/Fomantic-UI/commit/61cf566488d757fcc3d9690d5599ada0f9d7a030)
- Fix typo in menu [`f49b549`](https://github.com/fomantic/Fomantic-UI/commit/f49b5495e5a257cfa281896f7e9189f0e11eef83)
- Explain query is available in onSearchQuery [`a8d28c5`](https://github.com/fomantic/Fomantic-UI/commit/a8d28c5bd8a2b3578c665fd0f086b620fae26c33)
- Add missing background-color variable for vertical tabular menu [`54acbe7`](https://github.com/fomantic/Fomantic-UI/commit/54acbe7bd45ed9a01c1cec28e69cfc82acf67a64)
- Fix date [`236f761`](https://github.com/fomantic/Fomantic-UI/commit/236f761cf69f52a7d4b71d86892d49e9101f8170)
- Formatting [`8b3b9d3`](https://github.com/fomantic/Fomantic-UI/commit/8b3b9d3b7fea2d29ce4945e9ae2b8b46cde672d4)
- Exit process with explicit success code [`303b657`](https://github.com/fomantic/Fomantic-UI/commit/303b6579c69622112c123413a6b45258f3103c78)
- Messaging for install [`d640afc`](https://github.com/fomantic/Fomantic-UI/commit/d640afca4d74f422c392ae6c4c8c7155661ad294)
- Messaging [`6a94e11`](https://github.com/fomantic/Fomantic-UI/commit/6a94e11e14a98d0e4d294ec9547b0da4f8214aec)
- Update message [`71b8121`](https://github.com/fomantic/Fomantic-UI/commit/71b8121d90e1160d8e0291c432cf99688a6d2e92)
- test stuff [`c9feedd`](https://github.com/fomantic/Fomantic-UI/commit/c9feedd0f1f23dd36d8f1ad9631d2272e136b0ba)
- Dropdown 'is disabled' did not return a value #2699 [`f9c3a63`](https://github.com/fomantic/Fomantic-UI/commit/f9c3a632cf46adac8936482ce1029a9b537b11a6)
- RLsnotes [`19bf6da`](https://github.com/fomantic/Fomantic-UI/commit/19bf6da7072c34d5f4c6bff8eab1e1778f0974b8)
- #2687 Revise Readme [`0e9c3a2`](https://github.com/fomantic/Fomantic-UI/commit/0e9c3a211a6c830c7518ed4de5e9b874d6fc3721)
- Rlsnotes formatting [`ea7f223`](https://github.com/fomantic/Fomantic-UI/commit/ea7f223c2d864151df98c21f58ec327b5336c423)
- Formatting rlsnotess [`357aa8e`](https://github.com/fomantic/Fomantic-UI/commit/357aa8eeb19503ac671ba95e97fe61830b1c6d64)
- Add rlsnote date 2.0.4 [`79738f8`](https://github.com/fomantic/Fomantic-UI/commit/79738f8a6e9e911b1c7f2caba72b72d5409b99bd)
- Fixes issue with search selection not removing default text when inside ui menu #2624 [`2e03545`](https://github.com/fomantic/Fomantic-UI/commit/2e035456a81994c18959cd90b87841588a950f26)
- #2644 remove unnecessary call to remove direction in destroy [`d74255f`](https://github.com/fomantic/Fomantic-UI/commit/d74255fe5709e4c49034450b189842b34e0d5a75)
- Update gulpt watch [`90e7a60`](https://github.com/fomantic/Fomantic-UI/commit/90e7a60d244d2deeb13f0da9f65999c7d37385e7)
- #2526 Increase jitter [`0775e8f`](https://github.com/fomantic/Fomantic-UI/commit/0775e8fffa7c072798fa5b403e734dba19ce4313)
- Add issue number #2556 [`197ff5c`](https://github.com/fomantic/Fomantic-UI/commit/197ff5cf1694f1b287a676dca2ab1f0bef9f43d1)
- Add misssing square/square outline icon #2532 [`fc84f5a`](https://github.com/fomantic/Fomantic-UI/commit/fc84f5a847fa05d80cb5d18dcd2bb2e85a929915)
- #2581 add rlsnotes and credit [`50264b9`](https://github.com/fomantic/Fomantic-UI/commit/50264b91874c5280782f9f219e80175c26b78695)
- Fix italicized checkbox check [`8f39d19`](https://github.com/fomantic/Fomantic-UI/commit/8f39d19ce0b445b5b7873c6f9b3c319bdef1daf9)
- Exit processs [`1e6315e`](https://github.com/fomantic/Fomantic-UI/commit/1e6315e972f4108ac2307c184e99fd80975d2f39)
- #2666 remove debug [`e906663`](https://github.com/fomantic/Fomantic-UI/commit/e906663f5f19779679a5bf0fda1dc6c37f2e6e14)
- #2617 rlsnotes [`20e6b47`](https://github.com/fomantic/Fomantic-UI/commit/20e6b47f3dfc9e105a79ce9dd480161428e8a83f)
- Merge pull request #2597 from jammiemountz/patch-1 [`c2f416d`](https://github.com/fomantic/Fomantic-UI/commit/c2f416d702b5b8caad5899502730b45bb6f05724)
- Rebuild dist [`5e040e0`](https://github.com/fomantic/Fomantic-UI/commit/5e040e0d4f610e52642099a0d96f9c9276625dfc)
- Package 2.0.1 [`9362682`](https://github.com/fomantic/Fomantic-UI/commit/9362682f5ef07186ab87c6b1020b73b8bc9f6964)
- Dimmer now correctly removes variations in 'destroy' [`5d90243`](https://github.com/fomantic/Fomantic-UI/commit/5d90243f0e826e0372ce8ef4bd49a19c3c2111fc)
- Checkbox- Fixes issue where radio checkbox would uncheck itself mistakenly when unchecking other radios #2506 [`7d64b86`](https://github.com/fomantic/Fomantic-UI/commit/7d64b86c6cd66bb5e9a297f270d674b69624cbd7)
- #2516 dropdown will now cycle between choices starting with a letter [`459194a`](https://github.com/fomantic/Fomantic-UI/commit/459194a750270b7db4a547eb899021bdca5677fd)
- #2524, clicking on labels will no longer trigger toggle behavior. Caused by detached dom element not being considered click inside module [`9b96a04`](https://github.com/fomantic/Fomantic-UI/commit/9b96a047df303461c3eeebc6751ec5bac1fd75b8)
- #2538 @size ratio values should always be expressed in terms of default em size, so that they scale with @emSize [`6e5755b`](https://github.com/fomantic/Fomantic-UI/commit/6e5755bd7c8d2fb813d5289d5d9d39a0d375a971)
- Update rlsnotes [`0268ade`](https://github.com/fomantic/Fomantic-UI/commit/0268ade8a38f12971290a0f209c41a1e163d06e7)
- Dropdown will now show when only messsage in menu. Fixed maxSelections from hiding dropdown after selection. #2523 [`ecccaf5`](https://github.com/fomantic/Fomantic-UI/commit/ecccaf50a3c88b803252f076af11f8f12b6a349f)
- RLSNOTES [`cf19a3e`](https://github.com/fomantic/Fomantic-UI/commit/cf19a3e77162f728683f5c2a85c9716f05d9887a)
- #2533 - Fixes issue with hideAndClear when no maxSelection [`4514ac4`](https://github.com/fomantic/Fomantic-UI/commit/4514ac4089870a8d73d25a2a3cfdec32b2da52bc)
- Fix issues with ajax tabs not obeying cache #2493 [`7a53664`](https://github.com/fomantic/Fomantic-UI/commit/7a5366423c9be107e18cd05923db6f4f916434bb)
- #2505 Fixes indeterminate checkbox styles causing radios to appear checked when none selected [`f49c554`](https://github.com/fomantic/Fomantic-UI/commit/f49c554aa65d3b829e341aaf08670df62fb41fc0)
- #2500 Attached label border radius, add new variables [`d84c4d2`](https://github.com/fomantic/Fomantic-UI/commit/d84c4d24b5235ff96cebbc1d77c6754362fa81c6)
- Update release notes [`d5b4ebb`](https://github.com/fomantic/Fomantic-UI/commit/d5b4ebbe3dce1a8f0c0410077cc92eb6aa191964)
- #2510 Fix dropdown icon to always toggle visibility of dropdown menu [`89e0512`](https://github.com/fomantic/Fomantic-UI/commit/89e05127d0b326a06b0d60cc42fea6c601972da7)
- RLSNOTES [`2185d20`](https://github.com/fomantic/Fomantic-UI/commit/2185d200b76a2fa3761c22e71321de82b5bc47ca)
- Removes transparent border from inverted menu. Fixed vertical compact menu [`9794ece`](https://github.com/fomantic/Fomantic-UI/commit/9794ecefa66f8d3d541acc427f365c689c5c78ec)
- #2525 Remove toggle on multiple dropdown touchstart, fix tap color [`6e2938b`](https://github.com/fomantic/Fomantic-UI/commit/6e2938bb37df563f8ae3299d6360d43f11307aa3)
- RLSNOTES [`15db4c3`](https://github.com/fomantic/Fomantic-UI/commit/15db4c3e855fb073fd440226a41ce32b9038e4fd)
- Fix incorrect margin on attached segment #2503 [`bd166b8`](https://github.com/fomantic/Fomantic-UI/commit/bd166b8fed927edf584ba5fa9a658162dcf00d8e)
- Adds justify content rules for centered cards #2520 [`6ab0e48`](https://github.com/fomantic/Fomantic-UI/commit/6ab0e48084e86e6515fd1c30eb747c593cd2d796)
- #2539, update text before onChange [`77a1257`](https://github.com/fomantic/Fomantic-UI/commit/77a12579dae41b9b1641d15263a2956039ecb85e)
- Update rlsnotes [`bbf3609`](https://github.com/fomantic/Fomantic-UI/commit/bbf360958c7b33e3a39ee433e1d9bd2aeb6125fe)
- Fix border top on fixed bottom [`8d4b0f2`](https://github.com/fomantic/Fomantic-UI/commit/8d4b0f248b192f283a74c4ad362c391131065568)
- #2522 Read metadata method does not set progress correctly. Debug should be off by default [`e35ca4d`](https://github.com/fomantic/Fomantic-UI/commit/e35ca4d2fa9ab7a0d8408f7811eaa378e0bb873d)
- Rlsnotes [`2620249`](https://github.com/fomantic/Fomantic-UI/commit/262024940303c9d35bad090b7a74321f7c536da7)
- #2524 - remove console log (actually) [`64b087d`](https://github.com/fomantic/Fomantic-UI/commit/64b087d6632e6a0942c47197c4dedc7a5bb8bd31)
- #2524 - remove console log [`43b8be1`](https://github.com/fomantic/Fomantic-UI/commit/43b8be1934cc82eb3a04d61ce730ec2155b80035)
- #2538 Remove test emSize change [`4ca68e8`](https://github.com/fomantic/Fomantic-UI/commit/4ca68e818a0a98aaba2a19e4fed58969954e1a4f)
- Safely removes .field .field margin #2487 [`de53fd2`](https://github.com/fomantic/Fomantic-UI/commit/de53fd257d6edec58eeb600ba97db457249ad4d0)
- #2518 better check for hidden [`ee69a51`](https://github.com/fomantic/Fomantic-UI/commit/ee69a51921e03ee243c5a0f5db05d4c053f02707)
- Add a default file set for jsDelivr [`651ad1d`](https://github.com/fomantic/Fomantic-UI/commit/651ad1d6b331c65d11c5d3916e09d832e541926e)
- Rlsnotes #6269 [`aebff18`](https://github.com/fomantic/Fomantic-UI/commit/aebff182e9e0329c5abd8c831fab531457db5085)
- Rlsnotes #6268 [`c699610`](https://github.com/fomantic/Fomantic-UI/commit/c699610ff4e27da9afab7eae1ca79687eda63466)
- Rlsnotes #4183 [`050d182`](https://github.com/fomantic/Fomantic-UI/commit/050d182d6a473abd1b00bd02f2a42ab41fac82a2)
- Rlsnotes #6223 [`4eef977`](https://github.com/fomantic/Fomantic-UI/commit/4eef97737bcaa349bfb0870ddd9ce6c6f1bcd110)
- Update ISSUE_TEMPLATE.md [`9d23bed`](https://github.com/fomantic/Fomantic-UI/commit/9d23bed313d8b59db41c6a274f1748fce06ca38c)
- Rlsnotes #6167 [`16b3b27`](https://github.com/fomantic/Fomantic-UI/commit/16b3b276854b7ca6dd41595b7eb0bc6585123b53)
- Thanks #4631 [`39f20bc`](https://github.com/fomantic/Fomantic-UI/commit/39f20bc2adc91355cd67e325be6f99e100cf4383)
- #4423 Thx [`0992f41`](https://github.com/fomantic/Fomantic-UI/commit/0992f41e90c1cb9702c5b506af1549822d3bf912)
- Thanks #5902 [`f85744f`](https://github.com/fomantic/Fomantic-UI/commit/f85744f0781e37f295be3d55e247b22a07205018)
- Rlsnotes #6059 [`d088665`](https://github.com/fomantic/Fomantic-UI/commit/d088665d84adb6485b53236ca4b799af88edc970)
- Remove closing &lt;/div&gt; element for which no opening elements exists [`90cbd99`](https://github.com/fomantic/Fomantic-UI/commit/90cbd99e50b7c5d73e90563c849fc858dbb0a980)
- Rlsnotes #5603 [`7c691d2`](https://github.com/fomantic/Fomantic-UI/commit/7c691d2505be325e42a3d0c7203cf0462ad6c70b)
- Rlsnotes [`0e69d40`](https://github.com/fomantic/Fomantic-UI/commit/0e69d407b032d839326bfbaec28f51cfd3ddf2a1)
- Rlsnotes #5097 [`1526d1e`](https://github.com/fomantic/Fomantic-UI/commit/1526d1e66b8156bc2f9f89ccfdbaba4fbc3af4e5)
- Release notes #5681 [`3159fa1`](https://github.com/fomantic/Fomantic-UI/commit/3159fa17f5430026f67c072572efd1d7950d2064)
- Added .idea for PhpStorm and WebStorm [`637cdc1`](https://github.com/fomantic/Fomantic-UI/commit/637cdc1c37a69fcdcc57dcdeb339b76b0c7eb590)
- Rlsnotes popup [`bea9eb7`](https://github.com/fomantic/Fomantic-UI/commit/bea9eb724da7c4857d9dde6a6703ffd14bf94a7d)
- #5559 rlsnotes [`2849c90`](https://github.com/fomantic/Fomantic-UI/commit/2849c904141d8d038646ef874a94653dcdb62ec8)
- #3744 one last console log [`9683df5`](https://github.com/fomantic/Fomantic-UI/commit/9683df5e909fe46ee9eaf57f8df81de9437ee0c1)
- Update rlsnotes [`de525a5`](https://github.com/fomantic/Fomantic-UI/commit/de525a58b4de95b0a0c47182026c97b033d9d40d)
- Rlsnotes #4506 [`af6ddfa`](https://github.com/fomantic/Fomantic-UI/commit/af6ddfa97462d7d6ba972cfcfd058bd738f6b1c9)
- Update form.js [`2060fd5`](https://github.com/fomantic/Fomantic-UI/commit/2060fd5af1b7178f21ebc1bcd109a6d66152cae5)
- #4688 #4692 release notes [`0e4075d`](https://github.com/fomantic/Fomantic-UI/commit/0e4075d06b0aa5155bc23f41544b208ce5e8e474)
- Rlsnotes #4547 #4497 [`9e6e5f9`](https://github.com/fomantic/Fomantic-UI/commit/9e6e5f9db6cdfa0721aea5867f017889ac61925a)
- Rlsnotes #4651 [`8b80a62`](https://github.com/fomantic/Fomantic-UI/commit/8b80a626126d5e1b4d8454d83eb6c45d80831354)
- Fix escape key not working to close search [`738b9fa`](https://github.com/fomantic/Fomantic-UI/commit/738b9faa16a32bfc4bc9d0330f92becd3736e9b6)
- Add missing checkbox var [`09455f5`](https://github.com/fomantic/Fomantic-UI/commit/09455f5c9bb78bf4b5f4b3f98e90ca4841df3c74)
- Fix fg-color on inverted forms in Flat theme. [`4a459b2`](https://github.com/fomantic/Fomantic-UI/commit/4a459b2e25a6dff12f98887c01e2984c37f5fd55)
- #4463 - remove bad dep [`190e8e5`](https://github.com/fomantic/Fomantic-UI/commit/190e8e59bb3ebbaa35fbea6a7d540c09e36596e5)
- Rlsnotes #4399 [`56a15d1`](https://github.com/fomantic/Fomantic-UI/commit/56a15d1583c9f7b94090f001dff23499fa256680)
- #4305 rlsnotes [`dff3b86`](https://github.com/fomantic/Fomantic-UI/commit/dff3b86dd3d5a7d3f36f089bbd2e0be4cd03a68c)
- Rlsnotes #4225 [`eb9f043`](https://github.com/fomantic/Fomantic-UI/commit/eb9f043ca8795b4f5ee307524506ade1535f4644)
- Remove unreachable code #4225 [`52a8b6b`](https://github.com/fomantic/Fomantic-UI/commit/52a8b6b4d1ca71e56009066dd7ba2100888f9007)
- #4354 [`ad4e939`](https://github.com/fomantic/Fomantic-UI/commit/ad4e93919d5542119b06a69107a7b2846ef7d1f1)
- Rlsnotes #4074 [`93f6b5e`](https://github.com/fomantic/Fomantic-UI/commit/93f6b5e13243eadb11a4eb57863b630b8680261c)
- Rlsnotes #4311 [`50d332e`](https://github.com/fomantic/Fomantic-UI/commit/50d332e4570aa33d93f1bdf6a1c5bb5c564c5b1c)
- Rlsnotes #4156 4150 [`e9407ca`](https://github.com/fomantic/Fomantic-UI/commit/e9407ca4a5101c15a0ca9525c994d0667608ff42)
- Rlsnotes #3879 [`179ad3d`](https://github.com/fomantic/Fomantic-UI/commit/179ad3d851db41e5dee74baa6f39a00be3c55574)
- Rlsnotes #3409 [`c7529b6`](https://github.com/fomantic/Fomantic-UI/commit/c7529b643278bcad80b0c285957bdad42aecac7b)
- Rlsnotes #4005 [`85c8647`](https://github.com/fomantic/Fomantic-UI/commit/85c864783d0fa867a4bdf58413e4dc6ef08dcaff)
- Rlsnotes #4010 [`93ff159`](https://github.com/fomantic/Fomantic-UI/commit/93ff159ea15a2196d81e8c2972fc04d6c273c4d3)
- Rlsnotes [`82309fe`](https://github.com/fomantic/Fomantic-UI/commit/82309fef0e6daa9432b638a43939e0e1e69578ff)
- Adds missing alias for .assistive.listening.systems. [`a72869a`](https://github.com/fomantic/Fomantic-UI/commit/a72869ab790bf886946f21fa955a42621a133c5d)
- #3200 remove debug [`5816875`](https://github.com/fomantic/Fomantic-UI/commit/58168755d70491de1f74ac9bcc3e2603055346b2)
- Accidental checkin of incomplete line [`4a8ecbf`](https://github.com/fomantic/Fomantic-UI/commit/4a8ecbf3135bf89409b0c02d1fba6c6ff673f0ea)
- Add rlsnotes #3755 3955 [`af7fcf6`](https://github.com/fomantic/Fomantic-UI/commit/af7fcf64599664aca3cbc1cd1fc8f0f2e235217b)
- Fix icon header content padding in some cases [`ae2373f`](https://github.com/fomantic/Fomantic-UI/commit/ae2373feab78e5c1cf4a09f50919cb43d6f74119)
- Fix issue with refocusing menu [`ff7824f`](https://github.com/fomantic/Fomantic-UI/commit/ff7824f396a7f6fbc33f76c4816c420157dfbbec)
- #2779 - remove redundancy [`f913a97`](https://github.com/fomantic/Fomantic-UI/commit/f913a97a90cadf78e3ce1686ea725550bd1e70a7)
- #2510 remove debug [`dbaac4f`](https://github.com/fomantic/Fomantic-UI/commit/dbaac4fc0f32e549ecc8afea918d13fe532e044d)
- RLsnotes [`04458b4`](https://github.com/fomantic/Fomantic-UI/commit/04458b4c50c0e89adb0d5f03c657641001ccd545)
- 'Merge branch 'master' of github.com:Semantic-Org/Semantic-UI into next [`9d5a31d`](https://github.com/fomantic/Fomantic-UI/commit/9d5a31df38934bc1c4a4e3af5c12c123eec7b191)
- Rebuild dist [`011cd3b`](https://github.com/fomantic/Fomantic-UI/commit/011cd3b74c8637d736a773f6607a1ef672cdc0ca)
- Add many more examples, load components as iframe [`2a98e42`](https://github.com/fomantic/Fomantic-UI/commit/2a98e427f8e922f3b042c8904065c49f3b9361f7)
- Rebuild dist [`e574fde`](https://github.com/fomantic/Fomantic-UI/commit/e574fde681abd188eebb679da353ccd52cf4a97b)
- Build beta dist [`6cde905`](https://github.com/fomantic/Fomantic-UI/commit/6cde9059b7ed313560c657a42471baeb1a384056)
- rebuild dist [`2ad0ca4`](https://github.com/fomantic/Fomantic-UI/commit/2ad0ca4918b52c4ee42968873e42876455edd1b2)
- Rebuild dist [`2d7de0a`](https://github.com/fomantic/Fomantic-UI/commit/2d7de0a03d33b05fc986f7fddd0e283483cc4c47)
- Build 1.12.0 [`90ad645`](https://github.com/fomantic/Fomantic-UI/commit/90ad6459275779e84f74efb2aff17d292d2d2045)
- Build version 1.11.7 [`8d69682`](https://github.com/fomantic/Fomantic-UI/commit/8d69682ec12d6a0bd8f204f8cf21c76268326703)
- Build 1.11.8 [`134d0ad`](https://github.com/fomantic/Fomantic-UI/commit/134d0adffe202824ed768e2c51733370b24d1b41)
- #2092 rebuild dist [`baff246`](https://github.com/fomantic/Fomantic-UI/commit/baff246c796bd5b20bf8c77d5fa588a208c265d5)
- Convert steps to flexbox [`3ef8c72`](https://github.com/fomantic/Fomantic-UI/commit/3ef8c728a1fe01f53b454d186de63a58d2fea55f)
- Ports sticky/visiblity from 2.x early xmas #2127 [`cd54328`](https://github.com/fomantic/Fomantic-UI/commit/cd54328cb9d919e311bfc5e04aa014b93204523b)
- #2050 - Fix doubling row in doubling grid. fix doubling grid column row [`6ccdc83`](https://github.com/fomantic/Fomantic-UI/commit/6ccdc83c28f1c0f3ee7498dcdb3933629b1e5f25)
- Iteration on multiselect fixes [`02c9fb2`](https://github.com/fomantic/Fomantic-UI/commit/02c9fb2e8a84266afeaa8001b69c769b39463f80)
- Rebuild for demo #2057 [`c6e3b13`](https://github.com/fomantic/Fomantic-UI/commit/c6e3b134cfc6405b4ede3a864652911091e98f75)
- * Added metadata docs task to scrape *.html.eco files in docs repo for [`1acf816`](https://github.com/fomantic/Fomantic-UI/commit/1acf81622ba6aaf01280991fa2cab6f2f81102c0)
- Reverts #2061 scrollbar changes, adds blurring/inverted settings in modal settings [`46198c9`](https://github.com/fomantic/Fomantic-UI/commit/46198c9feae1d3105b9a3bdc9a26addda3a5420d)
- Darken progress bar [`7be4d85`](https://github.com/fomantic/Fomantic-UI/commit/7be4d85d3572f34462ddafe7799460ed9bf01fd7)
- Iterating on multi select completion [`f76eb49`](https://github.com/fomantic/Fomantic-UI/commit/f76eb496c02e354308caf96988a1a686e46a069c)
- Metadata in docs build [`a9e1580`](https://github.com/fomantic/Fomantic-UI/commit/a9e158014742cb537a8278c435c785306a628557)
- #2046 First pass of grouped icons [`b21a566`](https://github.com/fomantic/Fomantic-UI/commit/b21a5669189999fc878f25d6708bfd66abc55b82)
- Add colored checkbox theme, add additional theming variables #394 [`0803d41`](https://github.com/fomantic/Fomantic-UI/commit/0803d41fc6ff9e7106760b4b43b6ae9b71daa4ee)
- Adjust default menu styles [`75973bb`](https://github.com/fomantic/Fomantic-UI/commit/75973bbdfd717d87a1bd55d12f216c13f8bcc4d7)
- Fix several important edge cases for multiselect keyboard events [`8dd14e0`](https://github.com/fomantic/Fomantic-UI/commit/8dd14e08c5c6a286375770e1415e300c2ed51527)
- Consolidate input browser line height across components, fix multi select to match input height in all cases [`7e7d8ed`](https://github.com/fomantic/Fomantic-UI/commit/7e7d8ed3cce30fa004d90fd8a261ae6df783c80e)
- Spruce up video styles [`be7ef7e`](https://github.com/fomantic/Fomantic-UI/commit/be7ef7e298d5363e814810376743b6cb16354f31)
- Adjust inverted menu styles [`8244f9b`](https://github.com/fomantic/Fomantic-UI/commit/8244f9b24bbf5967fe7764bdb668a60f6e9b27ee)
- #394 extend checkbox theming variables to make colored variations simpler [`288a6dd`](https://github.com/fomantic/Fomantic-UI/commit/288a6dde1c54a40692b249c1b4cf8724f7fbe13d)
- Adds multiple select filterActive option, adds placeholder option #2072 [`99d849c`](https://github.com/fomantic/Fomantic-UI/commit/99d849c875648d9522facd3c5eab8d0f43964112)
- Add sub header sizes [`d0a3166`](https://github.com/fomantic/Fomantic-UI/commit/d0a31664f6355827d3657cc363f1614033b28c6f)
- Adds ms-placeholder values #2074 [`e3eea69`](https://github.com/fomantic/Fomantic-UI/commit/e3eea69c6240a66bcb8cd263974b77f943c53052)
- #2042 missing delegated selector in search [`04df7b8`](https://github.com/fomantic/Fomantic-UI/commit/04df7b8101536482aa816ddecffa3be3acacd872)
- #2042 add delegated events to video, form. remove debug dimmer [`bfed8b3`](https://github.com/fomantic/Fomantic-UI/commit/bfed8b3a7db276386ee4924e1c140633ed3ce494)
- Add category search padding var [`558ff69`](https://github.com/fomantic/Fomantic-UI/commit/558ff69ec2fb0ec6bc322a44626a3e2f4247d893)
- Install path changes #2101 [`d6e0ccb`](https://github.com/fomantic/Fomantic-UI/commit/d6e0ccbf23ca50b209bc067297e212aa7cc4d454)
- Add active reveal state, tweak colors [`251d683`](https://github.com/fomantic/Fomantic-UI/commit/251d6834f6bdbedfd7c26061268420118eb8d51c)
- Add mock response async, yahoooo related to #2059 #2070 [`6b08e2d`](https://github.com/fomantic/Fomantic-UI/commit/6b08e2d5ce9ab93a5de8b0dad6ac7bad2e9ffe14)
- More obvious name for merge copy #2101 [`77923da`](https://github.com/fomantic/Fomantic-UI/commit/77923dad447891a3d192a37f1fdefd9e69971060)
- Adds #2083, search can specify whether to match on text, value or both [`5c538e7`](https://github.com/fomantic/Fomantic-UI/commit/5c538e70f27b8e64c345be56a28034f79a78e3cc)
- Update [`081e7c8`](https://github.com/fomantic/Fomantic-UI/commit/081e7c8cc5bd23ea3099a1961afc05a012ec62c0)
- Reducing selection dropdown shadow [`732f9cc`](https://github.com/fomantic/Fomantic-UI/commit/732f9cc1e8da96e1860caedaf225077903e159ef)
- Update many colors to increase contrast with text [`5861f36`](https://github.com/fomantic/Fomantic-UI/commit/5861f3694b30eb06c4826eac39375af3aebe1869)
- Similar #2092 add ability to mock server response using function [`e3f6d18`](https://github.com/fomantic/Fomantic-UI/commit/e3f6d18e403b049fd5c28d0b0589e75708ec089e)
- #2092 Add onResponse callback to allow for response transformations [`e441beb`](https://github.com/fomantic/Fomantic-UI/commit/e441bebedd78c23b44604ae25764c4df54228e57)
- More name consolidation #2101 [`588d785`](https://github.com/fomantic/Fomantic-UI/commit/588d785edf4bcb61fe4e57c952cb60ab2e3287a7)
- Implement filter function for transforming server responses [`23dfec6`](https://github.com/fomantic/Fomantic-UI/commit/23dfec6f22862d5a0e15b7f8b4797cbf8be5c4c9)
- Odds and end fixes for dropdown [`dcf0190`](https://github.com/fomantic/Fomantic-UI/commit/dcf0190a3f503f4a791657e1587c542c0b5d15e4)
- Fix active hover color [`ab8d581`](https://github.com/fomantic/Fomantic-UI/commit/ab8d5812ab448a4fa15114c1098d0d4e80520279)
- #2060 fix escape keyboard shortcut not working correctly, add in debug to search keyboard shortcuts [`39ab200`](https://github.com/fomantic/Fomantic-UI/commit/39ab2002c2e6ec437d59d667ac86a93efb60c425)
- Update gulpfile [`e2d1da1`](https://github.com/fomantic/Fomantic-UI/commit/e2d1da18dec4bb0a2c5aab25797b4e7c538ac636)
- Updates tos earch [`e571eac`](https://github.com/fomantic/Fomantic-UI/commit/e571eacc502fdc79e20eab51bc44a6ed9f4452d0)
- #2059 Finish ability to mock responses in API [`e38a168`](https://github.com/fomantic/Fomantic-UI/commit/e38a168448dc0e822ce16eebe60a4b37f4be97fa)
- Refactor conditional [`85c7553`](https://github.com/fomantic/Fomantic-UI/commit/85c75534b9733c28a5ec732450f2c86f33c6797b)
- Add comments to search settings [`ec558ac`](https://github.com/fomantic/Fomantic-UI/commit/ec558acd3f0b5d91c1b043dfff05c7de2165f899)
- Fix issues with sticky when doesntFit scroll being slow [`1d47939`](https://github.com/fomantic/Fomantic-UI/commit/1d479395c2e44351ea16054028848fca033b2fef)
- Fix border colors to match, add veryStrongTransparentBlack. Increase contrast on checkboxes [`ded08e3`](https://github.com/fomantic/Fomantic-UI/commit/ded08e39f77da048bfb774f0f0f0affb78e75cbc)
- Add missing color variablef [`4878e71`](https://github.com/fomantic/Fomantic-UI/commit/4878e712ece0008e6194ed5651ee11f560d2059c)
- #2065 add clear cache to search [`a0e7ba3`](https://github.com/fomantic/Fomantic-UI/commit/a0e7ba3666269c2a991b8688ad12b29c61737e73)
- One last fix 1.12.0 [`ca030eb`](https://github.com/fomantic/Fomantic-UI/commit/ca030ebb332ab9249a9eafc2d158e49f48c294dc)
- Remove faulty error conditions from search #2066 [`eacd01b`](https://github.com/fomantic/Fomantic-UI/commit/eacd01bb5a013382b347139dc06d49a2749c5a01)
- Adjusts default button colors [`26446d1`](https://github.com/fomantic/Fomantic-UI/commit/26446d16b2ecf325beb179183e7e32c6795a93bd)
- Fixes scrolling class being stuck, related #2061 [`f7d8eac`](https://github.com/fomantic/Fomantic-UI/commit/f7d8eacba5aeca774024c05b2bb3dd349f539303)
- #2070 - dont continue loop unnecessarily, clarify variable names [`26fe5ba`](https://github.com/fomantic/Fomantic-UI/commit/26fe5ba81c6b3fd155adf870f71e7a3f841ffac6)
- NPM Update should only update default theme folder (not whole theme path) #2101 [`3d2fec4`](https://github.com/fomantic/Fomantic-UI/commit/3d2fec4461cb2f8f62ea80c0013dbd51808f92a6)
- #2079 - Fix variable names [`07b83aa`](https://github.com/fomantic/Fomantic-UI/commit/07b83aa01a7d53c1b41efa22445dc30f3d7e287a)
- Fix popup called with incorrect target or popup [`33cb715`](https://github.com/fomantic/Fomantic-UI/commit/33cb715a5ca380c5105b3cb0ef1c245aa8c48d42)
- Add transition global [`e9f4fe2`](https://github.com/fomantic/Fomantic-UI/commit/e9f4fe283cfaa8076e8f7d3823da6689e241ab3a)
- Data-validate takes precedence on matching [`d48a9f0`](https://github.com/fomantic/Fomantic-UI/commit/d48a9f01a0a628bb1e21da1695e8141b715330f7)
- Fix keyboard selection styles for errored form dropdown [`6e74de4`](https://github.com/fomantic/Fomantic-UI/commit/6e74de41ee13d772405b498a53d708ccdd3c8161)
- Backport flex fix for cards #2069 #2021 #2105 [`05a7a32`](https://github.com/fomantic/Fomantic-UI/commit/05a7a320f2c364fb58c5cef923c6d81728fce563)
- Fix internal borders, remove border from fixed [`c248ccb`](https://github.com/fomantic/Fomantic-UI/commit/c248ccbe44b0cf83226c2d296da3100900109b26)
- adjust em calculations, some rlsnotes [`26567b9`](https://github.com/fomantic/Fomantic-UI/commit/26567b92b1c2c4d75730f5767edc6c7c99707283)
- #2061 set modal setting defaults, change blurring els [`7074e24`](https://github.com/fomantic/Fomantic-UI/commit/7074e24384403ba19c2ee1121f9aac627421e8c1)
- Add #2113 Add accordion on event, update rlsnotes [`421845e`](https://github.com/fomantic/Fomantic-UI/commit/421845e3c68c11ac8549b4d945004788b0f7fe21)
- #2041 Adds showonFocus option to dropdown [`87b3cd0`](https://github.com/fomantic/Fomantic-UI/commit/87b3cd08c5c481de631c74150873e44f29ca4c62)
- #2101 finish fix for npm install [`2df4e82`](https://github.com/fomantic/Fomantic-UI/commit/2df4e8232af5c64e175ff2c0439d982ac052d134)
- Adjust step variables, fix pointers [`b3749aa`](https://github.com/fomantic/Fomantic-UI/commit/b3749aa823fb7ffa57656ff799f21ec13078a13c)
- #2079 - Make sure element is in DOM when determining close event [`a50b1ea`](https://github.com/fomantic/Fomantic-UI/commit/a50b1ea1168b1b89f12e945f558f6e7a11379905)
- Popup will not appear on hidden elements [`d0b4512`](https://github.com/fomantic/Fomantic-UI/commit/d0b451290b49e3691bc0df372444debea4c1cea3)
- Formatting on rtl [`a60deeb`](https://github.com/fomantic/Fomantic-UI/commit/a60deeba3623e0610253a1477a1b45f69007f32a)
- Add back in hover state [`50c3d8b`](https://github.com/fomantic/Fomantic-UI/commit/50c3d8bd9e2237f75b638a7e83c67d5e2d96c44a)
- Remove clearfix from segment [`621fbf0`](https://github.com/fomantic/Fomantic-UI/commit/621fbf0ede373037367a31a6d1e1e14a2c764870)
- Version tick 1.11.8 [`cec5b9f`](https://github.com/fomantic/Fomantic-UI/commit/cec5b9fd1925f5e0dbca4c82aa2acfc2ba2fc198)
- #2084 setup reference does not query behavior after adjusting selectors [`b063a39`](https://github.com/fomantic/Fomantic-UI/commit/b063a3989665f61b91cd34f654fb60ef4989efbe)
- Make bulleted/ordered list bullets unselectable [`eb2189b`](https://github.com/fomantic/Fomantic-UI/commit/eb2189bb06d6b9243fc10a691269b9fdd9936353)
- Fix debug  #2059 #2070 [`618e783`](https://github.com/fomantic/Fomantic-UI/commit/618e7839a1478ea312b3966722dcfb92ba526fdf)
- #2062 adds onOpening onClosing callback, adds rlsnotes [`f067a67`](https://github.com/fomantic/Fomantic-UI/commit/f067a67b56f295832c630506b6742b9bd31f422e)
- Add missing error in nag [`556cac1`](https://github.com/fomantic/Fomantic-UI/commit/556cac1bb9247c1f736a7b91ecb80b9b3749284a)
- Remove admin tasks from npm gulpfile [`7d80a0e`](https://github.com/fomantic/Fomantic-UI/commit/7d80a0ea99bef8e3e84728e53c957d0ef95931b1)
- Fixes broken card hover background [`1e11e62`](https://github.com/fomantic/Fomantic-UI/commit/1e11e6285a0743a4cafe3d918aab0db4706e3b41)
- Fix dimmer init issue [`42435f6`](https://github.com/fomantic/Fomantic-UI/commit/42435f692522cfd1dab6f71678c76f695dec941f)
- Publish tasks fail with latest git due to add syntax [`5ce21df`](https://github.com/fomantic/Fomantic-UI/commit/5ce21df071615368768235b7b4264b6dfdcf1fb7)
- Try again with no transform on visible transition [`6b6b90b`](https://github.com/fomantic/Fomantic-UI/commit/6b6b90b81baf4a8a9c725f809799d6bb745f4fb1)
- Still tweaking white colors [`fba4ad1`](https://github.com/fomantic/Fomantic-UI/commit/fba4ad148e2f8e27f9be10f34d2bc431f847a333)
- #2065 rlsnotes [`fa38c82`](https://github.com/fomantic/Fomantic-UI/commit/fa38c822aaf6ea8e7e253d9d493e42656be80023)
- Adjust inverted text color opacity [`8aa2338`](https://github.com/fomantic/Fomantic-UI/commit/8aa233821f9f9e2d4c139241f98bbd2c5e0a00fb)
- Fix basic step theme, bring back old teal [`e7cb4f2`](https://github.com/fomantic/Fomantic-UI/commit/e7cb4f290eac00f52a900008827857100b20a4c6)
- Add internal border color [`09f05db`](https://github.com/fomantic/Fomantic-UI/commit/09f05db99607172ead87f510d5e6afd96052f183)
- Remove unnecessary perspective from flip transition [`bd619a1`](https://github.com/fomantic/Fomantic-UI/commit/bd619a116e79b49389b4f8968003c0bb023a1283)
- No font-size on accordion [`c7f61ef`](https://github.com/fomantic/Fomantic-UI/commit/c7f61efd461cab8b86c67802259c2432426b4a96)
- #2117 #2096 backports fluid input fix to 1.x channel [`c051338`](https://github.com/fomantic/Fomantic-UI/commit/c05133874d38b7f3497cf212ce3fdc749e46f2b3)
- Remove debug #2092 [`d926eaf`](https://github.com/fomantic/Fomantic-UI/commit/d926eaf25f8b3ddb6857b3e39538691f6bcc544e)
- Add #2102 to 1.x [`81fe545`](https://github.com/fomantic/Fomantic-UI/commit/81fe545ecb9506c0751960233f328cb94870869b)
- Fix theme path #2101 [`13303c0`](https://github.com/fomantic/Fomantic-UI/commit/13303c04895179266eec9c0b5cf5c43a501580e9)
- And derp #2072 [`784b440`](https://github.com/fomantic/Fomantic-UI/commit/784b4401b886f211c2d99b796159c7cc3548fd6c)
- Keep blank values when placeholder is passed a string or false [`9b7ecef`](https://github.com/fomantic/Fomantic-UI/commit/9b7ecef679b1e01b5de6cb74bdcf55fc5a9b3866)
- Fix placeholder uses auto not boolean true #2072 [`3913c17`](https://github.com/fomantic/Fomantic-UI/commit/3913c17d931625eb054357198428b9ba84193a55)
- Comment [`cdce7f7`](https://github.com/fomantic/Fomantic-UI/commit/cdce7f72b1d332cb8b3404748ddee726255aefa4)
- Remove autoprefixr test #2074 [`0aa0abd`](https://github.com/fomantic/Fomantic-UI/commit/0aa0abd78eaba94be61d25d314c98d1c04d94e3b)
- Add credit #2069 [`83e43a5`](https://github.com/fomantic/Fomantic-UI/commit/83e43a5d462faaac67df87cbe1d5025970606dba)
- Top/bottom no longer removed on refresh (issue with cantFit) [`b1f7450`](https://github.com/fomantic/Fomantic-UI/commit/b1f7450c308a69bf88eeda4d79ec4c66e39cf156)
- Removes margin from normal accordion content [`63ebc0f`](https://github.com/fomantic/Fomantic-UI/commit/63ebc0f5051092e6ca6dc7c80884e3b53518aa04)
- Transform in .animating.transition causing display issues in new FF update [`2e9eb08`](https://github.com/fomantic/Fomantic-UI/commit/2e9eb0892f2499478dd3304407cc12a2b1b36465)
- Add shadow back in message [`deefb35`](https://github.com/fomantic/Fomantic-UI/commit/deefb355b828481cf603409ee01a2156944c7546)
- Fix input in dropdown [`3f1d08a`](https://github.com/fomantic/Fomantic-UI/commit/3f1d08a92f72a3b37619ea5c5c681fb6e94aa673)
- Adjust dropdown vars [`5541e43`](https://github.com/fomantic/Fomantic-UI/commit/5541e439de9b1a89112c5267e4e5b58d94b931cf)
- adjust hover box shadow [`f427697`](https://github.com/fomantic/Fomantic-UI/commit/f42769749280f042fd0fc4abf064512dae92afba)
- Update rlsnotes [`c457dea`](https://github.com/fomantic/Fomantic-UI/commit/c457deaf25489902e17085cca315fdaa56c9387c)
- Rlsnotes #2059 #2070 [`5c72a08`](https://github.com/fomantic/Fomantic-UI/commit/5c72a085ebe57b89279fd4c4e9e5d0815dd326e3)
- #2092 RLSNOTES & Cred [`ffdd52b`](https://github.com/fomantic/Fomantic-UI/commit/ffdd52b9b053c74c12a72f50a11771c6dd159c68)
- Rlsnotes 1.11.7 [`6e2df06`](https://github.com/fomantic/Fomantic-UI/commit/6e2df067e43883e1a9bbf64bc3d746e0aab257d0)
- Remove console.log from sticky #2107 [`fae8749`](https://github.com/fomantic/Fomantic-UI/commit/fae8749744cb7ac3fbe7ec572f9cd93d28c194e4)
- Notes [`f205f4d`](https://github.com/fomantic/Fomantic-UI/commit/f205f4df4931b1d77b698c8caac9884e68377e8b)
- Update rlsnotes [`6a7b7ed`](https://github.com/fomantic/Fomantic-UI/commit/6a7b7edfdfc508ca37cccf37cb0818b09fd41e59)
- Remove extra brace [`e1f25a2`](https://github.com/fomantic/Fomantic-UI/commit/e1f25a21d0643141f89cd42933561008cea2e9b4)
- #2066 rlsnotes [`fd3489b`](https://github.com/fomantic/Fomantic-UI/commit/fd3489bc5eb7ca50041e9f0229b80742f02ae11d)
- Fix divider in grid with flexbox [`ef10f3e`](https://github.com/fomantic/Fomantic-UI/commit/ef10f3e69d24f722cbcfc86e119cdfb1263a892a)
- RLSNOTES [`df6a752`](https://github.com/fomantic/Fomantic-UI/commit/df6a752308a1c1437c22befd898eab10f8a190c8)
- Add category result padding [`dc3b297`](https://github.com/fomantic/Fomantic-UI/commit/dc3b2976342b9caa2af623e03eeac8e586c74e64)
- Merge https://github.com/pcj/Semantic-UI into next [`04d8080`](https://github.com/fomantic/Fomantic-UI/commit/04d8080055fa90df3be76bc285277e37f8a1a814)
- Build for jsfiddle [`9f60a77`](https://github.com/fomantic/Fomantic-UI/commit/9f60a77391814de3116d38ef2ffa8741eab57204)
- build dist for select [`8da0ff7`](https://github.com/fomantic/Fomantic-UI/commit/8da0ff7eb12badd04e292cdc4c12fd7d1895a457)
- Build 1.10.3 [`951a35f`](https://github.com/fomantic/Fomantic-UI/commit/951a35f79c31d3f4e0a4a8eb0cd1fb63976b7967)
- Build 1.11.0 [`838badb`](https://github.com/fomantic/Fomantic-UI/commit/838badb2aae41124101505e3e3666cf73dabfa92)
- Build 1.9.0 [`4db4e84`](https://github.com/fomantic/Fomantic-UI/commit/4db4e84ba1c693bafb7736f951260b8c6b95f03f)
- Moving whole grid to flex [`28b3a25`](https://github.com/fomantic/Fomantic-UI/commit/28b3a253e84cc839906669fc4af0afcd85f8a3dd)
- Build 1.11.5 [`4dd6d89`](https://github.com/fomantic/Fomantic-UI/commit/4dd6d897693d7e2b294ef83295cb9717d5e679fa)
- Build 1.11.2 [`1fc4ead`](https://github.com/fomantic/Fomantic-UI/commit/1fc4ead6a49e9d771d6a8cf5132385c94d2b1c9b)
- Iteration on container [`2986331`](https://github.com/fomantic/Fomantic-UI/commit/29863318eb2d2f27c56825fe99db6b254e76ff23)
- Package 1.10.0 [`373578a`](https://github.com/fomantic/Fomantic-UI/commit/373578a3eba519a8b3fec29c46def27bf66ba229)
- Build 1.11.3 [`ccdf35b`](https://github.com/fomantic/Fomantic-UI/commit/ccdf35b1ae6bebc06343a42e9eb2df2f3da0a0f1)
- Build 1.11.4 - Fighting the flex edition [`e8e2c0c`](https://github.com/fomantic/Fomantic-UI/commit/e8e2c0c8ad21cc97e17a02c6adc7815f809f2a10)
- Adding css/less admin tasks [`173f640`](https://github.com/fomantic/Fomantic-UI/commit/173f6400d05fffc05000c4b040bb18c5850bf499)
- Rebuild dist [`e9fdb08`](https://github.com/fomantic/Fomantic-UI/commit/e9fdb082d0d17e0a995bd07ba1a53b085df4382d)
- Iteration on multiselect, adds label deletion, proper string delimiters [`78cee91`](https://github.com/fomantic/Fomantic-UI/commit/78cee91a532adc10cddc183f782634dbe4ffee10)
- Build 1.11.1 [`0a9ccfd`](https://github.com/fomantic/Fomantic-UI/commit/0a9ccfd821fe532d16e7cf4b94cddc93438e98a6)
- Add label selection, group selection, fixes some keyboard events [`3c4294f`](https://github.com/fomantic/Fomantic-UI/commit/3c4294fbb0027e125f90167651bff460b4dda6b2)
- Add back loadUIOverrides() [`0fa47ce`](https://github.com/fomantic/Fomantic-UI/commit/0fa47ce04c1223e0fc90b7cfa2e078ef69084aec)
- Release 1.10.4 [`6309377`](https://github.com/fomantic/Fomantic-UI/commit/6309377315cb0bdf76907c4adbdc1f3e5603d5c3)
- Updates from bootstrap example [`0255bbf`](https://github.com/fomantic/Fomantic-UI/commit/0255bbfe8f44247e1c7b818f9b69fe8ec43b7fb1)
- Update licenses in src [`121107f`](https://github.com/fomantic/Fomantic-UI/commit/121107fbf2865a89cf34efdd6befc6cbc14f04f9)
- Update examples, fixes [`c2b16c2`](https://github.com/fomantic/Fomantic-UI/commit/c2b16c2d3e1569df73227d33d1261c4c8da4e43e)
- Build 1.9.3 [`4450b9f`](https://github.com/fomantic/Fomantic-UI/commit/4450b9f2d378aeeb1c0f049b6bb3e1ddecbb942f)
- Finish fixing scope in less [`af45f1a`](https://github.com/fomantic/Fomantic-UI/commit/af45f1a9a6f35c075166a8021cbcd112170d9d1a)
- Rebuild src for jsfiddle [`8b63dfd`](https://github.com/fomantic/Fomantic-UI/commit/8b63dfd91f8df85645a50acdca3a405e6bac8daa)
- #1894 Fix basic icon paths to not try to load woff2, add src variable [`0d39fd6`](https://github.com/fomantic/Fomantic-UI/commit/0d39fd6637ce195e5cbc3a91cae0b04cbf3d06b4)
- Build 1.9.2 [`50536b6`](https://github.com/fomantic/Fomantic-UI/commit/50536b6502394c85c6ab060f78ea6f1603784bc2)
- Update tasks to try SHA again [`31ca866`](https://github.com/fomantic/Fomantic-UI/commit/31ca8667ffc1b6303e38834641ffe82d417f51ae)
- Release 1.10.1 [`7c82659`](https://github.com/fomantic/Fomantic-UI/commit/7c8265941949b836eec6e8f2a8f7491a6977e68e)
- Adds dropdown overriding rules to menu fixing several dropdown iossues [`b1713f7`](https://github.com/fomantic/Fomantic-UI/commit/b1713f7c06acd2bfc41b87b1b8e8323062cab3c2)
- Remove scoping, add to semantic.less [`9f750c2`](https://github.com/fomantic/Fomantic-UI/commit/9f750c262f832e979337d43c872f8a2c88c7d3b0)
- Revisions from examples [`55273f0`](https://github.com/fomantic/Fomantic-UI/commit/55273f038a8d56276f667e4adedff694e91f32b7)
- Increase contrast on button hover/down colors [`f2c9333`](https://github.com/fomantic/Fomantic-UI/commit/f2c9333b79a1a41058d09709c251dfa30bc236e4)
- Initial commit blank container element [`8f3bffe`](https://github.com/fomantic/Fomantic-UI/commit/8f3bffeeb2eac466da64bf4df3a6fce95fa12821)
- Iteration on menu fixes with flex, along with some design changes to make menu more neutral Fixes: #1281, #1475 [`5cc8f33`](https://github.com/fomantic/Fomantic-UI/commit/5cc8f33aebf3d6b7209e695422bb00a231d5bc71)
- Swap mix-in for & {} [`f7f1d19`](https://github.com/fomantic/Fomantic-UI/commit/f7f1d1939d731f877b41073afc9ad71d63887945)
- Adds 2 new themes(ish) adds more missing menu variables [`0d81d9a`](https://github.com/fomantic/Fomantic-UI/commit/0d81d9a8f31b9c6702860fc55749ae51a509ae9e)
- Rewrite admin tasks as export [`2f8a164`](https://github.com/fomantic/Fomantic-UI/commit/2f8a1643efaf2512d6001c5b4c1b87ce0d5bb0b0)
- Retooling of admin tasks [`c015875`](https://github.com/fomantic/Fomantic-UI/commit/c01587558e4395b2d0649502aaac131032e279b6)
- Fixes for inverted menus, changes to active styles [`0db9045`](https://github.com/fomantic/Fomantic-UI/commit/0db904587838130187630c16f0eb2916a2d9c4cb)
- Add missing task [`56e7323`](https://github.com/fomantic/Fomantic-UI/commit/56e7323e4ea288dc506668c3eedcad90f2e959c2)
- Iteration on multiselect #847 [`52897fd`](https://github.com/fomantic/Fomantic-UI/commit/52897fdbc4d63973f119284fc70074bf9a1d8541)
- Add init repo task [`ebe25eb`](https://github.com/fomantic/Fomantic-UI/commit/ebe25eb70cb449b2f4d970ea0abbfe84f874a5b9)
- Finish meteor integration of dist/ [`c9b9900`](https://github.com/fomantic/Fomantic-UI/commit/c9b990060e10f48fe808dee90a136ebf01566ba2)
- Lockdown deps and more lenient peer deps [`6184a9b`](https://github.com/fomantic/Fomantic-UI/commit/6184a9b5446601132896e3c28d9298399a435fb2)
- Updates to menu flex [`9852706`](https://github.com/fomantic/Fomantic-UI/commit/985270694323e8ca7bce7e3ab15d4312106ccd3b)
- Updates to type image, and type fixed. [`7b9ad9d`](https://github.com/fomantic/Fomantic-UI/commit/7b9ad9d2daad32fdfdde573a04ac81da241c2d8c)
- try updated deps [`c1d8bdc`](https://github.com/fomantic/Fomantic-UI/commit/c1d8bdc98738b7f166b62e767510c1e70a186c6b)
- Beginning multiselect rewrite [`a1d77ec`](https://github.com/fomantic/Fomantic-UI/commit/a1d77ec37400cfe2383b00cd7a25ce17b8dcaafc)
- Move gulp walk over to admin task #1607 [`c6371cc`](https://github.com/fomantic/Fomantic-UI/commit/c6371cc8d2942034a0712e8fb2d7cefb2ddc9bee)
- Begin examples [`d8c300d`](https://github.com/fomantic/Fomantic-UI/commit/d8c300de3712d05abe091bb384a95a46f1cd6fce)
- Simplify visibility/sticky to use .load instead of worrying about each image loading [`360f9dd`](https://github.com/fomantic/Fomantic-UI/commit/360f9ddbd72591af60751120eee1626ea2465c78)
- Admin task iteration [`268b30a`](https://github.com/fomantic/Fomantic-UI/commit/268b30a017c6f72846627964079a63f39c3ef564)
- Fix paths from sub-folder [`45de05e`](https://github.com/fomantic/Fomantic-UI/commit/45de05e2ce4db5d8589acedce7a316aef31e3e5f)
- Iteration on multiselect [`5513680`](https://github.com/fomantic/Fomantic-UI/commit/5513680a9f1e8ce9eebb9e5d140d6111af17bbd6)
- Possible solve #1899 Issues with blank string results evaluating as undefined when minCharacters = 0, issue with saved results not being retrieved when response pulled from cache [`2ed793a`](https://github.com/fomantic/Fomantic-UI/commit/2ed793a351476d569ab1b036f3e97c7f33dbee34)
- Fixes basic padded table, adds vertical alignment [`6fecacf`](https://github.com/fomantic/Fomantic-UI/commit/6fecacf398eb34718b463f6bb0553163a50dda4a)
- Add flexbox version of menu [`4aa4729`](https://github.com/fomantic/Fomantic-UI/commit/4aa4729b7e4ca9941dc0ec6f6d4d8346a75418fa)
- Optimizations to visibility [`c58553c`](https://github.com/fomantic/Fomantic-UI/commit/c58553cdce4a391fbe5461c32f6331c783e3772a)
- Latest version [`0025844`](https://github.com/fomantic/Fomantic-UI/commit/00258448a53eae636acad9bfbe144464ca8f19f8)
- Simplify dep ver [`3f690d6`](https://github.com/fomantic/Fomantic-UI/commit/3f690d6c9be6bb369f76d450a03d4fb7a399f3c2)
- Sticky now handles bottom edge conditions better [`29c4f82`](https://github.com/fomantic/Fomantic-UI/commit/29c4f821255b61398e672fddfe6bc940d5fb1e51)
- Iterations on visibility, getting ready for docs [`dec01c0`](https://github.com/fomantic/Fomantic-UI/commit/dec01c0adabd56008c70bfb26cd60c3d4abbf1ba)
- Bug fixes for transition [`28c81f5`](https://github.com/fomantic/Fomantic-UI/commit/28c81f5801f85e416740ef8d911a3b3d9d7036ef)
- #1866 - Adds more intelligent regexp version number replace, preserves component names in banners [`b423847`](https://github.com/fomantic/Fomantic-UI/commit/b42384752d7a644fd2c5b2921e0e5b5e46bc863d)
- Grid fixing foreva [`1932dca`](https://github.com/fomantic/Fomantic-UI/commit/1932dca4e7c95c2ef73a12b6bc3b2221e00b6598)
- Adds scrolling dropdown variation [`71e3285`](https://github.com/fomantic/Fomantic-UI/commit/71e32857ed9188920ea16897b872b39d8969774b)
- Delete GETTING-STARTED.md [`db6c0f2`](https://github.com/fomantic/Fomantic-UI/commit/db6c0f249331bd3327f49668aa6fe80ebf2372d0)
- Increase delay of performance logging [`3701bdc`](https://github.com/fomantic/Fomantic-UI/commit/3701bdc35f007228925545efa3d47cd52113540b)
- #1844 - Fix ui cards &gt; .ui.card to have correct margins, fix consecutive ui cards groups to preserve row spacing [`870794c`](https://github.com/fomantic/Fomantic-UI/commit/870794c9df1adc0e3271a022fe1aca8b7ca32ea5)
- Swap deps backP [`9fa2908`](https://github.com/fomantic/Fomantic-UI/commit/9fa2908788d4299b5d221c17640444ca57f106be)
- Add renamed tasks [`d8cb644`](https://github.com/fomantic/Fomantic-UI/commit/d8cb6442f55d387d03410540bf247c58f056138f)
- Finish releases [`ce342f5`](https://github.com/fomantic/Fomantic-UI/commit/ce342f58fd0bfb5b19ad14143b96d2e1a7669bec)
- #1806, Add multiple select to set value, get value. [`181066e`](https://github.com/fomantic/Fomantic-UI/commit/181066e055e58516f0543ef426737d75b588e8d5)
- Add focus box shadow [`6035d28`](https://github.com/fomantic/Fomantic-UI/commit/6035d288d235d60f9e4f982db360da4d95163398)
- #1987 #1916 #1912 Correctly fixes onChange to fire only when value is adjusted [`bbcbf56`](https://github.com/fomantic/Fomantic-UI/commit/bbcbf5673d5b6ee6511c061d87b6e22a4fffd9ed)
- #1814, Fixes valign inside equal height. Simplifies rules [`417172b`](https://github.com/fomantic/Fomantic-UI/commit/417172be5ab527edca2bc96766d311f306ced8d2)
- Fixes for menu formatting [`cffc730`](https://github.com/fomantic/Fomantic-UI/commit/cffc730141dbb0f802fb20f5d199022ac6d48c76)
- Iteration on menu fixes from border changes [`7b3a84f`](https://github.com/fomantic/Fomantic-UI/commit/7b3a84f861dc23e72a50f6ed830f851e5d9b065f)
- Add new transition settings for grouped animations [`ac559ad`](https://github.com/fomantic/Fomantic-UI/commit/ac559ad2553e1d63ba225fc2fbf9669145fea6e3)
- Iteration on multi select #847 [`41a9f96`](https://github.com/fomantic/Fomantic-UI/commit/41a9f963948741c10c628af392e0b4c12b17f282)
- More things to install [`c40c881`](https://github.com/fomantic/Fomantic-UI/commit/c40c881040cd0019415062db0c9f65840ce79304)
- Pub/sub visibility? [`b90f8f7`](https://github.com/fomantic/Fomantic-UI/commit/b90f8f7b8d48de19aca382f3fb8c4b5aa3552a57)
- #1968 Fixes undetachable scrollable modal in ideal circumstances (not inside a container with z-index) [`d9850a0`](https://github.com/fomantic/Fomantic-UI/commit/d9850a0ba64fa879ac7fa87dc449acc5f69b36ff)
- Accordion can now close while opening [`cf28f60`](https://github.com/fomantic/Fomantic-UI/commit/cf28f602c30e091ef4f6108ffcc588a0dd0b9f38)
- Fixes dimmer variation not working due to typo [`806a362`](https://github.com/fomantic/Fomantic-UI/commit/806a362e93e1e6136060c58e8a6a756843fd91e8)
- #1607 Fix components without assets not creating manifest lists correctly [`052d074`](https://github.com/fomantic/Fomantic-UI/commit/052d0743583a929cfbe0c5812f0548d2a3c924a4)
- Visibility now watches for images loading and automatically refreshes afterward [`fad2d1b`](https://github.com/fomantic/Fomantic-UI/commit/fad2d1b57c6247d1da9cdc6678005dc04ff5e413)
- #1896, move over to element namespace [`7c839c9`](https://github.com/fomantic/Fomantic-UI/commit/7c839c938a4477765947e824cf69442d48ce48b4)
- Adds #1858, case sensitive/insensitive form validation rules [`a690601`](https://github.com/fomantic/Fomantic-UI/commit/a690601b3fd8b63867771ab5aae31d18b306a31f)
- Fix issue with destroy in visibility [`b685c94`](https://github.com/fomantic/Fomantic-UI/commit/b685c948e0ae7f116ed059c2f87dfa3bb22e3a4b)
- Fix admin tasks to use commit SHA of last release #1607 [`e3f66ec`](https://github.com/fomantic/Fomantic-UI/commit/e3f66ec2a0a69db2212d966a4d1c6c42d9cdd540)
- Rlsnotes [`4fc75e4`](https://github.com/fomantic/Fomantic-UI/commit/4fc75e4a04ceb0b02a0573fdbadafe1060e9c2a4)
- Update dist [`f4b25e1`](https://github.com/fomantic/Fomantic-UI/commit/f4b25e1fda834b63ebc072df01a89cfbf7fc27d6)
- Fixes for text menu: [`5d508db`](https://github.com/fomantic/Fomantic-UI/commit/5d508dbb2be4df02677ed0bb248d88f05ea4a152)
- Everything is golden [`5689680`](https://github.com/fomantic/Fomantic-UI/commit/568968065839ba187d6c7d55946e4b54d4d899fe)
- 100% working component update script with no .git index lock issues [`139117d`](https://github.com/fomantic/Fomantic-UI/commit/139117d5d37792d79fce444ab205927b5fb3ea17)
- Fixes placeholder value in select multiple [`4fc448e`](https://github.com/fomantic/Fomantic-UI/commit/4fc448ed4751258fc04564a3cbab2e909c19f196)
- #1933 Cache width/height/isRTL on load to improve animation performance of sidebar [`e064401`](https://github.com/fomantic/Fomantic-UI/commit/e064401708f15988ae1828557256ea11fb263431)
- Greatly speed up visiblity events [`1982c95`](https://github.com/fomantic/Fomantic-UI/commit/1982c95461823ff6d961eeca4d502347a7dd3397)
- Adds coupling for ribbon label with image/card #1807 [`af7c709`](https://github.com/fomantic/Fomantic-UI/commit/af7c70978e44d84a135fe92a99489041d136feb4)
- Dropdown can now have behaviors invoked on select [`96a577d`](https://github.com/fomantic/Fomantic-UI/commit/96a577d2c9809ca9ef4469c3d4a8f3da08848fdc)
- Admin tasks no longer pipe gulp stream (buggy), use mergeStream instead [`f7d69cd`](https://github.com/fomantic/Fomantic-UI/commit/f7d69cd283800432035093a75eff6a3b7274ed76)
- Updates release repos task [`5dc9f53`](https://github.com/fomantic/Fomantic-UI/commit/5dc9f53f17adcc7c67ecf8c5526dc853b452f201)
- Updates dropdown focus color to be more consistent [`8dcb5bd`](https://github.com/fomantic/Fomantic-UI/commit/8dcb5bd5406439428703be1face2cedf6cfadcc6)
- Fixes for images inside menu [`12cd7a5`](https://github.com/fomantic/Fomantic-UI/commit/12cd7a593de90e15db28302727434248520e2940)
- Add #1897 dimmer now has an opacity setting [`e3b3ab4`](https://github.com/fomantic/Fomantic-UI/commit/e3b3ab4e97ca50477935567a41183275e009e0fa)
- Add transition interval setting for delayed group animations [`4a0d6c8`](https://github.com/fomantic/Fomantic-UI/commit/4a0d6c866851bc184674061f1b0e2d1add523f3a)
- Fix background colors with grids [`dfa2e02`](https://github.com/fomantic/Fomantic-UI/commit/dfa2e029d3a78634dd3ca50866c5680990577c41)
- Adds #1873, stop, stop all, clear queue [`835b755`](https://github.com/fomantic/Fomantic-UI/commit/835b7555dcaf5ea2b071febc27666660dfb062a8)
- Update grid examples [`1a11764`](https://github.com/fomantic/Fomantic-UI/commit/1a117648bc121b7dbd2c039a0da37986e66a7088)
- Add grid container coupling [`413810c`](https://github.com/fomantic/Fomantic-UI/commit/413810cf69c7d43a422617589412e4c575fb67bb)
- Add segment groups #1809 [`6c27b61`](https://github.com/fomantic/Fomantic-UI/commit/6c27b6117bd241c5eabbdb9e346ecf37ef2d6b33)
- Complete visibility [`e1b6add`](https://github.com/fomantic/Fomantic-UI/commit/e1b6addb106ce6f2be7c050542e1adc28e9223bd)
- Remove meteor package.js [`8fe6b69`](https://github.com/fomantic/Fomantic-UI/commit/8fe6b698571db7549c619d0713faba38de2bf59d)
- Add fuzzy search algorithm [`4cd4a9e`](https://github.com/fomantic/Fomantic-UI/commit/4cd4a9ee0d4bbc02a12212b2b786a78a8685a542)
- Add filemode ignore to admin tasks [`dda23b4`](https://github.com/fomantic/Fomantic-UI/commit/dda23b4a124553735ba08d15212d7739fb3f012e)
- iteration on release scripts [`6f8c94e`](https://github.com/fomantic/Fomantic-UI/commit/6f8c94e52eed5b8e845a0e4b2b6c7b2ea75a1077)
- Adds #1032, vertical tabular menus [`be77c6a`](https://github.com/fomantic/Fomantic-UI/commit/be77c6adef65af0ad18d1d304e75ca4b125f4495)
- Iteration on container [`e4fa1ae`](https://github.com/fomantic/Fomantic-UI/commit/e4fa1aebe00d7ac5c28c7fd90e39ee43eb952d15)
- Make stretch optional variation, fix valign [`fb33a60`](https://github.com/fomantic/Fomantic-UI/commit/fb33a600d32af3a6693e535441b1be0960151b43)
- Fix some placeholder text cases with multiple [`267d948`](https://github.com/fomantic/Fomantic-UI/commit/267d948b345966fbf21c7ce63e4ca02f0a5f04e1)
- Iteration on flexbox bugs in menu [`38cd215`](https://github.com/fomantic/Fomantic-UI/commit/38cd215ff617896e6be8b45c89eadd0cbdc2ab09)
- Update container element [`1e8f60c`](https://github.com/fomantic/Fomantic-UI/commit/1e8f60cea3514ab384ecf44bc09c76da75bb48bc)
- Add #1908 Trigger selector for accordion [`b552961`](https://github.com/fomantic/Fomantic-UI/commit/b5529616a179528e5ee45b3979a95067c6941cb8)
- Adds margins to  h1-h5 [`1e8b65e`](https://github.com/fomantic/Fomantic-UI/commit/1e8b65ea49cf713b5e15e57b9ed233bc1e49dc3a)
- Calling show without animation now sets display type [`ecc3c8a`](https://github.com/fomantic/Fomantic-UI/commit/ecc3c8a3e04610c919510120f6465d958e9263ef)
- #1807, make labels have segment padding by default [`68f7408`](https://github.com/fomantic/Fomantic-UI/commit/68f740874cf8f7450bb23538ae4bf21f6d352026)
- Iteration on menu flex fixes [`2df8721`](https://github.com/fomantic/Fomantic-UI/commit/2df87210a03cfa4a444a0b279805fdda52f854d0)
- Add comments to vis js settings [`a272e92`](https://github.com/fomantic/Fomantic-UI/commit/a272e9276934ad3a9c5c3e2da00542f950ff801e)
- Fix menu to have same border color on keyboard tab [`3510d96`](https://github.com/fomantic/Fomantic-UI/commit/3510d967df4f815cb3ee87def3f931474cc59d3f)
- Fix paths in win [`a7c6cd3`](https://github.com/fomantic/Fomantic-UI/commit/a7c6cd3384305784e98174b00f12312bdd922159)
- Cut out deps? [`48057d2`](https://github.com/fomantic/Fomantic-UI/commit/48057d20b1bf57ef2c74453e9c5e6f8027bce7a3)
- Move checkbox setup into method [`651c65a`](https://github.com/fomantic/Fomantic-UI/commit/651c65a025b6b3c5d2779411d8624b0873c39e34)
- Change lineheight to round corrrectly [`5f96357`](https://github.com/fomantic/Fomantic-UI/commit/5f963574954e68c54a6e17a0f1e09508f050ab84)
- Fix rating valign [`db2abcb`](https://github.com/fomantic/Fomantic-UI/commit/db2abcbd6b6bb8dce6d2d1690dff408abd84112a)
- Add shadow to all messages [`f088dd9`](https://github.com/fomantic/Fomantic-UI/commit/f088dd9c1834693152f99b222f1250b6b796fc34)
- Button fixes icon height instead of using 0.9em icon height [`7464684`](https://github.com/fomantic/Fomantic-UI/commit/74646843d2d21103d395efe67e5d7416fb28bc0b)
- Fix themes path backslash matching regex group (positive lookahead) [`419ffd8`](https://github.com/fomantic/Fomantic-UI/commit/419ffd8562fbc3ce380f313c53e575f486f4a4ca)
- Adds flex basis to (x) wide and doubling card #1982 [`4290439`](https://github.com/fomantic/Fomantic-UI/commit/42904390cbc088c830a9088b94586fdcd1960dfd)
- Update register task to remove bower [`194ca7b`](https://github.com/fomantic/Fomantic-UI/commit/194ca7bd89351a2bea91abb7cd3ace7e9f332fbe)
- rebuild with fixed comment banner for icon [`e6cbb90`](https://github.com/fomantic/Fomantic-UI/commit/e6cbb90f8c1cb38a4958603795d22771a620f40c)
- #1880 Fixes modal showing while another hiding unsucessfully attaches callback to 'hide others'. Dimmer no longer hides between modals appearances with allowMultiple [`aac5321`](https://github.com/fomantic/Fomantic-UI/commit/aac5321d47860d2fd3d3359292ad75187239ee3a)
- #1896, add 'get id' to all modules with element namespace, move uniqueID generation to 'create id' [`91b2ffd`](https://github.com/fomantic/Fomantic-UI/commit/91b2ffdf49ee441eb7cd56beb0740d375e13fbe1)
- Fix equal width/height to now require row wrappers [`755d0bf`](https://github.com/fomantic/Fomantic-UI/commit/755d0bf2cd709fa32fc82d387a52ba300b4f12f0)
- Add missing menu vars [`8d16197`](https://github.com/fomantic/Fomantic-UI/commit/8d16197f1284099b4edd1e829a0bd0c1d2a6fa00)
- time to integrate menu [`a476ad6`](https://github.com/fomantic/Fomantic-UI/commit/a476ad6d10b5f65fb071d04477afc58d3d9b013f)
- Organize comments in gulpfile [`09a6e75`](https://github.com/fomantic/Fomantic-UI/commit/09a6e759b89a674053333d1eab302ef8820d7688)
- Add examples [`050c151`](https://github.com/fomantic/Fomantic-UI/commit/050c15144da180f35d46eb06583fdd7816811d0f)
- Fix alignment inside flex containers for text and valign [`05fc0f8`](https://github.com/fomantic/Fomantic-UI/commit/05fc0f84ed02339298913300b85b91c274743444)
- Fixes specificity of grid column colors [`33bb7df`](https://github.com/fomantic/Fomantic-UI/commit/33bb7df7b71e757fbc22f86d5fc901fc8e4a5160)
- Add flexbox cards to default theme [`0432874`](https://github.com/fomantic/Fomantic-UI/commit/04328747ed55701699bec0bff29f407656468319)
- Slight modification to remove looping [`089bf33`](https://github.com/fomantic/Fomantic-UI/commit/089bf334009ff145f09bdf23e1584dba312f9938)
- Fix the flex [`3874dbb`](https://github.com/fomantic/Fomantic-UI/commit/3874dbbc48f872208e58dd1539218db072ae02a2)
- Disable debug in state #1825 [`4a03003`](https://github.com/fomantic/Fomantic-UI/commit/4a0300362702ce3e54cf0615818b2296dcaa91bb)
- #1607 Remove git tag, use only release [`a9272d9`](https://github.com/fomantic/Fomantic-UI/commit/a9272d9e57d8c923eb85defd8be8fc3671f61bd3)
- Partial fix for #1190, search selection in menu [`dbf67c1`](https://github.com/fomantic/Fomantic-UI/commit/dbf67c1e4024131b9eb4b2daee17fbd1f67f755c)
- #1933, more optimizations for sidebar [`243243a`](https://github.com/fomantic/Fomantic-UI/commit/243243a78a38c8ae591b639447a4c6fdfa3d930c)
- #1607 Apparently commitish doesnt matter, just need to wait at least a second before creating release after push [`326820f`](https://github.com/fomantic/Fomantic-UI/commit/326820f7c40ff1967eb3f7b02957d41d1149dc1c)
- Fixes useFailSafe to work with queued animations #1848 [`1428178`](https://github.com/fomantic/Fomantic-UI/commit/14281784a71a7f636442f170d04c6c0b1c47b104)
- Related #1840, force removing duplicate slashes from path when auto: true [`32e32d3`](https://github.com/fomantic/Fomantic-UI/commit/32e32d3934d8aa0a77eaf35ce6ba0e48b8fc5d1d)
- Update dropdown from next [`802dc97`](https://github.com/fomantic/Fomantic-UI/commit/802dc97948c08c7598b525b2efb89e5c4b390571)
- Fix sizing in form/input [`efd9a07`](https://github.com/fomantic/Fomantic-UI/commit/efd9a07ac3e00c0aeaf32e21999f7436f8dd3f56)
- Adds sub headings [`8a30271`](https://github.com/fomantic/Fomantic-UI/commit/8a30271f278bc72c216d91b36bc6de5b7f94d802)
- New homepage [`876d30e`](https://github.com/fomantic/Fomantic-UI/commit/876d30ecf2b4a84a1f9598a6739cb54bbc3a4f11)
- Update release notes [`7b32ea1`](https://github.com/fomantic/Fomantic-UI/commit/7b32ea1b090d969259f3434d94d02058a0caa456)
- API no longer produces 'no action specified' error when defaulting to form action [`5f9a1ab`](https://github.com/fomantic/Fomantic-UI/commit/5f9a1ab7152b97acf35157ef43a370440b550889)
- #1853 Fix some composer.json fields [`8da0414`](https://github.com/fomantic/Fomantic-UI/commit/8da0414acdea459563cddc8e174dd9125ce0c792)
- Update release notes [`e3cd003`](https://github.com/fomantic/Fomantic-UI/commit/e3cd0038ca0f010c3c17fd8404014e6643a3fc67)
- Adds huge menu [`b9d170f`](https://github.com/fomantic/Fomantic-UI/commit/b9d170fe50d446c91732e4c980b99d18f2651991)
- Adds padded segment [`663d054`](https://github.com/fomantic/Fomantic-UI/commit/663d05436c696de8f860068a5b297552c1832ba5)
- #1896 Add elementNamespace to other document/context events [`59e2f98`](https://github.com/fomantic/Fomantic-UI/commit/59e2f986ce4dc646856404589d275b6969ae8b1c)
- Add to rlsnotes [`7cd0d9d`](https://github.com/fomantic/Fomantic-UI/commit/7cd0d9d32bc0eb207453df6e553ca265b5b230f7)
- Add segment/card coupling with attached progress [`aea9abd`](https://github.com/fomantic/Fomantic-UI/commit/aea9abd6187564265e9c1a64a1930aa93c719b36)
- Remove mkdir on node_modules, add logs [`d06c2db`](https://github.com/fomantic/Fomantic-UI/commit/d06c2dbd75e12bdd87f5ca3c78d22ef7d437a7d0)
- Fixes LESS watch errors are eaten [`4585362`](https://github.com/fomantic/Fomantic-UI/commit/458536279e5b8055334adb24894ba55db329912e)
- Fix destroy method to not possibly unbind scroll evenit from window [`7d8646e`](https://github.com/fomantic/Fomantic-UI/commit/7d8646eb90a95d71cdded513d9734a16ec50247f)
- Merge in #1791 [`818b04f`](https://github.com/fomantic/Fomantic-UI/commit/818b04fc5286c6fc2874cca78e6ddd8e3d5f4e2d)
- #1804, Fix resize logic for scrolling modal to include padding [`dada633`](https://github.com/fomantic/Fomantic-UI/commit/dada633c7f1b025c985f191ab9a253204bb8582c)
- Update release notes remove empty rule [`fcf17d2`](https://github.com/fomantic/Fomantic-UI/commit/fcf17d202d8dc79253a30a61b22b81076d017cd5)
- #1846 Equal height grids now automatically stretch column child elements to full width [`2bdabbc`](https://github.com/fomantic/Fomantic-UI/commit/2bdabbc1007f657bb4fe8e9f4382a0643529c4cb)
- Fix icon banner in icons, add visiblity to single component releases [`c7a1b47`](https://github.com/fomantic/Fomantic-UI/commit/c7a1b475996f69695b4346a1f72c8acdfd2e7dd1)
- Edge cases [`7851d3a`](https://github.com/fomantic/Fomantic-UI/commit/7851d3ae42d7f98618df7c40ba43e759b3beedac)
- Remove form pointers [`3e79081`](https://github.com/fomantic/Fomantic-UI/commit/3e79081e02d42b6778d557f666cca95175f1748e)
- Add several missing variables, resolve dropdown padding to exact pixel values [`3290dbb`](https://github.com/fomantic/Fomantic-UI/commit/3290dbbef994bd47b5a2346b8fb27e0acfa78a20)
- Fix x wide inside equal width/height [`5a5a360`](https://github.com/fomantic/Fomantic-UI/commit/5a5a360f06802adbb88d883046f8e1376c38057b)
- Update css package for meteor #1607 [`ec415f5`](https://github.com/fomantic/Fomantic-UI/commit/ec415f500b4b68ddc46993202ba191da37f166b7)
- Fix bug where equal height rows would always expand to 100% width [`7c6babf`](https://github.com/fomantic/Fomantic-UI/commit/7c6babff7905d2e6f5ab13265245b39d47eba629)
- Fix typos from regex [`738edcc`](https://github.com/fomantic/Fomantic-UI/commit/738edccabb7c3ca323561913b7fc1c387fd7b68e)
- Fixes comma delimited [`a0d3040`](https://github.com/fomantic/Fomantic-UI/commit/a0d30404127be257a9e0f3f4d37be172d94ff4d3)
- Fix valign again [`af05d23`](https://github.com/fomantic/Fomantic-UI/commit/af05d23d83e7493e38e64e91166d2e8768d02726)
- Text width inheritance issue [`8915d9c`](https://github.com/fomantic/Fomantic-UI/commit/8915d9c46d0a2afc38be00d15934e8d190cd4beb)
- Fix issue in chaining when dropdown inits on select [`1550b49`](https://github.com/fomantic/Fomantic-UI/commit/1550b4937e67edf2f1c5deb67adf52b819a03b2b)
- Fix duped variables in theme.config.example [`5df2a39`](https://github.com/fomantic/Fomantic-UI/commit/5df2a392292ffe4e82d5aa6477eacfd59ae28437)
- Fix (x) item menu, labeled icon menu [`c7b4981`](https://github.com/fomantic/Fomantic-UI/commit/c7b4981f224383c966a7e2f2059db812dff89bed)
- Stackable grid now pads unless inside a segment or nested grid [`75fa024`](https://github.com/fomantic/Fomantic-UI/commit/75fa02411de8db021ccc355b91fac7d8b24829ee)
- Finalize card flexbox #1760 [`cc46869`](https://github.com/fomantic/Fomantic-UI/commit/cc46869465c110879ef4bd44f071ef50a2f617a6)
- Update rlsnotes [`e9f2f48`](https://github.com/fomantic/Fomantic-UI/commit/e9f2f489bdf4e13f1c37c351cec72554181b1fdb)
- Fixing more walks on WIN32 [`e57b009`](https://github.com/fomantic/Fomantic-UI/commit/e57b009a592fd57ffee8db4de24398ec5d70d649)
- Remove variable size overrides [`e48e5ce`](https://github.com/fomantic/Fomantic-UI/commit/e48e5ce970fc83799ca7cd21b5eec646e970ca8a)
- Add line height offset for label inside header [`235dc8a`](https://github.com/fomantic/Fomantic-UI/commit/235dc8a8cad03c24a6d3667e8ac33fc1cd2c3d7e)
- #1908 accordion can now specify a triggering element that is not title [`b4d0b8f`](https://github.com/fomantic/Fomantic-UI/commit/b4d0b8f3ecbae615a87928d123f962fd4313eefb)
- Update rlsnotes [`b09f257`](https://github.com/fomantic/Fomantic-UI/commit/b09f257235eec311d895d9f7f0e1e67471258e07)
- Fixes margins on ui segments [`e0daade`](https://github.com/fomantic/Fomantic-UI/commit/e0daade0c3465bb5069b294896f697183e736f50)
- Increase delay before creating release after pushing files to repos [`0e382b7`](https://github.com/fomantic/Fomantic-UI/commit/0e382b747e5031dcb3ba284c9576c709135e175f)
- Category search no longer warns about maxResults #1850 [`0dec900`](https://github.com/fomantic/Fomantic-UI/commit/0dec90028ad6473165874dfddeabb2b33f52bc02)
- Update release notes [`c89a02d`](https://github.com/fomantic/Fomantic-UI/commit/c89a02d10dc93bf416b5309928c7df160313d2fd)
- Install message [`7027240`](https://github.com/fomantic/Fomantic-UI/commit/702724006f4566e770b5585b7c1249fee9e3d339)
- RLSNOTES [`f9cf499`](https://github.com/fomantic/Fomantic-UI/commit/f9cf499fe3bf768943169646d773d42c4f83bf0e)
- Fix popup in menu, add min-height [`e1499e6`](https://github.com/fomantic/Fomantic-UI/commit/e1499e61d6ffe9cf59b6b4336be4056f56ad8b13)
- Fixes for sticky/vis [`28e1231`](https://github.com/fomantic/Fomantic-UI/commit/28e123102b4b131afa6663b500309ac16def8758)
- Increase delay of performance logging [`bb1cb54`](https://github.com/fomantic/Fomantic-UI/commit/bb1cb54c959380d46aa5685433e91ae2a36def8b)
- Add onUpdate callback to visibility, fix event handlers [`4fe0ae0`](https://github.com/fomantic/Fomantic-UI/commit/4fe0ae076060b27fddd2983f9ea416ff021a9ce7)
- Remove debug from transition [`affb406`](https://github.com/fomantic/Fomantic-UI/commit/affb40689e1f10d503d324ac0e23beb1ed6b7e02)
- Updates rlsnote for next [`c744c16`](https://github.com/fomantic/Fomantic-UI/commit/c744c166c1266fd30a2508de00431fe56ec4cdb5)
- Remove rlsnotes from next [`219feda`](https://github.com/fomantic/Fomantic-UI/commit/219fedaaa3a12761a13d5f98a4b962848d63cc2d)
- Remove stub oauth [`dc622c4`](https://github.com/fomantic/Fomantic-UI/commit/dc622c4dadd6bdbccc69064fec28ac96184a6185)
- Backports dropdown fixes [`776b654`](https://github.com/fomantic/Fomantic-UI/commit/776b6542d69e5f4e204ac5ecd3875a2fa780fcb7)
- Adjust text container paragraph settings [`6670978`](https://github.com/fomantic/Fomantic-UI/commit/66709782e55aad19df9b185fa1df81867d0c15f9)
- Make labels slightly larger inside headers in default theme [`cf235f0`](https://github.com/fomantic/Fomantic-UI/commit/cf235f0b8b57ccdf13f297a4d8ca19e244fd436a)
- Updates styles for ui item [`3843371`](https://github.com/fomantic/Fomantic-UI/commit/38433712258fea1631feb51a7dc2cb322ca6ddbf)
- #1607 remove client typo in package.js [`5e372c3`](https://github.com/fomantic/Fomantic-UI/commit/5e372c394d9b4dfdfb3aee7a4b52536b045c545f)
- All inputs now use flexbox, adjust flex-grow value to fix ie10 [`7a5654d`](https://github.com/fomantic/Fomantic-UI/commit/7a5654d9682f0f0836e547d986207efd3f4e995a)
- disables flex in IE for cards #2021 [`d420cb0`](https://github.com/fomantic/Fomantic-UI/commit/d420cb0908a54828068735025cc97f29726bdfce)
- Fix dropdown icon selection [`fd9d457`](https://github.com/fomantic/Fomantic-UI/commit/fd9d45749d2453350a4b120c79f3eeeec4335233)
- Tweaking flex align settings [`db69f38`](https://github.com/fomantic/Fomantic-UI/commit/db69f38bb3402f27d6949ba838a8c801bac8988d)
- Updates release notes [`74ef751`](https://github.com/fomantic/Fomantic-UI/commit/74ef751d82a5d1d85bbd30bfb5e4c42b0c97d3d3)
- Fix header sizes in chubby header theme [`3d3f058`](https://github.com/fomantic/Fomantic-UI/commit/3d3f0581754060dc4f4a63588e0db1c08594ee6f)
- Add back in placeholder prefix (still necessary) #1791 [`86be8ff`](https://github.com/fomantic/Fomantic-UI/commit/86be8ff1f78c0cfcb86457090cb701d0b9077846)
- Update notes [`c7c84fb`](https://github.com/fomantic/Fomantic-UI/commit/c7c84fbe21ecd774e038178fa8b07547c37ddeea)
- Simplify default API debug output for clarity [`58609bf`](https://github.com/fomantic/Fomantic-UI/commit/58609bf62ad33e90fd68b0e41fa6e2e02deb6eb1)
- Rlsnotes [`761daab`](https://github.com/fomantic/Fomantic-UI/commit/761daab891f366cbd1ca18c416f5af69689644d7)
- Rail is 100% height by default [`2c45285`](https://github.com/fomantic/Fomantic-UI/commit/2c45285ff57fed06fd74ca3bd601deefc0e3fe03)
- Fix inverted text menu, fix active font weight [`3e19a5a`](https://github.com/fomantic/Fomantic-UI/commit/3e19a5ad0745d80a8d6391ac73d970fd2b3cb6ba)
- Update rlsnotes [`f789010`](https://github.com/fomantic/Fomantic-UI/commit/f7890108c3a12f0e1df143ebec7d2fd69f4a7fde)
- Fix rebuild on site.variables debug [`8ce8f11`](https://github.com/fomantic/Fomantic-UI/commit/8ce8f11496008a889b9820dc9f647309d26fb838)
- Rebuild 1.10.3 [`e8c57f5`](https://github.com/fomantic/Fomantic-UI/commit/e8c57f5e1d9551f5c18bc24acea5af98a74c41d5)
- Adds centered inline loader [`4119075`](https://github.com/fomantic/Fomantic-UI/commit/41190759812be52570f678324ad2e32f2bde7a45)
- Update rlsnotes, grid specificity [`e03b104`](https://github.com/fomantic/Fomantic-UI/commit/e03b104e2ba6c0ddbbb3142a5e74c9b8ac5a2990)
- Fix gulp watch not erroring out with legitimate errors [`8102cff`](https://github.com/fomantic/Fomantic-UI/commit/8102cff1846d695669e8d755aca7b9c384888fd8)
- Update visibility debug [`4d82349`](https://github.com/fomantic/Fomantic-UI/commit/4d82349dc695182a4d2ba220f5d2a55453bd0a7a)
- Fix activator with settings.popup [`63561c5`](https://github.com/fomantic/Fomantic-UI/commit/63561c514f7961f36d3de3246285fd1ab9d33f30)
- Make site theme optional [`3df6034`](https://github.com/fomantic/Fomantic-UI/commit/3df6034a0b524202346ec9c5fe58a37e458788a7)
- Slightly darken border colors [`a8cf810`](https://github.com/fomantic/Fomantic-UI/commit/a8cf810e01967dbd20d7910099c7adc943b7d6fe)
- Fix table escapes container at mobile [`2a21019`](https://github.com/fomantic/Fomantic-UI/commit/2a210192523d4ef835bc5b9626e583dfd508ff83)
- #1475, quick fix before flexbox merge for dropdown hover [`f0109a0`](https://github.com/fomantic/Fomantic-UI/commit/f0109a06acd810062dd5b373af1e24af798d3aa5)
- Adds variable into def for scrollbar #1875 #1831 [`f891852`](https://github.com/fomantic/Fomantic-UI/commit/f891852d09dc418f3de5cda8e892a545ba54c8af)
- Adds #1874 Search input styles added to form [`972bda8`](https://github.com/fomantic/Fomantic-UI/commit/972bda8756e5cf4daeefcbcf0a6b8cd7a3f67da7)
- Fix config comment replace regex not to be greedy [`5a1e347`](https://github.com/fomantic/Fomantic-UI/commit/5a1e347ed5471de7ce7b1583ccc277d1beec367c)
- Fix gulp docs glob [`b2994d5`](https://github.com/fomantic/Fomantic-UI/commit/b2994d58d0a1e0d38dab0802fbea74fa57f7398f)
- Debug [`bb8f9d3`](https://github.com/fomantic/Fomantic-UI/commit/bb8f9d3ed7eb74f41c0d8589f49a906904375b32)
- Button now uses focus shadow from site.variables [`8d48a25`](https://github.com/fomantic/Fomantic-UI/commit/8d48a259457ed18dc24fdbd47a12d6596fcc130b)
- Fix dropdown focused but not hovered colors [`f85da30`](https://github.com/fomantic/Fomantic-UI/commit/f85da30ae7faf1548a7dc845b3b7a4778fac7c1a)
- Observe changes now groups related mutations [`35de853`](https://github.com/fomantic/Fomantic-UI/commit/35de853327ba7d81cb5f14b4af2b6beaeaa1a399)
- Fix md spacing [`9133603`](https://github.com/fomantic/Fomantic-UI/commit/91336038a21dcf222f03d0b3f2acc9e74ecd849e)
- #1607 Removes a bunch of files from addfiles [`5603db5`](https://github.com/fomantic/Fomantic-UI/commit/5603db5398ff7536ff2b15f9dacd12ca1df6c1b8)
- Watch now compiles concat again [`74a52c5`](https://github.com/fomantic/Fomantic-UI/commit/74a52c5b305584ed613d9c7a3b57f5875915205f)
- Fix issue with popup removal [`1ab7165`](https://github.com/fomantic/Fomantic-UI/commit/1ab71653ee5a606d6ae1d804b5b5eaecbd263de2)
- Add rlsnotes [`8e53100`](https://github.com/fomantic/Fomantic-UI/commit/8e531004582672adc382bf7bbcf3f2560cc993e7)
- Rebuild all UI on site.variables change [`ed085db`](https://github.com/fomantic/Fomantic-UI/commit/ed085dbc11d7116be2acbb00953dd6b5867532c1)
- Fixes background shorthand causes blank dimmer variable to evaluate as none [`63e12b6`](https://github.com/fomantic/Fomantic-UI/commit/63e12b6a9206137f24a2ca449523ac0b7d17bafc)
- Fix flat dropdown style [`d4dc873`](https://github.com/fomantic/Fomantic-UI/commit/d4dc873241d6a16f0a60292a1a794e636e609bdb)
- Darken toggle checkbox text [`a6447b1`](https://github.com/fomantic/Fomantic-UI/commit/a6447b11501d24598bd0864202e48bdbf9d78f7b)
- #1996 #1992 issue with calc interpolation in dropdown LESS [`683b5aa`](https://github.com/fomantic/Fomantic-UI/commit/683b5aa5fcb14d181a140093aa925c629f4cc127)
- #1960 adjusting site.variables now rebuilds all files [`75efd94`](https://github.com/fomantic/Fomantic-UI/commit/75efd947640c10ece970bb821430e395d2b9bf81)
- Fixes background shorthand causes blank dimmer variable to evaluate as none [`b209b64`](https://github.com/fomantic/Fomantic-UI/commit/b209b64d0f7b7f8c23b9dce681c3700b5577023b)
- Fix recording final display state as none [`54bd5af`](https://github.com/fomantic/Fomantic-UI/commit/54bd5afac69a5119c7e4b3c0eb663264a9360482)
- Debug for radio [`4fb0f38`](https://github.com/fomantic/Fomantic-UI/commit/4fb0f38734fe2b4d3a459d9fad2ffe3ca271b7f3)
- Remove unnecessary calls [`e0f100e`](https://github.com/fomantic/Fomantic-UI/commit/e0f100ecca0f841147e3ca3aac04122e54df7a0d)
- Increase delay between git push due to issues with flooding [`2b52ce3`](https://github.com/fomantic/Fomantic-UI/commit/2b52ce349f78f5cf5424d933d78dbdaaa459974e)
- Non queued animations trigger complete event immediately [`a957a5c`](https://github.com/fomantic/Fomantic-UI/commit/a957a5cfde8fb587e69f21605f8022a005580a2d)
- Update rlsnotes 1.11.0 [`f1cc86d`](https://github.com/fomantic/Fomantic-UI/commit/f1cc86db5d7a29a41c69420522c104545e19d652)
- Fix bottom to use bottom-margin, instead of bottom prop [`c38cb19`](https://github.com/fomantic/Fomantic-UI/commit/c38cb190752b41efe48d77d29b3f87c2ce394a99)
- Update rlsnotes [`698f071`](https://github.com/fomantic/Fomantic-UI/commit/698f0710ccfbec0bf1ceaa8421c77f1b9c8186aa)
- Stackable grid no longer sits flush on mobile [`9a659a1`](https://github.com/fomantic/Fomantic-UI/commit/9a659a194991b4720074801b181684761baf6fc1)
- Corrected wrench config for `src/site` merges [`f8472c8`](https://github.com/fomantic/Fomantic-UI/commit/f8472c87ddbd54251e093bb045a1cd2e7768099f)
- Swaps out __dirname constant for path.resolve() #1607 [`3a75bdc`](https://github.com/fomantic/Fomantic-UI/commit/3a75bdc8d14e2d6786fe0e51c72da34fa042a741)
- #1607 add npm require to package.js templates [`22a2b29`](https://github.com/fomantic/Fomantic-UI/commit/22a2b2901aef01eee458536d7689e7a3791c9b6c)
- Update release notes [`d2b24b3`](https://github.com/fomantic/Fomantic-UI/commit/d2b24b3d2de9df376f22e8d4999ca4f4f37ae77a)
- Lighten dropdown error hover color [`1ce202f`](https://github.com/fomantic/Fomantic-UI/commit/1ce202ffae1062ac93c8aa37d999c06b4fe79464)
- #1794, checkbox and dropdown now trigger blur event on controlled input [`4e2f0b0`](https://github.com/fomantic/Fomantic-UI/commit/4e2f0b02911d21f96342b06a861fd0d6ed0ebe43)
- Make icon size round to exact pixel to avoid valign issues #1779 [`f37b2a8`](https://github.com/fomantic/Fomantic-UI/commit/f37b2a83ba4a52b58affcb4253c9fff6ff52a91b)
- Tested versioning [`822acf2`](https://github.com/fomantic/Fomantic-UI/commit/822acf2ae9b85f560f1bece8f3694d48581f6b90)
- Test versioning [`e9a29b6`](https://github.com/fomantic/Fomantic-UI/commit/e9a29b6c611a97df524fc406be6df345b0c7fe13)
- Sticky component does not set height when already same height [`b4338c7`](https://github.com/fomantic/Fomantic-UI/commit/b4338c702eb38a03d22ff78119d789fa990491bc)
- LESS repo missing semantic.less [`f589173`](https://github.com/fomantic/Fomantic-UI/commit/f5891730ef6e9d4adca6dd923b00fe742e0cdbef)
- Fixes meteor package.js for css build [`893d688`](https://github.com/fomantic/Fomantic-UI/commit/893d6887931ddfc783e9e6ddd963d337d4c80668)
- Update rlsnotes [`9d27b68`](https://github.com/fomantic/Fomantic-UI/commit/9d27b68b7d468fe9a6874e567b969a75b4915155)
- Fix issue with search selection tabbing [`203a06c`](https://github.com/fomantic/Fomantic-UI/commit/203a06cdc129c099cf888266c3264bc8c4a6fe6f)
- Fixes dimmer variation not working due to typo [`af76214`](https://github.com/fomantic/Fomantic-UI/commit/af76214036fe14e3d3c0c193f62fed6c223e4bee)
- Fix for filtered item override [`027ab45`](https://github.com/fomantic/Fomantic-UI/commit/027ab45c724f6763b854fc497f076fd299f4175b)
- Fix table align issue, adjust white border opacity [`a789a07`](https://github.com/fomantic/Fomantic-UI/commit/a789a07889797f6d93f46972ae495ed1d8d6c090)
- set flex direction for grid align [`07eef3c`](https://github.com/fomantic/Fomantic-UI/commit/07eef3c42eb1b2bc36a0d0c082a3a402a922476d)
- Update rlsnotes [`38990ef`](https://github.com/fomantic/Fomantic-UI/commit/38990ef687e238b67184bdafa44d70ac630898d8)
- Add largest monitor breakpoint, remove paragraph line height by default. Use page line height [`ce5fec7`](https://github.com/fomantic/Fomantic-UI/commit/ce5fec7c7a0e80335d9efc2accd971fa5efd5139)
- Remove performance timer testing [`310e5d4`](https://github.com/fomantic/Fomantic-UI/commit/310e5d4041f614b5d65733a8b141f7f966c92de3)
- #1905 min-width issue on material theme [`38f5993`](https://github.com/fomantic/Fomantic-UI/commit/38f59932ebcf30254dd9227f2209eac8b42ed1e7)
- Remove onscroll [`9a290c9`](https://github.com/fomantic/Fomantic-UI/commit/9a290c9aba48046fd09d6c8653451da9efa1814f)
- Update rlsnotes #1899 [`c2ffaa7`](https://github.com/fomantic/Fomantic-UI/commit/c2ffaa7cdcd5417859ca335e48af994261f0cbea)
- Fixed a memory leak in Popup module [`1def81b`](https://github.com/fomantic/Fomantic-UI/commit/1def81b60b99ad2006a2376e7800873badffb439)
- #1831 #1875 Adds scrollbar size to global variables [`d36f38a`](https://github.com/fomantic/Fomantic-UI/commit/d36f38a55fbf13d4ffc9ddd8c23de86c75d6f287)
- #1607 Regexp formatting [`6079676`](https://github.com/fomantic/Fomantic-UI/commit/6079676eb5d82a1709a482a9b1467d4de6db6461)
- Comment [`0a43676`](https://github.com/fomantic/Fomantic-UI/commit/0a436768c64fef0e82612e207250e3f03e30861d)
- Remove debug [`1440814`](https://github.com/fomantic/Fomantic-UI/commit/1440814609204eccbdc9affec0b2018bfc22d95c)
- Backports fix for dropdown headers in menus #2022 [`4e3fe4b`](https://github.com/fomantic/Fomantic-UI/commit/4e3fe4bf378b9e6e2469be87f84a1c6a1266e28d)
- Experimenting with no zindex again [`7be3645`](https://github.com/fomantic/Fomantic-UI/commit/7be36454ab7044da3ba8edee3dc7dcd7b2bbd856)
- Adjust selection padding [`2b54b0e`](https://github.com/fomantic/Fomantic-UI/commit/2b54b0ec1b0e096555e58913a310f1a73fe79b5e)
- #2020 Fixes trim string method being called on non-string dropdown values [`7034230`](https://github.com/fomantic/Fomantic-UI/commit/703423013e7dfbad62c886cf2119e4f05fb9cbcf)
- remove debug [`cc78b80`](https://github.com/fomantic/Fomantic-UI/commit/cc78b803a5a48f9cc4e7b61f36ca74f7ae2b127a)
- Fix search button padding [`21d695c`](https://github.com/fomantic/Fomantic-UI/commit/21d695c46fee35b2f19f1c7c088ad8ddd6d441c0)
- Extend sticky mutation observer wait period [`ff69bb8`](https://github.com/fomantic/Fomantic-UI/commit/ff69bb80ce69989856259fe0ecef0566e571f7b0)
- #1927, remove transform from tnansition [`4862d43`](https://github.com/fomantic/Fomantic-UI/commit/4862d4369e5fe2ca14345e72c07f83eb85561471)
- Adding missing event namespace in form validation [`97e8bf5`](https://github.com/fomantic/Fomantic-UI/commit/97e8bf5fdaf703b41c16175bb2771d1d5c9f9719)
- Fix cenered inline loader [`0b8d71a`](https://github.com/fomantic/Fomantic-UI/commit/0b8d71aeae37dd7e3927bac2220fd6643b162691)
- Fix missing selector in stretched grid [`0a651aa`](https://github.com/fomantic/Fomantic-UI/commit/0a651aaa9f2bf4972454fc1f1e80614f79b223ed)
- Header uses border color [`6aee3be`](https://github.com/fomantic/Fomantic-UI/commit/6aee3becc97df8f189b97f69a654fe3398398d7c)
- Icons no longer set height, better valign. [`777b802`](https://github.com/fomantic/Fomantic-UI/commit/777b8020ed1778d7ff6bd892b7ec3bb6c6de0508)
- Adjust small computer page grid gutter [`5823e92`](https://github.com/fomantic/Fomantic-UI/commit/5823e926cc9f7d3daf3c82e49a38c5f27ab837fb)
- Table default to top align [`b238c3e`](https://github.com/fomantic/Fomantic-UI/commit/b238c3e074b4e13de59eab1a0ad928c674a4dc34)
- Update rlsnotes [`9bc43d2`](https://github.com/fomantic/Fomantic-UI/commit/9bc43d26d10610fd11e570d8533268aa29b90ec2)
- Update performance log of site.js [`d8e256d`](https://github.com/fomantic/Fomantic-UI/commit/d8e256d5fdd7250588f91781629b9f67beaa2d54)
- Simplify label margin [`6d54ff0`](https://github.com/fomantic/Fomantic-UI/commit/6d54ff0d6dac326f1ae8757bae488595b7fa3d04)
- Fix label size inside header [`be2b5cd`](https://github.com/fomantic/Fomantic-UI/commit/be2b5cdfe172d4e10ba524e6a6b32f845b3ff96e)
- Deprecating Slack [`0e4e687`](https://github.com/fomantic/Fomantic-UI/commit/0e4e687a99a87fade1f97dcc68a66f7e58a6bc50)
- Add missing var [`6220673`](https://github.com/fomantic/Fomantic-UI/commit/622067393084f76fba5033284ee87ef74e590655)
- Reset hide delay to 0 #1852 [`0fb55e2`](https://github.com/fomantic/Fomantic-UI/commit/0fb55e2bddc04b6a623c6bd25ec17024b10d791d)
- Swap out this reference for  in API [`6c80605`](https://github.com/fomantic/Fomantic-UI/commit/6c8060538a8e145358144c9f7836ab3be651edcd)
- #1889 serializeForm produces unnecessary error [`d3b4315`](https://github.com/fomantic/Fomantic-UI/commit/d3b43154138a5bd697cd3011aad79d002562b41a)
- Fix version tock [`9cecdf0`](https://github.com/fomantic/Fomantic-UI/commit/9cecdf06a876bd1eb3369f29b7790b4332561fa4)
- Popup displays module on error [`7eb0302`](https://github.com/fomantic/Fomantic-UI/commit/7eb0302dba6d49e4b63197cb412186c7b1f1fe97)
- Fix releasenotes link [`2c65133`](https://github.com/fomantic/Fomantic-UI/commit/2c651336bb6e6f1b660aeaaf93cf04c045ff1b33)
- Missing comma in admin config  #1607 [`27771e2`](https://github.com/fomantic/Fomantic-UI/commit/27771e216f58c11c6871c9de454187fcf0e3d5b9)
- Tick version [`c85c032`](https://github.com/fomantic/Fomantic-UI/commit/c85c032fd27d443f36d6e29de8c01c81418ab18e)
- Update rlsnotes #1844 [`f23748d`](https://github.com/fomantic/Fomantic-UI/commit/f23748de68d02115c2a2c935d7ff20380cdca5f4)
- Update rlsnotes [`609c55c`](https://github.com/fomantic/Fomantic-UI/commit/609c55c408a6f32d868544127b34e7ad8fba0167)
- Fix grid inside vertical segment [`782b61b`](https://github.com/fomantic/Fomantic-UI/commit/782b61b00771159ae8c3da2b962bda5880c8abcd)
- #1845 fix package.json format for git url [`b53005f`](https://github.com/fomantic/Fomantic-UI/commit/b53005f9d059615fad3a4076c9e5f4a03aea8eaf)
- #1845, move wrench to forked dep [`f8e4465`](https://github.com/fomantic/Fomantic-UI/commit/f8e4465e3c0fd5e743ea874ea149ba4a331832dd)
- Update rlsnotes [`00166ee`](https://github.com/fomantic/Fomantic-UI/commit/00166ee6aee6b946246b998e4a3e0e4226b8617e)
- Fix tiered menu sub menu border radius [`c4b99c1`](https://github.com/fomantic/Fomantic-UI/commit/c4b99c1e2fdc2646a9de41876e37c237aad9519e)
- Update rlsnotes [`f69369e`](https://github.com/fomantic/Fomantic-UI/commit/f69369e32fcebd9bef2def0f14ba1c6ab9a0dda7)
- #1607 missing theme.less from LESS repo [`6e6f6cd`](https://github.com/fomantic/Fomantic-UI/commit/6e6f6cd71c641ec6306d68c2c0202605b2bd0e53)
- Fixes description redundancy #1607 [`d98656a`](https://github.com/fomantic/Fomantic-UI/commit/d98656a3c63d029ff5e05da4b7b61d32e9c5d9f4)
- Update rlsnotes [`cff289a`](https://github.com/fomantic/Fomantic-UI/commit/cff289aad420adb39872eb6abc2485477312ad38)
- Fix date [`6328b8d`](https://github.com/fomantic/Fomantic-UI/commit/6328b8d7d15f9be0fbc105dec92d648c390fc209)
- Ignore oauth.js [`7716024`](https://github.com/fomantic/Fomantic-UI/commit/7716024ffa4a439bb6df6a7c4bb0f6a89472341d)
- Update readme [`e0ffa2b`](https://github.com/fomantic/Fomantic-UI/commit/e0ffa2bfec25eb716d97a856c15ebcbf9a226ea6)
- Update notes [`c0e9571`](https://github.com/fomantic/Fomantic-UI/commit/c0e9571aa1c9b697e4ff711ff0bc235b47f5ddc1)
- Update release notes [`33cae72`](https://github.com/fomantic/Fomantic-UI/commit/33cae72a0f804fdf63b24f0ee09a8065f328f473)
- Update rlsnotes [`e158398`](https://github.com/fomantic/Fomantic-UI/commit/e158398c64bfe5f7de5a1857309740dcb9bd9e6f)
- Fix config path [`8c27ff5`](https://github.com/fomantic/Fomantic-UI/commit/8c27ff5c0557de0ca87a095c447d03da835e5914)
- Oops old dep [`6332f70`](https://github.com/fomantic/Fomantic-UI/commit/6332f70cbc1d66078a2f3944300be41de8710433)
- dedupe [`dcceb36`](https://github.com/fomantic/Fomantic-UI/commit/dcceb369f0f03f9801f78e789a9cb2550d1276bb)
- Remove unused variables from input [`5a56b3e`](https://github.com/fomantic/Fomantic-UI/commit/5a56b3ec414aed9b7d402dba8c0f62f44c35ea34)
- RLSNOTES [`f7f8319`](https://github.com/fomantic/Fomantic-UI/commit/f7f83191c466e0ef472bfaf1f59c5d6301f5315a)
- RLSNOTES #2017 [`731e44d`](https://github.com/fomantic/Fomantic-UI/commit/731e44dd2b3124ceff24193bc0737f33067da6a1)
- RLSNOTES #2012 [`6675886`](https://github.com/fomantic/Fomantic-UI/commit/66758868b951bcb3e2443c28efed3d8fb3fd8b8b)
- #2012, Search should pass along debug to API [`b03c7d3`](https://github.com/fomantic/Fomantic-UI/commit/b03c7d3faf1cfec39067f93fa626411247747765)
- Rlsnotes [`2b02d6c`](https://github.com/fomantic/Fomantic-UI/commit/2b02d6c1fe1e4f20dc9a2df2d567343d63a786bb)
- Rlsnotes [`6cb49b0`](https://github.com/fomantic/Fomantic-UI/commit/6cb49b0b75da86504af451c49d74a85dc64c8bbf)
- RLSNotes: [`36d91ff`](https://github.com/fomantic/Fomantic-UI/commit/36d91ff3a65eabea387f09a2a3856be465d575a9)
- #1990 rlsnotes [`36613f5`](https://github.com/fomantic/Fomantic-UI/commit/36613f54609580517d5a2cc04d0d36d6059caeb4)
- #1927 adds back in transform [`209db36`](https://github.com/fomantic/Fomantic-UI/commit/209db36bf20507dadc5d4a50d09f4ebbf7903a2e)
- Disabled icon have pointer events again [`f6ba97a`](https://github.com/fomantic/Fomantic-UI/commit/f6ba97a3382c3b615176ce72a4822306dc28d883)
- Update rlsnotes [`e5a2377`](https://github.com/fomantic/Fomantic-UI/commit/e5a2377c9c03730d65d57111268e135c973524d1)
- Fixes issue with concat css moving import [`6b54c45`](https://github.com/fomantic/Fomantic-UI/commit/6b54c4559f881e0716c4dffd2db4e7aecaf9d2ec)
- #1919 Fixes issue with minification [`b5a5d9c`](https://github.com/fomantic/Fomantic-UI/commit/b5a5d9cb6961246b0bbf111b33adf9a904355674)
- Update rlsnotes [`9d5da0c`](https://github.com/fomantic/Fomantic-UI/commit/9d5da0c4b23310bcc0996534be9a41c6d66e78fc)
- Update rlsnotes #1791 [`c942909`](https://github.com/fomantic/Fomantic-UI/commit/c9429097310de6f585904b92b350d467aa43f7d3)
- Update rlsnotes [`e0e6422`](https://github.com/fomantic/Fomantic-UI/commit/e0e64226ae5a7a63953e3cf67e3a356198c3c61f)
- Remove debug #1895 [`8260260`](https://github.com/fomantic/Fomantic-UI/commit/8260260f003275e14e627310a6c0f0a9d96dc130)
- #1897 removes log [`a5052e4`](https://github.com/fomantic/Fomantic-UI/commit/a5052e4db68f91f9dd0b4c395921e908378fbcc2)
- Update release notes #1845 [`a012db0`](https://github.com/fomantic/Fomantic-UI/commit/a012db000ce1f224585185b8b7b09b20bb0518d8)
- Infer composer.json version from tags #1853 &lt;https://getcomposer.org/doc/02-libraries.md#tags&gt; [`a262f3b`](https://github.com/fomantic/Fomantic-UI/commit/a262f3bd72e0997393cab42c3c6727195046c349)
- Update rlsnotes [`60a3bb0`](https://github.com/fomantic/Fomantic-UI/commit/60a3bb086113fd9c8f9e431bdd3618ab67f388e6)
- Rlsnotes #1812 [`05be471`](https://github.com/fomantic/Fomantic-UI/commit/05be4717e56aa3a0dfbba343e50d789f5d9700ee)
- Info messages are now visible inside forms [`51bfcbb`](https://github.com/fomantic/Fomantic-UI/commit/51bfcbb3a63ec6a88e3f77f18595b097fd7759ef)
- Add card color variations merges in #1764 [`7cf3625`](https://github.com/fomantic/Fomantic-UI/commit/7cf36257953cd138553db8a514571048b301174b)
- Rebuild for jsfiddle [`9d1f70f`](https://github.com/fomantic/Fomantic-UI/commit/9d1f70f8b75da9899de111e335d8f1859d2be96e)
- Beginning refactoring of admin tasks [`068df99`](https://github.com/fomantic/Fomantic-UI/commit/068df994a2e0734898ec260f3a86a27b7e346883)
- Update some examples [`859a36a`](https://github.com/fomantic/Fomantic-UI/commit/859a36a7e04f434775e71f2bdd799366535b5ac7)
- Fix issues with tasks caused by docs tasks [`0c99aa8`](https://github.com/fomantic/Fomantic-UI/commit/0c99aa85d300025cc3a8661bb4c1020f165c21b7)
- Nearly done here [`ac50bec`](https://github.com/fomantic/Fomantic-UI/commit/ac50bec3eca93ce76a5819df49d2bdc67250b784)
- Iterating on install [`42b176c`](https://github.com/fomantic/Fomantic-UI/commit/42b176cc7a986cb6ebb652d92be41c5cf21ad5a1)
- Let gulp tasks be run from any directory by using process.cwd, fix permissions q in install [`1e0ded8`](https://github.com/fomantic/Fomantic-UI/commit/1e0ded8af9c1af3ef3f01a855b58a6da797d3e4a)
- Add scoping to all ui elements [`c607790`](https://github.com/fomantic/Fomantic-UI/commit/c607790d16a9d8e998f3d75d1dff1741128e51b5)
- Now cards can use colors too! [`075efb5`](https://github.com/fomantic/Fomantic-UI/commit/075efb506bbec2ef7dd5d387537e01170f0f3407)
- All paths are now resolved from semantic.json location [`bf8b8f0`](https://github.com/fomantic/Fomantic-UI/commit/bf8b8f0a0384074b2107a4b3d40463c0fa7d860b)
- Fix theme.config to load multiple [`3dea109`](https://github.com/fomantic/Fomantic-UI/commit/3dea10949e410dfe13b8b395eb1e676cf8383a28)
- Attempt at README [`bdeca02`](https://github.com/fomantic/Fomantic-UI/commit/bdeca02aaed904ce54ea45b63f760a8ea6128d0f)
- Experimenting with deps [`d26385f`](https://github.com/fomantic/Fomantic-UI/commit/d26385f5a5224c55b7ddd761b413673d34dee746)
- Path fixes, rtl fixes [`1e0a71d`](https://github.com/fomantic/Fomantic-UI/commit/1e0a71d9e4c96aa0b65300a3f08b9314346c945a)
- Fix @type variable [`ab8fc99`](https://github.com/fomantic/Fomantic-UI/commit/ab8fc99cea4967efa2e930713b767666da2ecf19)
- Adds rudimentary sub-module detection to avoid end-user install when used as a sub-module [`de85e5a`](https://github.com/fomantic/Fomantic-UI/commit/de85e5a82c9299ee8ef346ee98a40e32135ba683)
- Format gulpfile, dashes [`ddbe345`](https://github.com/fomantic/Fomantic-UI/commit/ddbe3458b49c8937891e927da8af3c01633ac82d)
- Adds headers with images #1663 [`494c78f`](https://github.com/fomantic/Fomantic-UI/commit/494c78fdf756e0b34764b622504031aaafee8d57)
- So much fun [`9b15303`](https://github.com/fomantic/Fomantic-UI/commit/9b15303b66471f39ac708a1c0be6447f18029b7f)
- Dependencies [`48f6468`](https://github.com/fomantic/Fomantic-UI/commit/48f64685fd50c5fbe9bdaeb7f294b840bb0bbc9f)
- Add back in tasks, debugging cwd paths [`d88a1db`](https://github.com/fomantic/Fomantic-UI/commit/d88a1db00ae4b491c295ae9c348ddf45f221fe46)
- Update install again [`86f8631`](https://github.com/fomantic/Fomantic-UI/commit/86f863100abcc3a62f8f7214ba96a4f9e4ee3f50)
- It was all caused by using shallow extend! [`1c915c1`](https://github.com/fomantic/Fomantic-UI/commit/1c915c121067061245942f5b5817006bcae97870)
- better if without child selector. Class .image wont be use other way in .card .content [`edd8373`](https://github.com/fomantic/Fomantic-UI/commit/edd8373c4c41d13d6cd6669df6c60e13a72d2adf)
- Readme [`da494f8`](https://github.com/fomantic/Fomantic-UI/commit/da494f85c45cb2f8ecef55c339643829536aac41)
- better if without child selector. Class .image wont be use other way in .card .content [`20f2d96`](https://github.com/fomantic/Fomantic-UI/commit/20f2d9641215d9bffe6c2c5c9d5aecffbfb1ab93)
- Commenting [`2de6a35`](https://github.com/fomantic/Fomantic-UI/commit/2de6a35b58e89d80985384ccd2906524dccae6d2)
- Missing dep [`6270124`](https://github.com/fomantic/Fomantic-UI/commit/62701243f85a14093f798eec4249f3d617c29502)
- Update dependency tree [`a88694a`](https://github.com/fomantic/Fomantic-UI/commit/a88694a77469f678175acc3b7c97b78b0edcccfe)
- #1753 #1368 Adds forceSelection option to force user to current search selection when element blurred [`4870dad`](https://github.com/fomantic/Fomantic-UI/commit/4870dad08611a46a6e7e8427aa5b11086e4e72cb)
- Refactoring config [`6943bfa`](https://github.com/fomantic/Fomantic-UI/commit/6943bfac53204bd8752913f2960004e01d66d71a)
- Some cleanup [`a246807`](https://github.com/fomantic/Fomantic-UI/commit/a2468070ac3ca3cc062825f026f616e94a8a28c3)
- #1771 Fixes sidebar in IE with context. Makes all sidebar use position: absolute, instead of transform fix when not initialized in body [`4e71ee4`](https://github.com/fomantic/Fomantic-UI/commit/4e71ee417cb3a3d8cff311afa19484f5e7ba7c5a)
- #1784 Updates Tab remote API syntax with changes in 1.x [`0b9edd1`](https://github.com/fomantic/Fomantic-UI/commit/0b9edd1eda44b5b7714f251848754254db974e7d)
- Add use permission question [`c236c6e`](https://github.com/fomantic/Fomantic-UI/commit/c236c6e17c80368bb82dd8ebdf36a24e2d5a7e34)
- Updates release notes [`c718d65`](https://github.com/fomantic/Fomantic-UI/commit/c718d6577186101b003b960fa5b590c5de36caca)
- Add failsafe for dimmer [`296463b`](https://github.com/fomantic/Fomantic-UI/commit/296463bfb8da1cefe7fdeef997ba8433d30931d6)
- #1754, Fixes namespace being called out of order in transition init [`5653f6f`](https://github.com/fomantic/Fomantic-UI/commit/5653f6ff0911b63a07edae792172b14eafbff292)
- Debug [`0ca0a37`](https://github.com/fomantic/Fomantic-UI/commit/0ca0a37e9160d28659bea73485b9d3752668946f)
- Debug [`53321bc`](https://github.com/fomantic/Fomantic-UI/commit/53321bc27a2175b84f351a4cc2e3860870c56381)
- More debug [`0a23437`](https://github.com/fomantic/Fomantic-UI/commit/0a23437d75889263f273b87c14c4e78051bfc83a)
- Fix iterating [`a70ce06`](https://github.com/fomantic/Fomantic-UI/commit/a70ce06f4a60c39bff7ec8b916b3ce2db809d211)
- Update readme [`ddbc6c4`](https://github.com/fomantic/Fomantic-UI/commit/ddbc6c4ec932374dc7bba1da13fb0d65b38e93ee)
- Readme update [`1173fbb`](https://github.com/fomantic/Fomantic-UI/commit/1173fbb78b5d7ddf696e42da2151b3fd9931b04d)
- Fix rtl css build [`3d81a91`](https://github.com/fomantic/Fomantic-UI/commit/3d81a91385aa4ebc35156371e17b50c0b5039d59)
- Fix update path [`a52d1c0`](https://github.com/fomantic/Fomantic-UI/commit/a52d1c0bfe2a7a8deece84c4ed49f35eb4849d0d)
- Extend debug [`d1c7b48`](https://github.com/fomantic/Fomantic-UI/commit/d1c7b48583dfe37ffe6354a491e327fdef948a86)
- testing include order [`d99bd4e`](https://github.com/fomantic/Fomantic-UI/commit/d99bd4e747b0dde2800fe8cb2165da79a771e27e)
- Add tasks to update [`25d4322`](https://github.com/fomantic/Fomantic-UI/commit/25d432276421fc9c51d102ad00277e73ba471c87)
- Trying out new  extend [`0cf3212`](https://github.com/fomantic/Fomantic-UI/commit/0cf3212f5dc67586da6718d24bcd6231593ff439)
- Debugging update path [`2f80495`](https://github.com/fomantic/Fomantic-UI/commit/2f8049558e1bc88a5e19760feb26dad27b86b31f)
- #1755 #1744, adds additional variables for loading button, makes pointer events disabled in default theme [`f1b9da3`](https://github.com/fomantic/Fomantic-UI/commit/f1b9da3ce1774994a900d50401c2f9f8866bcce8)
- connecting the missing dots [`6b1d205`](https://github.com/fomantic/Fomantic-UI/commit/6b1d2057f1cfaea293945707c230bb67fca29add)
- Update release notes, whitespace [`8d60353`](https://github.com/fomantic/Fomantic-UI/commit/8d60353321066a664708cf64df2f7016bbd4dc70)
- Update now updates gulpfile [`44c628d`](https://github.com/fomantic/Fomantic-UI/commit/44c628df8e11f616946a87d49b0599c8c95cf794)
- Remove cleanup from NPM install [`e7e867d`](https://github.com/fomantic/Fomantic-UI/commit/e7e867df7b42425b3a630bbccf24f97f175a2b7a)
- Update config [`f5c0596`](https://github.com/fomantic/Fomantic-UI/commit/f5c0596c486499982c4c3b03d3538dfccb908272)
- Fix for object shadowing? [`eb223c6`](https://github.com/fomantic/Fomantic-UI/commit/eb223c6fad2de00dcdcd69184aa64747d6a47d07)
- Fix tabular menu valign issue in IE [`512abdf`](https://github.com/fomantic/Fomantic-UI/commit/512abdf83acf06114a23fa987b4190d561dd51a0)
- Remove some debug [`960f592`](https://github.com/fomantic/Fomantic-UI/commit/960f5925453a2bd74636a8b91f0013562b584fa9)
- Consolidate when logic [`6b27f37`](https://github.com/fomantic/Fomantic-UI/commit/6b27f376e103ae2726eb43de7717cc63084db133)
- Readme [`6d2b72e`](https://github.com/fomantic/Fomantic-UI/commit/6d2b72e735ae3c076c87ae152410496e4954d93a)
- Testing [`f048f4a`](https://github.com/fomantic/Fomantic-UI/commit/f048f4a6e1dd86ee747cfe1edfc2af516034d1d9)
- Break it [`c70ed31`](https://github.com/fomantic/Fomantic-UI/commit/c70ed3139678dd485fec0306ea7ab73c886b98b0)
- Update readme [`da397ba`](https://github.com/fomantic/Fomantic-UI/commit/da397ba3d4740c4dc628664aa3a2ee67674f6023)
- Trying to stay sane [`fa002e8`](https://github.com/fomantic/Fomantic-UI/commit/fa002e87c04fa49ef3291fab163f1dc1f127ee27)
- Fix update paths [`19d50b6`](https://github.com/fomantic/Fomantic-UI/commit/19d50b6b476940d87de00acbc298d43313c58310)
- Add back in install script [`04eb70f`](https://github.com/fomantic/Fomantic-UI/commit/04eb70f0390803643e4450b429fc38034b74d3d9)
- Fix cleanup questions for NPM [`ee159a2`](https://github.com/fomantic/Fomantic-UI/commit/ee159a2b4f5d620a3f6f8ac4059b52448cca110e)
- Add error formating for basic selects [`988375f`](https://github.com/fomantic/Fomantic-UI/commit/988375f7d3f798c52265d032329e096c7253257d)
- Debug [`396c4f2`](https://github.com/fomantic/Fomantic-UI/commit/396c4f278e1cdf07b5939e9a0685be531cc56e5c)
- Same [`6a5135f`](https://github.com/fomantic/Fomantic-UI/commit/6a5135f4e7ccdf5ab1a5abe5e725906f93046099)
- Readme [`2c04636`](https://github.com/fomantic/Fomantic-UI/commit/2c04636d4a0be92ebdd70420117eda6ca657aa51)
- Add release notes [`71f9bdb`](https://github.com/fomantic/Fomantic-UI/commit/71f9bdb20bd9b87d3e89347cd0b4159deb2abe27)
- like a monkey with a miniature symbol [`d3d6adf`](https://github.com/fomantic/Fomantic-UI/commit/d3d6adf0ff6a7398e95de948f240c165f8a54573)
- over and over [`76805d0`](https://github.com/fomantic/Fomantic-UI/commit/76805d0f0263e1507ca54658a457d2c399de06db)
- Toying with deps [`634ef9a`](https://github.com/fomantic/Fomantic-UI/commit/634ef9a19c1ed9b2173283757dc95fcb75cb408f)
- Testing [`e1a682e`](https://github.com/fomantic/Fomantic-UI/commit/e1a682ee932b98d5e3dd2a8bf3caf31a3508b3cb)
- more debug [`25f700f`](https://github.com/fomantic/Fomantic-UI/commit/25f700fe289d2f6d9736bc74b2ebd9ba122faeef)
- Debugging installer [`ea36185`](https://github.com/fomantic/Fomantic-UI/commit/ea36185cd2eb8ffa6def90a1460a1198fd36177c)
- Fix permission Q [`10ba573`](https://github.com/fomantic/Fomantic-UI/commit/10ba573e1a26e7e8c796e67b87182d54a70d092a)
- Fix links in src/ [`5ee82cc`](https://github.com/fomantic/Fomantic-UI/commit/5ee82cc4e08cca2efb238b9107f222d7f5438d39)
- Fix gulp mistake [`02ac6f7`](https://github.com/fomantic/Fomantic-UI/commit/02ac6f7e24e4b2d03df2cae0fadbc0f70b998824)
- Fix some permissions values [`b435531`](https://github.com/fomantic/Fomantic-UI/commit/b435531df3a126009f121a31603aa850361dba57)
- Fix last path [`aeda6ab`](https://github.com/fomantic/Fomantic-UI/commit/aeda6abe1e3eff1804fd73daf7c67e7cd49cb876)
- Debug package.json [`48bae26`](https://github.com/fomantic/Fomantic-UI/commit/48bae264b2049e9703e50078bfebb220be6fd578)
- Fix vertical sub menu positioning bug [`1b027a1`](https://github.com/fomantic/Fomantic-UI/commit/1b027a1b64dadb61e28771cbb47a4a1eb91b0e9b)
- images with .image inside .content will display nicely [`0060fa8`](https://github.com/fomantic/Fomantic-UI/commit/0060fa800f16cfc99f8223e592c3e456a0a2f5be)
- Combine divider rules [`967a03b`](https://github.com/fomantic/Fomantic-UI/commit/967a03b99b4b8af0322acf6ad0fe1f3c2d314768)
- Fix semantic.json inheritance [`5040387`](https://github.com/fomantic/Fomantic-UI/commit/5040387b9c764d5c07d10dd0dea424bce4adcf4a)
- Remove console log, fix watch task on definition [`f7b7ecf`](https://github.com/fomantic/Fomantic-UI/commit/f7b7ecfb62c1bfb8aa23abe63d7c982d9b5cc598)
- Fix variable order causing bugs in invoke in transition [`b62e8b8`](https://github.com/fomantic/Fomantic-UI/commit/b62e8b8a5a20c53d7872d322389b049594119ac7)
- corrected .yellow.card css [`21f4cc8`](https://github.com/fomantic/Fomantic-UI/commit/21f4cc8d10611914a911b82ac29722bcb1ecc39b)
- Testing around [`3f18396`](https://github.com/fomantic/Fomantic-UI/commit/3f18396493c2b1dc330a13f68315548a0f3667de)
- Version change [`f9b71d9`](https://github.com/fomantic/Fomantic-UI/commit/f9b71d970a1b47cddc9282c0c2c9e37db88ad81b)
- Missing comma [`815effc`](https://github.com/fomantic/Fomantic-UI/commit/815effc123e1b19e0bf1d0e949a66901acb00dd8)
- Fix tasks path in update [`098430f`](https://github.com/fomantic/Fomantic-UI/commit/098430f7ac5c55700f3ec564ab8ac8f21c3a7f1d)
- Add update message [`cc09985`](https://github.com/fomantic/Fomantic-UI/commit/cc09985f8cceaa8ae2ac1ebf57f700777ebf1f28)
- Testing update [`fc806c3`](https://github.com/fomantic/Fomantic-UI/commit/fc806c3dbe23d2e90d792a61ba3c4da031c173e7)
- Update version [`8d3b3bb`](https://github.com/fomantic/Fomantic-UI/commit/8d3b3bb260bfde28f8fd5f35800d5f3eb86d7c37)
- More debug [`3b7d554`](https://github.com/fomantic/Fomantic-UI/commit/3b7d554de6cd930a44a716d5b704690721b96e4b)
- Remove debug [`a598273`](https://github.com/fomantic/Fomantic-UI/commit/a598273a8f85f11b790c80a105240ebb562d2587)
- Test version bump [`83415b2`](https://github.com/fomantic/Fomantic-UI/commit/83415b27d935fd32910f04786df9a602657049d1)
- #1771, specificity match [`37757ca`](https://github.com/fomantic/Fomantic-UI/commit/37757ca6355b29a65341fdd5e33418df9bcf3145)
- I bet you can guess whats in this commit [`cbc0600`](https://github.com/fomantic/Fomantic-UI/commit/cbc06001dc94e16492031bcfe26485209dd8a7c9)
- 	Merge branch 'master' of github.com:Semantic-Org/Semantic-UI into next [`aa68a56`](https://github.com/fomantic/Fomantic-UI/commit/aa68a56686c54cccbb86d769cc7e9219a60084b8)
- build for jsfiddle [`5a29833`](https://github.com/fomantic/Fomantic-UI/commit/5a29833e1de94d5dee51d04e162be215a552c631)
- Updates build dist for jsfiddle [`5a03b66`](https://github.com/fomantic/Fomantic-UI/commit/5a03b66b81532b674e310850ceba92e12cd373d1)
- Rebuild dist [`90f5c0d`](https://github.com/fomantic/Fomantic-UI/commit/90f5c0d8d3c0eed4ae7dfd2fed82e4d00c2f6319)
- Stubs out all missing task files [`5065dbd`](https://github.com/fomantic/Fomantic-UI/commit/5065dbd1fbfa9929d57128663b7bccead10dcf9a)
- Rebuild dist [`f097f25`](https://github.com/fomantic/Fomantic-UI/commit/f097f25e2c9c4bda34bf9952dffe4e3a3c5ac38d)
- Update some color defaults and rlsnotes [`ee6988b`](https://github.com/fomantic/Fomantic-UI/commit/ee6988b5fd126bbbc39b6f347cb1d135d945c537)
- Rebuild dist [`527ce14`](https://github.com/fomantic/Fomantic-UI/commit/527ce14d444a7346104e53dab2e0f16a1b9e9667)
- Adds task rewrite, incomplete [`a68ab85`](https://github.com/fomantic/Fomantic-UI/commit/a68ab855ef98cdd8939cee0d796332e0667db4aa)
- #2263 release notes and build [`e3c2b67`](https://github.com/fomantic/Fomantic-UI/commit/e3c2b670398721dae48d29ac9665797ad9d0e629)
- rebuild dist [`e4c9b2d`](https://github.com/fomantic/Fomantic-UI/commit/e4c9b2daecafafb3b6d9485004a76ccc83727bce)
- Add fix for iframes in chrome [`d5e0225`](https://github.com/fomantic/Fomantic-UI/commit/d5e0225f3f441d3fffed0e75a0f3a8e17ac819e8)
- Rebuild dist/ [`9a78029`](https://github.com/fomantic/Fomantic-UI/commit/9a7802979a646a808018abc8738600f1d68e0264)
- Finalize folder structure [`0e9da27`](https://github.com/fomantic/Fomantic-UI/commit/0e9da27234b9dbb8d7a477d8e48067cafcbb1c1d)
- Work on examples [`14b1a4f`](https://github.com/fomantic/Fomantic-UI/commit/14b1a4feab97b8d434e4956575187e3bee983dd8)
- Build 1.8.0 [`a3932fc`](https://github.com/fomantic/Fomantic-UI/commit/a3932fcbdbec684cdd20e6b0fc7eacdad78377bf)
- Iteration on gulpfile [`0d0ffef`](https://github.com/fomantic/Fomantic-UI/commit/0d0ffef0ed24e15a4308d28ea339e5dbed72715a)
- Rebuild dist #2466 [`a438180`](https://github.com/fomantic/Fomantic-UI/commit/a438180dedd24aa84189d388cff4218bc2d50cf2)
- Rebuild dist [`a07e699`](https://github.com/fomantic/Fomantic-UI/commit/a07e6995ba6eb8689df9691351db39be6593afcb)
- rebuild dist [`ebbad9f`](https://github.com/fomantic/Fomantic-UI/commit/ebbad9fb73a3a8281edf226941ddeba92abc5134)
- Rebuild dist [`6c0d692`](https://github.com/fomantic/Fomantic-UI/commit/6c0d692c919e097335ceaef166f1186ef0fa9484)
- Rebuild dist/ [`cdf8aad`](https://github.com/fomantic/Fomantic-UI/commit/cdf8aadda1049c20b363ceef34645a6f917f2914)
- Adds WOFF2 and new icon files #1729 [`3e34e58`](https://github.com/fomantic/Fomantic-UI/commit/3e34e58ee3b6d67ea249ee64f284f8ad2ae50240)
- Rebuild dist [`30cb980`](https://github.com/fomantic/Fomantic-UI/commit/30cb9803005a0c5bdd4e0a8915585f7aabf70fd4)
- Complete docs tasks [`a9b9b07`](https://github.com/fomantic/Fomantic-UI/commit/a9b9b07514144491f36560f27cc78eaec05dcc5f)
- Adds github themes from example repo [`2ae29ec`](https://github.com/fomantic/Fomantic-UI/commit/2ae29ec09a5258220e2197eea9786c5139b44d4c)
- Setup embed component, fix all contributors banners in src [`40fb074`](https://github.com/fomantic/Fomantic-UI/commit/40fb0743eb4062d9028f4f47494502458902578c)
- Rebuild dist #2382 [`13a739b`](https://github.com/fomantic/Fomantic-UI/commit/13a739b3254b35e60e7980a440e63ba22774238d)
- New examples [`df06ea3`](https://github.com/fomantic/Fomantic-UI/commit/df06ea37f4054c2c3cdff3962e70f10ecbc2224f)
- Rebuild dist #2252 #2212 #1912 #230 [`1e18d4f`](https://github.com/fomantic/Fomantic-UI/commit/1e18d4f26f0a0e4229a3c8561bc62fbcad88d759)
- Build 1.8.1 [`c56a538`](https://github.com/fomantic/Fomantic-UI/commit/c56a53886f4686c4a2b96836ab790d0cb152461e)
- Iteration on embed rewrite [`26d2003`](https://github.com/fomantic/Fomantic-UI/commit/26d20037953eb567dd062cf316b9288cceba0943)
- #2280 Add colored variations for labels [`70a87a2`](https://github.com/fomantic/Fomantic-UI/commit/70a87a20202e1eaacaad1ea89e532d019f01b181)
- Rebuild dist [`30e87b3`](https://github.com/fomantic/Fomantic-UI/commit/30e87b352112d8aa3eb97fc775c36ac079e1e12c)
- Build 1.7.0 [`37179d2`](https://github.com/fomantic/Fomantic-UI/commit/37179d2fc7b35dc15b2b5c2ff7f2397a99137018)
- Build 1.12.1 [`b63c641`](https://github.com/fomantic/Fomantic-UI/commit/b63c64161f99c0aa3628e1750cd58303a3725077)
- #2467 - Add examples for many responsive element patterns [`07026da`](https://github.com/fomantic/Fomantic-UI/commit/07026da5dc45a878a0b9105c550de8bba07a5c0c)
- Rebuild dist/ [`9bdcc14`](https://github.com/fomantic/Fomantic-UI/commit/9bdcc14561fb462ec6c0afc09769debdb2f8f621)
- #2280 Add olive color, add other missing header colors [`b145912`](https://github.com/fomantic/Fomantic-UI/commit/b145912c6baa488dd5a5e8029b71785691e86b8c)
- Merge in PR and sort transitions alphabetically #1623 [`405db33`](https://github.com/fomantic/Fomantic-UI/commit/405db334f021d998f06929e1a300b50d98af8cf2)
- Rebuild dist [`75a2955`](https://github.com/fomantic/Fomantic-UI/commit/75a295591283ede279d1b40bb3bbbdc2ab3c446a)
- Rebuild dist [`daa358d`](https://github.com/fomantic/Fomantic-UI/commit/daa358dd1a9106ac6048e3bced13a9ea890740e3)
- Rebuild dist [`394d9b4`](https://github.com/fomantic/Fomantic-UI/commit/394d9b404ee1714be775a7db36ea76c9e81a12d7)
- Rebuilding dist [`971c4cd`](https://github.com/fomantic/Fomantic-UI/commit/971c4cd9d3d0c26c0aa26ecb03a7821aad4076e5)
- Rebuild dist [`1ca7ed0`](https://github.com/fomantic/Fomantic-UI/commit/1ca7ed05b9e390536040d7e522ff5e82c85eef96)
- Rebuild dist/ [`271905f`](https://github.com/fomantic/Fomantic-UI/commit/271905f2bb86366e5955db750f34473ea1b94e16)
- Rebuild dist [`4c71529`](https://github.com/fomantic/Fomantic-UI/commit/4c71529b1dece3a1c13ab5699591bb77cf0b51ca)
- Rebuild and remove form debug [`e2330f8`](https://github.com/fomantic/Fomantic-UI/commit/e2330f8b7545033b6ba3ee34a1081f77bac88581)
- Rebuild dist [`d82a103`](https://github.com/fomantic/Fomantic-UI/commit/d82a103bb99dbf8cabe149641fb0e3b65a88def6)
- rebuild dist [`9f44700`](https://github.com/fomantic/Fomantic-UI/commit/9f44700dbc5d1794a36678f1c3ed2b2855266bd1)
- Rebuild dist [`967a764`](https://github.com/fomantic/Fomantic-UI/commit/967a7647bc37b07cb9faeadbdc4c113c7900e813)
- Rebuild dist [`5d20107`](https://github.com/fomantic/Fomantic-UI/commit/5d201078f7d4a9562ceba0e9fe1b46b7d578eca4)
- #2264, add focus colors to site, add focus rules for all possible button styles [`d7f7bab`](https://github.com/fomantic/Fomantic-UI/commit/d7f7babd314e6647925685f23de96fa3526980ac)
- Build 2.1.3 [`5fc32e1`](https://github.com/fomantic/Fomantic-UI/commit/5fc32e173b23670488aacbe14aea4a77040a409c)
- Version tick and build [`a69dc2f`](https://github.com/fomantic/Fomantic-UI/commit/a69dc2fc6d1fd18fd0405c79d82e9049ca9c118e)
- Rebuild dist #2335 [`de4a9b0`](https://github.com/fomantic/Fomantic-UI/commit/de4a9b08b5117758583d289eacc2e9773db72050)
- Build 1.12.2 [`ad0b21e`](https://github.com/fomantic/Fomantic-UI/commit/ad0b21e315df693406da5495296fe4bd2529fa9d)
- Build 1.12.3 [`069ea0a`](https://github.com/fomantic/Fomantic-UI/commit/069ea0aef47ce4f32c1c17b4f6a9a4effddc9600)
- Update gulpfile incomplete [`f657d1e`](https://github.com/fomantic/Fomantic-UI/commit/f657d1eb3acb92c30c0a29a2ea01db7e26d5efe0)
- Rename bounce as fly #1623 [`e7e73a1`](https://github.com/fomantic/Fomantic-UI/commit/e7e73a1a18815c2f312dd748bde7c031cbe02bc6)
- Update version to 2.1.6 [`d2b7520`](https://github.com/fomantic/Fomantic-UI/commit/d2b75201c95645f3f76867f32916784247390ff1)
- Update version to 2.1.6 [`637471e`](https://github.com/fomantic/Fomantic-UI/commit/637471e86c1e44039c38ade112de64b7a349c1ef)
- Update rlsnotes, rebuild [`0359dd1`](https://github.com/fomantic/Fomantic-UI/commit/0359dd12ecfdf5c0263c63bc9ea615429d33d105)
- Iteration on settings inheritance [`00cfecd`](https://github.com/fomantic/Fomantic-UI/commit/00cfecdc9a8819f7249e83d40be9b2a114134631)
- Rebuild dist/ [`6c5d49d`](https://github.com/fomantic/Fomantic-UI/commit/6c5d49d25345d1e7ad05d84a390bd4a2cee62613)
- Build 2.1.2 [`4f99f1e`](https://github.com/fomantic/Fomantic-UI/commit/4f99f1ef0bb4ae73152784ff71f7e70ae118e98e)
- Add multiple validation rules to form validation, convert form validation to using one settings object, add errored styles to multiple form validation [`8bc6274`](https://github.com/fomantic/Fomantic-UI/commit/8bc627461c88c93ea3b6906fb0f14c2df48cee51)
- Build 2.1.1 [`3025892`](https://github.com/fomantic/Fomantic-UI/commit/3025892c7295ac65b2eb6031c617ce6eccec6d7b)
- Rebuild dist for next [`81dbde6`](https://github.com/fomantic/Fomantic-UI/commit/81dbde6cbac9bf5d56e9ca3a9127acab8bd9167e)
- #2435 rebuild dist [`cb0cdae`](https://github.com/fomantic/Fomantic-UI/commit/cb0cdae2072a644097d62391a79dc1ec49b90d35)
- Rebuild dist [`dff4e18`](https://github.com/fomantic/Fomantic-UI/commit/dff4e186b40d56d533719c1e613e57c4e42702ce)
- Build 1.7.1 [`887a6fb`](https://github.com/fomantic/Fomantic-UI/commit/887a6fbb0239f27cfb08c54d39632d1d160d6056)
- Rebuild [`d6f5861`](https://github.com/fomantic/Fomantic-UI/commit/d6f5861ff094faf8368f7667b1d5351f29b9e3db)
- Rebuild dist #2334 [`de3fd74`](https://github.com/fomantic/Fomantic-UI/commit/de3fd74a92759e176d189164aef3048fef84489b)
- Adds colored basic labels [`8d69390`](https://github.com/fomantic/Fomantic-UI/commit/8d6939084b3f51035e042df29b62e6b50ddd215d)
- Variables now in chroma order, adds violet #2280 [`6edcf51`](https://github.com/fomantic/Fomantic-UI/commit/6edcf5198a9302f34e956a3a967d9caf39c61c15)
- formatting and build dist #2656 [`3552fb5`](https://github.com/fomantic/Fomantic-UI/commit/3552fb525731ff5e9e584cd620a0f570e438cd6c)
- Rebuild dist #2824 [`54d01ad`](https://github.com/fomantic/Fomantic-UI/commit/54d01adcffa48e7dd1cacf00910d9eca4de562de)
- Iteration on install scripts [`2295e50`](https://github.com/fomantic/Fomantic-UI/commit/2295e507f9b559d660cdf506aaceae144006fcf2)
- Big Change: Replace all derived em values with @px values. [`2f20aca`](https://github.com/fomantic/Fomantic-UI/commit/2f20acad7a7e69797d95c5df274d723638954d85)
- Finish first completed draft of embed component [`00cb9c7`](https://github.com/fomantic/Fomantic-UI/commit/00cb9c7586faeba0926998a7779d28d1802f3761)
- Build 1.6.4 [`862adba`](https://github.com/fomantic/Fomantic-UI/commit/862adba46323d1d86200f50971a21ff798a37add)
- Build 1.7.3 [`257d175`](https://github.com/fomantic/Fomantic-UI/commit/257d175bf6138cc19e767b8061466cc7f3d97017)
- Related #2014, separate css and javascript into separate tasks [`2457ca6`](https://github.com/fomantic/Fomantic-UI/commit/2457ca65ad657646b9828d318e841d9b2a7f9c10)
- Rebuild patch 1.6.3 [`02b0529`](https://github.com/fomantic/Fomantic-UI/commit/02b0529718ebc847369b0f77792da39011ddf5c2)
- Finishes recode of mock and complete callbacks from API. Aims to improve comprensiveness of debug statements. Adds ability for mocked responses to use all the settings available to regular API requests like loadingDuration [`66f8090`](https://github.com/fomantic/Fomantic-UI/commit/66f809067d6586667edcefc4c6262c5e7927b91b)
- Package 1.7.2 [`7b8d7fa`](https://github.com/fomantic/Fomantic-UI/commit/7b8d7fa02780d14bff4844d9a617605adf5c8db1)
- Rebuild dist/ [`d01b787`](https://github.com/fomantic/Fomantic-UI/commit/d01b7873569f4c971dba1c38cb8a0be5678d3283)
- Rebuild dist [`73c959c`](https://github.com/fomantic/Fomantic-UI/commit/73c959cc930a630070e69ac12b3f50b59bf26abd)
- Fix bug in has direction that causes animations with name containing in/out to work incorrectly #1623 [`b66dfac`](https://github.com/fomantic/Fomantic-UI/commit/b66dfac9eab067c84fb2833301732c53c1ea87fb)
- Finish refactoring, search now returns result object in onSelect #1634 [`7322fe9`](https://github.com/fomantic/Fomantic-UI/commit/7322fe971d9d295b5bd49422ad263084dcce97b9)
- #2440 Finish indeterminate, consolidate API to avoid confusion [`8db305a`](https://github.com/fomantic/Fomantic-UI/commit/8db305a460d4e7697e34221e84c9abf749a8b470)
- Collapsing some grouped button rules, fixes inline-flex white space issues with grouped basic button #2280 [`b0991d5`](https://github.com/fomantic/Fomantic-UI/commit/b0991d52c7be419ccc40b5d18ea0afd68cab53f7)
- Revert themes until LESS.js inheritance works correctly in browser for theme preview [`641a837`](https://github.com/fomantic/Fomantic-UI/commit/641a837a99ebd5775967c87fb6a7b98beeb05c96)
- Rlsnotes and build [`5bd45a2`](https://github.com/fomantic/Fomantic-UI/commit/5bd45a2fcf3d820ed1b925194856d9d836564317)
- Spruce up some examples [`0fcb0da`](https://github.com/fomantic/Fomantic-UI/commit/0fcb0da163a375d28aa1b21382665f823c88d8f8)
- Initial wiring of API to dropdown [`5585502`](https://github.com/fomantic/Fomantic-UI/commit/5585502e2600844b0f5d464106db81cacfaeeb0c)
- Rebuild dist [`17ef6ba`](https://github.com/fomantic/Fomantic-UI/commit/17ef6ba20398b38295289d483af8f9c1026f16a4)
- Added bouncing apperance transitions for all directions. Animations from Animate.css [`85bacce`](https://github.com/fomantic/Fomantic-UI/commit/85bacce8a85a27beff9dc319bb87408ac9c870fa)
- Rebuild dist/ [`5bb7b98`](https://github.com/fomantic/Fomantic-UI/commit/5bb7b980e6e2f21767dffcbfb2e71c3bf84c4b0b)
- Iteration on install [`93cd582`](https://github.com/fomantic/Fomantic-UI/commit/93cd582642230b4d76bd4aa9f43a3ea9a7ce829d)
- Rebuild dist [`3f11d8f`](https://github.com/fomantic/Fomantic-UI/commit/3f11d8fb737c79768c6bdba99ee6382e84622bb4)
- Complete restructure of checkbox for comprehensivenesss, adds indeterminate state, new callbacks, #2440 [`9b3665e`](https://github.com/fomantic/Fomantic-UI/commit/9b3665eb013d457a42e41843478ca4d855c23b03)
- Iteration on tasks [`47bf0a9`](https://github.com/fomantic/Fomantic-UI/commit/47bf0a99f2536a5cab2fa37417d07301f9dd0b15)
- Rebuild dist for jsfiddle #2637 [`d4143c1`](https://github.com/fomantic/Fomantic-UI/commit/d4143c1307528e71b06235148678609a6e9ca80e)
- #3713 - adds silent option to all modules [`7040acd`](https://github.com/fomantic/Fomantic-UI/commit/7040acdc440a42e508142e58dc114bbab39cbade)
- #2280 Add grey, make sure colored buttons use variable to determine text color swapping [`85e7956`](https://github.com/fomantic/Fomantic-UI/commit/85e7956928a4d104e9a926ceffd11ae4585e95a5)
- Iterating on gulpfile restructure [`2bc5d6f`](https://github.com/fomantic/Fomantic-UI/commit/2bc5d6fd3fd850e548281eb6fcb772225fd21dfb)
- Fix greyscale saturation turning red (caused by absolute saturate call) [`601aad9`](https://github.com/fomantic/Fomantic-UI/commit/601aad9c124a50dc8fcf1791271639330275bb74)
- Begin rewrite of popup calcs to cache correctly on each position check [`794d082`](https://github.com/fomantic/Fomantic-UI/commit/794d08221810860b58a39ce58e3f899caecaf4d3)
- Iteration on theme site install [`57b35d2`](https://github.com/fomantic/Fomantic-UI/commit/57b35d2150f556ea91a334cc11a52f5289052583)
- Fix remove/add conditions for user additions [`e6194fb`](https://github.com/fomantic/Fomantic-UI/commit/e6194fb9af5962556879c15d7bcd81d744fd7aae)
- Added fades for all directions [`cfe1617`](https://github.com/fomantic/Fomantic-UI/commit/cfe1617bc485eeeaae6cdb278c6806d94ed3732d)
- Adds updated amazon and github theme [`61af1f3`](https://github.com/fomantic/Fomantic-UI/commit/61af1f3aa6246358722014821983f34644acc26b)
- Finishes embed component [`6c64098`](https://github.com/fomantic/Fomantic-UI/commit/6c640987b3d86f97e36a9bb1d5619c9d34385930)
- Build 2.1 [`13661ce`](https://github.com/fomantic/Fomantic-UI/commit/13661ce5155c610a8395dec7479f356b9b60543f)
- Rebuild [`046612e`](https://github.com/fomantic/Fomantic-UI/commit/046612ec4c7fa0a4e220ee74bdb5346b0f98de72)
- Redo inverted colored menu styles [`fa099bd`](https://github.com/fomantic/Fomantic-UI/commit/fa099bd29e0ad14b8ac66e38fd787dc164e638b1)
- Adds get value(s), removes serialize #1630 [`c5ff8ec`](https://github.com/fomantic/Fomantic-UI/commit/c5ff8ec0158589fbd21dfe7ea7056556c911d268)
- Rebuild dist #2165 [`b4470ef`](https://github.com/fomantic/Fomantic-UI/commit/b4470ef9d090fbc06aae7042b983e0aa1a653a29)
- Octicons rls [`e160b46`](https://github.com/fomantic/Fomantic-UI/commit/e160b46be7c15d096c78bffefd9b50229bea77da)
- #2280 Add icon color variations, fix bordered icon line height [`08f301c`](https://github.com/fomantic/Fomantic-UI/commit/08f301ccb595c1abe67f333de4374c66f38e50ec)
- Silly update icons to FontAwesome v4.4 [`8c9bd9c`](https://github.com/fomantic/Fomantic-UI/commit/8c9bd9c2b11a0833f5b48b2044bae91e2b73ec58)
- Iteration on install rewrite [`6da6f18`](https://github.com/fomantic/Fomantic-UI/commit/6da6f186a40cae9241953707d0e39648e4f7e9d6)
- Revamp statistic styles, move to flex [`7b702fc`](https://github.com/fomantic/Fomantic-UI/commit/7b702fc606433b29353055588dd7a9933be049e6)
- Adds default prompts for form validation [`edc9b34`](https://github.com/fomantic/Fomantic-UI/commit/edc9b34928bbe7360ee01689b0f0ce7b67c3228c)
- Rebuild dist/ [`479706e`](https://github.com/fomantic/Fomantic-UI/commit/479706ee662e8b57bdedea5b75a8e31be4c45f04)
- #2334, Re-organize attached code, fix attached button groups [`406a95c`](https://github.com/fomantic/Fomantic-UI/commit/406a95cfc7b444c99fed5ef27baad993255c4dd4)
- Rebuild dist #2374 [`5ef73e4`](https://github.com/fomantic/Fomantic-UI/commit/5ef73e4f4e27c2cd3eb628a19ca2b8d2a8777031)
- #2280, add brown button styles for testing color [`e20b456`](https://github.com/fomantic/Fomantic-UI/commit/e20b456f66a80b69b8c1bac9feea5b5f14dc5671)
- Rewrite dropdown keyboard shortcuts to support sub-menus [`13886b2`](https://github.com/fomantic/Fomantic-UI/commit/13886b2eb54351a1ae661e2402ecc7f644f413ef)
- Add maximum selection setting [`416390e`](https://github.com/fomantic/Fomantic-UI/commit/416390ee27ad2c660dc4f2f99bc02bc8c9718117)
- Fix @defaultEasing and @transitionEasing variable duplication, Fix @defaultDuration and @transitionDuration variable duplication [`663e2c2`](https://github.com/fomantic/Fomantic-UI/commit/663e2c2569937f11a48926b9dad3fda86a91b61d)
- Fix paths issue [`8dafefd`](https://github.com/fomantic/Fomantic-UI/commit/8dafefd858f6e24b344dcab8768865996982aa2b)
- Iterating on install script [`01e1b7b`](https://github.com/fomantic/Fomantic-UI/commit/01e1b7b61648ff02e18e9544de7ce03dd243beaf)
- JS formatting: implicit brackets, full words, removing meteor tasks from build/install [`ba2e1f6`](https://github.com/fomantic/Fomantic-UI/commit/ba2e1f6e499570495d9d8b34a87f6cde9fb9a347)
- #2280 Grid colors, and reduce ruleset [`183679b`](https://github.com/fomantic/Fomantic-UI/commit/183679b11f32deb40d1a6bba78868e172fa6eff8)
- Iteration on allowAdditions setting for selection dropdown [`99924ad`](https://github.com/fomantic/Fomantic-UI/commit/99924ad7004374a07b8d1b8a39376f6889cd26c4)
- Add new color rules to statistic #2280 [`ce18991`](https://github.com/fomantic/Fomantic-UI/commit/ce189914fcfacf0e34954b10bc2237a8cd5f02fa)
- Adds category search component [`4ea2514`](https://github.com/fomantic/Fomantic-UI/commit/4ea251490579a262f65d12ac75415e222b6ed8e0)
- Fix issues with tab module scoping caused by m initializeHistory. Fixes some minor jslint [`98de07d`](https://github.com/fomantic/Fomantic-UI/commit/98de07d98c379c5fd160e0ff0cbf6bf555113f7e)
- #2411 Adds horizontal segment groups [`f59c707`](https://github.com/fomantic/Fomantic-UI/commit/f59c7074bfd64e88f0da1e04aaf25104fd0f1718)
- Partial rewrite animation [`149b784`](https://github.com/fomantic/Fomantic-UI/commit/149b7844040514548475332a64e99f6f7b1591c0)
- Fix animations to return to same direction, fix css for consistent formatting [`018fb85`](https://github.com/fomantic/Fomantic-UI/commit/018fb8503c3c868a4537fe158af35a07a937c5c1)
- Fixes issue where search wont close when clicked on message #3039 [`6d34ae2`](https://github.com/fomantic/Fomantic-UI/commit/6d34ae21e595d104b59481848ebf2f7873028dac)
- Consolidate and finish work on segment groups [`6258196`](https://github.com/fomantic/Fomantic-UI/commit/6258196a97a485db5800c4000a8015c535d942b1)
- #2466, recode some of progress. Fix module.value to not be estimated when using a total. Fixed issue with values less than 1 displaying incorrectly [`62ae343`](https://github.com/fomantic/Fomantic-UI/commit/62ae343363f84c3d5774516f2b91b72cd0260a25)
- #2402 - further house cleaning with transition [`df934c0`](https://github.com/fomantic/Fomantic-UI/commit/df934c05596a23533ba2611c82843b8a8cd69886)
- Adds violet button #2280 [`e03573f`](https://github.com/fomantic/Fomantic-UI/commit/e03573f8f23de64357e2937acea1da785b32ef6e)
- #2153, fix stacked tables from removing sortable/warning/error styles. Add selectable table variation #1803 [`257be28`](https://github.com/fomantic/Fomantic-UI/commit/257be28220d6dc96db061af8a8707ffd414f5bbd)
- #2280 Fix segment colors [`8eb3a6b`](https://github.com/fomantic/Fomantic-UI/commit/8eb3a6bbd1498ef0ecf1f18049d587a587813446)
- Redo icon font for indeterminate state, begin  js modifications [`5ddc887`](https://github.com/fomantic/Fomantic-UI/commit/5ddc8875c6ab10d907138a120c7bc1bae3347fed)
- Add new sticky example [`b527d8a`](https://github.com/fomantic/Fomantic-UI/commit/b527d8ac3b3e70a3375973369a4b572a81abb359)
- Finish popup rewrite [`d4aa962`](https://github.com/fomantic/Fomantic-UI/commit/d4aa9623d7e580158193d367536bba0370c9dfc1)
- Fix image visibility to only occur when on screen [`c72f790`](https://github.com/fomantic/Fomantic-UI/commit/c72f790bb4dc8c58f26cee02b0b87592a62c938c)
- Added direction to Slide transitions [`15d005a`](https://github.com/fomantic/Fomantic-UI/commit/15d005a37f744f3191175d7ff171ee242b48c91f)
- Proper rewrite of progress to support rapid updates [`95e2172`](https://github.com/fomantic/Fomantic-UI/commit/95e2172a5fe48df64c752783904416aafa7ba66b)
- Adds sub header variables, resizes per content heading size #1654 [`5fb4cc3`](https://github.com/fomantic/Fomantic-UI/commit/5fb4cc39f3ff1c9870e97c2b6cb3253327652180)
- xperimental rewrite of popup to use custom offsetParent #1605 [`91bdbb8`](https://github.com/fomantic/Fomantic-UI/commit/91bdbb8742cba410b3cea3be2951794b15f66536)
- Revisits link colors inside lists [`f16db3f`](https://github.com/fomantic/Fomantic-UI/commit/f16db3f70abc554e88c6eaa1a7815cfd0c0ae41b)
- Adds onVisible and onRequest callbacks, adds new 2.0 callback names onFirstLoad and onLoad, adds deprecation warnings for previous callbacks #1612 [`1ae05d6`](https://github.com/fomantic/Fomantic-UI/commit/1ae05d698bf2d4ec73d3d04aaf42e2785604a961)
- Wasted day of noodling over rendering, and dealing with indeterminate state issues [`8926012`](https://github.com/fomantic/Fomantic-UI/commit/8926012364bdf6e7f78edf8730ebbcd467250e9a)
- Remove legacy code from sidebar [`2229306`](https://github.com/fomantic/Fomantic-UI/commit/22293069205d2e68dbbe926481a99caa2682d1a0)
- Rebuild next dist [`4d488e0`](https://github.com/fomantic/Fomantic-UI/commit/4d488e0c15a0511e36c9a58f1f82b62b6d2a2994)
- Added 'swing' in and out transition [`6d4a7df`](https://github.com/fomantic/Fomantic-UI/commit/6d4a7df3b6b1fa31676b92fa59d55963bdf7dc40)
- #2645 adds fields parameter for using custom server responses with search [`57ee104`](https://github.com/fomantic/Fomantic-UI/commit/57ee1041f51794cc89ce49bf61c52ad708d24dd6)
- #2335 Loosen item css for some menu types to allow for work with container. Tweak horizontal labeled icon sizing and spacing [`95702d3`](https://github.com/fomantic/Fomantic-UI/commit/95702d3895fb6e177cb0ca1f4aebb60f8712ffa1)
- #1724 Added support for sub menus to check upward/downward independently of main menu, fix some styling on upward and left menu [`073f561`](https://github.com/fomantic/Fomantic-UI/commit/073f561ab2a291faf3d2073c66be91dca0bd2fc8)
- #2656 Adds before change callbacks for checkbox [`b2c0655`](https://github.com/fomantic/Fomantic-UI/commit/b2c0655b333c09153360a47fb3af28454308955f)
- Build dist [`f155488`](https://github.com/fomantic/Fomantic-UI/commit/f155488f382d0774c42e61dfa9b580a0fc86ad5b)
- Iteration on install script [`65d037d`](https://github.com/fomantic/Fomantic-UI/commit/65d037dd666386b273f38c239211e96a11f67f18)
- Rebuild dist [`17e0b1a`](https://github.com/fomantic/Fomantic-UI/commit/17e0b1aaf4765ca44f1701ff74b72d0333327688)
- Rebuild dist [`9fcc098`](https://github.com/fomantic/Fomantic-UI/commit/9fcc098f82339b648b7f00a4b26c5c7fff1ed3a6)
- Begins work on allowAdditions, adds error messages, and ui message coupling [`3a9821c`](https://github.com/fomantic/Fomantic-UI/commit/3a9821ca46a2fb2fa53700b522863195f9bcea68)
- Fixes issue with extending settings with [`d4ecfa1`](https://github.com/fomantic/Fomantic-UI/commit/d4ecfa12ff80110e522c2a9a19e287563b4884a6)
- Linkify all issues [`517c41f`](https://github.com/fomantic/Fomantic-UI/commit/517c41f9b9b65d2b782e9bb55b999cd3d61e93bb)
- Adds word order dependencies for transition [`8882a1f`](https://github.com/fomantic/Fomantic-UI/commit/8882a1f3d643432835a808f23a28970c734a523e)
- Rebuild dist/ [`73c0eef`](https://github.com/fomantic/Fomantic-UI/commit/73c0eefcf5d56b0a2b45585b59052279da1af872)
- #2280 Add table colors [`348bd56`](https://github.com/fomantic/Fomantic-UI/commit/348bd56beddcd653caff3972f737eaf9cb886a22)
- Fix several issues with API, including throttle on first request, moving interruptRequest to a setting, fixing loadingDuration not applying when using 'query' [`e88c529`](https://github.com/fomantic/Fomantic-UI/commit/e88c529af4e71730ba19630d58858cc92d5ac9e0)
- Add many new rating variables [`7288419`](https://github.com/fomantic/Fomantic-UI/commit/72884195de695e53556647c0302e8630b610982b)
- Adds credit card validation to form validation #2729 [`2769a6e`](https://github.com/fomantic/Fomantic-UI/commit/2769a6ee12eae8ee2c3da4e25a3f578efba01633)
- Adds focused input border styles, changes dropdown selection label valign [`c2945b6`](https://github.com/fomantic/Fomantic-UI/commit/c2945b608f2277ed20aecbeda8fce277f3ce3ef1)
- Add flexbox to form groups [`d20d244`](https://github.com/fomantic/Fomantic-UI/commit/d20d244b8f2d30e2d99139fdca5e7d43e0229382)
- Iterating on multiselect fixes [`d5308d3`](https://github.com/fomantic/Fomantic-UI/commit/d5308d3438e016d21a98d4cd89296f86374c7fd8)
- Abstraction abstraction abstraction #1634 [`f8fa373`](https://github.com/fomantic/Fomantic-UI/commit/f8fa3734822e54442aa07d99c768b8fb46799cce)
- Complete first pass of API integration with dropdown [`071d101`](https://github.com/fomantic/Fomantic-UI/commit/071d1012152d98a2f4a7b0bc374736a1f12b4490)
- Fixed animation reset issue with accordion and hideOthers [`6961e41`](https://github.com/fomantic/Fomantic-UI/commit/6961e4118bacb10bb40e4a03fb5c08f2333a008d)
- Card styles adjusted to be remove solid border shadow [`f5f8d0d`](https://github.com/fomantic/Fomantic-UI/commit/f5f8d0dbe12fe265384d7f469d7f6e5a4f126589)
- Remove label padding to work correctly with compact button [`a13cf04`](https://github.com/fomantic/Fomantic-UI/commit/a13cf04d235272e9677053a279ad1bca6d5e35c2)
- Finish popup rewrite [`b0f400f`](https://github.com/fomantic/Fomantic-UI/commit/b0f400fbc2ea691055663e150f76dfd3311aa4f5)
- Add new sticky behavior, automatically creates placeholder content [`dd010b0`](https://github.com/fomantic/Fomantic-UI/commit/dd010b02d9080fc7baf425f2513719abb950cece)
- Update examples, update transition error [`739bf5e`](https://github.com/fomantic/Fomantic-UI/commit/739bf5e79c8aa3e375cca55949d9b84062cbc39a)
- Fix merge commit [`5ccf607`](https://github.com/fomantic/Fomantic-UI/commit/5ccf607e7acf99f9289a4af3203daa1f64638b66)
- Rebuild dist [`cc0aaef`](https://github.com/fomantic/Fomantic-UI/commit/cc0aaef59842a975ee7187e335875db8ac2669ef)
- Implment reversed divided, reversed vertically divided, reversed celled, reversed internally celled grid #2685 [`e42fc29`](https://github.com/fomantic/Fomantic-UI/commit/e42fc29dc6fdb2840ada871a2e1e812eb6fa63c1)
- Add parse response method, add additional debugging, dont instantiate API on each query #1634 [`5f18f2c`](https://github.com/fomantic/Fomantic-UI/commit/5f18f2c1c3147d50cbc5c67c70240da94b45f8d5)
- Adds new color values for progress bars #2280 [`9d26b84`](https://github.com/fomantic/Fomantic-UI/commit/9d26b8466fb09240689ae6fe618b870dd9ff47ea)
- Steps now are horizontally pointing again (like 1.x), added many new variables to control [`6bceb47`](https://github.com/fomantic/Fomantic-UI/commit/6bceb47beba29a94e415eb8484d4a9cc75010c9f)
- Fixing spelling in release notes [`766e0eb`](https://github.com/fomantic/Fomantic-UI/commit/766e0eb8da128917b884deab90eadaf5a4603cd6)
- Adds a few more aliases. Gives every class its own css rule. Deletes number classes. Reorders by utf code. Fixes classes' conflicts. [`5f335b9`](https://github.com/fomantic/Fomantic-UI/commit/5f335b9aa9da1cef13c4a78079f6bc917e90706e)
- Adjust some underlying variables to have more comprehensible names [`a88ec27`](https://github.com/fomantic/Fomantic-UI/commit/a88ec27503b84621691e8134c583aa0f9907cc41)
- #2308, Fix rating module to refresh data attributes as well [`45ff8f8`](https://github.com/fomantic/Fomantic-UI/commit/45ff8f8e10ea6c59a0e4281b7dc1bb113d75c7bb)
- Add support for 'clear', 'restore defaults' for multiple #2303, update logic for fireOnInit to be more clean, fix issue with boolean values setting #2296 [`35edff6`](https://github.com/fomantic/Fomantic-UI/commit/35edff6b529c14eca3aa97775e4f1d8c0127be0d)
- Adjusting message colors [`c1f43c1`](https://github.com/fomantic/Fomantic-UI/commit/c1f43c18b6338c1ecb2e7761f55a5262e1f2e2f2)
- Update NPM deps solving some issues with min ver [`40fd305`](https://github.com/fomantic/Fomantic-UI/commit/40fd305824059f2fc6bf984e6b0fdc349678ea6e)
- Fix admin issues [`d1c6b9b`](https://github.com/fomantic/Fomantic-UI/commit/d1c6b9b7bacd59ea30e3d53222e5767401985929)
- Fixed content border radius when only-child. Added border between repeated contents [`4694c18`](https://github.com/fomantic/Fomantic-UI/commit/4694c181860e505d3ae0cd408792dcb7cf0975d1)
- Backports input definition to 1 [`61be84c`](https://github.com/fomantic/Fomantic-UI/commit/61be84ce02fa5ed3fe5cbbf80a072449a7c149b4)
- #2280 Order message colors and add missing colors [`ac647e8`](https://github.com/fomantic/Fomantic-UI/commit/ac647e8fcb2f0b8e81e36b8344dac430ce3f1919)
- Rebuild 1.7 add date [`b9b7fd6`](https://github.com/fomantic/Fomantic-UI/commit/b9b7fd67da9636be85ca0500840dab589c2c31dd)
- Adds #792 Checkbox now specifically matches against input type checkbox/radio [`227d3d3`](https://github.com/fomantic/Fomantic-UI/commit/227d3d3ac63daa7c6f3f5c82d65764b214434f50)
- Upgrading to FontAwesome v4.5.0 [`133101d`](https://github.com/fomantic/Fomantic-UI/commit/133101d8ce608551a4e0798f10098d23e804dd5b)
- Add new rating variables for text shadow, shadow color. Tweak styles for 2.0 [`03c8033`](https://github.com/fomantic/Fomantic-UI/commit/03c8033d67f54985add96b8e8e9b9a8d7e083b67)
- Adds ability to store name/value pairs for remote content [`f6f242c`](https://github.com/fomantic/Fomantic-UI/commit/f6f242cbda7766773dc486825dca6a845d695638)
- #3616 Adds autoInstall option to semantic.json, modifies installer to return correct questions object in autoinstall [`487c5cc`](https://github.com/fomantic/Fomantic-UI/commit/487c5cce539acee90ac5f56303a497cf874c0017)
- Adds large screen only and widescreen only grid variations #2467 [`bd46b4c`](https://github.com/fomantic/Fomantic-UI/commit/bd46b4ce1e22922bddf61d869b75215bf3f1aca2)
- Adjust cache type to be called local to allow for standard caching choices [`421fdad`](https://github.com/fomantic/Fomantic-UI/commit/421fdadd7634be4b25d0ee536d0aa2fe8d93eb64)
- Shapes now animate height/width on transition [`6611821`](https://github.com/fomantic/Fomantic-UI/commit/6611821d2ec3a1678519ca4dd529c45511194b1e)
- Intermediary work on tagging [`4f6cd38`](https://github.com/fomantic/Fomantic-UI/commit/4f6cd3809ce09be39becc2f6afa9c7a15ae01492)
- Adds #2060 Keyboard selection now works with all selection dropdowns, not just search [`145fa92`](https://github.com/fomantic/Fomantic-UI/commit/145fa9201ac28656cb1d98adf51d4314f4bae616)
- Add useLabels setting, and add templated text values for when not using labels in multiselect [`475fb9b`](https://github.com/fomantic/Fomantic-UI/commit/475fb9bf93847b203dec8e09f62339a9549fd530)
- Add observe change setting sticky [`ca323e6`](https://github.com/fomantic/Fomantic-UI/commit/ca323e62183a3282bf805e6df98b4f302e565aa6)
- Form Data Set [`644daec`](https://github.com/fomantic/Fomantic-UI/commit/644daecfc2cb908929be9e188711ed09c307cddd)
- Adds upward dropdown variation #1146 [`04d65e7`](https://github.com/fomantic/Fomantic-UI/commit/04d65e7483d1ac935ea9bdbb44996a4d0b876857)
- Ensures actual utf sorting. [`1207e42`](https://github.com/fomantic/Fomantic-UI/commit/1207e4278b9ef272880619b5c6db1465455911cc)
- #3001 Fixing all default prompts to use name [`ad62a7f`](https://github.com/fomantic/Fomantic-UI/commit/ad62a7f26111d7a9b1fda0cf4c514a66d82a4b41)
- Fix responsive styling on steps with flexbox [`bf32621`](https://github.com/fomantic/Fomantic-UI/commit/bf32621d683a2b8f969b8ba7ae360f9369ef8b53)
- #2366, rail now uses border-box to ensure that height matches container by default. Added sizing variables for calculating width with padding [`c6a5e97`](https://github.com/fomantic/Fomantic-UI/commit/c6a5e97eed1c26b85e1cc7fb586b03f5e836a1c0)
- #2366, fixes when sticky content is larger than context height. Fixes margin bottom not clearing when pushing: true [`629eeff`](https://github.com/fomantic/Fomantic-UI/commit/629eeff8928b89168142fbaaa226c03bc19475a0)
- #2280 complete global variables, adjust neutral saturation on hover/down/active [`0b10a55`](https://github.com/fomantic/Fomantic-UI/commit/0b10a5503461ebecaf1e28510083e84b776b3859)
- #1724 Implements dropdown automatically changes direction when off screen using visibility api coupling [`58544f6`](https://github.com/fomantic/Fomantic-UI/commit/58544f6ca3413ccda04471609d255003f6192c83)
- Add pageup and pagedown, fix selection on show for multi [`a7f2707`](https://github.com/fomantic/Fomantic-UI/commit/a7f27070632a3d5ff5c814ae03c5c444a60c97b7)
- Adjusts progress theme colors [`c59c017`](https://github.com/fomantic/Fomantic-UI/commit/c59c0176a6115bf91a259de22c2173c4b901ab47)
- Adds #1669, Dropdown will now recreate menus when option values change, dropdown will now produce errors when methods invoked on &lt;select&gt; and not ui dropdown [`4046863`](https://github.com/fomantic/Fomantic-UI/commit/4046863e37256943639a63bd80340ce52b7ad0e6)
- Begin work at converting hard coded em values [`ba7d428`](https://github.com/fomantic/Fomantic-UI/commit/ba7d4288a42614e388accef402c55577137d7106)
- #2383 Fix remove selected, and issues with placeholder selections being selected with multiple when value is empty string [`59ecddb`](https://github.com/fomantic/Fomantic-UI/commit/59ecddb1d54310146c6ed0a82d18dc6c957ca9f1)
- Add a new global text color variable, @mutedTextColor. Move subheader to muted text color. Remove orphaned and unused ui selection menu [`f91a260`](https://github.com/fomantic/Fomantic-UI/commit/f91a2604c3b4a61cdfa413c1ea3c153d77bd87b5)
- Fix NPM update to not install unless new version [`d67ca95`](https://github.com/fomantic/Fomantic-UI/commit/d67ca956fce477ff300c5b630e8a302d5e1eab4d)
- #1729, Order by UTF, add aliases, icon naming [`dc144c5`](https://github.com/fomantic/Fomantic-UI/commit/dc144c5e5e1a2e94da4a6d0c612b2bdf3cbac135)
- #2403, repacked dist/ [`2307123`](https://github.com/fomantic/Fomantic-UI/commit/23071232673d7c89d700162375768f856714cca1)
- RLSNOTES [`d9a1f09`](https://github.com/fomantic/Fomantic-UI/commit/d9a1f09e66b210958fdd4e191f03696e82245a46)
- Create global input variables and center all other valus around them [`12b27c1`](https://github.com/fomantic/Fomantic-UI/commit/12b27c1968e86a83c50efe45e07b8f2be4c54730)
- Flexbox feeds [`4a7868a`](https://github.com/fomantic/Fomantic-UI/commit/4a7868abc5695f2371f08318f0ead9c2b11fc811)
- #1681, Form now prevents keypress causing repeated form submit [`90992d9`](https://github.com/fomantic/Fomantic-UI/commit/90992d94b8e00a769ee0cf5ddc83be14bca7ab3c)
- Add new onScreen and offScreen callbacks for visibility [`eda7670`](https://github.com/fomantic/Fomantic-UI/commit/eda7670dde741c45516b63b61a1416d7136231d6)
- Iteration on embed [`25ba7f0`](https://github.com/fomantic/Fomantic-UI/commit/25ba7f03218b3b3567075ed963b73b2333c6e788)
- #2710 merge and modify this context [`09ecab6`](https://github.com/fomantic/Fomantic-UI/commit/09ecab67fc2f11a452b045e6530fae6e82067cbe)
- Add an automatic reinstallation process based on semantic.json [`8e272ac`](https://github.com/fomantic/Fomantic-UI/commit/8e272acb480acfd2c26f15cb7120c861f7ef6581)
- Consolidate UI input logic inside form [`705d289`](https://github.com/fomantic/Fomantic-UI/commit/705d289f1adde5542b35997f9486ca6a1f510e3e)
- Add body padding to examples [`699aeed`](https://github.com/fomantic/Fomantic-UI/commit/699aeed1584fd25f5a737eac5477957116b7ae7c)
- #2263, tweaking inverted pointing [`d16290e`](https://github.com/fomantic/Fomantic-UI/commit/d16290eb87ad16799ff2bb657b4bd6cb8b9598e4)
- Alphabetize input rules, add time type #1721 [`4ef796f`](https://github.com/fomantic/Fomantic-UI/commit/4ef796f6dcddc9ccc2958cb9270b283ec8a59d86)
- #1630 Adds form clear and dropdown clear behaviors [`7dffde0`](https://github.com/fomantic/Fomantic-UI/commit/7dffde0f825e723245d8415a14ec0497eaa60892)
- #2626 dropdown now updates selected values when input changes. Housecleaning with event binding [`12d6640`](https://github.com/fomantic/Fomantic-UI/commit/12d66408260db197659d8802deb27bccb5071ac3)
- Mark legacy grid variables [`aea4341`](https://github.com/fomantic/Fomantic-UI/commit/aea4341e1d4824e5f690b8c6c032f4fa0e0eb618)
- Add equal width grid [`e517219`](https://github.com/fomantic/Fomantic-UI/commit/e517219bfaa8612250ab45635a6a8cf3b944e77c)
- #3001 add support for more templated values [`4bb1d0d`](https://github.com/fomantic/Fomantic-UI/commit/4bb1d0d630bcaed1a1a5a3aa4827d9f291c45eee)
- Consolidate templatedURL behavior into one method [`f0dfe16`](https://github.com/fomantic/Fomantic-UI/commit/f0dfe16337a2eb025d61a8b2c4f87e17435a0d1b)
- Adds glass dimmers [`05877fe`](https://github.com/fomantic/Fomantic-UI/commit/05877fe905dc3992aa9bb258e6dd3f06a4a2f74f)
- Fix several issues with shape, but not all.. [`d31c309`](https://github.com/fomantic/Fomantic-UI/commit/d31c3094ec20ea6fdcd4db8b0d259d57dd12d1e8)
- Add clientside api caching setting [`f2ced9d`](https://github.com/fomantic/Fomantic-UI/commit/f2ced9db70a256ab8f56b82c26cdc17b366d1608)
- #3611 - Adds relative pixel variables up to 40px [`caad06c`](https://github.com/fomantic/Fomantic-UI/commit/caad06c30bffad5864fa807e0f6a5afc69292ba4)
- Resolve XHR error conditions for abort, with CORS [`d993d45`](https://github.com/fomantic/Fomantic-UI/commit/d993d45e90e8e4b057036f5403f84df804e15bc0)
- Fixes ui input sizing issues due to flex-box width collapsing being peculiar with &lt;input&gt; #2705 #2621 #2821 [`d7eaffa`](https://github.com/fomantic/Fomantic-UI/commit/d7eaffabae2330ad761b4e0f44f922b73fa0309e)
- #3475 - Adds deactivate setting for tab used to determine what elements user would like to deactivate when a tab is selected [`1b982e1`](https://github.com/fomantic/Fomantic-UI/commit/1b982e1842810506e04e7baea99f8963307ff4f4)
- #2637 fixes issues with placeholder [`1900729`](https://github.com/fomantic/Fomantic-UI/commit/1900729083f63b0a16e66644a041f654dfd67259)
- Fix language in rlsnotes [`c9e8a08`](https://github.com/fomantic/Fomantic-UI/commit/c9e8a089f339dda47bc646f5d730ae2aa44da0cb)
- Fix npm gulpfile [`d1fc358`](https://github.com/fomantic/Fomantic-UI/commit/d1fc3588af5503a367491402fc98120898a8bf50)
- Update rlsnotes [`8b41023`](https://github.com/fomantic/Fomantic-UI/commit/8b41023ab31286fca06f48fee9a9b0157810376b)
- FSearch: Fixes border radius, matching box shadow with global, increases vertical padding [`5eb6a48`](https://github.com/fomantic/Fomantic-UI/commit/5eb6a489b32d1df2fc863c3904f318d0d8312068)
- Adjust scale in animation globally, fade up/down [`4ed930f`](https://github.com/fomantic/Fomantic-UI/commit/4ed930f91c36261accd78fc0550400176d946db9)
- Add many new variables for label colors [`6954a93`](https://github.com/fomantic/Fomantic-UI/commit/6954a936b38ee580127754e9235b9f6e772e2360)
- #2842, Calling show results does not require input to be focused [`d649872`](https://github.com/fomantic/Fomantic-UI/commit/d6498722ec262ac467bc75152c767de271edf4a6)
- Github buttons are using compact style! [`a548b63`](https://github.com/fomantic/Fomantic-UI/commit/a548b6361be211ccefc2bb7648cc420f20d4ecd9)
- Fixing some conditions with checkbox double firing #2440 [`889b7cd`](https://github.com/fomantic/Fomantic-UI/commit/889b7cdff67bf716ff483d2ef0bc7961f428cec5)
- #2382 Increase code coherence, restructure into new methods [`e3d4347`](https://github.com/fomantic/Fomantic-UI/commit/e3d43478b980204005139807bb19c2cb50dc8130)
- #1612 adds deprecation warnings for old callbacks [`b50c7da`](https://github.com/fomantic/Fomantic-UI/commit/b50c7da845460799fcaaa8eba23974fcc30abc57)
- #2266, minCharacterLength should be part of query, not throttled input event [`f1b8455`](https://github.com/fomantic/Fomantic-UI/commit/f1b84555cb98998e395a8dcd9fff0b8563a48ca0)
- Feature: Form reset [`e079320`](https://github.com/fomantic/Fomantic-UI/commit/e079320083c5fc4398b6cb37e05d5b2edd6179ec)
- Fix formatting [`af8c4a5`](https://github.com/fomantic/Fomantic-UI/commit/af8c4a54549d4301fc51959c585881477313e3a4)
- Fix formatting [`f967c80`](https://github.com/fomantic/Fomantic-UI/commit/f967c80b3e4e4948b1ddb78c7717ddeebba3ff73)
- Add variables for setting prompt color inside form, update to new style #2593 [`c596630`](https://github.com/fomantic/Fomantic-UI/commit/c596630e1c791b7693e4aa5e56d89a4321be1564)
- Fix grid example [`0173292`](https://github.com/fomantic/Fomantic-UI/commit/0173292ce4fc6083333ea67f474a8b7cf08dec6b)
- Rebuild 1.7.0 proper [`18ba063`](https://github.com/fomantic/Fomantic-UI/commit/18ba063836f0d61ea6b26fd153493ed55089fe04)
- Adds response/responseAsync, fixes settings returned #3466 #3491 [`b2dd449`](https://github.com/fomantic/Fomantic-UI/commit/b2dd449f21bff1e4c07d510e8dbde17dbf95385e)
- Segments now use border not box-shadow, add new plural variations #2411 [`a34bd91`](https://github.com/fomantic/Fomantic-UI/commit/a34bd91704a144daba865cbfbfccccf5845cfb1e)
- Fixes clicking a[href] inside checkbox not working as expected #2804 [`d50538f`](https://github.com/fomantic/Fomantic-UI/commit/d50538fd707dc169a72ad7434828cc18729e047c)
- #2434 - Checkbox no longer need any init/for to work [`291f143`](https://github.com/fomantic/Fomantic-UI/commit/291f14367b33f9bf1b6c01182f850e96ed892b93)
- Fix API to use session storage for caching values so they are available across a session [`d951380`](https://github.com/fomantic/Fomantic-UI/commit/d951380b4048a2d88878e628dcd452d72579a96b)
- Adjust ribbon label padding to be more spacious [`a05a388`](https://github.com/fomantic/Fomantic-UI/commit/a05a38892b8839e5822f37f4e974ad727e74eb0e)
- Redo stackable grid divider to use table cell #2311 [`b7ccfa7`](https://github.com/fomantic/Fomantic-UI/commit/b7ccfa75f43b74344b7654256778a8115e76ba43)
- Fix hide delay being less than show delay causing elements not to hide [`a0ea788`](https://github.com/fomantic/Fomantic-UI/commit/a0ea788f167c516536e72825ba66003797313109)
- #2042 addes delegated events to dimmer [`cd4cced`](https://github.com/fomantic/Fomantic-UI/commit/cd4cced83a523d97cf4967dff619c471785bcd2b)
- Adds arrow bg colors [`e3bc0c5`](https://github.com/fomantic/Fomantic-UI/commit/e3bc0c52878cde38c5f33b8aaf62392c168576eb)
- Build 2.1.4 [`08d073d`](https://github.com/fomantic/Fomantic-UI/commit/08d073dd183ad4d793db7ac3122d4d36b06825ad)
- Adds arrow bg colors [`421d32a`](https://github.com/fomantic/Fomantic-UI/commit/421d32ac816c6a6b761e0b96fd8ee42d937c2cd7)
- Build 2.1.4 [`1cdfbd8`](https://github.com/fomantic/Fomantic-UI/commit/1cdfbd8bb69baa623fe6e524755b83c018b247ab)
- Add significant word order to label [`f6b1659`](https://github.com/fomantic/Fomantic-UI/commit/f6b1659282267edc321e9db0cbd8dd79e1f46b9b)
- Fix focus styles not applying to selected checkbox [`6bb04f6`](https://github.com/fomantic/Fomantic-UI/commit/6bb04f6b1167f65b3145ba918819c4205e41c6fb)
- Fix combo action [`af129c5`](https://github.com/fomantic/Fomantic-UI/commit/af129c52c9f3ca38d833d68749b8dcc8a5004744)
- Iteration on install [`fc3967b`](https://github.com/fomantic/Fomantic-UI/commit/fc3967b02cd6278e1b2c0308f817db431677649f)
- Fix issue with left/right floated [`d32ce3b`](https://github.com/fomantic/Fomantic-UI/commit/d32ce3b1a3b7fa55bbb959482e787ccea0ab4777)
- Fix issues with inverted secondary/tertiary segment, adjust lightness of inverted #2306 [`8f6a15a`](https://github.com/fomantic/Fomantic-UI/commit/8f6a15a323ce121df7a0d1ccec82648ab587de00)
- Modal now only closes on approve or deny selector match [`eb0e67e`](https://github.com/fomantic/Fomantic-UI/commit/eb0e67ed59acff47ce34716912bf593e6642e4ee)
- #2165 adds parseScripts option to tabs, defaults to once [`994fedc`](https://github.com/fomantic/Fomantic-UI/commit/994fedcca9eb22abe5a9924c812e6bb2f2c06ad6)
- Fix dot-file dep, add postinstall [`e3d8766`](https://github.com/fomantic/Fomantic-UI/commit/e3d8766078b00f17ed28152905b8503c402fc5fb)
- #2729 unimportant formatting [`643a330`](https://github.com/fomantic/Fomantic-UI/commit/643a3301e3eb18d67859951437bc7911cfd7c22e)
- Fixes autocomplete style inheritance for dropdown [`3264929`](https://github.com/fomantic/Fomantic-UI/commit/3264929572de59bb3e2552b637a971a715473d43)
- Fix all the linting errors i forgot to check [`b3612b2`](https://github.com/fomantic/Fomantic-UI/commit/b3612b2792b8f1c564838a3a62d6025bc20e95a5)
- Adds multiple regexp exp formats, cleans up some things #2133 [`86b1896`](https://github.com/fomantic/Fomantic-UI/commit/86b1896fa3b5afcec16a74f74fe187c29dc4e142)
- Restructure test/ for meteor #1607 [`8afab4a`](https://github.com/fomantic/Fomantic-UI/commit/8afab4af8d6c19e047c1986884250b5d69cba94e)
- Fix dropdown direction: auto, to open downward when no space above or below. [`625c1a4`](https://github.com/fomantic/Fomantic-UI/commit/625c1a46b2f6e7477873f36256ed653a6f07215f)
- Adjust stripe color [`7ea65c0`](https://github.com/fomantic/Fomantic-UI/commit/7ea65c018db9d32fd7c5b13c0e03403deed6cacc)
- Add fix for restoring labels [`14014ef`](https://github.com/fomantic/Fomantic-UI/commit/14014ef4b506f826a00313208a9873c6493be6c1)
- Add visibility check back to can show #2842 [`2e27d00`](https://github.com/fomantic/Fomantic-UI/commit/2e27d00a97795c7f9fee5f6f04c94a78ee592d71)
- Rebuild dist [`2b568a3`](https://github.com/fomantic/Fomantic-UI/commit/2b568a30a48742b94d2251131613aec82c214d57)
- Container widths are now based off min gutter width [`3cd1049`](https://github.com/fomantic/Fomantic-UI/commit/3cd104968df25849618f9a7b876c17a839f924d5)
- Adds reverse order variations for grid [`0c8ef1c`](https://github.com/fomantic/Fomantic-UI/commit/0c8ef1ccbbc7f516a8bcae46835a6761f3f2e0c0)
- Fix horizontal align with image/icon in list [`faa17ec`](https://github.com/fomantic/Fomantic-UI/commit/faa17ec883c2dc4e78c7926aaee4f70bbc4188c8)
- Swaps out all calls to trigger() #3108 [`2bae116`](https://github.com/fomantic/Fomantic-UI/commit/2bae11673d1752a0c2379c9b683427a052d5936b)
- Swaps out all calls to trigger() #3108 [`e5aca0a`](https://github.com/fomantic/Fomantic-UI/commit/e5aca0a5237126759a6d2fc248963fb8470ddfcd)
- #2579 make form identifiers optional [`3b109b2`](https://github.com/fomantic/Fomantic-UI/commit/3b109b2ed60cc973f52a4505dc6887f759042490)
- Add example for attached header, fix issues with attached header given new attached system #2798 [`66e46f5`](https://github.com/fomantic/Fomantic-UI/commit/66e46f5a0a8ed07894701920ca5a21fbb9de961b)
- #2308 Refactor as getters, to allow public API for retrieval [`544e92d`](https://github.com/fomantic/Fomantic-UI/commit/544e92d279c501e0ee8cdd922943d4bc903550b8)
- Fix keyboard selection after multi remove, settings comments [`bcc4809`](https://github.com/fomantic/Fomantic-UI/commit/bcc48092370ac18b05d231724c62b363f96d1429)
- #3193, renames scroll to scrollContext for clarification internally, adds fits check [`697fcfe`](https://github.com/fomantic/Fomantic-UI/commit/697fcfe326c40c01aea3097e9a0e76de9992e4cc)
- #3193, renames scroll to scrollContext for clarification internally, adds fits check [`9856d4b`](https://github.com/fomantic/Fomantic-UI/commit/9856d4bb414dc5097c11f6b5e9604cf81bb06797)
- rebuild dist [`45b00a5`](https://github.com/fomantic/Fomantic-UI/commit/45b00a566d417e42316f1391c2b7bf272277c7bf)
- Add disabled item, remove disabled selection from dropdown [`2275f2b`](https://github.com/fomantic/Fomantic-UI/commit/2275f2b0967b9435ca5acadc444f82b1389c8026)
- Adjusting themes to match with changes in 2.0 [`7f4b39f`](https://github.com/fomantic/Fomantic-UI/commit/7f4b39f4ebc8eaef7ad01eb304314cb4d2e6e161)
- Adds fixes for sidebar inside context other than body [`caf76a7`](https://github.com/fomantic/Fomantic-UI/commit/caf76a7f1f0c6a0a02bf9ba0be8b4578b8a12134)
- #2426, onSelect did not correctly attach result metadata with category search [`a988e3e`](https://github.com/fomantic/Fomantic-UI/commit/a988e3e858f81b7fc7d054fcb3cd42ac8ef5b4a1)
- Cards can now have multiple content blocks, images not on top [`8147a77`](https://github.com/fomantic/Fomantic-UI/commit/8147a77e28f0daea908e962e0754038446f52a20)
- Set all modules to verbose: false by default [`6f1bf2e`](https://github.com/fomantic/Fomantic-UI/commit/6f1bf2ea897d98e0e41334211970b3f545bef67e)
- #3710 - Fixed issue with unnecessary padding on first and last items of divided and relaxed lists [`f10577c`](https://github.com/fomantic/Fomantic-UI/commit/f10577c4a390c417b03176b47cac1aa7380a56f6)
- Support modification of 'closable' setting while modal is open [`e444af2`](https://github.com/fomantic/Fomantic-UI/commit/e444af24834cacd43dd25a4a988b352025a541d3)
- Redo pointing label to use transform to avoid line-height issues [`44f1adb`](https://github.com/fomantic/Fomantic-UI/commit/44f1adb0a77fcd680ed8eabacfed93c488de394d)
- #2163, #2162. Create id now uses counters for index, in case results are returned as object instead of array [`1d481d2`](https://github.com/fomantic/Fomantic-UI/commit/1d481d23be975a08193a3ee33705a99d3ae2f9a2)
- Rework pointing / basic label for more accurate arrows [`b7667cf`](https://github.com/fomantic/Fomantic-UI/commit/b7667cfa5cdb9ef58cdc8205dfe4c974a06eb760)
- Adjust modal scale in animation to be more subtle [`64f0be8`](https://github.com/fomantic/Fomantic-UI/commit/64f0be8ee74106fd608ffd56ac58aa10b277607c)
- Slightly more efficient shape calcs [`21df81a`](https://github.com/fomantic/Fomantic-UI/commit/21df81ab40bbb88713a456f4242b3cca56f39a22)
- Basic colored button now grow their border size [`38949ab`](https://github.com/fomantic/Fomantic-UI/commit/38949ab2c16e1f862a0e595a142d0a4944a7535e)
- Adds useLabel setting, fixes search in menu [`e2f796c`](https://github.com/fomantic/Fomantic-UI/commit/e2f796c369b661062324195a39549fe9715b8b76)
- Arrows now use translateX/Y instead of @arrowOffset. Adds better arrow bg colors for pointing menu #1653 [`8de80fb`](https://github.com/fomantic/Fomantic-UI/commit/8de80fbc0e650f9dcd5477686c4694e08093f325)
- #2862 adds variables, and fixes spacing for sub menu in secondary menu and text menu [`1f74594`](https://github.com/fomantic/Fomantic-UI/commit/1f745948769ccb0d18bd6e03a9c588160b533541)
- #2440 continuous lineheight noodling [`859243f`](https://github.com/fomantic/Fomantic-UI/commit/859243fb60bb0db8cacae4a5411b6416e111eb97)
- Add instagram theme for card [`b410692`](https://github.com/fomantic/Fomantic-UI/commit/b4106926c93cdec5a0ddc8f395ecbc37a0e3d813)
- Adjusts message colors [`658792e`](https://github.com/fomantic/Fomantic-UI/commit/658792edd05d2380d988931a897a90aec012e41a)
- Add peer deps #3511 [`04a3c48`](https://github.com/fomantic/Fomantic-UI/commit/04a3c48a0dd3bd9b440b59036004409239a6db16)
- Fix links to github issues [`ae592a9`](https://github.com/fomantic/Fomantic-UI/commit/ae592a9f61c71410eab345d24fcd8b9167877106)
- Fix links to github issues [`b2ef3a8`](https://github.com/fomantic/Fomantic-UI/commit/b2ef3a8847adf8e147da185ae99b107cea22dd44)
- Work on ui input fixes [`0e127ea`](https://github.com/fomantic/Fomantic-UI/commit/0e127ea0b8476b8b6f0ca7d60412bcb37ae11725)
- #2656 adds missing function defaults [`8c98ada`](https://github.com/fomantic/Fomantic-UI/commit/8c98ada923af961f5c180134484c4b79d2773657)
- Sort rlsnotes [`7352849`](https://github.com/fomantic/Fomantic-UI/commit/7352849d25ebd330eacb1ce1e30e6fd51e995fb6)
- #2375 Remove number variations from button [`a7e4c00`](https://github.com/fomantic/Fomantic-UI/commit/a7e4c00e88ae857d93ffc328e733f906fdf4b712)
- Unlike other use-case, container should not have any left/right padding when inside a menu on mobile sizes. [`6f6a7f9`](https://github.com/fomantic/Fomantic-UI/commit/6f6a7f95b0e5a232115e1131ec811546afd921d2)
- Rebuild dist/ [`cc3077e`](https://github.com/fomantic/Fomantic-UI/commit/cc3077e59dcb632820af3634be874aab2e2ce382)
- Fix transition variables, adjust list padding to round numbers [`aea9953`](https://github.com/fomantic/Fomantic-UI/commit/aea99536f62723f8676418d45c257e1a14cdda91)
- #2214 Adds different[] validation, match not working correctly [`b9af864`](https://github.com/fomantic/Fomantic-UI/commit/b9af8643417b2bc59e4611995d02e36d86addcc5)
- Transition no longer determines vendor prefixes for animation-name prop. Removed 2 unnecessary prop lookups from animation increasing performance [`10a88eb`](https://github.com/fomantic/Fomantic-UI/commit/10a88ebef4dcc8fe9d4379e12389386fd78636ce)
- Add &lt;select&gt; support for adding user options [`732e22c`](https://github.com/fomantic/Fomantic-UI/commit/732e22cf3deb4a8ccb681af8f74994020f67d7a3)
- #2042 add delegated events to rating [`3520e51`](https://github.com/fomantic/Fomantic-UI/commit/3520e510be79a7bf56f33771c282fd6e905d7cea)
- Sort release notes a-z [`d70886c`](https://github.com/fomantic/Fomantic-UI/commit/d70886c92850ff1b3682726191cbd634cde96c7c)
- Added rubberband attention grabber from Animate.css [`be51cea`](https://github.com/fomantic/Fomantic-UI/commit/be51cea045cd5a7c19c772ce231ccdd58c94ff34)
- #3001 #2579, add new form validation shorthand, drastically simpler [`e364c16`](https://github.com/fomantic/Fomantic-UI/commit/e364c1658eb28f41f4d02655f454553d43abcb77)
- #2042 add delegated events to search [`3f44b1c`](https://github.com/fomantic/Fomantic-UI/commit/3f44b1cad7ec8d25cbf59e4dfa16732add098809)
- Make shortcut key values a setting #3016 [`4ca20c4`](https://github.com/fomantic/Fomantic-UI/commit/4ca20c47cf1071ed92fb508b13151c013a4a1f39)
- Make shortcut key values a setting #3016 [`474cc73`](https://github.com/fomantic/Fomantic-UI/commit/474cc7351bdcbfeab2a4719ceb671a99220e623b)
- Adds margin left/right 0 to stackable grid on mobile #2895 #2898 [`2c30d40`](https://github.com/fomantic/Fomantic-UI/commit/2c30d409c8b5dc2970c857a609b229e4b0b3c9c5)
- Fix remaining issues #2335 [`7242cc3`](https://github.com/fomantic/Fomantic-UI/commit/7242cc33695673b0e4f4fef37dc1844786321686)
- Bugs with remote [`6a95f19`](https://github.com/fomantic/Fomantic-UI/commit/6a95f1920beef05f28c52356956ae9a271908867)
- Adds fuzzy search to dropdown [`5abbcd5`](https://github.com/fomantic/Fomantic-UI/commit/5abbcd5351d9f1fe89c1b745b08a22d21ecd012f)
- Fix error with get xhr not returning promise, add abort method [`42cbd74`](https://github.com/fomantic/Fomantic-UI/commit/42cbd74d0233b70da4726f944c2ec3cf6a0fc95f)
- Radio fix + Form serialize function [`d5ad7df`](https://github.com/fomantic/Fomantic-UI/commit/d5ad7dfa16e179c0e67a59af84538daee0c24a41)
- Comments in API js [`6bc7758`](https://github.com/fomantic/Fomantic-UI/commit/6bc77583e942b50aef1593ae8c7ca5fe2999e781)
- #2479 Adds debug data for saving defaults [`c17e254`](https://github.com/fomantic/Fomantic-UI/commit/c17e254c966beaf445825fc29fa459d37755fab6)
- #2403 [Dropdown] Merge and organize metadata refresh [`913194c`](https://github.com/fomantic/Fomantic-UI/commit/913194ca6b53c89f94b2ceae387b871de88af135)
- Adds brown variables, re-orders colors some more [`1be0130`](https://github.com/fomantic/Fomantic-UI/commit/1be0130a72d318b6fc95d4c8791f76267376ba77)
- #1729 More icon renaming, aliases [`66c2412`](https://github.com/fomantic/Fomantic-UI/commit/66c2412137c91fc411018f90ee25c76fe138e418)
- Fix release notes formatting [`87566e9`](https://github.com/fomantic/Fomantic-UI/commit/87566e98eb5d3a19e1f51c01ce850aa37dcbd87b)
- Fixes issue with .data() storing/retrieving values as original type causing mismatch with .val() [string only] #2754 #2755 [`6c178d0`](https://github.com/fomantic/Fomantic-UI/commit/6c178d0168fa9bb37b430bc70302e9d53e350c4d)
- #2812, improve settings docs for accordion [`c9c81e0`](https://github.com/fomantic/Fomantic-UI/commit/c9c81e005fac4ed0133d94d29bbfa35b73436b48)
- Rebuild dist for 2.0 [`36b0695`](https://github.com/fomantic/Fomantic-UI/commit/36b06958e186020c91e72864542e5a194a01a289)
- rebuild dist [`5ce1780`](https://github.com/fomantic/Fomantic-UI/commit/5ce1780fbf8372015671151ecf5fd7eab7006367)
- Add examples to docs tasks [`4675aaf`](https://github.com/fomantic/Fomantic-UI/commit/4675aaf93e903b9055e63d9b040c6d64617cd9dc)
- Fix scrolling dropdown not to depend on a minimum width, calculate padding with scrollbar [`4e355a2`](https://github.com/fomantic/Fomantic-UI/commit/4e355a2afb3d2e48c5e5f6e53d8f3f29439a6ccd)
- Iteration on dropdown tweak list [`2198d01`](https://github.com/fomantic/Fomantic-UI/commit/2198d01247c01016f733f2741fa898d05f2f1c73)
- Revise clean/version tasks [`8b4c421`](https://github.com/fomantic/Fomantic-UI/commit/8b4c421711c86a22d9a8fc24d8e56b33f72e4080)
- Set transition duration to false by default, inherits from CSS [`3c9ea43`](https://github.com/fomantic/Fomantic-UI/commit/3c9ea4301e27f366cacd0081d7860b60b8f4330c)
- Adds missing doubling grid sizes #1671 [`92e8f8f`](https://github.com/fomantic/Fomantic-UI/commit/92e8f8f2e7280d730d9a5be298efb494ea0ca279)
- Fix search dropdown to allow input to support bgcolors (autocomplete), fix lineheight offset on input in search selection so bged inputs do not overlap borders #1508 [`4f8b806`](https://github.com/fomantic/Fomantic-UI/commit/4f8b80648da33cc11caa01e1f247302989e40ca5)
- Add file permissions and RTL to setup [`91ab032`](https://github.com/fomantic/Fomantic-UI/commit/91ab03268c93c74624005187873dbce501f85be2)
- Fixes issue where cache local was not working because debug code [`c34f6d3`](https://github.com/fomantic/Fomantic-UI/commit/c34f6d3462ba4f892fbeda296dd4d9dd72698c76)
- Update RLSNOTES [`7b364b4`](https://github.com/fomantic/Fomantic-UI/commit/7b364b438d12f9c282cfc68715c68c625d71318b)
- Updating examples [`7c2552c`](https://github.com/fomantic/Fomantic-UI/commit/7c2552c4c5443a5a23b59dff18113140bc4c2fa0)
- First pass simple material theme [`ea906db`](https://github.com/fomantic/Fomantic-UI/commit/ea906db4c53cd3bcff5b7eddb5f1a36483784a5c)
- Label now have default img styles [`6374ad3`](https://github.com/fomantic/Fomantic-UI/commit/6374ad3506db0121be9dc05bdc5f62de697c0f81)
- #1698 Remove set.value calls from actions, add set value to set selected. [`3cf2db6`](https://github.com/fomantic/Fomantic-UI/commit/3cf2db6a4bfe5994a59e8dbbac394680f2c1fff5)
- #3300 Fixes load order of very thin sidebar [`1062ce9`](https://github.com/fomantic/Fomantic-UI/commit/1062ce91101a4a532d191241c9152955535edf1b)
- Updates to themes from example repo [`adb7af2`](https://github.com/fomantic/Fomantic-UI/commit/adb7af2de948e93a533b0d3859301c4891a3b8f9)
- #2601 fix issue where popups with variations will not correctly recieve class names if pre-existing content [`f307ef2`](https://github.com/fomantic/Fomantic-UI/commit/f307ef2069165fe63b47714b9eab7c3cb86929fc)
- #2842 consolidate diners club [`d3b280b`](https://github.com/fomantic/Fomantic-UI/commit/d3b280b50063ab1203ea799ab81b0af21b50a9c2)
- Solves #1985, fixes scrollTop on mobile sidebar [`c68661d`](https://github.com/fomantic/Fomantic-UI/commit/c68661d913c2908a548167b95b2c8b84953d9f9c)
- Typo in form rule [`9db2175`](https://github.com/fomantic/Fomantic-UI/commit/9db217558e769d8bf0f2471bffb5c5687b9edfc6)
- Add tokenize on keyboard shortcut [`1afed3a`](https://github.com/fomantic/Fomantic-UI/commit/1afed3afb0aacb6675f71dee013adba67f647e60)
- Fix search removes filter before hiding [`960c82c`](https://github.com/fomantic/Fomantic-UI/commit/960c82cad21a9c71e452292464ab7a00fcb00506)
- Adjust input flexbox [`2362bf4`](https://github.com/fomantic/Fomantic-UI/commit/2362bf47af8f8a516fd086b596ec2ead2965a76b)
- Adds flexbox ui item [`a99af7b`](https://github.com/fomantic/Fomantic-UI/commit/a99af7b4934dc58ad15084a571a84d528c558239)
- Rebuild 1.7.0 [`008885b`](https://github.com/fomantic/Fomantic-UI/commit/008885b140f242176b260d785afe5e4bd4878ea7)
- Fixes indeterminate radio checkboxes in chrome, adds definition table new class names [`2e60169`](https://github.com/fomantic/Fomantic-UI/commit/2e601695e57db7b8d418bec220647f0915813314)
- Correctly adds #3179 [`4adad40`](https://github.com/fomantic/Fomantic-UI/commit/4adad40d8947840f1f575b3a3d9d5fe2d0f14541)
- Correctly adds #3179 [`0404ce5`](https://github.com/fomantic/Fomantic-UI/commit/0404ce536dacf64da6b604c8e54fcc2492ed718f)
- Fix 2.0 to be backwards compatible with emsize variables from 1.0 [`e160570`](https://github.com/fomantic/Fomantic-UI/commit/e1605707a237ee8c2cef3d40d25cdb89418e722b)
- Add dropdown direction [`136f912`](https://github.com/fomantic/Fomantic-UI/commit/136f912dc5283b43079aee82fff34039a18c0143)
- Add autocomplete styles for forms [`647af37`](https://github.com/fomantic/Fomantic-UI/commit/647af37473523b856688008a4b3aa643d0f1b04c)
- Fix errors in math from #2168 [`442839c`](https://github.com/fomantic/Fomantic-UI/commit/442839c3527ed3b28b6f96d971336e6bc684d27a)
- Add global form highlight color #1508 [`e8c1c9d`](https://github.com/fomantic/Fomantic-UI/commit/e8c1c9d966b30a86ccd3d0687ce2791c4ba9daef)
- Add fixes for table [`2176869`](https://github.com/fomantic/Fomantic-UI/commit/21768696e49b2099624919d5aff547c7b0a346bb)
- Make placeholder error color more consistent, fix input placeholder color #2786 [`b42aac8`](https://github.com/fomantic/Fomantic-UI/commit/b42aac829e13cedac9d24198eb0adc86571ff616)
- #2434 - Label no longer shows hand cursor unless initialized with JS, fixed destroy to return input z-index [`b42bcbd`](https://github.com/fomantic/Fomantic-UI/commit/b42bcbde1dbd20623cc52c3977b2656f6861f659)
- Slightly de-emphasize message border colors, fix emSize variable [`e17ed5b`](https://github.com/fomantic/Fomantic-UI/commit/e17ed5b1bc019e52ec70412b63870f9279931bed)
- Search will now create results container automatically, and add category search classname [`bb8a9f5`](https://github.com/fomantic/Fomantic-UI/commit/bb8a9f57eecf99b61fefe6b1443f5673e44042ff)
- Fuzzy search no longer evaluates true on numerical matches. Fixed 'get result' when id is falsey i.e 0 [`74e5adb`](https://github.com/fomantic/Fomantic-UI/commit/74e5adbbd570e6a9ed6021ecaf395109df5a03ec)
- #1645 Fix default component inheritance from defaults [`de4fef9`](https://github.com/fomantic/Fomantic-UI/commit/de4fef91e0b6737f67598bd2d6db158d11762a4f)
- Adds selectable cell [`44c078e`](https://github.com/fomantic/Fomantic-UI/commit/44c078e5ad4f24ea3e5624b832c7d47c33586131)
- Fixes bug where sticky would stick at incorrect times when using a different scroll container than  and when the container's  is not 0 on init. [`6073367`](https://github.com/fomantic/Fomantic-UI/commit/6073367a3c53a9c13381e9a91b65a6fa334ad2d2)
- Adds selectable cell [`ca9728a`](https://github.com/fomantic/Fomantic-UI/commit/ca9728ac82038f5bdacd6a186dc6cbb491c820cf)
- Fixes bug where sticky would stick at incorrect times when using a different scroll container than  and when the container's  is not 0 on init. [`b8a2ee8`](https://github.com/fomantic/Fomantic-UI/commit/b8a2ee8fb6a411e08e2f53e554c66ad582977aee)
- #2481 remove styles no longer neceesary with rating with flex [`524937d`](https://github.com/fomantic/Fomantic-UI/commit/524937d6e7654f13f27767215bb26c3d9e71f637)
- Fix &lt;select&gt; chained reference with dropdown init [`904caac`](https://github.com/fomantic/Fomantic-UI/commit/904caacb7afdcd99b5f05c993015f070cf886162)
- Rebuild [`33b2e8e`](https://github.com/fomantic/Fomantic-UI/commit/33b2e8ed3c5a2049b55143ac7b7e63a9d3b2d34b)
- #2308, Fix issue with metadata caching prop values [`be5ec63`](https://github.com/fomantic/Fomantic-UI/commit/be5ec6394bdc97c25ca2a2c21f2612159dd1db44)
- Fix bug with search input inside dropdown [`ccf830a`](https://github.com/fomantic/Fomantic-UI/commit/ccf830a6009bcf4a629b72ae9bf8d1971ab86781)
- #2959 - fixes issue with inheritance with alignment and some table conditions [`92e0ee2`](https://github.com/fomantic/Fomantic-UI/commit/92e0ee2c54945590e900210d172a165d12dfec4e)
- Fix parameters being encoded by default in tab, add encodeParameters setting to API #2752 [`1cac8a5`](https://github.com/fomantic/Fomantic-UI/commit/1cac8a53f910580d0df492f4e8c502c9f8699c66)
- Visibility: add ability to cancel callbacks, add new checkOnRefresh option [`cbdb60f`](https://github.com/fomantic/Fomantic-UI/commit/cbdb60ff5f73255eaca0a48b74c4619632fe1fef)
- Dropdown: Better coupling button/label [`83c9e79`](https://github.com/fomantic/Fomantic-UI/commit/83c9e79a4c0bfaf35fa72d3aef91180e56c3b8c1)
- Remove fallback js animations from modal [`6a76302`](https://github.com/fomantic/Fomantic-UI/commit/6a76302ce54d0d080f3ae12f00f64acf18fa8614)
- Fix selection min-height, fix pageup/down do not work when scrolling less than a page [`f77e001`](https://github.com/fomantic/Fomantic-UI/commit/f77e00174f29f2eef3581e965edf29ad2dd3213b)
- Fixing min-height issues [`586ff85`](https://github.com/fomantic/Fomantic-UI/commit/586ff85796bfbfa21b904256aed15acfe7c7f09f)
- Popup no longer uses backup transitions [`1a52cfe`](https://github.com/fomantic/Fomantic-UI/commit/1a52cfe0c19710363e9350c4947eb5e11ce00fce)
- Decrease dropdown transition duration, remove tweens on box shadow [`e897a18`](https://github.com/fomantic/Fomantic-UI/commit/e897a183500e7ae519830d9c65be2c8e6156c8d4)
- Final build of 1.7.0 [`dc4fab7`](https://github.com/fomantic/Fomantic-UI/commit/dc4fab7bcb1d2eb1ddd52f6c560713510626d7f9)
- Update rlsnotes [`76678c1`](https://github.com/fomantic/Fomantic-UI/commit/76678c13bf9be8a3c0da6e62085d16f50c47fb58)
- Forgetting implementing `both sides labeled` [`0d92b4f`](https://github.com/fomantic/Fomantic-UI/commit/0d92b4f6ac286c2bda5e089424348f2e681d1b5c)
- Fix bookish/chubby theme font size variables [`f063d65`](https://github.com/fomantic/Fomantic-UI/commit/f063d6504e93584b42b35149eaf204dbe4fd16b0)
- #2869 merges fix for :only-child border radius with stylistic changes [`d553e8d`](https://github.com/fomantic/Fomantic-UI/commit/d553e8d4ff79dd35eb9211aa595a1c55eaf5208f)
- Embed- fix icons to work with other icons than 'play' [`815d528`](https://github.com/fomantic/Fomantic-UI/commit/815d5284e1aeb9333a64c942f5c1f2e2703938e9)
- Tab now correctly navigates to in page anchors in closed tabs [`856ba0a`](https://github.com/fomantic/Fomantic-UI/commit/856ba0ad298694cd8e219893490cdb0221029460)
- Fix valign on list automatically affecting content/image [`1adaa99`](https://github.com/fomantic/Fomantic-UI/commit/1adaa99e261db8767fa311361987838abb01753c)
- Expand on basic example [`bed2cda`](https://github.com/fomantic/Fomantic-UI/commit/bed2cda48bf641236beea40b728b01543541da20)
- Add spaced variation [`dfa7823`](https://github.com/fomantic/Fomantic-UI/commit/dfa78238a3c89a7bd003d36ef0d9806c6d69c691)
- #1753, Dropdown arrow is now clickable to hide dropdown in search selection dropdown [`3cb07f0`](https://github.com/fomantic/Fomantic-UI/commit/3cb07f0c8547ff665d31b690a878069f5791e29c)
- #1630 - Formatting on form serialize [`1bb3fe0`](https://github.com/fomantic/Fomantic-UI/commit/1bb3fe04ef263a5c2a33b1867ae6f1994961f0ab)
- Fixes poorly written config code #2920 #2875 [`4f01c14`](https://github.com/fomantic/Fomantic-UI/commit/4f01c14faaf5a35dd9cca4ac234c55565cefc100)
- Update rlsnotes finish #2769 [`d4a22d0`](https://github.com/fomantic/Fomantic-UI/commit/d4a22d0347b3822df4889bda8f8da9344c1a3ba7)
- Readme [`91aa157`](https://github.com/fomantic/Fomantic-UI/commit/91aa157f8a5a49b1ab1f931543cfb97c2614d94c)
- Update homepage example [`e86f40e`](https://github.com/fomantic/Fomantic-UI/commit/e86f40eea74af41fbe52a2555201be7f0938f5b9)
- #703 Adds form 'is valid' method [`9dabc86`](https://github.com/fomantic/Fomantic-UI/commit/9dabc86487dc49834b0cfc2f6d2688f84efff223)
- Fix some line height values to be exact px [`fe17f8e`](https://github.com/fomantic/Fomantic-UI/commit/fe17f8e35dcb7377cae3a4fea4acc48f6eabae1b)
- Update rlsnotes [`2ea04a3`](https://github.com/fomantic/Fomantic-UI/commit/2ea04a327243bb615983942f6336095449afe93a)
- Fix radio/checkbox output from serialize caused by formatting changes #1630 [`3de207e`](https://github.com/fomantic/Fomantic-UI/commit/3de207e0ad7a6a189a68d5e1099a0d44f574f6e1)
- #3712 - Fixed issue with rating firing onRate on initial load [`44837fa`](https://github.com/fomantic/Fomantic-UI/commit/44837faf5793fdfc7394e9a0fbc3ced5e701d73e)
- Fix some conditions which caused dropdown to hide all results [`a2347d6`](https://github.com/fomantic/Fomantic-UI/commit/a2347d68b771ec42c37ea1a3db0fd00c576f6e1b)
- Fix some conditions which caused dropdown to hide all results [`125e222`](https://github.com/fomantic/Fomantic-UI/commit/125e22295e7583d0077b0a4429f115d0c9198ca9)
- Rlsnotes [`765e400`](https://github.com/fomantic/Fomantic-UI/commit/765e40073fbe38ee9aab0502df82cb1063a4470d)
- Ribbon labels now automatically position inside tables #1930 [`9f17381`](https://github.com/fomantic/Fomantic-UI/commit/9f173819c68988e7ebd37d97e9a8450974d63dc5)
- #2836 add run sequence & formatting [`8814f05`](https://github.com/fomantic/Fomantic-UI/commit/8814f051729d42771e784cf66e778d796e5a67af)
- Fix hybrid &lt;select&gt; init [`223bd3b`](https://github.com/fomantic/Fomantic-UI/commit/223bd3b0fdcbc35d045df2206c818596e83e1925)
- #2486, Add @absoluteEM sizes to help clarify ambiguity in sizing, fix label sizing [`4f31c6d`](https://github.com/fomantic/Fomantic-UI/commit/4f31c6d7a2f484722644f310228ed26b813ea862)
- #2396, look for disabled values when initializing select [`3582d1c`](https://github.com/fomantic/Fomantic-UI/commit/3582d1cb35bddaf7cc705668f0dc8b90b5c601db)
- Clears up logic around corner labeled input #2361 [`27bf60b`](https://github.com/fomantic/Fomantic-UI/commit/27bf60be160528911e7e0f4c6328b7748b0efdd7)
- Fix overlap when selecting dropdown choice with keyboard when useLabels: false [`40bf2ce`](https://github.com/fomantic/Fomantic-UI/commit/40bf2cea3566fdfd1981f341d8b2114fc28c6ad4)
- Popup z-index going way up #1668. Add z-index variable for modal [`671948c`](https://github.com/fomantic/Fomantic-UI/commit/671948c25287ea3e0d135ee4a8eccd38193e81ee)
- #3311 - Adds better organization for mobile/pc/filesystem icons [`d103841`](https://github.com/fomantic/Fomantic-UI/commit/d10384137ce5768f85096b8f754299f7f77654d9)
- Update version and fix stupid order bug #3440 [`f9cb697`](https://github.com/fomantic/Fomantic-UI/commit/f9cb69737f1d9a0286f1b74ea913f7396aaa9e77)
- Add fixed table variation [`4d017c2`](https://github.com/fomantic/Fomantic-UI/commit/4d017c27e7623feb74d7e40bed2cfc8c79c317e2)
- Fix search to use rem, add additional sizes #2421 [`7c26f94`](https://github.com/fomantic/Fomantic-UI/commit/7c26f944d6f7bbc6dc6911b2ab68b002dc0a58e9)
- Resolved cache problem for data attributes of dropdown options. [`7325170`](https://github.com/fomantic/Fomantic-UI/commit/73251701549e3d502da83117bcf2b94ead54e966)
- #2299 fix conditions for RTL both [`283943b`](https://github.com/fomantic/Fomantic-UI/commit/283943bf5c0b39c85f54df82be962c8384e90487)
- Checkbox does not need to blur input on check #2254 [`3d01c07`](https://github.com/fomantic/Fomantic-UI/commit/3d01c076f7af041d7391ea54f8c8e6b1aab685f1)
- Move tasks config to somewhere easier to find [`4470d05`](https://github.com/fomantic/Fomantic-UI/commit/4470d050001a6e840b7df6c9ba2e9bf759827dcb)
- Tweaking card shadows [`5b4c5c6`](https://github.com/fomantic/Fomantic-UI/commit/5b4c5c617cb8a657ba259ddf53e9be07ece894fb)
- Fixes sub-menu spacing with dropdown + icon [`5b07ad7`](https://github.com/fomantic/Fomantic-UI/commit/5b07ad75db61718a5039d2a42f7e3846070d6e85)
- #1607 formatting [`db25fb6`](https://github.com/fomantic/Fomantic-UI/commit/db25fb6f166beab19df01f48d360cb5b2cdad4db)
- #3405 - formatting [`db38c17`](https://github.com/fomantic/Fomantic-UI/commit/db38c1723b05ec9ad2b5fd936ffd2c6fc63a0958)
- Grouping selectors [`ef529b3`](https://github.com/fomantic/Fomantic-UI/commit/ef529b3a1db8d769bba30ff0891d9d4a4669aacb)
- Adds decimal and number validation to form #2537 [`22b874a`](https://github.com/fomantic/Fomantic-UI/commit/22b874af755d7b00358dfc6026933671c7449f32)
- #2769 Fix logic in onHide, to only close when NOT false, add onShow [`81f50e0`](https://github.com/fomantic/Fomantic-UI/commit/81f50e0f7a2aae6e68683c17558b36e6bec0ce63)
- #2467 Add examples with stackable using (x) column row and (x) wide [`5704621`](https://github.com/fomantic/Fomantic-UI/commit/5704621d7337afee2ea5ff263c28b0407327194b)
- Rebuild dist [`406c54f`](https://github.com/fomantic/Fomantic-UI/commit/406c54fcb7ee8ee91175658815b7e6f3fb3ee242)
- Use slightly more performant triggerHandler for pub/sub [`ecbfa1d`](https://github.com/fomantic/Fomantic-UI/commit/ecbfa1de9391d51173e1901e6e2e3167a7f138f1)
- #2001 actually fix icon and positioning [`43d02ea`](https://github.com/fomantic/Fomantic-UI/commit/43d02eac54875065e1b9b0e2cf1553cc9257bd0e)
- Fix no results message when using scrolling menu [`432d39f`](https://github.com/fomantic/Fomantic-UI/commit/432d39f4e7416e3175db3e5a0565fa67eeed1d58)
- Moves all regexp to a separate settings object [`f552fdb`](https://github.com/fomantic/Fomantic-UI/commit/f552fdb90fd8aaeb986c289657a9145e897ce4e6)
- Update templated var names for meteor #1607 [`469a540`](https://github.com/fomantic/Fomantic-UI/commit/469a540bdee16f1ba55f4fe1d6ac4bb658b2448a)
- #3108 Adds native change to dropdown [`528a510`](https://github.com/fomantic/Fomantic-UI/commit/528a510d6ce17f58cde27352a3f9993dc3599f4a)
- #3108 Adds native change to dropdown [`03a0d87`](https://github.com/fomantic/Fomantic-UI/commit/03a0d87b148ad9770d459e8fb6ea28920f17bb68)
- #2645 adds fields array to dropdown [`ceb489e`](https://github.com/fomantic/Fomantic-UI/commit/ceb489e97654afd08c96b78349f21bec4c59c5a5)
- Deal with type casting in a consistent way [`c43ea73`](https://github.com/fomantic/Fomantic-UI/commit/c43ea73f7f0622441dc13cbee067ecbb1114c5b9)
- #2586 - Adds hideError setting, defaults to auto [`7ded1ac`](https://github.com/fomantic/Fomantic-UI/commit/7ded1ac6dade3907aed2e25b99973f8017626b1f)
- Remove unnnecessary properties leftover from days before flexbox grid [`55fb4d5`](https://github.com/fomantic/Fomantic-UI/commit/55fb4d56c7b77bf76c315cf680a09c600a24deec)
- Fix othersActive check missing some cases with multiple modals [`ba315da`](https://github.com/fomantic/Fomantic-UI/commit/ba315da43937543e7e68cf56b2dcd6ede342073b)
- Adds grey menu color variation [`3d233ec`](https://github.com/fomantic/Fomantic-UI/commit/3d233ec285da7fd53cd12531e5b7cc931a8e1649)
- Reverse ternary to allow falsey values to evaluate as no precision [`525a61d`](https://github.com/fomantic/Fomantic-UI/commit/525a61dff90373e866d5155dc3854aa92e6fc5c7)
- Update examples [`ea9762f`](https://github.com/fomantic/Fomantic-UI/commit/ea9762f8cee3fb40b6548dbfd6bf6a011a96aae7)
- Stub material theme, no content [`620d5b0`](https://github.com/fomantic/Fomantic-UI/commit/620d5b03171104fce7e2379e156e538e151e7d44)
- RLSNOTES [`9c2df0e`](https://github.com/fomantic/Fomantic-UI/commit/9c2df0eeaef3feb7d1e6ba54a05150424a287617)
- Fix feed font sizes [`32b007e`](https://github.com/fomantic/Fomantic-UI/commit/32b007ecdf1c6dc11a33739fd4f79583af405303)
- Finish rewrite of popup positioning #1605 [`81ab3b9`](https://github.com/fomantic/Fomantic-UI/commit/81ab3b98a6356f3bba5489681f0d3ede7464ef15)
- Relocate and better specify rule for step when only child [`8732d53`](https://github.com/fomantic/Fomantic-UI/commit/8732d53b583c06a7b0b7de88cc509611c6e90f60)
- Desperately trying to fix 1px offset based on line height valign #2440 [`d5ba1b8`](https://github.com/fomantic/Fomantic-UI/commit/d5ba1b8b522771ae37c73f1279c2890e9bd8dd9e)
- Resolves first/last margin on secondary menu [`142539c`](https://github.com/fomantic/Fomantic-UI/commit/142539cacb9fafaf0681b0605de6925df7fb7646)
- Fix vertical arrow flicker [`a80a32d`](https://github.com/fomantic/Fomantic-UI/commit/a80a32d5aa99f070fcc780af3591cae54c715398)
- Form Validation: fix reset/clear triggering validation on checkbox. Fix form validation requiring checkbox js [`3a98342`](https://github.com/fomantic/Fomantic-UI/commit/3a98342ec7d53e54c6d4c3abb912a3b2b9ba4a48)
- Minor re-ordering [`bdf1f0a`](https://github.com/fomantic/Fomantic-UI/commit/bdf1f0a387b4f0571af151fa2c4540162f681702)
- Rebuild dist [`d3e5dd3`](https://github.com/fomantic/Fomantic-UI/commit/d3e5dd3170df8c6ebcccd71de59996e7472900c1)
- Fix config load [`a11f709`](https://github.com/fomantic/Fomantic-UI/commit/a11f709391fe52748889f2929ad79cf50126a5e3)
- Add {left} value for progress text templates #1611 [`26a4e42`](https://github.com/fomantic/Fomantic-UI/commit/26a4e4280de6826deee76b3151c5aabe28f1463e)
- Add ability to get popup and change content with behavior [`36fc2ac`](https://github.com/fomantic/Fomantic-UI/commit/36fc2ac7ca93b15e1cf6fd15b12d3ccba332a049)
- Fixed inconsistency with `widescreen only` class [`0df9212`](https://github.com/fomantic/Fomantic-UI/commit/0df92126ef704885b81defadd3fc3b2f31cda02d)
- Add ability to get popup and change content with behavior [`cb12641`](https://github.com/fomantic/Fomantic-UI/commit/cb12641bdc79647bf2ed5f965391585d0218e998)
- Fixed inconsistency with `widescreen only` class [`5dbfaa6`](https://github.com/fomantic/Fomantic-UI/commit/5dbfaa6295d7d5dcdfd6f64ee4798149932dc497)
- Fixes ui list alignment in message #2958 [`ee33a7d`](https://github.com/fomantic/Fomantic-UI/commit/ee33a7d35f9a0a8045295442a72d16759b1903e3)
- Reveal modifications [`3da68db`](https://github.com/fomantic/Fomantic-UI/commit/3da68db432a4b009b9974e7be380b15d92423e1f)
- #2766, concatenated stream removes dupes [`2c74b56`](https://github.com/fomantic/Fomantic-UI/commit/2c74b56cc13620ed35a150247e14a83fd591dc5e)
- Fix rounded and circular image [`93d68c9`](https://github.com/fomantic/Fomantic-UI/commit/93d68c956a1033e3bce1a33ea06bab0a18a722ad)
- Segment now uses the global floatedShadow value for raised segment [`9e5bee9`](https://github.com/fomantic/Fomantic-UI/commit/9e5bee97e29b0d4605d104c8f80d0e3660d5b997)
- Use real flex for vertical menu [`883bcbd`](https://github.com/fomantic/Fomantic-UI/commit/883bcbda5ef0c5137bdf0bf4702f4b47b714b68e)
- Remove use of get() [`4765913`](https://github.com/fomantic/Fomantic-UI/commit/476591320fa1797ba3b1749db7682d563c4c3fc2)
- Fix warning color using background warning color [`80e529b`](https://github.com/fomantic/Fomantic-UI/commit/80e529b0b585d3dd007d16c9868d02e84006d1a8)
- Fix bad multi-edit on button #2280 [`ff60600`](https://github.com/fomantic/Fomantic-UI/commit/ff60600e2f761e417fe6d82b95965d0e6dcf27c0)
- Adjust default colors [`4ca5a2f`](https://github.com/fomantic/Fomantic-UI/commit/4ca5a2ff85c5d7159bbca1a5e5253069d48985f0)
- #2180 Remove repeat dom value lookups [`50ec6f7`](https://github.com/fomantic/Fomantic-UI/commit/50ec6f7b5ebf3ccebeb47b7651a4d6d3829fb7d6)
- Adds regexp form pattern matching #2133 [`f0e1227`](https://github.com/fomantic/Fomantic-UI/commit/f0e12276ace3ac64cc45c7968e16894e06a51197)
- Fix celled grid container sizing [`b465f28`](https://github.com/fomantic/Fomantic-UI/commit/b465f285093fccc2daa157e4e5a52757ed801fbd)
- Fixes height on scrolling menu, adds dividers [`6316407`](https://github.com/fomantic/Fomantic-UI/commit/63164074e2e8e93eded471920ad71c60a78023af)
- Update rlsnotes [`f47c73c`](https://github.com/fomantic/Fomantic-UI/commit/f47c73ce10a0224d1cd7c7b1738d0f9d343b1494)
- Remove some css values, add variables for disabled dropdown #1615 [`ef43c1e`](https://github.com/fomantic/Fomantic-UI/commit/ef43c1e379b4597c1c86acb3c655ac947d919b31)
- #3311 battery alises [`8a3a52e`](https://github.com/fomantic/Fomantic-UI/commit/8a3a52eeafe11de0872ad5afc53337607e7e721e)
- Fixes semantic.json version overwriting package version [`3d20d5e`](https://github.com/fomantic/Fomantic-UI/commit/3d20d5e9796e05cc100af73370173f3383cf1d81)
- #2635 Fixes issue with inverted active state not being defined, adds inverted focus state [`783b08c`](https://github.com/fomantic/Fomantic-UI/commit/783b08cbb66182e5c508f1e596a09e368f27f9ee)
- Fix issues with attached tabular with changes to segment [`cdcb13d`](https://github.com/fomantic/Fomantic-UI/commit/cdcb13d423aa2cda689eba2f0e036d8b8565c79c)
- Add content divider in default theme [`5c2ee54`](https://github.com/fomantic/Fomantic-UI/commit/5c2ee54c7c9465e8d018e3cb40783a5dfec35ec1)
- #2336 Add clearing segment variation [`2c801bc`](https://github.com/fomantic/Fomantic-UI/commit/2c801bcc16e3545280ea2984fc470e051d796899)
- Add #2260 to next [`e179975`](https://github.com/fomantic/Fomantic-UI/commit/e179975995ab35a5963cc5a35bfe1b84f65bc013)
- Fix dropdown issues with min-width [`cfe3b2e`](https://github.com/fomantic/Fomantic-UI/commit/cfe3b2ec5645e0f89d9263e9c6da6f4b682fce72)
- Remove use of :visible, fix backspace on tag when tag is user value [`7dd5089`](https://github.com/fomantic/Fomantic-UI/commit/7dd508946fc048fcb1b408129da89a1251f6d683)
- #2173, form does not allow immediate invocation of behaviors in 2.0 [`04c4fde`](https://github.com/fomantic/Fomantic-UI/commit/04c4fde067423dc438b7572dbb1d8e9036947953)
- #1687 Clicking on fixed elements no longer closes sidebar [`d5d0a25`](https://github.com/fomantic/Fomantic-UI/commit/d5d0a25069f31cf083b144eaad01603e0232aa5c)
- Fix undocumented components in theme.config.example [`16620b8`](https://github.com/fomantic/Fomantic-UI/commit/16620b81e049a99b4e54d50d04be7545a1cd1a5d)
- Complete integration of autocomplete on ui search dropdown #1508 [`218083b`](https://github.com/fomantic/Fomantic-UI/commit/218083b5a35861cbaf28e4c993d11ed158f2df48)
- More order. More. [`3ffbd81`](https://github.com/fomantic/Fomantic-UI/commit/3ffbd8193a27542d89828bd253b677e1bc828f36)
- added raised style [`89b77ba`](https://github.com/fomantic/Fomantic-UI/commit/89b77ba86cfd9ce43d6898527ac4cc925ed14cc4)
- Rlsnotes [`3f3ccdf`](https://github.com/fomantic/Fomantic-UI/commit/3f3ccdf7498ef6f22f656a395c72991222243a46)
- #2694 adds disabled state for input [`d6c6b68`](https://github.com/fomantic/Fomantic-UI/commit/d6c6b6896bf8ee2fa6bf4742c90fd43742f66c46)
- #2758 #2760 fix this context for transition callbacks [`0d23f97`](https://github.com/fomantic/Fomantic-UI/commit/0d23f9733568d501f29182650b2c94cd9b309510)
- Cherry pick #2816 for patch [`b340a56`](https://github.com/fomantic/Fomantic-UI/commit/b340a5659cc69776de4194ca6d5329c5a2981ea6)
- Fix vertically stackable grid spacing #2467 [`cd7bf32`](https://github.com/fomantic/Fomantic-UI/commit/cd7bf32a21e082a11ce364b57e1ebfaf91ce3efc)
- #2457 child selector for label causes sibings() selector to fail [`dee9d09`](https://github.com/fomantic/Fomantic-UI/commit/dee9d09a665470d4a885ec46df5b42a0ccdde317)
- Code formatting [`5889b94`](https://github.com/fomantic/Fomantic-UI/commit/5889b94b60faae05cedbd1022c65fc6b13b942d0)
- Fix breadcrumb em rounding [`9b2865f`](https://github.com/fomantic/Fomantic-UI/commit/9b2865f91667f5dc295cbee8b9403d5c674a56c6)
- Fix checkbox needs slower transition [`6213cbb`](https://github.com/fomantic/Fomantic-UI/commit/6213cbb5dbfccc05d322508a356bcac7f0769db3)
- Only set scroll position on selection dropdown, unnecessary tabindex [`4b07a2b`](https://github.com/fomantic/Fomantic-UI/commit/4b07a2bfb46cbfba4b83ace38632b9b876fd77df)
- Popups now have default sizing [`84c7449`](https://github.com/fomantic/Fomantic-UI/commit/84c744989aa002ab24f4ca950a7bad3bb54cea41)
- Fixes extend settings in some modules using old format [`9bfe781`](https://github.com/fomantic/Fomantic-UI/commit/9bfe781f50796ab1e6d0dca5d462e95763ba0152)
- Rename setting to evaluateScripts [`0417374`](https://github.com/fomantic/Fomantic-UI/commit/041737482525b48d4e71e1ef838adfe2cb8902ff)
- Adds menu coupling for ui message [`afff903`](https://github.com/fomantic/Fomantic-UI/commit/afff903c1d53065dccf84c441491fe119a12306f)
- Adjust link color, menu border, dropdown item font-size [`ad674dd`](https://github.com/fomantic/Fomantic-UI/commit/ad674dd7a3d61130c7594f53e4ebd23c3a11e6a7)
- Toggle checkbox now use primary brand color for legibility [`2a2a3cf`](https://github.com/fomantic/Fomantic-UI/commit/2a2a3cf8df7bd3ae7f30ca0f4198a5b2a32a6685)
- Ability to disable dropdown without destroy it. [`ed251dd`](https://github.com/fomantic/Fomantic-UI/commit/ed251dd226e86c9e9e35a64d9a3137048dc7c00f)
- Fixes createEvent to use same bubbling/cancelable settings as specified in spec [`83e2ef5`](https://github.com/fomantic/Fomantic-UI/commit/83e2ef579714635b4f98bf9e79c8442d0167a8f0)
- Fixes createEvent to use same bubbling/cancelable settings as specified in spec [`0905774`](https://github.com/fomantic/Fomantic-UI/commit/0905774143a3e106460883dad915d59251cbb722)
- Adds ability to use a different expected field group with API #3080 [`e5c5e09`](https://github.com/fomantic/Fomantic-UI/commit/e5c5e090f39b75b19d946433165de413aff8494b)
- Removes divider rules from form #3092 [`377dfe2`](https://github.com/fomantic/Fomantic-UI/commit/377dfe20b40e7efda7623eef9b63a3336ed63015)
- Implements onLabelRemove #3209 [`58e8f68`](https://github.com/fomantic/Fomantic-UI/commit/58e8f684aa9c03984f42709ea336e9976f8e2fc8)
- Adds ability to use a different expected field group with API #3080 [`89c3a44`](https://github.com/fomantic/Fomantic-UI/commit/89c3a44c4c6717ded54d0769e00dc7b0579a55b0)
- Removes divider rules from form #3092 [`1e64983`](https://github.com/fomantic/Fomantic-UI/commit/1e64983ac2e24edba0d5d34ed01944c0ec195a8e)
- Implements onLabelRemove #3209 [`61c8441`](https://github.com/fomantic/Fomantic-UI/commit/61c84411aa8ed475b462addcaeff721bf7f86f27)
- Adds fitted icon variation [`50decfb`](https://github.com/fomantic/Fomantic-UI/commit/50decfbd1b85107793f9959835cac91af8a5ac0b)
- Fix focus color on basic button #2264 [`8cfcf56`](https://github.com/fomantic/Fomantic-UI/commit/8cfcf568e1d0ca58a82ac833a438a17f593d3c39)
- Enable local caching in all modules by default, add release notes [`7fbf624`](https://github.com/fomantic/Fomantic-UI/commit/7fbf624b987bcd546aae74eeeec73eb6ac549af7)
- Popup, fix transform origin order [`becbb7e`](https://github.com/fomantic/Fomantic-UI/commit/becbb7ef814b74bd18c10e8b44747069a827db37)
- Migrate corner label coupling to input to be able to use variables #2361 [`3ec6bef`](https://github.com/fomantic/Fomantic-UI/commit/3ec6beffd4ea0cf0805317d9f2e68b5337398dcd)
- Popup- Add ability for onShow and onHide to cancel popup show/hide [`c1cc319`](https://github.com/fomantic/Fomantic-UI/commit/c1cc319b07d1c72991c7d863bea359141341a1b2)
- Fix specificity for column without row not overrriding grid [`7951b32`](https://github.com/fomantic/Fomantic-UI/commit/7951b32c19e9eefeefc86b51e3ad06fe68a967e7)
- #2294 fixes issue with icon line height on sizing [`1949377`](https://github.com/fomantic/Fomantic-UI/commit/1949377434499103d5e3d616a95e07c2007cc3b8)
- Fix secondary pointing 'right item' [`1653135`](https://github.com/fomantic/Fomantic-UI/commit/16531356350d4bd53d3db044303be954d38776a7)
- Fix loading dropdown rules [`dac96b4`](https://github.com/fomantic/Fomantic-UI/commit/dac96b485b1b3d01adb4b7612af03a570898c857)
- Drastically improve performance of scroll position on menu show [`363ad36`](https://github.com/fomantic/Fomantic-UI/commit/363ad3634a83a590d4fb93b497290e39c71a2b6e)
- Adds parameter to onApprove, onDeny #2191 [`c5877b6`](https://github.com/fomantic/Fomantic-UI/commit/c5877b670d146a2fe9a03e9e0555e8c2bf358c9a)
- Fix check install [`cce98f7`](https://github.com/fomantic/Fomantic-UI/commit/cce98f7b94ce12e8b3bb8ace61040298add34b2c)
- Adds equal width fields/form [`9de3e1f`](https://github.com/fomantic/Fomantic-UI/commit/9de3e1f897f634b13f964102ca5c65fba7f7e09f)
- Adds equal width fields/form [`c7554ad`](https://github.com/fomantic/Fomantic-UI/commit/c7554add96eb65b04a14e6201c4efa7173a7f7ef)
- Fix formatting with (x) column table segment [`80f1bd4`](https://github.com/fomantic/Fomantic-UI/commit/80f1bd450c50c889b690454b623d2eba4f0e6807)
- Support labels attached on both sides for input [`9b53954`](https://github.com/fomantic/Fomantic-UI/commit/9b53954f7727d659885e5b1a20c00cc897b68e79)
- Disabled fields disable pointer events #555 [`baaf91c`](https://github.com/fomantic/Fomantic-UI/commit/baaf91c85c79a6090747864225114c52d9dea9fd)
- Add colored items on inverted menu [`da55e02`](https://github.com/fomantic/Fomantic-UI/commit/da55e020559cc63c081bb995fe4192baa2274f0c)
- #2838 fixes missing variable grep, formatting [`d020528`](https://github.com/fomantic/Fomantic-UI/commit/d020528fedbe3e5093053f1d95960b36f34cb4e5)
- #2825 Fixes empty messages showing in form state [`8c82942`](https://github.com/fomantic/Fomantic-UI/commit/8c829425ea20746e087abdef7d39f65f9c746487)
- Links inside lists now use default styling, increases bullet leading [`4209cc2`](https://github.com/fomantic/Fomantic-UI/commit/4209cc2a09d7e381d4c01cbfb229bceee006e35c)
- Fix issue from fix earlier today with multi select selecting blank quote values [`a9c94a1`](https://github.com/fomantic/Fomantic-UI/commit/a9c94a197221debb6d2573a74f5c66e078c0a686)
- Remove indicating label colors [`1652f2c`](https://github.com/fomantic/Fomantic-UI/commit/1652f2c62fedeca7735f3f86e2d42e504a9068bc)
- Fix for #16644 - Safari iOS fix for canvas resizing affecting Chrome iOS display of fixed content [`fe7e04e`](https://github.com/fomantic/Fomantic-UI/commit/fe7e04e6ac7fa7962651d7a6a330c3fbe3be138d)
- Release notes and removing old rules #2361 [`9f38ef5`](https://github.com/fomantic/Fomantic-UI/commit/9f38ef58358148283a1f4d1d1c19c3504c66f2e7)
- Fix scrolling menu item height [`e5807f4`](https://github.com/fomantic/Fomantic-UI/commit/e5807f48aac0bdd7144a33c3743dd400ebbc8977)
- Add flexbox buttons [`65bb3a8`](https://github.com/fomantic/Fomantic-UI/commit/65bb3a8ce388a4d926f39e85e6e2f48d59b8bbce)
- Fix dropdown keyboard selection styles inside menu [`8680cad`](https://github.com/fomantic/Fomantic-UI/commit/8680cade64f0852d9aee2a66b5da2325a53a3f1b)
- Make fixed menu word order dependent [`c492ca5`](https://github.com/fomantic/Fomantic-UI/commit/c492ca58ddb7948f2bb1452cec3a2cf0e8cc9adf)
- rebuild [`97cb8af`](https://github.com/fomantic/Fomantic-UI/commit/97cb8af0181e779706ef64b7bf7b6525e3504358)
- Add RTL: both option [`535ad56`](https://github.com/fomantic/Fomantic-UI/commit/535ad5623dcf4a81386d51a59b9a6b3859a73411)
- Fix image label format [`1fd1b40`](https://github.com/fomantic/Fomantic-UI/commit/1fd1b404a09cc203c9c9f74f3c018e1e26d1f612)
- Update next rlsnotes [`747d983`](https://github.com/fomantic/Fomantic-UI/commit/747d983ccc41ef0df2303717b02026cb1ba24e6a)
- Fix buttons in action input, still 1px offset with buttons.. [`f347a66`](https://github.com/fomantic/Fomantic-UI/commit/f347a667a7751a67c2606bce28a79347c8332a84)
- #1683, iOS and Mobile match return false on 2nd+ matches due to use of regexp test [`2b79648`](https://github.com/fomantic/Fomantic-UI/commit/2b79648a11a56cda10c4838df295ff0ea5da92fa)
- Fix search results close when change browser tab [`913aa77`](https://github.com/fomantic/Fomantic-UI/commit/913aa7744fd8a80999bd8652ebc69c98e860a23d)
- #3040 rename transition error to be more reasonable #3040 [`2506edc`](https://github.com/fomantic/Fomantic-UI/commit/2506edc11ee56be638fe9919222cb0e4b7657116)
- Adds many rlsnotes [`d3e10e8`](https://github.com/fomantic/Fomantic-UI/commit/d3e10e873a34cf088341496cb7dcf1974579a895)
- Adds many rlsnotes [`e192d04`](https://github.com/fomantic/Fomantic-UI/commit/e192d043ed5cfae77c43bb876d23eb2d94d8545c)
- #2537 rlsnotes [`91d0bf3`](https://github.com/fomantic/Fomantic-UI/commit/91d0bf3b2265b276eb53d372d9f2561fd099a533)
- Adds #2808, vertical divider can now be used multiple times in a column [`a82cead`](https://github.com/fomantic/Fomantic-UI/commit/a82ceadede2a36fef3cd50a6d0da883931ec850a)
- Add compact segments [`38ca5e0`](https://github.com/fomantic/Fomantic-UI/commit/38ca5e0f025f019a27b7fdb8a483505fd3e4fd2b)
- Simplify debug on blur [`f3f2e7f`](https://github.com/fomantic/Fomantic-UI/commit/f3f2e7f50ee23aef2991a013395e081213bc0979)
- Make input autofocus faster [`edd8f79`](https://github.com/fomantic/Fomantic-UI/commit/edd8f7996e8cd3ef2aeb1c2a9c0b1402440f3d3a)
- Fix missing return from $.each in transition [`1270e03`](https://github.com/fomantic/Fomantic-UI/commit/1270e031fb26724faa664076410c1fa26a31458e)
- Prevent sticky from calling .offsetParent() on every method call by finding container only in init [`923e3d4`](https://github.com/fomantic/Fomantic-UI/commit/923e3d40cf0318df2402cec0494ec3e944c31725)
- Fix reveal transition duration [`1855ea6`](https://github.com/fomantic/Fomantic-UI/commit/1855ea66fed93d25585d43f6cc6a83e9f565df94)
- Fix loading dropdown button, duplicate loading state, similar #2295. Fix search inside menu does not clear search term on select [`1a5010b`](https://github.com/fomantic/Fomantic-UI/commit/1a5010b36e1373d658b6adcb5a127d24fc8d950b)
- Make sure sticky does not reflow when setting same scroll [`ddd8f79`](https://github.com/fomantic/Fomantic-UI/commit/ddd8f796a2690dbe6c49dadb30fcfd139bb1cee9)
- Update theming page [`d842e46`](https://github.com/fomantic/Fomantic-UI/commit/d842e46aa793d7284d3c7fc8fe17eae727cbae62)
- Ordered list does not invert number color. [`6addaf7`](https://github.com/fomantic/Fomantic-UI/commit/6addaf716033c6a6e97b7716b698464159f68681)
- Fixes keyboard nav when active item is in hidden menu [`56217fa`](https://github.com/fomantic/Fomantic-UI/commit/56217fad27ac19f9727e87ea1725810e664e8bd8)
- Clean up spacing #1627 [`00b9b9d`](https://github.com/fomantic/Fomantic-UI/commit/00b9b9d4a370d80a4fe36779221306807f9b2b03)
- #3388 adds unplaceable callback, fixes docs [`99b3228`](https://github.com/fomantic/Fomantic-UI/commit/99b3228a956569f06d0e44dc50f8c6cc83c25291)
- #3002, fixes tab index broken on selection dropdown [`77954a2`](https://github.com/fomantic/Fomantic-UI/commit/77954a298c465601e43589bc06ba542fe7803015)
- #3096, adds autocomplete off to init [`af43ede`](https://github.com/fomantic/Fomantic-UI/commit/af43edea8f19eddeae9472d6503c66fd3e22e972)
- #3002, fixes tab index broken on selection dropdown [`d85ce6e`](https://github.com/fomantic/Fomantic-UI/commit/d85ce6e20792485955bfd9a71843faf687326771)
- #3096, adds autocomplete off to init [`36c83c5`](https://github.com/fomantic/Fomantic-UI/commit/36c83c541f9158b48a9388a36564c10039d42250)
- Add sessionstorage support to nag module [`cf41b4f`](https://github.com/fomantic/Fomantic-UI/commit/cf41b4f1afcd27620eb2fd282b72e36e02aade90)
- Add mini/tiny icons [`34f748e`](https://github.com/fomantic/Fomantic-UI/commit/34f748efa6f1d2b0c6a1e1b73659620c2813aaa8)
- Labeled buttons now vertically align labels, adds more label varaibles [`3500e36`](https://github.com/fomantic/Fomantic-UI/commit/3500e369f99fdeab9d90db1f3f3bc910fd7083ad)
- Use hexadecimal literals istead of octal literals in install tasks [`a0e5980`](https://github.com/fomantic/Fomantic-UI/commit/a0e5980725cdb844be2fa4fa9b0a73aa2a75fedb)
- Add comments to button material theme [`612d868`](https://github.com/fomantic/Fomantic-UI/commit/612d86858997b7a2fecd9c90bda9fb46373ba65f)
- #2472 Add centered variation to card [`1ada042`](https://github.com/fomantic/Fomantic-UI/commit/1ada0429bf7ac0da47cd6d0fc3a7cd63bf7251d5)
- Remove border on fixed menu [`60e6d35`](https://github.com/fomantic/Fomantic-UI/commit/60e6d35d5e20991acd7c636cfbea72ccc245d980)
- Fix dividing rail variables [`21fd039`](https://github.com/fomantic/Fomantic-UI/commit/21fd03971d2bdeaf5b42d8d7b5f3b151214d5307)
- Fix theming example colors [`233a651`](https://github.com/fomantic/Fomantic-UI/commit/233a65159e3b879e51a30d0095fb59aaf40cca42)
- Fix border radius on last inline-flex item [`ce76685`](https://github.com/fomantic/Fomantic-UI/commit/ce76685fc066ea4cc3302b51eabe3692bdf2e1df)
- Update example [`cf9345a`](https://github.com/fomantic/Fomantic-UI/commit/cf9345a948bf298ed474cf61d21082384c67776e)
- Rebuild dropdown dist #2213 [`d6c21ca`](https://github.com/fomantic/Fomantic-UI/commit/d6c21ca7128aacb582bff74f6f3e4a47b9227f32)
- RLSNOTES [`dc40574`](https://github.com/fomantic/Fomantic-UI/commit/dc405747defb000dfa117e35799939b9c5b9977e)
- Disable feature detection on sidebar init [`3ea416e`](https://github.com/fomantic/Fomantic-UI/commit/3ea416eae3c73db3041b1a0b140a1f59b5326e6f)
- Fix page down/up scrolling page when not search selection, simplify letter select shortcuts (first value with letter only) [`af56587`](https://github.com/fomantic/Fomantic-UI/commit/af565875e86bbd3e8b8d9e46035005a42b73dfb2)
- Increase sticky performance with scroll [`187e68f`](https://github.com/fomantic/Fomantic-UI/commit/187e68f9a28fb73418978501c07349880a33c701)
- Tweaks to card/item sizing [`a663f2b`](https://github.com/fomantic/Fomantic-UI/commit/a663f2bdd75cd68e9ae59dc991f40a7f07d8811e)
- Update rlsnotes [`603da61`](https://github.com/fomantic/Fomantic-UI/commit/603da61c73d290a40a235f309d106fa38c20acb2)
- Some UI missing load override #1637 [`98afd22`](https://github.com/fomantic/Fomantic-UI/commit/98afd2230d435271c3596d5b2ebf793d3d0b7888)
- 1.6.4 ... grr [`e6ae08e`](https://github.com/fomantic/Fomantic-UI/commit/e6ae08eacb23beeb56ec071792e34f6d51507067)
- #3604 - fixes issue with right menu / item including margin when stacked [`c46c170`](https://github.com/fomantic/Fomantic-UI/commit/c46c1704c40c62013cdf586c579acfb9c3330fb1)
- #3655 Removes deprecated use of size() [`679ee67`](https://github.com/fomantic/Fomantic-UI/commit/679ee677725cb0ed234f0c136f1538b25c54a23f)
- Update release notes [`011840d`](https://github.com/fomantic/Fomantic-UI/commit/011840d036f8191aa4fab5ae3455772608c4eead)
- #3148 fixes default setting name for onEnabled to match typo name [`740b0d1`](https://github.com/fomantic/Fomantic-UI/commit/740b0d13e13bfb2eae4c353a0255bef3fbfec983)
- Fixed fields.url [`3035d47`](https://github.com/fomantic/Fomantic-UI/commit/3035d478bb91536c971d238971b6412c59f12652)
- Fixed fields.url [`6fce682`](https://github.com/fomantic/Fomantic-UI/commit/6fce6825ee959e45ff89e47639110140c49887d2)
- #2973 - fixes spacing on right icon inside labeled icon button [`ad4a057`](https://github.com/fomantic/Fomantic-UI/commit/ad4a057297dbe8066e00255c1c8c073735a9f093)
- Rebuild 2.1.3 #2956 [`6e27ec9`](https://github.com/fomantic/Fomantic-UI/commit/6e27ec9dc360839081bc2533753c28a53c3a604a)
- Rlsnotes [`8b0bf71`](https://github.com/fomantic/Fomantic-UI/commit/8b0bf718e8fc7bb3fec8fb1d89007f33b5ff5db2)
- #2824, Fix issue where single search selection would filter active item and not re-display on cleared filter. Additionally fixes issue with forceSelection not working on pageLosesFocus #2824 [`3a15983`](https://github.com/fomantic/Fomantic-UI/commit/3a1598356b745dd1f0c1fb33c6969eedd20cadf7)
- #2754, fix issue with not using correct metadata setting for label value [`506f96f`](https://github.com/fomantic/Fomantic-UI/commit/506f96ffd77afff06b25522cdfa88650a6c1d779)
- #2795, ignore change event on initial load when not fireOnInit [`bac6193`](https://github.com/fomantic/Fomantic-UI/commit/bac6193db40dc264172373e7c894d86641b73a9f)
- #2802 - add support for attr value in ordered list [`e0724cb`](https://github.com/fomantic/Fomantic-UI/commit/e0724cb51699335ad4e36cba0d1ae58a7705f53a)
- Add margin to steps [`eb8c1f5`](https://github.com/fomantic/Fomantic-UI/commit/eb8c1f5999e1b59a00a38602872941b749a8bc0a)
- Adjust some card variables [`e5186d5`](https://github.com/fomantic/Fomantic-UI/commit/e5186d553b5f9b95350b57f90ae89d71a4535fca)
-  #2316, incorrect show rules for message in form [`457f9c5`](https://github.com/fomantic/Fomantic-UI/commit/457f9c5868fce946a4ac74493655e7d4139f031d)
- Fix move reveal timings [`88d1581`](https://github.com/fomantic/Fomantic-UI/commit/88d1581b9f8e170db1c31e962533a06a5e6eecf0)
- Fixes issue with search selection tabindex, fix z-index of selection dropdown icon when autocomplete [`7b791f4`](https://github.com/fomantic/Fomantic-UI/commit/7b791f43bf9b3d7a3444d24874801489179d8d4f)
- Adjust fonts in site.variables [`faf0192`](https://github.com/fomantic/Fomantic-UI/commit/faf0192241db8cb00874f5e2e13c458e987eb857)
- Fix internally celled margin [`32940b2`](https://github.com/fomantic/Fomantic-UI/commit/32940b279ab1cd13bc37b5a86b40883e5f28b4b1)
- Commits dfa2e02 to 1.x, backports fix for column colors #2272 [`eee2c96`](https://github.com/fomantic/Fomantic-UI/commit/eee2c968c676ea7947aea6c71078385852886a8b)
- RLSNOTES [`d777f5a`](https://github.com/fomantic/Fomantic-UI/commit/d777f5a9edf606445893111ec5f74795467e6798)
- Fixes select chaining not invoking methods [`1821ae9`](https://github.com/fomantic/Fomantic-UI/commit/1821ae9fbc957c54c73fd9be8d4fcd797f24e83f)
- Update rlsnotes [`05bd4ee`](https://github.com/fomantic/Fomantic-UI/commit/05bd4ee3230532e0395a35a63a1ddf5f318d76ec)
- Adjusts breadcrumb spacing [`8f021e6`](https://github.com/fomantic/Fomantic-UI/commit/8f021e6a0b7e140b3dd5606b01c6acb5ed9b8f8b)
- Finishes math on ribbon triangle offset [`4a6d444`](https://github.com/fomantic/Fomantic-UI/commit/4a6d444f08553180e06ddc6d533baef6d1678446)
- Fix divider on vertical basic button group #1677 [`99a3ba2`](https://github.com/fomantic/Fomantic-UI/commit/99a3ba222a8a34a2f1d21b86b79df8d62874b80c)
- Update release notes [`5847a02`](https://github.com/fomantic/Fomantic-UI/commit/5847a02c9ce1e1e3831c9707afc789cfde3dc036)
- Update v for next [`2e3b34a`](https://github.com/fomantic/Fomantic-UI/commit/2e3b34a7f94379c3e75ef8fb4c5d41e32d41e9a6)
- Remove borked copy and paste job [`2a43f4a`](https://github.com/fomantic/Fomantic-UI/commit/2a43f4a96a07d9aab1810c901c5cbdaf08556114)
- 3311 - Modifies several aliases [`27dc1c7`](https://github.com/fomantic/Fomantic-UI/commit/27dc1c79aa5e063ca345613aa998ba7faa2b65c0)
- onLabelUpdate is now called with the current state [`06c32bc`](https://github.com/fomantic/Fomantic-UI/commit/06c32bc46ef9b9e4ec672ab7e0450c996a70d594)
- Fix issue with next timer not being removed on complete [`a6c03f8`](https://github.com/fomantic/Fomantic-UI/commit/a6c03f8565ed115ffbc97264ee46c2fcc18d869d)
- [Flag] Adding Scotland and Walles [`a912dd6`](https://github.com/fomantic/Fomantic-UI/commit/a912dd615075c6173deee70149c72b60687d3ace)
- Fix vertical inverted border radius [`2b4f415`](https://github.com/fomantic/Fomantic-UI/commit/2b4f415c1c580298f7a5aee945f1eb393e497ba9)
- Add .ui.form.fluid rule [`7203e99`](https://github.com/fomantic/Fomantic-UI/commit/7203e99fbf6a818a6f17fd0a431b2069ff255ce1)
- Fix placeholder text when useLabels: false and 0 selected [`ade6ab5`](https://github.com/fomantic/Fomantic-UI/commit/ade6ab536b5443ae2999537e2cdc4d01e9227b94)
- Fix using 'package' reserved keyword in JavaScript (ECMAScript 2) [`134ee18`](https://github.com/fomantic/Fomantic-UI/commit/134ee189345a9de97e3ed480041ebc6fa13b9e67)
- Minor dropdown formatting [`16ae41d`](https://github.com/fomantic/Fomantic-UI/commit/16ae41d83e0024d79e5d9ff4c64f80fe6c08d03e)
- Fixes calendar vendor styling in chrome being too damn tall #2704 [`650ed5a`](https://github.com/fomantic/Fomantic-UI/commit/650ed5a439c8c7decffb63dad74203091bc4e595)
- Fix scrollbar width in IE [`b19a687`](https://github.com/fomantic/Fomantic-UI/commit/b19a6873647fc5fa1a74dbcb21a77972a2ceb419)
- Update all dependencies [`9fd58ea`](https://github.com/fomantic/Fomantic-UI/commit/9fd58ea0bcef1fdab1d547d0f32578280c9cc3c5)
- Update notes [`d480d5e`](https://github.com/fomantic/Fomantic-UI/commit/d480d5e9ae8528f1efed2a7da74da836d89294c0)
- Fixes incorrect margin value on attached table [`8a1ba16`](https://github.com/fomantic/Fomantic-UI/commit/8a1ba16eef7e1609bfa6b7dd1bea3f104ecc81af)
- Fix header inheritance in modal [`6d48688`](https://github.com/fomantic/Fomantic-UI/commit/6d486888a6961ee7fd38261758df2ab038c61e6c)
- Chubby form theme [`fce4255`](https://github.com/fomantic/Fomantic-UI/commit/fce42557b814ad876e6a2efbd49157fd2e3cd61f)
- Fix some search inheritance [`0570887`](https://github.com/fomantic/Fomantic-UI/commit/0570887f2db70de0963e0cc786ee0bf460621e54)
- onFailure will now fire in API when XHR Error occurs [`af6934e`](https://github.com/fomantic/Fomantic-UI/commit/af6934e39a824ebaae54c7997903fdc5145f244c)
- Prevent looping for values in multiple if no values set [`fcd8f69`](https://github.com/fomantic/Fomantic-UI/commit/fcd8f6910802250064640d61a22c45b7e8cfe5dc)
- Fix issue with stackable menu not dividing items correctly [`8ca2d00`](https://github.com/fomantic/Fomantic-UI/commit/8ca2d00a1677f417679c01eedb39d32becb6a300)
- Add allowTouchEvents setting #2322 [`472af4d`](https://github.com/fomantic/Fomantic-UI/commit/472af4d86f33ddd05cf5e1e7e5d3cbdd9273db7c)
- Fix bug in nested icons in amazon button theme [`84ad0ea`](https://github.com/fomantic/Fomantic-UI/commit/84ad0eaf5a0f20c74ee4a0419320623630530de7)
- Fix last border on inline menus [`d8314fd`](https://github.com/fomantic/Fomantic-UI/commit/d8314fd659912c76dca1ede7c8fba748397145bd)
- Make modal mutation observers opt-in #2166 [`85282f5`](https://github.com/fomantic/Fomantic-UI/commit/85282f5a348f8ae14ef8b3a2527d2b67d82c8aba)
- Disable observe changes by default [`0c5c5da`](https://github.com/fomantic/Fomantic-UI/commit/0c5c5daf1bc6e4ef6f29c1a1b2e7b0da358a40b4)
- #2199 Fixes preventDefault called even without sub menu [`89c1138`](https://github.com/fomantic/Fomantic-UI/commit/89c1138cd1bf5fc273c16eef660328515a910de8)
- Fix misnamed variables [`554069d`](https://github.com/fomantic/Fomantic-UI/commit/554069d7ee7e8df1fc553e0908c8818c62d53404)
- Fix text menu sub menu position [`70797e9`](https://github.com/fomantic/Fomantic-UI/commit/70797e95ffc281be416968b59252fc62081ff725)
- Probably better var name #2139 [`c480422`](https://github.com/fomantic/Fomantic-UI/commit/c4804220aaf714908f3dc379b0fd85332268cc8e)
- Install [`d39cac3`](https://github.com/fomantic/Fomantic-UI/commit/d39cac35cca5084b12dc2a8b52a28da896c66702)
- Dropdown clear now removes selected value [`b86b5ce`](https://github.com/fomantic/Fomantic-UI/commit/b86b5ced8651b29060be941451ae93d3c4261a7b)
- Modify distance for bounce to max at 1440P [`d705787`](https://github.com/fomantic/Fomantic-UI/commit/d705787ad2bf9d4e0c6f33b0f7a8ac54dd5c76ad)
- #1619 fix columns to not be flex containers [`44328b5`](https://github.com/fomantic/Fomantic-UI/commit/44328b51d4b69747fa4ef5ca23ff5b7c6274d06f)
- Update version to 1.6.3 [`517e367`](https://github.com/fomantic/Fomantic-UI/commit/517e367dd9ecc35cde4265eeef444ac387e06847)
- Removes position: relative, from dimmable when set to 'body' #3692 [`09fa415`](https://github.com/fomantic/Fomantic-UI/commit/09fa415ef6cecaa462b51ced167364302eb26e49)
- Fixes margin on icon button right icon #3525 [`d9c88a0`](https://github.com/fomantic/Fomantic-UI/commit/d9c88a0de0b3d5fa2bf1f79602669e64b5e73e0a)
- #3122 fixes issue with loading form styles [`d34b18b`](https://github.com/fomantic/Fomantic-UI/commit/d34b18b661b8186df2235973f82337b24dbbd629)
- ADds #3131 [`8369a58`](https://github.com/fomantic/Fomantic-UI/commit/8369a5820969bf17b4a2d10e191dcd85f04ae9f3)
- Added the ability to cancel a modal hide from the onHide callback [`f0e2ec5`](https://github.com/fomantic/Fomantic-UI/commit/f0e2ec552659def180628b92236559fc327ec510)
- ADds #3131 [`c89ff7a`](https://github.com/fomantic/Fomantic-UI/commit/c89ff7ae6cdc7e1fb1815896f8a2f1b2fbd2ce4e)
- Added the ability to cancel a modal hide from the onHide callback [`b06b877`](https://github.com/fomantic/Fomantic-UI/commit/b06b8779cc7d309a38399bc76b71902397af61bc)
- Added ability to specify dropdown label text when using API [`81e269b`](https://github.com/fomantic/Fomantic-UI/commit/81e269bd6541d4fbc166f9f60685aba768b822a4)
- RLSNotes [`b3d5bbb`](https://github.com/fomantic/Fomantic-UI/commit/b3d5bbbcdb1aee3111ef0a121572fe873f87103d)
- Fix responsive fluid step [`bc8100a`](https://github.com/fomantic/Fomantic-UI/commit/bc8100a547fc6f2efd0a0d76d5319f09b4741caa)
- Reverse tab case sensitivity #2455 [`4b14d45`](https://github.com/fomantic/Fomantic-UI/commit/4b14d4501f8d00c95e5397ad68cadc80bce23639)
- #1483, Fix bug with webkit button rollovers. Remove stale code of unknown origin related to position:relative on hover [`adfd541`](https://github.com/fomantic/Fomantic-UI/commit/adfd5417504e777985fc171e116e5c1cf08007f9)
- Fixes last scroll position not clearing on ui sticky when using refresh [`f016798`](https://github.com/fomantic/Fomantic-UI/commit/f016798c67be5943bae3a5553688b5976bdefb55)
- Add additional background variables to button [`9ff0d90`](https://github.com/fomantic/Fomantic-UI/commit/9ff0d90d6a099e86273a1e09e82c0baa6f7e1e7d)
- Fix vertical flex align [`4695e6b`](https://github.com/fomantic/Fomantic-UI/commit/4695e6ba837f2ce064271bf6dc90eef9310c9546)
- Fix border radius on first item of attached menu [`5c54940`](https://github.com/fomantic/Fomantic-UI/commit/5c54940a949281598eaedf9c0ed37d084d910acb)
- #2374, Dont set height of textarea with rows set [`f2623de`](https://github.com/fomantic/Fomantic-UI/commit/f2623de766a27fe2188bb756cb7f438f33a3f5d0)
- Icon menu should be auto width when vertical [`ea250f3`](https://github.com/fomantic/Fomantic-UI/commit/ea250f3704544e30576b4cdbda2f1b443b685b4c)
- Add transform origin to search [`30ec470`](https://github.com/fomantic/Fomantic-UI/commit/30ec47021ea9b195f21d71768c156d1d248947a4)
- Uses floating shadow for popup, fixes mobile issues with reflow [`0e883ff`](https://github.com/fomantic/Fomantic-UI/commit/0e883ff404d58d800d8d525bf5f7b442abb9fe90)
- Double vertical spacing on vertically divided grid, remove body &gt; grid fix [`8b716df`](https://github.com/fomantic/Fomantic-UI/commit/8b716df1ad11e88a92702fc50148b34335a08927)
- Add fluid container variation [`72a1216`](https://github.com/fomantic/Fomantic-UI/commit/72a12168c7a9d960370c0d5321e41a5121aaa71c)
- Update statistic.less [`d6f75ba`](https://github.com/fomantic/Fomantic-UI/commit/d6f75ba1e72a9033d0e530001b416f7353953b70)
- Example formatting [`4a4bcdc`](https://github.com/fomantic/Fomantic-UI/commit/4a4bcdc37004d757a945d99003d3675a2c9a3328)
- Styling on example [`8cf0adb`](https://github.com/fomantic/Fomantic-UI/commit/8cf0adb8cd1d8592905baac36bc760bd35f38963)
- Use slightly more performant triggerHandler, fix RLSNOTES [`747fe4b`](https://github.com/fomantic/Fomantic-UI/commit/747fe4bef8a1becfe87f14633d9b7ab47054f463)
- #2143. Using title in injected styles causes issues... for some reason? [`3d92ed9`](https://github.com/fomantic/Fomantic-UI/commit/3d92ed9c20c9f56b027757ce3740cddcf14bd877)
- Update button focus styles [`4ec4fd1`](https://github.com/fomantic/Fomantic-UI/commit/4ec4fd1dddb58c95c9b0ad9d2dd28e891e4faa5e)
- Add onRequest callback #1736 [`b8fd93b`](https://github.com/fomantic/Fomantic-UI/commit/b8fd93ba7b0f53c9885813b4e30db4582ad8fb0b)
- Add #1711 Remove text-align from grid column [`334fa87`](https://github.com/fomantic/Fomantic-UI/commit/334fa871bc4171cf83570838c981f261f9a22004)
- Renamed 'rubberband' transition to 'jiggle' [`22097b9`](https://github.com/fomantic/Fomantic-UI/commit/22097b96069bbf3db684fe5b4531c8cf0c39ce66)
- Embed: only add question mark when parameters are set. [`8adc755`](https://github.com/fomantic/Fomantic-UI/commit/8adc7553e6de3f21a7fc5bd2d9ab2555099e0c95)
- Final 2.1.8 [`118bf89`](https://github.com/fomantic/Fomantic-UI/commit/118bf897ae84630ee390e97fc7279b7eb6c7b629)
- #3405 - more formatting [`0a84ca0`](https://github.com/fomantic/Fomantic-UI/commit/0a84ca0b703a09279aaf323f04af21d7470ab4d4)
- Even more order. [`0a87a75`](https://github.com/fomantic/Fomantic-UI/commit/0a87a751bec2a57aa8ee928dff8cd5ff39ff7750)
- Dropdown settings comments [`eb65cc3`](https://github.com/fomantic/Fomantic-UI/commit/eb65cc39cbcb670e8518844dccb7e16fb3f158e7)
- Build 2.1.0 [`fb0ebe2`](https://github.com/fomantic/Fomantic-UI/commit/fb0ebe29d77bd65268dec216f537c5f94c07e62e)
- Finish release notes [`9797fec`](https://github.com/fomantic/Fomantic-UI/commit/9797feca5a3ac234c4ca3ba2e7f6b7837458e16c)
- Fix margin in secondary fluid menu [`3e7575d`](https://github.com/fomantic/Fomantic-UI/commit/3e7575ddde466459607c69be9675435008bd1b4d)
- Details [`326e1df`](https://github.com/fomantic/Fomantic-UI/commit/326e1df31bd1de4cf4085faa194feb4fd836ea38)
- Fix scrolling modal spacing on mobile [`43b488f`](https://github.com/fomantic/Fomantic-UI/commit/43b488fcb66b0e0da46f43946828618bf04d55d6)
- Add yaml and map-stream as peer deps #2453 [`6ba18a8`](https://github.com/fomantic/Fomantic-UI/commit/6ba18a8ddd1bbc75fe8cfe52f37134e9ae8d07b5)
- Adjust step example [`c28353a`](https://github.com/fomantic/Fomantic-UI/commit/c28353a53b8af20d44ea5f2891ba0c312fe34c8a)
- Fix issues with mocking caused by get templated url rewrite [`167faba`](https://github.com/fomantic/Fomantic-UI/commit/167fabad187081ec4b618ebb632a817a51ef6fd1)
- Fix issue in scrolling menu width in some cases [`6dedf83`](https://github.com/fomantic/Fomantic-UI/commit/6dedf83e8c6636ef46ce3ca40f52cd5cf97f512d)
- Fix rounding of icon margins [`b39fadc`](https://github.com/fomantic/Fomantic-UI/commit/b39fadcf3b1e1aafd41cabda319f681baf5f42fe)
- Make rating flex [`89969f8`](https://github.com/fomantic/Fomantic-UI/commit/89969f8cf3a23063574289f9e66a2a9d4cca3a96)
- Fix unnecessary classes in examples [`212d9da`](https://github.com/fomantic/Fomantic-UI/commit/212d9da67e95fed357ff298862f2264633b0bd1a)
- Speed up get.item when null or undefined [`66ee664`](https://github.com/fomantic/Fomantic-UI/commit/66ee66477c6b66f82b3d66ea168bce024f922ba9)
- Add back in menu transition [`08fa823`](https://github.com/fomantic/Fomantic-UI/commit/08fa823e6d406cd89f3f36920135da329643f8d6)
- Adjust info colors slightly [`8d04937`](https://github.com/fomantic/Fomantic-UI/commit/8d049370c6a6788189d23f84b8df1d0d51d1b481)
- #2259 - Fix get selection value returns 1 when null [`01e9f39`](https://github.com/fomantic/Fomantic-UI/commit/01e9f39242d4afa8a8b738ee060dbe750c6ce78e)
- Fix tabindex issue [`15e109b`](https://github.com/fomantic/Fomantic-UI/commit/15e109b37387cf07600d1eff6f3a370c4835ff14)
- Remove hidden checks from label [`4d5908f`](https://github.com/fomantic/Fomantic-UI/commit/4d5908f40dc7508e40f72bdabfaad32fc69f94f4)
- Reworking paths [`127c2ee`](https://github.com/fomantic/Fomantic-UI/commit/127c2eedf1ee4cebbc36077531bc5ed4a9f4a810)
- Fix multiple match for some rules [`ae74507`](https://github.com/fomantic/Fomantic-UI/commit/ae745077aa50b645258959fe0fed210985342b7b)
- actually make classes be inverted [`6745243`](https://github.com/fomantic/Fomantic-UI/commit/67452432cde80670719e842ef2ceea37160bd8cc)
- Sub header position [`d129c5d`](https://github.com/fomantic/Fomantic-UI/commit/d129c5d6c3616389a9e15536f2a0628a439a8736)
- RLSNOTES [`a7492fa`](https://github.com/fomantic/Fomantic-UI/commit/a7492faf6b056260326cc3abd9ceb8a3571ecbae)
- #2060, clean up debug, remove testing settings [`60db38e`](https://github.com/fomantic/Fomantic-UI/commit/60db38ea72619110fba96e3b4805acc6634ac74a)
- Search IDs now not zero indexed [`bcd6ebe`](https://github.com/fomantic/Fomantic-UI/commit/bcd6ebe87ceb5a176f7e8c30ddda61ab5fc1be1e)
- Update rls notes [`9a12b51`](https://github.com/fomantic/Fomantic-UI/commit/9a12b5182f85d424780cf10cc5ca458bb6ac47eb)
- Fix right menu item [`2aa7066`](https://github.com/fomantic/Fomantic-UI/commit/2aa70665008395614bb3ac6d60d958572e1e5e55)
- Add international notes [`25d08b4`](https://github.com/fomantic/Fomantic-UI/commit/25d08b43c90d702c271f9e3db966e6213c3839a7)
- Tick version, observechanges true by default sticky [`8cc32e1`](https://github.com/fomantic/Fomantic-UI/commit/8cc32e1293d2d777c4bdcbb5d42076d6cef3c388)
- Update rlsnotes [`46a8913`](https://github.com/fomantic/Fomantic-UI/commit/46a8913905c36b507898a5e965583371e1a37221)
- Fix seven column tablet #1716 [`9960580`](https://github.com/fomantic/Fomantic-UI/commit/99605806c69b1723cd137f0150e2f38b95d48278)
- Adds clear events on clear buttons [`8a2ba42`](https://github.com/fomantic/Fomantic-UI/commit/8a2ba42d4d3775a3676efc5b873ca96533f235a7)
- Selector cache schange #3183 [`d8e505c`](https://github.com/fomantic/Fomantic-UI/commit/d8e505cd657a5eb4fb0fe69996be0eccab97f46b)
- #3660 - Fixes issue with refactor where beforeSend cannot cancel request [`8f1233f`](https://github.com/fomantic/Fomantic-UI/commit/8f1233fe215ba5854177001f0d23508105a13968)
- Fix attached segment to tabular menu [`49a8ea9`](https://github.com/fomantic/Fomantic-UI/commit/49a8ea9d7222a7846ae685362aa6282d090a5bba)
- Adds #3226 [`5062d0b`](https://github.com/fomantic/Fomantic-UI/commit/5062d0b5fb9f3c5605f04cd8e1cfa82499fe0d2a)
- Adds #3226 [`f131f7d`](https://github.com/fomantic/Fomantic-UI/commit/f131f7dea54822c9f26c9ea648804c0898bdbd20)
- Removed the unused `values` variable [`8c2ed75`](https://github.com/fomantic/Fomantic-UI/commit/8c2ed75b028a02eb6e7fb70f25ef54829fbd503b)
- #3016 fix comma not delimiting correctly [`fe7a246`](https://github.com/fomantic/Fomantic-UI/commit/fe7a2468336fa9926a547016c4643def8ff743cd)
- Update rlsnotes [`464ab23`](https://github.com/fomantic/Fomantic-UI/commit/464ab23d159beefce885d44ee7e0b4faa0e25d5e)
- Prune #2944 [`0fece6a`](https://github.com/fomantic/Fomantic-UI/commit/0fece6a4c96ad94af9f52ee3e3ed9825b6648581)
- Fix inline form validation prompt styles [`8b19b0d`](https://github.com/fomantic/Fomantic-UI/commit/8b19b0d8f8fdb84ecabc0eae8ba7b3af2b316a60)
- #2934, fix onRemove firing when no popup removed [`6f4ac86`](https://github.com/fomantic/Fomantic-UI/commit/6f4ac8697b3488afe4582a7129cca61bb0eccc2c)
- Rlsnotes [`3ba6a5b`](https://github.com/fomantic/Fomantic-UI/commit/3ba6a5b914a8d9ba021620d2fff13c4af9fd002d)
- Fix some issues with using padding for text menu [`0ae0cbd`](https://github.com/fomantic/Fomantic-UI/commit/0ae0cbde521aba118c85fb0954fcd45657965143)
- Add PR to rlsnotes [`632c215`](https://github.com/fomantic/Fomantic-UI/commit/632c215c867a9a5ace24c20bab14cd3756c1844f)
- onAbort now triggers failure conditions, as mentioned in release notes [`5dfd30a`](https://github.com/fomantic/Fomantic-UI/commit/5dfd30a8f3f5cecc0c4da3c2fde0fc4f2ac083be)
- Update rlsnotes [`00b08ba`](https://github.com/fomantic/Fomantic-UI/commit/00b08ba150552db49bb77cff0ada850585cbf3c3)
- Fix image width on ui image in vertical menu [`0257c76`](https://github.com/fomantic/Fomantic-UI/commit/0257c764b39e35a670aa4f344b317485c8ab5d16)
- Bulleted horizontal list color variable [`91d1e7a`](https://github.com/fomantic/Fomantic-UI/commit/91d1e7a454f9e487bba4566e2a6018e071201466)
- Remove some unnecessary voodoo [`384ea12`](https://github.com/fomantic/Fomantic-UI/commit/384ea1226cf258f9d08efb48638af814e5902c49)
- Add lineheight to popup [`bc96dca`](https://github.com/fomantic/Fomantic-UI/commit/bc96dcadc017d692383de88fbe79ce9f105ab7e3)
- #2295 Fix loading search showing double loader with icon button [`b11ae77`](https://github.com/fomantic/Fomantic-UI/commit/b11ae774acf7be020be32c0a38c9b763492a5255)
- Remove console [`05a2d1b`](https://github.com/fomantic/Fomantic-UI/commit/05a2d1bcdc1d2ba08b1f86a1949d5336fa7eb0d8)
- Fix hover color on pointing menu #2263 [`3022fa0`](https://github.com/fomantic/Fomantic-UI/commit/3022fa0ca9c2616cc627900c8d4f3442ba9656f3)
- Fix issues with shape backface visibility in chrome [`b65ecfc`](https://github.com/fomantic/Fomantic-UI/commit/b65ecfcc1482eb8af2ead3a88f898629cd27fb54)
- Fixes dropdown force selection to not filter until after hide [`7887dae`](https://github.com/fomantic/Fomantic-UI/commit/7887dae2ea60697a274e8b2d2746435d0fdc1c31)
- Clean up rlsnotes [`828a799`](https://github.com/fomantic/Fomantic-UI/commit/828a799f4c1ba2727b468cb83b3ec5bef92390dd)
- Update rlsnotes [`f7ff76e`](https://github.com/fomantic/Fomantic-UI/commit/f7ff76e41e091b880eb2f12f5deffafc59881896)
- Adjust default alphas to improve legibility [`042995d`](https://github.com/fomantic/Fomantic-UI/commit/042995d4e0ddf8d160c84828667a63618edfda3a)
- Fix display: flex issues when content has no image [`57e5cba`](https://github.com/fomantic/Fomantic-UI/commit/57e5cba3a028f1bf0cec15a3d03bf5819ec2c89c)
- RLSNOTES [`5cd52c0`](https://github.com/fomantic/Fomantic-UI/commit/5cd52c0d8654604cb3554d79a33a9d34a4dd8e37)
- Fix item menu item border [`c8eba15`](https://github.com/fomantic/Fomantic-UI/commit/c8eba15a6198a6e6ab67c8cd5cc19b8513968f26)
- Add upward pointing icons for upward dropdown [`b3dd117`](https://github.com/fomantic/Fomantic-UI/commit/b3dd117747bf8a05843212cc33ce81964adeb454)
- Needless formatting of gulpfile [`211bc4f`](https://github.com/fomantic/Fomantic-UI/commit/211bc4f44eba81f81802e8db932800271ef3deec)
- Fix issue with css selector starting with number (invalid) #3311 [`479f4b2`](https://github.com/fomantic/Fomantic-UI/commit/479f4b21daff6b3b9d5e0854c51c269e7f10e54e)
- Fix missing table variables [`980db0e`](https://github.com/fomantic/Fomantic-UI/commit/980db0ec003753e092a49384505ba322a643d0fb)
- Fix issue with divider descendors being cut off  #3585 [`45e4bd8`](https://github.com/fomantic/Fomantic-UI/commit/45e4bd84c1da0980899536cff34574352d6dda03)
- Fixing classnames for facebook and pinterest. [`423a4d0`](https://github.com/fomantic/Fomantic-UI/commit/423a4d025ce5e08b42e68baaa58343019b1172e6)
- #3016, dont use delimiter key when not multiple with additions allowed [`f86b801`](https://github.com/fomantic/Fomantic-UI/commit/f86b8015b1fb2352ebd8cfa288e2e5254dcb230f)
- Make overrides optional for packaged themes [`9965473`](https://github.com/fomantic/Fomantic-UI/commit/9965473ff8c6f5720083dfaab39422e25309338f)
- Tabs does not work properly for duplicate names [`6aba684`](https://github.com/fomantic/Fomantic-UI/commit/6aba6845079404408276814daa0d25e7c3e6ed32)
- Build readme [`dfed6bc`](https://github.com/fomantic/Fomantic-UI/commit/dfed6bcd65b48e1395cce730e2ff8bdbbe4f74b3)
- Revert flex on vertical menu, no real need, and causing issues with ios [`a16c140`](https://github.com/fomantic/Fomantic-UI/commit/a16c1402c8cf11b5e5dda74bd56b18a4c9f927d9)
- Fix jshint errors in search [`8278323`](https://github.com/fomantic/Fomantic-UI/commit/8278323cad3cd1e818309b3318ed5a458476ef0c)
- Fix consecutive grid spacing #2467 [`549f040`](https://github.com/fomantic/Fomantic-UI/commit/549f04009e7afed140a74e9a43724b09fbb21c2a)
- Fix font family rule on :before [`2984026`](https://github.com/fomantic/Fomantic-UI/commit/2984026ec78da0ada86ed17a80358c36fd13368d)
- Fix grouped field label [`d3775b4`](https://github.com/fomantic/Fomantic-UI/commit/d3775b4c95affa9992939602453c30d9962f4579)
- Fix issue where userAdditions failed to recreate element when using single selection [`16a70cd`](https://github.com/fomantic/Fomantic-UI/commit/16a70cd597457c80a7aee1e1a22a08ca1c2337e8)
- RLSNOTES [`4b07dcc`](https://github.com/fomantic/Fomantic-UI/commit/4b07dccad5f39175337aa9d0aa13563a7cec41e9)
- Couple unnecessary lines [`fc28d64`](https://github.com/fomantic/Fomantic-UI/commit/fc28d6457738490260d1ea15144f848daf21237c)
- Rlsnotes [`74cb2c9`](https://github.com/fomantic/Fomantic-UI/commit/74cb2c900ca49a9171875d954e9080bf8fbe8033)
- Adjust selected border color and floating shadow [`9ea18b3`](https://github.com/fomantic/Fomantic-UI/commit/9ea18b3fed8dc8521968aa01ef3a827bc67a66cc)
- Fix issues with secondary pointing offset [`562763b`](https://github.com/fomantic/Fomantic-UI/commit/562763b990c48a918ced920b953b1cd76a483a1a)
- Fix sub header overriding first/last-child rules [`86e4f45`](https://github.com/fomantic/Fomantic-UI/commit/86e4f454de97e7438f2f8c99f5f788450ecdce5c)
- Fix icon item not centering if narrow icon in menu [`c1ace94`](https://github.com/fomantic/Fomantic-UI/commit/c1ace94d43077c8d600a01e6ae96f0b8b7552553)
- #2358, remove component glob from assets [`d0e4f74`](https://github.com/fomantic/Fomantic-UI/commit/d0e4f74cd10ed265abe19e2007be9c4146a82201)
- #2353, last field group should not have bottom margin [`b51de13`](https://github.com/fomantic/Fomantic-UI/commit/b51de13da8bcc4fe6912604ee5776eebce2e10ac)
- Fix mobile styling of 'image content' not appearing correctly [`c06a11e`](https://github.com/fomantic/Fomantic-UI/commit/c06a11e4ae29994f4b915e6064e412c2856c6204)
- increase icon distance slightly #2335 [`13d9d11`](https://github.com/fomantic/Fomantic-UI/commit/13d9d112867236680b49a94d9506c7eb357934a6)
- Accidental merge conflict commit [`bf21ab9`](https://github.com/fomantic/Fomantic-UI/commit/bf21ab95e44651ab07ac945667248f3c5fb48010)
- #2299 Fix rtl typo [`701426b`](https://github.com/fomantic/Fomantic-UI/commit/701426bcb37871051b5741f42b707e53a230b4ab)
- RLSNOTES [`666b916`](https://github.com/fomantic/Fomantic-UI/commit/666b916e37f72f1c3203a73770afd48b3a01dc24)
- Fix wrong black header colors #2280 [`18c0fb7`](https://github.com/fomantic/Fomantic-UI/commit/18c0fb7a290eee7324ea3bb477214409c913133b)
- Fix attached message to segment [`80fb00a`](https://github.com/fomantic/Fomantic-UI/commit/80fb00a6364acbf28aba4ef84eb8ae6b0bb0f290)
- Fix fluid flex, rounding of padding [`7d402ff`](https://github.com/fomantic/Fomantic-UI/commit/7d402ff4e8073019dcc7148ca4361ec5b78809c5)
- Fix example title [`152da4d`](https://github.com/fomantic/Fomantic-UI/commit/152da4d0190d5e961ab4800915b447cdec59054a)
- Adjust floating box shadow on dropdown menu [`06ad93e`](https://github.com/fomantic/Fomantic-UI/commit/06ad93e5eb636e44e8ee13b29d382c9a98744705)
- Adjust info/posi/negi again [`7aa9875`](https://github.com/fomantic/Fomantic-UI/commit/7aa9875cd9abc72bfea8e02cdaf0165e42777806)
- Fix icon line height in header/modal [`542e727`](https://github.com/fomantic/Fomantic-UI/commit/542e7273863740d289c90703a5492cc294c4917b)
- Fix colored theme transition [`d4ddfd4`](https://github.com/fomantic/Fomantic-UI/commit/d4ddfd4a57783be922d0b4f9ad8f390c35411921)
- formatting [`5b3ff7e`](https://github.com/fomantic/Fomantic-UI/commit/5b3ff7e895f3b58c32f52a1a3087db284ffd4780)
- #1724, make sure any method invocation forces position recalculation in visibility api [`159ccfc`](https://github.com/fomantic/Fomantic-UI/commit/159ccfc879568ad0b1c520019deb9ff488ea6d85)
- #1724 Minor fixes [`d3c1928`](https://github.com/fomantic/Fomantic-UI/commit/d3c192803347c1e631b31f874390f5b29c4b7866)
- #2218 slightly reduce avatar image size [`b0c6d25`](https://github.com/fomantic/Fomantic-UI/commit/b0c6d25c851352260419cc32422e577df9a22c3c)
- Dropdowns now use internalBorderColor global [`c85f27f`](https://github.com/fomantic/Fomantic-UI/commit/c85f27fec63f72782808cf0cf696553a97db4b13)
- Remove erroneous pagination menu rule [`a2273f7`](https://github.com/fomantic/Fomantic-UI/commit/a2273f716d8f92ad5f73b26948ed3ad33a22f3d8)
- Fix typo in table [`4e47008`](https://github.com/fomantic/Fomantic-UI/commit/4e4700834dfe2ccdf36f9345b4eb5e251d005a46)
- Remove vendor prefix from transition (jq &gt; 1.8) [`e996b65`](https://github.com/fomantic/Fomantic-UI/commit/e996b655d469c6e18ebe0c82cbbeeef749517878)
- Remove pressed submit button on form [`9395853`](https://github.com/fomantic/Fomantic-UI/commit/93958536dbb6ddd367ed8d5faba1c53f537df400)
- Fixes inline dropdown dropdown icon alignment, fixes menu item using relative sizes [`5cf488e`](https://github.com/fomantic/Fomantic-UI/commit/5cf488e195d393e89b944c425d0dfde441b994ee)
- Fixes paths in tasks that were incorrect from last commit [`83c9b32`](https://github.com/fomantic/Fomantic-UI/commit/83c9b32d12e92b185cb1896223b520a7c7f52d72)
- Fix min-width flex issue on item [`c239569`](https://github.com/fomantic/Fomantic-UI/commit/c239569802813f011ec2bf732d8c5687441d4820)
- Corner label should be em not rem [`8970819`](https://github.com/fomantic/Fomantic-UI/commit/897081955dce27e4163b33f6299a3031c8a97fcd)
- Fix some flex input conditions [`3fca1e0`](https://github.com/fomantic/Fomantic-UI/commit/3fca1e0b3e30918678d15350c76f4363e85e6532)
- Fix text align for dropdown item in centered container [`fdf3354`](https://github.com/fomantic/Fomantic-UI/commit/fdf3354c8de374a5d906f8802f9b3e753b92712f)
- Variable name mismatch #2139 [`85d66ba`](https://github.com/fomantic/Fomantic-UI/commit/85d66bad45d35b431775ac333a8c8a1c727a791b)
- #2042 add delegated events to nag (stupid nag) [`e2593c9`](https://github.com/fomantic/Fomantic-UI/commit/e2593c98af31ced0979359a75d5ffebbacefe610)
- Fix label word wrap [`fa7d16e`](https://github.com/fomantic/Fomantic-UI/commit/fa7d16e608ac62d229bebf282c668f246a27aa73)
- Fix &lt;select&gt; inside form &gt; inline field [`0690850`](https://github.com/fomantic/Fomantic-UI/commit/0690850b5deb3e8ebf63193df87d6a410b7d180b)
- #1878 Update regexp replace for npm build to fix browserify [`95b996f`](https://github.com/fomantic/Fomantic-UI/commit/95b996fac145afcb6bc121dac1f3964ada25a5b1)
- #1709, force table-cell on ui labeled input, ui action input [`45b00b9`](https://github.com/fomantic/Fomantic-UI/commit/45b00b9fb930a19faba2bb60ce7586a86e235024)
- Fix camelcase on var in modal [`15dc0bd`](https://github.com/fomantic/Fomantic-UI/commit/15dc0bdac64dd281f06b3c5a138ee50e39892f97)
- Remove error messages for repeated animations, too verbose [`0fe91e0`](https://github.com/fomantic/Fomantic-UI/commit/0fe91e083a0ed3bf6d37a192bcdc89645d2a6df5)
- Fix corner labeled icon zindex issues [`98d55d0`](https://github.com/fomantic/Fomantic-UI/commit/98d55d0b9340c17f7a90ed5819ad9af2121b06ba)
- Remove duplicate variable [`82f07d6`](https://github.com/fomantic/Fomantic-UI/commit/82f07d61164fd5b0a19beb705e0fb5113760c845)
- Update rlsnotes [`18ba05a`](https://github.com/fomantic/Fomantic-UI/commit/18ba05a1ac2f3ea052bd642ecce236ecc340f051)
- Update v [`daece4a`](https://github.com/fomantic/Fomantic-UI/commit/daece4af4b57b1523cb2c4dd9723a89794776319)
- #1613, Proper Fix for http [`ddc6c2c`](https://github.com/fomantic/Fomantic-UI/commit/ddc6c2ccc26875511239882421dc3f1cb263e24f)
- Fixes svg use with popup #3043 [`4445a27`](https://github.com/fomantic/Fomantic-UI/commit/4445a27ad243d8520e436751a04e51e643994835)
- Rlsnotes [`dc5eac0`](https://github.com/fomantic/Fomantic-UI/commit/dc5eac012ed35d5bf8a70ea48064a2f61efa16ed)
- Fixes decimal rule to only match decimals #3060 [`77dfa8f`](https://github.com/fomantic/Fomantic-UI/commit/77dfa8f03a6f507e3d707b4a89b66ce038e19674)
- Fixes static animation onComplete event [`eaec2fb`](https://github.com/fomantic/Fomantic-UI/commit/eaec2fb776939e469c06797ceaba1ea6a460c58d)
- Fixes svg use with popup #3043 [`8ddd2ee`](https://github.com/fomantic/Fomantic-UI/commit/8ddd2ee7dede9de14e30e3d9cabab2d6ec0d2e54)
- #3082 [`09d2411`](https://github.com/fomantic/Fomantic-UI/commit/09d2411d4f7070d626002c4aa3297319c16659e0)
- Rlsnotes [`6ac5a01`](https://github.com/fomantic/Fomantic-UI/commit/6ac5a01234633c67294533a2ebcd0d268e150613)
- Fixes decimal rule to only match decimals #3060 [`53576bf`](https://github.com/fomantic/Fomantic-UI/commit/53576bfc532014d818e21f1173af39c5479d3da7)
- Fixes static animation onComplete event [`34ea9f9`](https://github.com/fomantic/Fomantic-UI/commit/34ea9f94b4b9186ef7ef08e0de6b0b52afcb705b)
- #3082 [`c579a4e`](https://github.com/fomantic/Fomantic-UI/commit/c579a4e7a6d81c43af87ab198dc3b2788d0a1252)
- Add support for placeholder as fallback #3001 [`72639db`](https://github.com/fomantic/Fomantic-UI/commit/72639dbbd5365cefa2e7da43fbf9fb91bb0267f6)
- Fix tag transition [`a266d55`](https://github.com/fomantic/Fomantic-UI/commit/a266d555630565ccbd28b72573b605871c96fb67)
- Fix offset on bottom tabular menu [`5d11b3f`](https://github.com/fomantic/Fomantic-UI/commit/5d11b3f3709a437024c1edbf1ebfb69476a4b915)
- Rlsnotes #2836 [`37bc2fd`](https://github.com/fomantic/Fomantic-UI/commit/37bc2fd32a92e7506e46561633eda63de02ad693)
- RLsnotes [`c07ab00`](https://github.com/fomantic/Fomantic-UI/commit/c07ab00e73ab77588f3e8e540f878d8c65fd7e2a)
- #2760 - remove console.log from embed [`145b4f5`](https://github.com/fomantic/Fomantic-UI/commit/145b4f526ccf9b776e1f1da7e41781b63c1c1168)
- Fix comitted merge conflict [`9445939`](https://github.com/fomantic/Fomantic-UI/commit/94459392416335a4e64e580b6de0f8da734b6787)
- Update rlsnotes [`bd48a09`](https://github.com/fomantic/Fomantic-UI/commit/bd48a09acc01d1f8d6c600616ebd10fce87b32d4)
- Update single component repos readmes #2816 [`eb2f5fa`](https://github.com/fomantic/Fomantic-UI/commit/eb2f5fad3fe821785998bd8118d6da10ef5d2ede)
- Fix icon menu appearing fluid [`13bea8f`](https://github.com/fomantic/Fomantic-UI/commit/13bea8fbda339158ee235bdbd0569ac51a63bb08)
- Add indeterminate to rlsnotes [`f540588`](https://github.com/fomantic/Fomantic-UI/commit/f540588ea9608fbd5f563c074c0895ca72d45c57)
- Rlsnotes [`85d5093`](https://github.com/fomantic/Fomantic-UI/commit/85d5093bc04cc0b30e6d3c6aa30f5c6460aa8e48)
- Fix secondary pointing menu vertical margin [`4e41405`](https://github.com/fomantic/Fomantic-UI/commit/4e414059595074676f845479974800e5979d360e)
- RLSNOTES [`9188dca`](https://github.com/fomantic/Fomantic-UI/commit/9188dcaea28192784609df94ac98aaa36f148c24)
- Reuse some code [`c6b47c7`](https://github.com/fomantic/Fomantic-UI/commit/c6b47c7a0f8f974c4e2f143ca691a40294c2db49)
- Fix one pixel offset on inverted menu due to lack of border [`784b0a4`](https://github.com/fomantic/Fomantic-UI/commit/784b0a495bf0ebfe2fd061b4afac9f099f61f2ab)
- Fix single select dropdown does not correctly save name/value pairs in session [`ea859db`](https://github.com/fomantic/Fomantic-UI/commit/ea859dba9bb228cc8c1abd228a5b2fed8bc30ce5)
- Rail should inherit @medium [`f46fd54`](https://github.com/fomantic/Fomantic-UI/commit/f46fd548f102a7577032687f1ca3d44b4f1f863c)
- Update rlsnotes [`cbe491c`](https://github.com/fomantic/Fomantic-UI/commit/cbe491c9abaa29a68285ffa487cf0157225039ba)
- Fix container width, should be auto unless flex (menu is flex) #2343 [`5b6e427`](https://github.com/fomantic/Fomantic-UI/commit/5b6e42717ddb804b96256123348c9e5322b8de56)
- Rlsnotes swap inverted color back [`243a03f`](https://github.com/fomantic/Fomantic-UI/commit/243a03ff86719e7fe7df8ff14dfe0efddc40df89)
- #2340, in cases where context is automatically determined because it was not specified in settings, refresh on resize [`bd8824c`](https://github.com/fomantic/Fomantic-UI/commit/bd8824c11d8811262a29608b63ce9773a7759e2b)
- Update amazon button spacing [`1b31e76`](https://github.com/fomantic/Fomantic-UI/commit/1b31e7643d849ac2df48f66f6f0675e5211bf506)
- Fix rounding of header line height [`7873189`](https://github.com/fomantic/Fomantic-UI/commit/7873189a28916f2b80611d5f23427e99cae59a49)
- Table footers get bg color [`ae685c1`](https://github.com/fomantic/Fomantic-UI/commit/ae685c1bf57460e22c79b7920af6ac7e99070ac3)
- #2288 Fixes label word-wrap issue on dropdown [`ee33d26`](https://github.com/fomantic/Fomantic-UI/commit/ee33d26e36717254dacfc357511f6894d43a3718)
- Fix flex fluid width [`6ceb7fd`](https://github.com/fomantic/Fomantic-UI/commit/6ceb7fd0b8c59fa1df8772932c23db95e9beb02f)
- Move accordion settings around [`9726dd0`](https://github.com/fomantic/Fomantic-UI/commit/9726dd0523dd60896110d516ec22a4adcdf89379)
- Remote unused method #2260 [`1cddeba`](https://github.com/fomantic/Fomantic-UI/commit/1cddebabd49f31d279f9798fe6c3b9372b02ea2d)
- Dupe rule [`a5c69dd`](https://github.com/fomantic/Fomantic-UI/commit/a5c69ddc7049008ead8fd1256c0df186d73474f7)
- Update semantic.less links [`913cd28`](https://github.com/fomantic/Fomantic-UI/commit/913cd28a27f46befdf5782ea708503b66f5505ef)
- RLSNotes [`622ec64`](https://github.com/fomantic/Fomantic-UI/commit/622ec64e839d04ef9dad96ed0d7d3c8dc58a52d1)
- Fix static transition not fixing display type [`bf70b90`](https://github.com/fomantic/Fomantic-UI/commit/bf70b90343e211660509a456b37b526770ba7182)
- Removes min-width rule for mozilla [`f87c07f`](https://github.com/fomantic/Fomantic-UI/commit/f87c07fa4abf6ebabc5d821d6e4f450462c1bb14)
- Fix text align [`82654d3`](https://github.com/fomantic/Fomantic-UI/commit/82654d314488b8f1ace9801fc4d377be2c7ea065)
- Fix input size overflow [`0ecfd8a`](https://github.com/fomantic/Fomantic-UI/commit/0ecfd8adba61ea2e37623a3c965a063bdf4f0a12)
- Backport LESS repo fix [`561fa8c`](https://github.com/fomantic/Fomantic-UI/commit/561fa8c841be9bfaae9256b0748235cfed32ac9e)
- Test again [`909630a`](https://github.com/fomantic/Fomantic-UI/commit/909630a790d56d2396a26968a3b233fed88659ee)
- Update post-install [`12ae622`](https://github.com/fomantic/Fomantic-UI/commit/12ae6221ffe102b110bea9587ac24bb79f9ae044)
- #1729, Add cart aliases [`981cba6`](https://github.com/fomantic/Fomantic-UI/commit/981cba6405771de030a435d0eb4419c7332ceed7)
- Fix bug with doubling grid setting width #1635 #1716 [`3f7033d`](https://github.com/fomantic/Fomantic-UI/commit/3f7033df5cad7ce49b8e52978d3f1147a4403485)
- Update release notes [`7145497`](https://github.com/fomantic/Fomantic-UI/commit/7145497f8e085a897d2b738e25e9f44f0e7e05fa)
- Adds #1669, Dropdown will now recreate menus when option values change, dropdown will now produce errors when methods invoked on &lt;select&gt; and not ui dropdown [`31fb8e1`](https://github.com/fomantic/Fomantic-UI/commit/31fb8e12371fa8113dc3c7b52045184178b44d3c)
- Remove debug [`08f4e32`](https://github.com/fomantic/Fomantic-UI/commit/08f4e32f060b3b6940db0fabee4926e836edb075)
- Add else conditions #1600 [`30b12e0`](https://github.com/fomantic/Fomantic-UI/commit/30b12e0acc35459f5f8a7e6c1f9cad6dbc938505)
- Allow first letter selection without selection dropdown [`989c8d5`](https://github.com/fomantic/Fomantic-UI/commit/989c8d582a6de3885873473584cb0f90c6c67e4e)
- Remove errant console.log from API [`76f1f2d`](https://github.com/fomantic/Fomantic-UI/commit/76f1f2d024625e010921f12c702181c920d15a13)
- #3475 update rlsnotes [`469f7e0`](https://github.com/fomantic/Fomantic-UI/commit/469f7e0a39f094f7ae78d210c92278a28d71ad1d)
- #3616 -  RLSNOTES [`cf84a74`](https://github.com/fomantic/Fomantic-UI/commit/cf84a740f91abafcd0eb5db4e60f68f4fa053c5d)
- If semantic.json was not found, exit with an error code. [`79e615a`](https://github.com/fomantic/Fomantic-UI/commit/79e615a0bbf0c3d2e6cd225514279be55a43e118)
- #3514: the fix for issue: 'The checking for semantic.json always fails when npm dependent package uses Semantic UI'. [`0800482`](https://github.com/fomantic/Fomantic-UI/commit/0800482ec9899193ea4415bdbac2509336707b2b)
- Rlsnotes [`5a07cef`](https://github.com/fomantic/Fomantic-UI/commit/5a07cef17e6409222a2c9acee15a2f9745bbd176)
- Remove console log #3466 #3491 [`4468781`](https://github.com/fomantic/Fomantic-UI/commit/44687819ef55da6e3e43426958afb04acc646728)
- #3306 remove transform hack from sidebar [`e194140`](https://github.com/fomantic/Fomantic-UI/commit/e19414021079871aff9382afcc48843f3e684e91)
- Call order, params [`6a23d51`](https://github.com/fomantic/Fomantic-UI/commit/6a23d515070ac7916df1dd45db27f9459349ad2a)
- Fix FontAwesome header version [`7a7f9c3`](https://github.com/fomantic/Fomantic-UI/commit/7a7f9c36e9cb2ebd20c6373df7d44457e68cedb6)
- Correcting name: yes, Wales [`cc8c2b9`](https://github.com/fomantic/Fomantic-UI/commit/cc8c2b9c41a378b5134b5d702ad6e43ed27510fb)
- #3272 fixes comment [`f8b4e12`](https://github.com/fomantic/Fomantic-UI/commit/f8b4e129b2c4a8201f0ebe8af848a08484b4c2fb)
- Added support for dimmer with zero opacity [`4d80f94`](https://github.com/fomantic/Fomantic-UI/commit/4d80f94f5e7aa4ae06d0b3f97e4bdf264fd584a7)
- Simplifies test [`fb0222f`](https://github.com/fomantic/Fomantic-UI/commit/fb0222fbc1be26ceb0837004760afd6c31047161)
- Fix integer validation [`19ec0c8`](https://github.com/fomantic/Fomantic-UI/commit/19ec0c82a1b0360e92662902ce85443d6a7b78ed)
- #3272 fixes comment [`b644286`](https://github.com/fomantic/Fomantic-UI/commit/b644286c05670e12b7722f31c5b7fe54b51d226d)
- Added support for dimmer with zero opacity [`f269e3c`](https://github.com/fomantic/Fomantic-UI/commit/f269e3c19aab34bcbf96501a4245e8a3880fb5f4)
- Simplifies test [`97d4300`](https://github.com/fomantic/Fomantic-UI/commit/97d4300da28bb85b2b4faf502c1fc54f04c9e13e)
- Fix integer validation [`a31d678`](https://github.com/fomantic/Fomantic-UI/commit/a31d67808101ec7cc13389abf9264257216a12f0)
- Remove word-wrap from label #3006 [`180f963`](https://github.com/fomantic/Fomantic-UI/commit/180f9639daa99ad4e65619090a0f3d8c4610e9ff)
- Version [`4ccfad5`](https://github.com/fomantic/Fomantic-UI/commit/4ccfad5afe63339fc707b897913c3e72b4f3ab84)
- Fixes container inside ui menu on mobile #2969 [`c30fba9`](https://github.com/fomantic/Fomantic-UI/commit/c30fba9ca41c23e84bf4dcf1f13db8b65cc8851c)
- #3009, fix issue where theme will fail building if packaged theme does not include site.variables [`afbd7d5`](https://github.com/fomantic/Fomantic-UI/commit/afbd7d5f88c5bb410aeab7e3ab199d5a4a772fe5)
- Fixes backwards incompatible callback #2945 #2944 [`0d89f9d`](https://github.com/fomantic/Fomantic-UI/commit/0d89f9dc0f1bb79df218126a297f96f71cf4fa62)
- Rlsnotes 2.1.1 [`c33e5c2`](https://github.com/fomantic/Fomantic-UI/commit/c33e5c2346ec0d046360306bb4d9fdd358d68b4b)
- Update rlsnotes [`52f6c66`](https://github.com/fomantic/Fomantic-UI/commit/52f6c66863255aae7941ea3257a5370334f4cd5a)
- Fix storage.remove method localstorage check [`83563e2`](https://github.com/fomantic/Fomantic-UI/commit/83563e2cf93d70dc9693868c196921c77d3780b4)
- #2924 update browser support in readme [`142ff6b`](https://github.com/fomantic/Fomantic-UI/commit/142ff6b56a544fdff01db8e18f91d929cf32a04f)
- Adds #2850 rlsnotes [`298f6ea`](https://github.com/fomantic/Fomantic-UI/commit/298f6ea96926fd1c45e77e189cc0b7e5d7d02c65)
- #2685 rlsnotes [`ce23372`](https://github.com/fomantic/Fomantic-UI/commit/ce2337200edec5f460881a78c55b1829e1157c2e)
- Tag rlsnotes #2685 [`7889d19`](https://github.com/fomantic/Fomantic-UI/commit/7889d19656e876dba97ef695b69efc34b2fd5276)
- Rlsnotes #2838 [`ef1ac3b`](https://github.com/fomantic/Fomantic-UI/commit/ef1ac3b3952dd7a8ad400bd3ef286382da1aed4e)
- #2825 empty form comment banner [`d89e9d9`](https://github.com/fomantic/Fomantic-UI/commit/d89e9d90f3e6a23d661a19e56f43caff1d71009e)
- #2664 Removes unnecessary right border on header item in secondary menu [`8e01074`](https://github.com/fomantic/Fomantic-UI/commit/8e010740692309deb6b69b6c6c80b8c67d4acf96)
- Disable sticky debug [`93a6c3f`](https://github.com/fomantic/Fomantic-UI/commit/93a6c3fd453e0200cc9b74505c34cf1cab67da84)
- #2778 fix issue with flex-direction on left dropdown menu in menu [`2c8aa03`](https://github.com/fomantic/Fomantic-UI/commit/2c8aa03bb4530e6b5bde3fd8fb915e7dac178a6e)
- Fix next version # [`ab7b3be`](https://github.com/fomantic/Fomantic-UI/commit/ab7b3be53d9314e0f270ea8d7cffc5faa29e337f)
- #2765 fixes bad icon utf value [`44be32a`](https://github.com/fomantic/Fomantic-UI/commit/44be32a0e728271c26f68c906e9e24f48ff5c298)
- Look for inline popup in all siblings of target, not just immediate sibling. [`2fadf77`](https://github.com/fomantic/Fomantic-UI/commit/2fadf77f3754a9941c2aca86e962de61be9eb50f)
- #2558 Fixes vertical divider border right in stackable grid [`8bb7244`](https://github.com/fomantic/Fomantic-UI/commit/8bb724440e969a8e9f396dacc314b28818906474)
- #1369 Popups should not preserve content by default [`ca3a301`](https://github.com/fomantic/Fomantic-UI/commit/ca3a3013a68eb005965e9a34df4ecff4eedefbdf)
- Revert changes to install task [`0291b5d`](https://github.com/fomantic/Fomantic-UI/commit/0291b5dfdf28661ec903a276e2ff1af066e18de1)
- Instead of clearing on reset when no default was set, do nothing #2504 [`90b581f`](https://github.com/fomantic/Fomantic-UI/commit/90b581f05e2d29aea876f529c5ae13d6e4391274)
- #2522, less confusing variable usage [`540e629`](https://github.com/fomantic/Fomantic-UI/commit/540e629efbc34e487520d1bca582bd206cebb5a4)
- Remove PM check from update scripts [`e51d09d`](https://github.com/fomantic/Fomantic-UI/commit/e51d09df109b71d3771ecfcb58a26521663f9f91)
- #2486 Fix label inside input not rfesizing [`3bc76f9`](https://github.com/fomantic/Fomantic-UI/commit/3bc76f9f7353c7048283d3ef1048fe85d3037056)
- Dropdown: removes errant console.log statements [`6438895`](https://github.com/fomantic/Fomantic-UI/commit/6438895b6b2358897dd7a5920be964480bfa0f42)
- Fix link [`ce4b3c7`](https://github.com/fomantic/Fomantic-UI/commit/ce4b3c76e91b6627a81c93bd54f0fc7a7aa0cd72)
- Fix 2.0 release date [`d72d351`](https://github.com/fomantic/Fomantic-UI/commit/d72d351986e5b7efd5dcb24447bcaffde8760320)
- Rlsnotes [`a96b0e3`](https://github.com/fomantic/Fomantic-UI/commit/a96b0e36fa0af30c5860888705a710b9fc201682)
- Fix colored checkbox bullet [`cdbc7b3`](https://github.com/fomantic/Fomantic-UI/commit/cdbc7b3447bc432db70be5fc9f6cd25b2881fd83)
- Prevent grey from turning red in saturate [`2015dae`](https://github.com/fomantic/Fomantic-UI/commit/2015dae9f64e0508e9a255d2c4ec759fde13463d)
- Fix exit conditions for search object [`3ed7ff7`](https://github.com/fomantic/Fomantic-UI/commit/3ed7ff7ba5fd51de8bd14294a2f4a59f2183dba5)
- Fixes bugs introduces with wide column in stackable grid #2467 [`21df62e`](https://github.com/fomantic/Fomantic-UI/commit/21df62eeb4890ab4ccb14d1e1a918daca6bb7a7c)
- Update rlsnotes [`f19c086`](https://github.com/fomantic/Fomantic-UI/commit/f19c08620d795907c433271c2e0ad637952a6adf)
- Debug [`cb34a9e`](https://github.com/fomantic/Fomantic-UI/commit/cb34a9e4c7b9ef6733dcf1a89a094da9836c1b43)
- Formatting [`0672b3f`](https://github.com/fomantic/Fomantic-UI/commit/0672b3f1a245df2c6b0b5804bbf1b5075a1f3e76)
- Adjust inline label align [`9d5d104`](https://github.com/fomantic/Fomantic-UI/commit/9d5d104f12adabca962829ecf96a37e64fcc8dd2)
- #2456, specificity issue with vertical tabular border radius [`7e36f61`](https://github.com/fomantic/Fomantic-UI/commit/7e36f6154cf25458cd8706eb89bd1849ca455555)
- Fix attached fixed menu border [`3e6634b`](https://github.com/fomantic/Fomantic-UI/commit/3e6634bf4aee6e67be14e3c68e5b48b6e4aca13b)
- Increase vertical pointing secondary menu horizotnal padding slightly [`8f3f966`](https://github.com/fomantic/Fomantic-UI/commit/8f3f966b099c6fc9f7ace4b0c7c83a3e1e36c60d)
- #2433 Fix issue with basic segment rule [`1dd822b`](https://github.com/fomantic/Fomantic-UI/commit/1dd822b678d15d0e8c808b8b905ceb5dbdef8ad6)
- #2446 issue in css selector in menu [`cec3cfc`](https://github.com/fomantic/Fomantic-UI/commit/cec3cfc967b872128d134c5f5d76b9aa971c97b6)
- RLSNOTES [`bdb6058`](https://github.com/fomantic/Fomantic-UI/commit/bdb6058db6bb469b65a2ffde3fdafb140b843936)
- Darkens link hover color [`4a58afd`](https://github.com/fomantic/Fomantic-UI/commit/4a58afdd140034f25c70883c01e31bcf56d5edd0)
- Fix header using wrong @medium value [`1568c53`](https://github.com/fomantic/Fomantic-UI/commit/1568c5329d0a4a11d0e3c37095b76c4ff42ff576)
- Adjust default padded segment value [`e82c35d`](https://github.com/fomantic/Fomantic-UI/commit/e82c35da3c57877fb444247a965f846825829dcb)
- Fix enabled module list [`54ed25a`](https://github.com/fomantic/Fomantic-UI/commit/54ed25acd448d831e0996b14a6c82663700b8c9c)
- Fix card header [`7cd229f`](https://github.com/fomantic/Fomantic-UI/commit/7cd229f4f6fabe7bb688dc3949a384e780789626)
- Mistaken last border radius rule [`7d2f6bd`](https://github.com/fomantic/Fomantic-UI/commit/7d2f6bd9ba3ba03427d4a74a7564ae28492799a4)
- Incorrect error text [`364ad39`](https://github.com/fomantic/Fomantic-UI/commit/364ad398d86fed6b14a09d765c20d5f4c5ab9b9f)
- Large monitor breakpoint now corresponds with container breakpoint [`781fa9d`](https://github.com/fomantic/Fomantic-UI/commit/781fa9d3d7881958b76dc19211b7b14243c8234c)
- #2343 Mobile container width should be 100% not auto [`a51e8c2`](https://github.com/fomantic/Fomantic-UI/commit/a51e8c2c04365f7f74b7600312872c5586c8005c)
- Fix vertical menu flex [`72ffccb`](https://github.com/fomantic/Fomantic-UI/commit/72ffccb96ba2bc1cdb36f6be201280e1d93aa667)
- Fix icon header spacing [`919e893`](https://github.com/fomantic/Fomantic-UI/commit/919e89315d1fe23a7c58b7ac52616e928f90a405)
- Fix margin on secondary pointing [`2ac6237`](https://github.com/fomantic/Fomantic-UI/commit/2ac623765f991b0047d6312517b50a1e5a39a440)
- #2308 RLSnotes [`ff68bbf`](https://github.com/fomantic/Fomantic-UI/commit/ff68bbff08a65113e1bce2ef748bd43a5af6b389)
- Slightly darken grey [`caf2ad3`](https://github.com/fomantic/Fomantic-UI/commit/caf2ad3beb8d2d30118248d31e66741cf2244dc8)
- #2313, remove value does not check selection count #2313 [`aadeb1d`](https://github.com/fomantic/Fomantic-UI/commit/aadeb1d437cfe48034915ecde53a9a5f083ab128)
- Unnecessary semicolon [`7ca5fdf`](https://github.com/fomantic/Fomantic-UI/commit/7ca5fdfbdcc594317adad9e5ec276f39fd7849e4)
- Try diffent css @import to possibly resolve issues in some environments [`7c5d770`](https://github.com/fomantic/Fomantic-UI/commit/7c5d7703a9a0407a3b05dfc76cd09f89d34a26fb)
- #2289 - github theme typo [`6e684ab`](https://github.com/fomantic/Fomantic-UI/commit/6e684ab84b4448a1bc8614e64d2dc9286ccedc7d)
- #2288 Typo [`ac2d474`](https://github.com/fomantic/Fomantic-UI/commit/ac2d47462a85e687d45be63a7964ed66701da978)
- Fix reveal timing [`1e50b6d`](https://github.com/fomantic/Fomantic-UI/commit/1e50b6dc3336ffea91b96352a868c65a445a17bd)
- Adjust table header padding [`aa82e50`](https://github.com/fomantic/Fomantic-UI/commit/aa82e5040e7cfe1d06394e9f08d26985e1756998)
- Reduce transition duration to increase responsiveness [`752e9b0`](https://github.com/fomantic/Fomantic-UI/commit/752e9b08215a9ee38f265d6bcd6a8bc2fd2081c3)
- Container shouldnt overwrite display [`86da57c`](https://github.com/fomantic/Fomantic-UI/commit/86da57cf20771f8c573cf2be13395f102b7faf3d)
- Adjust divider margin [`77232d6`](https://github.com/fomantic/Fomantic-UI/commit/77232d6a1c52f5a2079ec8757d43d096124d8932)
- Fix table responsive styles padding [`7c8c5ab`](https://github.com/fomantic/Fomantic-UI/commit/7c8c5ab5b3f4d3ae85ff58810eade828f121ee2d)
- Fix menu dropdown border radius [`84da9ba`](https://github.com/fomantic/Fomantic-UI/commit/84da9ba97d30ee8de7628387912dfff48da8f8b7)
- Fix placeholder vis [`d1c1e60`](https://github.com/fomantic/Fomantic-UI/commit/d1c1e603088e154ac95a4b3faa552114ac715e50)
- Rlsnotes [`1c51811`](https://github.com/fomantic/Fomantic-UI/commit/1c51811b2adb87ee633e365de7effbcfcd5dc2f1)
- Fix context for beforeSend [`a4ef6c1`](https://github.com/fomantic/Fomantic-UI/commit/a4ef6c1041f32941a6e110175a100438a2f6c88a)
- Local cache disabled by default [`57702c1`](https://github.com/fomantic/Fomantic-UI/commit/57702c1eb4ed14e3230ce3264606933ac13c08c7)
- Fix header border color to be internal [`46ea660`](https://github.com/fomantic/Fomantic-UI/commit/46ea66052c34eb855e24691c2aa0228a6b4ab776)
- Adjust global disabled opacity [`caea209`](https://github.com/fomantic/Fomantic-UI/commit/caea209ed33cc0c4359423cde8f86c3e890ef042)
- Remove grey buttons forced on disabled buton [`7db0aa3`](https://github.com/fomantic/Fomantic-UI/commit/7db0aa398936259d832d303bca84bcad9b4fc3db)
- Fix interrupted animatinos [`91b72fe`](https://github.com/fomantic/Fomantic-UI/commit/91b72fe20bdbfd489cbe6f54be7f8ffd885c88c8)
- Fix bug in mockResponseAsync [`89f35d3`](https://github.com/fomantic/Fomantic-UI/commit/89f35d3a49813f0446bd1cdd1ee59190865dd20b)
- #2237 [`8d9f4e6`](https://github.com/fomantic/Fomantic-UI/commit/8d9f4e684156e4f62f5ff8c2a2e65cb657d7949e)
- Consider inline-block header to fix link hitbox [`644f331`](https://github.com/fomantic/Fomantic-UI/commit/644f3311227c70cbfa769cb60e251fd6d65775a5)
- #1724 err actualyl remove debug [`eb9f6f8`](https://github.com/fomantic/Fomantic-UI/commit/eb9f6f83ec8a37058e702cde16073fdbd6fa983c)
- #1724 Remove debug, fix scrollTop [`4e73329`](https://github.com/fomantic/Fomantic-UI/commit/4e73329cfffc0b1baa9ce953981decb64a008a75)
- #2180 one last missing value [`8a94965`](https://github.com/fomantic/Fomantic-UI/commit/8a9496518f0525b1d238edb898a1cbe08078c21f)
- Fix prefixing of min-content [`e8aba03`](https://github.com/fomantic/Fomantic-UI/commit/e8aba032386d18b00c312d87b09dd81df1bf02b1)
- Rating stars should not break to a new line [`33463b6`](https://github.com/fomantic/Fomantic-UI/commit/33463b6ddadae0f0da4643ac53f153917c38d793)
- Equality on rtl [`8c5623d`](https://github.com/fomantic/Fomantic-UI/commit/8c5623d67f7ca461b0ecad45d8c178ff50a953a5)
- #2222 fix phone icon name [`16771df`](https://github.com/fomantic/Fomantic-UI/commit/16771dfe7f4d2fb802ff57654eee4097d176c8b4)
- #2210 adds rlsnotes & cred [`2b940ac`](https://github.com/fomantic/Fomantic-UI/commit/2b940acc42c4a7a1b47b2d2e464105e234472866)
- #2213, user value uses .text.toLowercase() not stored metadata value [`5bcc49a`](https://github.com/fomantic/Fomantic-UI/commit/5bcc49acef9a454377f29a02a6b298672746b3e0)
- RLSNOTES #2214 [`a7482f9`](https://github.com/fomantic/Fomantic-UI/commit/a7482f9c70d7211cb6449bfa2e3addc6225efa5f)
- Fix corner label size [`e0fbc0f`](https://github.com/fomantic/Fomantic-UI/commit/e0fbc0fa87e23fdb33725a5f78d8a4e9c45322c6)
- Match is slightly more performant [`79fb39b`](https://github.com/fomantic/Fomantic-UI/commit/79fb39bdd66a8b75fa71d1519f4c6b4fbc563178)
- RLSNOTES [`f09f881`](https://github.com/fomantic/Fomantic-UI/commit/f09f881f5cf1512376ae633c432eeaad9760d213)
- Creds #2158 [`7b75800`](https://github.com/fomantic/Fomantic-UI/commit/7b75800b329660d9ad744cc7ea729d2f2d5c1e77)
- RLSNOTES [`00a1c7f`](https://github.com/fomantic/Fomantic-UI/commit/00a1c7f118a8951965865b0193a914f95a9d31f0)
- Text menu not bold on active [`6e0bc8c`](https://github.com/fomantic/Fomantic-UI/commit/6e0bc8c44f4b3733e11b445d995d8a9d46153fd8)
- Popup not exclusive by default [`70a79aa`](https://github.com/fomantic/Fomantic-UI/commit/70a79aacb38cc274cb6b36a4fb492e433c730219)
- #2163 Logic error [`0498b4d`](https://github.com/fomantic/Fomantic-UI/commit/0498b4d405ef40c0c35277e113fc5bf2247c1da5)
- Reset debug to false #2173 [`3345fd1`](https://github.com/fomantic/Fomantic-UI/commit/3345fd1213669bc79cd77b763d56e203ef673bf8)
- #2175 Form set value should not automatically validate form [`ec853a6`](https://github.com/fomantic/Fomantic-UI/commit/ec853a6affc27610bbac4efd0562e63d62afe1c1)
- Fix meteor repo link [`07626c1`](https://github.com/fomantic/Fomantic-UI/commit/07626c18b53f59425fb8f9ce1de1d6c5cd379016)
- Fix meteor repo link [`437267b`](https://github.com/fomantic/Fomantic-UI/commit/437267badcc87379648a30435b3684451a82d280)
- Use labels by default [`ec21326`](https://github.com/fomantic/Fomantic-UI/commit/ec2132601f0d52d165baddbdbd7a4a6fbcc22c5e)
- Fix scaledown not hiding page in some conditions [`fbf0f3a`](https://github.com/fomantic/Fomantic-UI/commit/fbf0f3ab9d1b1df40cec9de4c04eef46dd507866)
- #2147 fix sidebar not correctly overflowing when taller than page [`1b3ff05`](https://github.com/fomantic/Fomantic-UI/commit/1b3ff0538a85cfe84f57b1d0dc4b43123e53e8eb)
- Remove debug and rlsnotes  #2133 [`b691d2f`](https://github.com/fomantic/Fomantic-UI/commit/b691d2f0588c4f158b80f2dc3cfda64e266c9e50)
- Debug [`80122d0`](https://github.com/fomantic/Fomantic-UI/commit/80122d0118ec8c8427c05c28fb2da744dc70b458)
- Adjust breadcrumb divider spacing [`19b2ea9`](https://github.com/fomantic/Fomantic-UI/commit/19b2ea9e741bfc156dfc9fba610e3001597d93cc)
- Site.variables now only rebuilds css files on change [`6e6c9d9`](https://github.com/fomantic/Fomantic-UI/commit/6e6c9d914e9fffc298120f7fa85212e9c393c2d4)
- Adds back in transform, prevent awkward flash on animate [`2cf1b0d`](https://github.com/fomantic/Fomantic-UI/commit/2cf1b0dc6ab911511c2413ec18414b39d028cd26)
- Fix casing of scrollbarwidth [`9839741`](https://github.com/fomantic/Fomantic-UI/commit/9839741220cb03a8a57e0869c8d890ee7916647f)
- Debugging installer [`0cc31d1`](https://github.com/fomantic/Fomantic-UI/commit/0cc31d1c0627d8ba2176f580c219aa99227e4d7b)
- Test fix [`2a556bb`](https://github.com/fomantic/Fomantic-UI/commit/2a556bb660ef063e014a2693ff05bb8139e7d529)
- Test upgrade path [`dc2fe9c`](https://github.com/fomantic/Fomantic-UI/commit/dc2fe9c13d661c016382f40a01b469d73df10de4)
- Fix typo in config [`388a11b`](https://github.com/fomantic/Fomantic-UI/commit/388a11bb1499d01ad2604290b5b285d0c7ecbbcd)
- Remove debug [`f8f9436`](https://github.com/fomantic/Fomantic-UI/commit/f8f943637097bfdee2d2052e8445ed9dda9bf7b1)
- Readme [`459b378`](https://github.com/fomantic/Fomantic-UI/commit/459b3785b90faa91dbd97086b6f530a0c3e95b49)
- Readme [`a1479b6`](https://github.com/fomantic/Fomantic-UI/commit/a1479b6e2111b5ad113fcb7cf555f4ef1ab6e2a8)
- How many typos can one dev make? [`f61d34a`](https://github.com/fomantic/Fomantic-UI/commit/f61d34a7ae030ead85719577f8a53e2453448367)
- More typos in install [`29a1062`](https://github.com/fomantic/Fomantic-UI/commit/29a10624937493e230f110ebc0d302fe20f5853e)
- Updates burma flag, reduces flags png size [`5eb9aff`](https://github.com/fomantic/Fomantic-UI/commit/5eb9aff51f7b10ee0bc3bc88a42caa75422aa0a6)
- Testing [`49583b3`](https://github.com/fomantic/Fomantic-UI/commit/49583b3428f8927a02358e7104bc3ddc7adb99a5)
- Testing [`eb73ea2`](https://github.com/fomantic/Fomantic-UI/commit/eb73ea2c6ff253984886638dbacc696aa07634fd)
- Removes hook for debug [`9f8eded`](https://github.com/fomantic/Fomantic-UI/commit/9f8eded2a4eee39b1b02d1a885b6771fe0ba8e91)
- Update release notes again [`0d502b7`](https://github.com/fomantic/Fomantic-UI/commit/0d502b7f1126fbd62e7af16212d147c0a06707b6)
- Dropdown can now hide other input types #1752 [`db7f0cb`](https://github.com/fomantic/Fomantic-UI/commit/db7f0cbe25795a0e6e20331ec6ff1ca534edb16e)
- Popup now transitions on hide all [`fe83dad`](https://github.com/fomantic/Fomantic-UI/commit/fe83dad22e40fb17568351a8cd1fc93ec140be9c)
- Update rlsnotes [`6d406b2`](https://github.com/fomantic/Fomantic-UI/commit/6d406b2996e34a9f7d63562be173b45c5022625e)
- Fix double negative variable in table [`ba52bec`](https://github.com/fomantic/Fomantic-UI/commit/ba52bec5dd1503da8cea32091c1bd659029e06d4)
- Disable transition debug [`eed25a6`](https://github.com/fomantic/Fomantic-UI/commit/eed25a6dcbc4ee34354defc482df56edf9d74a49)
- Fix container size method not called due to improper renaming to length [`5c4f79b`](https://github.com/fomantic/Fomantic-UI/commit/5c4f79b3c264f48d038ce3017c13a30aa064c814)
- Properly parse RTL question [`74eccd8`](https://github.com/fomantic/Fomantic-UI/commit/74eccd86fa8a02357d72cc0466b43dbefbc7e2ea)
- Select fix [`39e48ba`](https://github.com/fomantic/Fomantic-UI/commit/39e48ba2c04b894696c2c3ead9077758aca2a9e5)
- Remove RTL debug [`41b0c8b`](https://github.com/fomantic/Fomantic-UI/commit/41b0c8b093b278f4d4edb9fc4725f378b16f3e8a)
- Add background rule for list item to prevent inheritance of menu item [`4deadd6`](https://github.com/fomantic/Fomantic-UI/commit/4deadd6da86bb3c734b676d112597aee9e77e7c3)
- Update release notes [`cecde9c`](https://github.com/fomantic/Fomantic-UI/commit/cecde9c1b56e07e5bdb17242cda64a48af70c31d)
- #1607 Meteor version uses global version from package.json [`bf30fe0`](https://github.com/fomantic/Fomantic-UI/commit/bf30fe0e9f0fb1189a3b066282ea4cc99438c9c8)
- Release notes 1.6.3 [`9a0d696`](https://github.com/fomantic/Fomantic-UI/commit/9a0d69653e53f69df168b208810a4f107c73feed)
- Rlsnotes [`4ae227e`](https://github.com/fomantic/Fomantic-UI/commit/4ae227e38f63387a8941a3d942cb84f85f326f12)
- Remove debug [`d95a47e`](https://github.com/fomantic/Fomantic-UI/commit/d95a47e161b4981efdb4246584ccde4c84f6c5aa)
- Add silent notes #3713 [`7e750cb`](https://github.com/fomantic/Fomantic-UI/commit/7e750cba60e4498ac1c066814b5c2dbaaf37120e)
- #3715 - fixed issue with bullets being affected by font weight [`7e4983e`](https://github.com/fomantic/Fomantic-UI/commit/7e4983e6993dd4b4e3a853176c2fc42931e065f7)
- Rlsnotes [`4d1a5d6`](https://github.com/fomantic/Fomantic-UI/commit/4d1a5d6a2c3de62f779a15fc88716773e70b4160)
- Rlsnotes #3655 [`cdda2c6`](https://github.com/fomantic/Fomantic-UI/commit/cdda2c6a1e1a7ef6c6b47997f354db861adf827f)
- #3039 rlsnotes [`5de7fcc`](https://github.com/fomantic/Fomantic-UI/commit/5de7fcc9471ec815c1a7062c3470b529b8ef6969)
- Rlsnotes #3080 [`767ad26`](https://github.com/fomantic/Fomantic-UI/commit/767ad26cb93cd78f588919c6a51e6e25b1a15990)
- Sub headers now force display: block #3020 [`df3ef37`](https://github.com/fomantic/Fomantic-UI/commit/df3ef37da8a2689f2cce2e116566e92aeb4f621c)
- Rlsnotes [`206a674`](https://github.com/fomantic/Fomantic-UI/commit/206a674c211e638f8b5e349e73f5993d1c1678a1)
- Rlsnotes #3080 [`e4c3d4b`](https://github.com/fomantic/Fomantic-UI/commit/e4c3d4ba93ea13aad763d6fcbe7d2ca9252cabe1)
- Sub headers now force display: block #3020 [`db0ebda`](https://github.com/fomantic/Fomantic-UI/commit/db0ebda63a37ca82ac2328b36dc3be94ab4c9936)
- Rlsnotes [`ecd8eac`](https://github.com/fomantic/Fomantic-UI/commit/ecd8eac801711646905505fa79c4f6dad2258a60)
- #3016 release notes [`052a961`](https://github.com/fomantic/Fomantic-UI/commit/052a9616229dae5ee800ed9785ff5676de8c7945)
- Add missing dep [`d92411a`](https://github.com/fomantic/Fomantic-UI/commit/d92411a77b26ee345153323b2553d4b7deea5f9b)
- Remove background color from input, causes flash with autocomplete styles #2502 [`c1321e9`](https://github.com/fomantic/Fomantic-UI/commit/c1321e93652a05116c8db448b2c363c84e724059)
- Remove debug #2853 [`e954241`](https://github.com/fomantic/Fomantic-UI/commit/e95424107bb77adc3015668ca80a2fc913c837f7)
- Rlsnotes [`6dd1f4f`](https://github.com/fomantic/Fomantic-UI/commit/6dd1f4fb5d4c5e6554ec3807b9d40daab4f08b24)
- Rlsnotes #2264 [`7d23712`](https://github.com/fomantic/Fomantic-UI/commit/7d23712f8cd9ef24b35c7c69056d08de49bebe29)
- #2635 rlsnotes [`096a2f4`](https://github.com/fomantic/Fomantic-UI/commit/096a2f41f700fba6458314c587224f8c694a6576)
- Manually merges #2843, adds rlsnotes` [`dbe0c8d`](https://github.com/fomantic/Fomantic-UI/commit/dbe0c8dc46c179849b43b155c12e2fe0bf01da41)
- Rlsnotes #2839 [`61b4012`](https://github.com/fomantic/Fomantic-UI/commit/61b40125216540748eb1da72a879fee8a10ba630)
- #2825 rlsnotes [`b1668c4`](https://github.com/fomantic/Fomantic-UI/commit/b1668c47f76ea5646f7abbf3924281f64a73c9bb)
- #2637 notes on added behaviors [`50264e3`](https://github.com/fomantic/Fomantic-UI/commit/50264e3602c27bb1d06222df92c7080772da59f4)
- Rlsnotes #2824 [`4a62c79`](https://github.com/fomantic/Fomantic-UI/commit/4a62c797cbbf5eefb0a16a3316bbea8c076cdcb1)
- Rlsnotes #2795 [`49e03b3`](https://github.com/fomantic/Fomantic-UI/commit/49e03b361da43c3e3d374b09091a1c1aed1535b9)
- Remove console.log [`8a4f177`](https://github.com/fomantic/Fomantic-UI/commit/8a4f1777c01f7e9207dbe66cd4a822f59bf0f69c)
- #2704 remove unused variable [`938a32e`](https://github.com/fomantic/Fomantic-UI/commit/938a32e6b8d8972455a2c3590ef96da994a82ef6)
- #2655 rlsnotes [`6a6c295`](https://github.com/fomantic/Fomantic-UI/commit/6a6c295c43aaf8a24e1cca93c664c66ee706e503)
- #2648 rlsnotes [`ce3a190`](https://github.com/fomantic/Fomantic-UI/commit/ce3a19085ee626cd2f7285383568cc4b5f1bd0dc)
- #2649 rlsnotes [`7e4428e`](https://github.com/fomantic/Fomantic-UI/commit/7e4428e194bb5727f9df869f68c1029004fa5404)
- #2636 rlsnotes [`70186f7`](https://github.com/fomantic/Fomantic-UI/commit/70186f73ae29607473e579032a89dccddcc475b9)
- #2550 rlsnotes [`5f0d07c`](https://github.com/fomantic/Fomantic-UI/commit/5f0d07cf133a5166b6d1cc908bae842f7c6ca817)
- #2550 Fixes isssue with flex-basis in IE [`89ed5ef`](https://github.com/fomantic/Fomantic-UI/commit/89ed5effafb596adebd4417a6f8af367d62c365d)
- #2532 rlnotes [`c55ed42`](https://github.com/fomantic/Fomantic-UI/commit/c55ed428b5a397209ebb05714c0cdd98d559a5d1)
- Fixes initialized checkbox double trigger with for/id match. #2572 #2581 [`2fc6cf1`](https://github.com/fomantic/Fomantic-UI/commit/2fc6cf1bce96b33fa239f282e08a7da40f5a00a9)
- #2576 Modal will remove body style after hiding [`bb5222d`](https://github.com/fomantic/Fomantic-UI/commit/bb5222d9510321636d17a05d682b5eff50514add)
- Fix unnecessasry line from rlsnotes [`056f074`](https://github.com/fomantic/Fomantic-UI/commit/056f074895c931c93e661210f1e4879e1f3f8688)
- RLSNOTES [`4bbe8e9`](https://github.com/fomantic/Fomantic-UI/commit/4bbe8e9653ddbef2a31f60ec3f9fa0b2cab23813)
- Rlsnotes [`0b80b31`](https://github.com/fomantic/Fomantic-UI/commit/0b80b31267f6007d36ad48bb21a8ab7c3304f8d9)
- Restore defaults now correctly clears previous values [`f022cd4`](https://github.com/fomantic/Fomantic-UI/commit/f022cd4910f09e3d241c54fe881ba4079c255f08)
- Add container [`a224f78`](https://github.com/fomantic/Fomantic-UI/commit/a224f78ac6c16b2b8fb0a57c0046586066d4e501)
- Fix admin flag set in example json! #2453 [`82d9c2d`](https://github.com/fomantic/Fomantic-UI/commit/82d9c2d9cfc43cbdcc42cab30c4e416e390ab37d)
- Fixed terrible bug where IE would refocus wrong element if focused element was hidden with transition. Caused dropdowns to re-open in IE on click [`6b18675`](https://github.com/fomantic/Fomantic-UI/commit/6b1867531f13f1dc6087a7636ff3567bf942e714)
- Remove border color animation to avoid transition on responsive sizing [`12540e1`](https://github.com/fomantic/Fomantic-UI/commit/12540e1351878e2bd32e41f0f912bd17eda71645)
-  #2455 remove logging [`8f3adb4`](https://github.com/fomantic/Fomantic-UI/commit/8f3adb47bfa915454d17202cc579b58dc5a52754)
- #2445 add width: auto to input in dropdown. [`38300ed`](https://github.com/fomantic/Fomantic-UI/commit/38300edd19fe2114da93a52c0225d16416d4776f)
- Remove console log [`32a8344`](https://github.com/fomantic/Fomantic-UI/commit/32a8344288410a1b82974b2304860d8f4e07cbc4)
- remove console.log [`93baa5f`](https://github.com/fomantic/Fomantic-UI/commit/93baa5f165b3819711c8045ee6b5eafa69dbe986)
- RLSNOTES [`8a0b4ee`](https://github.com/fomantic/Fomantic-UI/commit/8a0b4eed527d7d74975b4164bfade5c35c050405)
- Merge sidebar background inherit rules [`5ac05dc`](https://github.com/fomantic/Fomantic-UI/commit/5ac05dcd153526b2a5eae0c52683281dee2a478f)
- RLSNOTES [`c579aa5`](https://github.com/fomantic/Fomantic-UI/commit/c579aa59d9a239adefc849073103c26e6b4c0038)
- Update rlsnotes [`9fe4910`](https://github.com/fomantic/Fomantic-UI/commit/9fe4910468552e31876e3d4ed1f79942956cc238)
- #2374 release notes [`96f6dc3`](https://github.com/fomantic/Fomantic-UI/commit/96f6dc38e7b57c3048269a766d3979d9c62bf975)
- Grids and containers inside menu should inherit valign [`77b924e`](https://github.com/fomantic/Fomantic-UI/commit/77b924ed9c87f66ca951179c379237772149cec3)
- Add debug [`58abe48`](https://github.com/fomantic/Fomantic-UI/commit/58abe484c1f118429304de4906ad064cef6d4a7a)
- Spacing [`b208d6f`](https://github.com/fomantic/Fomantic-UI/commit/b208d6fd222eba17a884159b0b91bf89cebbcce0)
- #703 RLSNOTES [`8598b65`](https://github.com/fomantic/Fomantic-UI/commit/8598b654de1723ee2f08412c0344ec7742a83891)
- Remove console.log [`5c565c7`](https://github.com/fomantic/Fomantic-UI/commit/5c565c774353b5be032d936c28bb41db8a2b94f1)
- Fix corner label mouse selection [`9588488`](https://github.com/fomantic/Fomantic-UI/commit/958848847cd39e1efc8e69bcd06db067d3e277d5)
- Fix basic table theme [`81abc21`](https://github.com/fomantic/Fomantic-UI/commit/81abc21172fe1868fb988e5752b87c84b7a1399f)
- #2309, missing line height rule for massive icon [`5fb6c54`](https://github.com/fomantic/Fomantic-UI/commit/5fb6c541b798d55399809f080fad198bef233f63)
- Attached msg back and forth [`8281c0c`](https://github.com/fomantic/Fomantic-UI/commit/8281c0c39108f04539a768740c8be16685e935c9)
- #2287 fix line height of groups [`73b0586`](https://github.com/fomantic/Fomantic-UI/commit/73b05865f93acb9f2b7eb92e82a658e5e2574e6b)
- Remove debug [`f74de3c`](https://github.com/fomantic/Fomantic-UI/commit/f74de3ce65ee3a698ebf1282c9d2b1180be2ba22)
- Rounded by default menu [`08b9607`](https://github.com/fomantic/Fomantic-UI/commit/08b96072dc406b2583aee37dd182f65ce99e5457)
- RLSNOTES #2266 [`2ca57cd`](https://github.com/fomantic/Fomantic-UI/commit/2ca57cd2920e9a3054328dbc74470167337fcae8)
- RLSNotes [`810c896`](https://github.com/fomantic/Fomantic-UI/commit/810c8960f8f1c6f8b4496eed396d3d14cc779f3a)
- Rlsnotes [`b8df8cd`](https://github.com/fomantic/Fomantic-UI/commit/b8df8cdced81a041a68af153cf06f64bf489e947)
- Remove unnecessary easing setting [`a2edb6f`](https://github.com/fomantic/Fomantic-UI/commit/a2edb6f15c2ac525fac4b868267c465ef998a3b3)
- Rlsnotes #2180 [`ac0b85c`](https://github.com/fomantic/Fomantic-UI/commit/ac0b85c6c40ff96c5162a1d8708aff9fbc265eec)
- #2218 rlsnotes [`1e486a2`](https://github.com/fomantic/Fomantic-UI/commit/1e486a2e3f7230e0a149d1941c8071cd0b87ddcf)
- RLSNotes #2222 [`9f07ceb`](https://github.com/fomantic/Fomantic-UI/commit/9f07ceb8bcbe232d4f000857c92fb409ac4a311e)
- #2181, min width on circular [`e604aef`](https://github.com/fomantic/Fomantic-UI/commit/e604aefa1d026991b0d8132646b7b0de28b4677c)
- Rlsnotes [`f88d6d4`](https://github.com/fomantic/Fomantic-UI/commit/f88d6d45bd4164ae40add8edd757400e49747f08)
- Remove redundant class set [`1d0918e`](https://github.com/fomantic/Fomantic-UI/commit/1d0918ea729cfd01b0cfdeffe428fde456817825)
- Fix img inside label [`93ca4b9`](https://github.com/fomantic/Fomantic-UI/commit/93ca4b9b88827144f0a654c0ee9107b304c65ed3)
- #2083 RLSNOTES [`fd36c1e`](https://github.com/fomantic/Fomantic-UI/commit/fd36c1eb19cee1b75071de2a109e8a51afce8e04)
- Add container to install [`849e5fe`](https://github.com/fomantic/Fomantic-UI/commit/849e5fe4778d14308b8a8d0134d633ff60e4b915)
- Rlsnotes [`9115599`](https://github.com/fomantic/Fomantic-UI/commit/911559941ec20602aa426ae1f58f05e9f57f4e67)
- Increase divider spacing in breadcrumb [`eacab1c`](https://github.com/fomantic/Fomantic-UI/commit/eacab1c2cc33a2b6e837d942df7b1ce98ee8a89e)
- Remove debug [`2a91429`](https://github.com/fomantic/Fomantic-UI/commit/2a91429802b591b353ceda8c22ef069a707a226d)
- More deps [`f80938e`](https://github.com/fomantic/Fomantic-UI/commit/f80938ef5b05cf0e176a8fc4442c3274b03c8f35)
- Remove hook [`4d11a1c`](https://github.com/fomantic/Fomantic-UI/commit/4d11a1cca8f27d8f8002dc4d27545b3360fe921c)
- #1698 Remove basic modal border radius [`ecc121f`](https://github.com/fomantic/Fomantic-UI/commit/ecc121fc1ff90e62701b43f78985c22c2c4db5df)
- #1630 - Form set values will now validate forms after value set [`c8a203b`](https://github.com/fomantic/Fomantic-UI/commit/c8a203b3132fb1577a743b012fb460488a348155)
- Merge in #1630, Match code style, remove mixed space/tabs, add debug statements. [`c3467ed`](https://github.com/fomantic/Fomantic-UI/commit/c3467ed808f28fe4486f44ca8b01c57bf0cc5e67)
- #1655 #1687 Collapsing margin on pusher inherits child margins [`de524c1`](https://github.com/fomantic/Fomantic-UI/commit/de524c134d24e14f0183aa38c68760548e8757de)
- Update releasenotes [`d42dbec`](https://github.com/fomantic/Fomantic-UI/commit/d42dbecd915ea02c31f21c2ed26146176c40d7e6)
- Update release notes #1680 [`6dcc5c7`](https://github.com/fomantic/Fomantic-UI/commit/6dcc5c7c525be0b43ded69548a36ddaa352ceb4c)
- Fix API abort to also resolve promise [`5a964f8`](https://github.com/fomantic/Fomantic-UI/commit/5a964f8385cd329763e73a60adeb8acf18c5f802)
- Remove debugger statement [`c0f6e61`](https://github.com/fomantic/Fomantic-UI/commit/c0f6e6130187f0b0c5b897efc0f5e9ca45d3611d)
- Update rlsnotes [`c079984`](https://github.com/fomantic/Fomantic-UI/commit/c079984a9162593923e3f5396a0ddd12bc539968)
- Remove console log [`03ce00a`](https://github.com/fomantic/Fomantic-UI/commit/03ce00acd96dac1fea377d0e17211db03b8b8c1e)
- Update release notes [`121e8f0`](https://github.com/fomantic/Fomantic-UI/commit/121e8f0d7cd1d516e8f5306f18c846f900af7d7c)
- Update release notes [`59c179c`](https://github.com/fomantic/Fomantic-UI/commit/59c179c8ff8d0cdbca89466a21e5415f8010f27b)
- Remove console log #1611 [`45c0232`](https://github.com/fomantic/Fomantic-UI/commit/45c0232b0691524c2e292eb923639aaa641a0ee2)
- add missing .woff2 file [`35053b6`](https://github.com/fomantic/Fomantic-UI/commit/35053b69ad09c5ee558c443b65aecc20ec884aae)
- Add example logo image [`e15f251`](https://github.com/fomantic/Fomantic-UI/commit/e15f251e809a69559e37ea52de7abb5183cc40ed)
- Move docs tasks [`2ac6d5f`](https://github.com/fomantic/Fomantic-UI/commit/2ac6d5fc6b95921f25fd087c25cd90334babf3fd)
- ]Merge branch 'master' of github.com:Semantic-Org/Semantic-UI into next [`175b84b`](https://github.com/fomantic/Fomantic-UI/commit/175b84bdddadb1184aa7a3bab1f981799d6e5d7a)
- Remove build files [`a4f565d`](https://github.com/fomantic/Fomantic-UI/commit/a4f565d033343cc87f568b7f8c45862b371b9a80)
- Everything getting moved around [`e5baeb9`](https://github.com/fomantic/Fomantic-UI/commit/e5baeb91f4f11046f6fe3a91a3495c281654aef1)
- Rename build to dist, update deps in package.json [`4551edc`](https://github.com/fomantic/Fomantic-UI/commit/4551edc097605e427c62f497779fc323370e956b)
- Initial commit of global site config [`fa1b35a`](https://github.com/fomantic/Fomantic-UI/commit/fa1b35a3efeb662403a4600f0907780221ee087b)
- Clear build dir for merge [`b6a3a38`](https://github.com/fomantic/Fomantic-UI/commit/b6a3a3824d1caabb86b3b2c5ffd473ad0124650e)
- Remove docs from sui main repo [`02ae601`](https://github.com/fomantic/Fomantic-UI/commit/02ae60187f1354e07e15f2b3f810ccda90fdfcd4)
- Rebuild files [`6d30b32`](https://github.com/fomantic/Fomantic-UI/commit/6d30b325896856af2b44a4fd929d9ebbd65cd885)
- Reworking grid to use fixed gutters, and padding on page grid. Fixing grid docs [`dc786e2`](https://github.com/fomantic/Fomantic-UI/commit/dc786e2c58f0d4ee778b371ea7a5667af153d1b2)
- Update jquery, fix broken link in docs [`5e069d6`](https://github.com/fomantic/Fomantic-UI/commit/5e069d6f5f8239601ab7aa3bad541d28c88b4cc8)
- Removes docs.json from root, updates dist [`91cce72`](https://github.com/fomantic/Fomantic-UI/commit/91cce72ae4fed3fc912f71f43c10192ecb44a066)
- Rebuild 1.4.1 [`a70cb4e`](https://github.com/fomantic/Fomantic-UI/commit/a70cb4e8ba4a5d2c49c365be1482103d93c2a79b)
- Build 1.3.0 for release [`620e444`](https://github.com/fomantic/Fomantic-UI/commit/620e444473881fdc726bc5eae6b86ab2f9a539d6)
- Build 1.2.0 [`5b36020`](https://github.com/fomantic/Fomantic-UI/commit/5b360207e002e6f8a5b8ae339935e31a6d21891d)
- Rebuild dist files [`40d2d6d`](https://github.com/fomantic/Fomantic-UI/commit/40d2d6def265081d53d2ff3b1fb751633f56986a)
- Rebuild css [`1b65d53`](https://github.com/fomantic/Fomantic-UI/commit/1b65d53afa4abee417ac11ee4be3b8b24187a25e)
- Moving around [`a80c154`](https://github.com/fomantic/Fomantic-UI/commit/a80c154fcf8bbc9fbaed89a9e3d3426ace04cdfe)
- Move contents back to src [`cf2673e`](https://github.com/fomantic/Fomantic-UI/commit/cf2673ebf66a329a199088a390c0bfd163134e34)
- Rebuild dist [`7ca439d`](https://github.com/fomantic/Fomantic-UI/commit/7ca439dcd381cb0e7583a3e494652a9b187c904b)
- Add dist to build [`2bce432`](https://github.com/fomantic/Fomantic-UI/commit/2bce4325d5ddaa2dafd89cb5ee86278944f008ef)
- Adds many more dropdown examples [`4348911`](https://github.com/fomantic/Fomantic-UI/commit/4348911ff5af741a4b4e4f266227ab6e06f1a76f)
- Add back in examples [`77e0f83`](https://github.com/fomantic/Fomantic-UI/commit/77e0f83481891e2fa3a7f2c3635c0e4650fc1221)
- Rebuild files [`eea211d`](https://github.com/fomantic/Fomantic-UI/commit/eea211d1c3dbda04b8fd230ca0a6f319ef84d308)
- Adds themed dimmer [`660aff6`](https://github.com/fomantic/Fomantic-UI/commit/660aff66f3be4bc9516ce89969be1eb342f3f53b)
- Adds mising files from build [`67ab010`](https://github.com/fomantic/Fomantic-UI/commit/67ab0101c5b773e16e6d96657a428337cf68ec1e)
- Attempting to fix some performance issues with sidebar [`0451463`](https://github.com/fomantic/Fomantic-UI/commit/0451463a84913b31d6dc4d7a7879c99027b07b42)
- Rebuild dist from latest changes [`4ca78a8`](https://github.com/fomantic/Fomantic-UI/commit/4ca78a842768a73eb2ea120fe6f459016d0c711b)
- Iteration on release tasks [`1054a4c`](https://github.com/fomantic/Fomantic-UI/commit/1054a4ca21424284dd372f068ac124f55515761f)
- Fix issue with localization modal showing twice, update localization percentages. [`469666b`](https://github.com/fomantic/Fomantic-UI/commit/469666be07e356b4333c6b30e1c83f542a563617)
- Deploying beta updates [`fdf47fe`](https://github.com/fomantic/Fomantic-UI/commit/fdf47fed12feca5faa07b327a7511b2de176b47b)
- Rebuild files for beta deploy [`37c6cab`](https://github.com/fomantic/Fomantic-UI/commit/37c6cab6e22d679172531d1682193e5d3e772ac5)
- Rebuilds files for beta [`d162fa2`](https://github.com/fomantic/Fomantic-UI/commit/d162fa2086715bfd60048aa4d874375abbbd0bcc)
- Iteration on state and api docs [`8719779`](https://github.com/fomantic/Fomantic-UI/commit/8719779f00bde974a1a383294299aa6ebd839669)
- Rebuild for beta docs [`c3f8131`](https://github.com/fomantic/Fomantic-UI/commit/c3f81313588c2bd3f85365bb1e37b38d5c999c30)
- Rebuild for docs deploy [`a0c1f98`](https://github.com/fomantic/Fomantic-UI/commit/a0c1f98300af3d69fbbe956d625e226dc9648682)
- Update release notes and rebuild [`b06da25`](https://github.com/fomantic/Fomantic-UI/commit/b06da25f665fb2d15a7e4739137b6ffa0ff610a0)
- Adds themes for modal, and updates to modal structure [`dfe043f`](https://github.com/fomantic/Fomantic-UI/commit/dfe043f5c26e545025faa26846152c79a6709190)
- Rebuild for deploy [`6b9893c`](https://github.com/fomantic/Fomantic-UI/commit/6b9893c38368c7d5074572c3da420fce05345905)
- Remove dependency on ACE editor, redo all code samples, redo code colors [`3024db0`](https://github.com/fomantic/Fomantic-UI/commit/3024db0b737ef62e68e2ba2c6ab7482865a3f9c2)
- Complete first iteration of site module [`1095937`](https://github.com/fomantic/Fomantic-UI/commit/1095937280780a51109c9bd5651bde4b5802b1b9)
- Update kitchen sink example [`573040a`](https://github.com/fomantic/Fomantic-UI/commit/573040a6281a1b25a9c808abb96c61db9aef2ad0)
- Finish porting of new FontAwessome [`b9e83b2`](https://github.com/fomantic/Fomantic-UI/commit/b9e83b2979f0d198407de29daabe3d4c5a8bc79b)
- Rebuild packages [`af41990`](https://github.com/fomantic/Fomantic-UI/commit/af41990b1f55ad9cd7b6d509d26ff910d5821598)
- Working on icon rewrite [`615a5be`](https://github.com/fomantic/Fomantic-UI/commit/615a5be6ea61641e5946123a121fcfeee72464d9)
- Rebuilds files and updates semantic.config with new components [`de54ab6`](https://github.com/fomantic/Fomantic-UI/commit/de54ab698410e8cccd98c78008153ee1a700fd3c)
- Work on API, and related behaviors [`d5bd827`](https://github.com/fomantic/Fomantic-UI/commit/d5bd827f151b353ef77a02fa60d2038bfba8ef25)
- Fixes issue with scale down animation in chrome [`5340f43`](https://github.com/fomantic/Fomantic-UI/commit/5340f43553ea6df8a4b5c0047c12e04f6ca0d4a3)
- Rebuild one last time dist/ [`44e47e2`](https://github.com/fomantic/Fomantic-UI/commit/44e47e2856e586de518763fd3441c0d8e7fdaaab)
- Build 1.4.0 [`3274804`](https://github.com/fomantic/Fomantic-UI/commit/327480468f64e5d2bf8a4c1a4f8dc0a1c1f35963)
- Restructures site variables, fixes slider/toggle checkbox to not change with em (like radio and checkbox), adds several missing form variables [`0106cd3`](https://github.com/fomantic/Fomantic-UI/commit/0106cd3fb0978b9d40c5e7ea4dcfd8d83080f84f)
- Rebuilds project files [`5fce891`](https://github.com/fomantic/Fomantic-UI/commit/5fce891258f4704d4bfdf3507ab3efdfb3b082e9)
- Iteration on grid docs, and grid fixes [`a801642`](https://github.com/fomantic/Fomantic-UI/commit/a80164233acb5be96e0622020860f2dfd0da2582)
- Adds more css reset themes, adds flag start docs, fixes piled segment for the zillionth time [`0e4d37b`](https://github.com/fomantic/Fomantic-UI/commit/0e4d37bd8f5dc95b68bbf733bec518fb1ad881e0)
- Rebuild dist [`e9a4b66`](https://github.com/fomantic/Fomantic-UI/commit/e9a4b6673e93ddd2911162bfc18af629585219b7)
- Continuing to debug issues with other UI elements when used inside 3d contexts [`10b5798`](https://github.com/fomantic/Fomantic-UI/commit/10b5798bc315cd4db8f2706081a099aa50096a0e)
- Incomplete work [`d1ba07a`](https://github.com/fomantic/Fomantic-UI/commit/d1ba07aaf14b44d6810205de8490be245519a3c5)
- Working on tab performance, and rewrite to allow for multiple tab groups to use HTML5 state together. CSS Variables for transitions [`5d14059`](https://github.com/fomantic/Fomantic-UI/commit/5d14059e681d4de96240b195184aba9f0755b092)
- Revisions to message/segment shadows, fixes for emotive colors, especially headers on warning/info/etc [`d9aa41e`](https://github.com/fomantic/Fomantic-UI/commit/d9aa41ed3252ed6da52e65e7665b19e05f7e5e9e)
- Complete card theme, add basic view [`1c042e6`](https://github.com/fomantic/Fomantic-UI/commit/1c042e6f6fdd0094c61d4af876e811dd79c7ff1f)
- Fix inverted segments, block/attached header adjustments, fixes for responsive table headers [`0597663`](https://github.com/fomantic/Fomantic-UI/commit/059766396985e6fd230d84712e822eb49f7f55e8)
- Updates testing js [`7ce0e35`](https://github.com/fomantic/Fomantic-UI/commit/7ce0e353d937458936647a8027c95399caa527ed)
- Finishes rebuilding of packages [`82aa999`](https://github.com/fomantic/Fomantic-UI/commit/82aa9993381aa8da271a70e5cea1cd977f234532)
- Rebuild files [`70c20f2`](https://github.com/fomantic/Fomantic-UI/commit/70c20f2f013ff29f7ac89b35987ce55df514e148)
- Rebuild files [`367e97b`](https://github.com/fomantic/Fomantic-UI/commit/367e97bd2de6e67b5ae4fbf62f754a0e496fd35d)
- Rebuilds project [`088498c`](https://github.com/fomantic/Fomantic-UI/commit/088498cf36ce0ae0ba47ed3c3fee89c7289d3170)
- Rebuild some missing assets for docs [`4f0d563`](https://github.com/fomantic/Fomantic-UI/commit/4f0d563c7a8f90675d37a1abdaeebce8159dac67)
- Rebuild dist [`99edade`](https://github.com/fomantic/Fomantic-UI/commit/99edadec30772472d1d27e378ed394095d3886c7)
- Spruces up accordion styles, add chubby accordion theme, adds more accordion variables, spruces up docs sidebar menu [`d3dd994`](https://github.com/fomantic/Fomantic-UI/commit/d3dd994c9b79e5e39e921672c817446aaabb3f62)
- iteration on global site module [`9bda901`](https://github.com/fomantic/Fomantic-UI/commit/9bda901d5a2aeb600481106f4677abd2bad960b0)
- Modify default button theme to be flat, add old theme as 'classic', fix centered popup offset, modify example styles [`23509d6`](https://github.com/fomantic/Fomantic-UI/commit/23509d650fa9a92bf51a6f04dee314e4b0ddaedf)
- Rebuild files after branch merge [`e12aa99`](https://github.com/fomantic/Fomantic-UI/commit/e12aa99e24a18e63f267c094d0c156d48181ac2f)
- Rebuild files [`947dce3`](https://github.com/fomantic/Fomantic-UI/commit/947dce3a090e4d86b0b28e831b3a2d0d2c687a36)
- mend [`ebfca78`](https://github.com/fomantic/Fomantic-UI/commit/ebfca78e4b55ac241064c5028ced50298b5998ee)
- Fix contributor messages, fix icon spacing bug [`d86e66e`](https://github.com/fomantic/Fomantic-UI/commit/d86e66ec3c0e8d19b99d51e6a8ab8f0fb160e398)
- Rebuilds packaged files [`0cd1899`](https://github.com/fomantic/Fomantic-UI/commit/0cd1899b882405c3baa8080ed0a32f9c1d3670c8)
- Adds inverted buttons finally! Iteration on form and button [`969c2a6`](https://github.com/fomantic/Fomantic-UI/commit/969c2a691827bf92727b752808cfb03bfaa41a35)
- Form variable beginning [`9f8c8e3`](https://github.com/fomantic/Fomantic-UI/commit/9f8c8e3f6e64449d84cfa00044992efeaf7af26e)
- Adds flat button theme [`3e78389`](https://github.com/fomantic/Fomantic-UI/commit/3e7838941ee9a58680ccd1f11d1792e16133557e)
- Rebuild files [`d84de60`](https://github.com/fomantic/Fomantic-UI/commit/d84de60120315f27ecce5c8fe65a91ab463ad54f)
- Finishing theming of messages, adds github and google message themes [`e66ce4d`](https://github.com/fomantic/Fomantic-UI/commit/e66ce4dcdc808a5f7850d7847964982c99c646da)
- UI Transiutions now forces display on element during animation with important to avoid inheritance issues. Rewrite of some more form variables [`869115b`](https://github.com/fomantic/Fomantic-UI/commit/869115b2068f665352a8f44181a64cbef6ca21af)
- Rebuild files [`6e8637f`](https://github.com/fomantic/Fomantic-UI/commit/6e8637f24e25b10d1e699e878dbdebec6f4889b6)
- Remove corner text labels [`7e674a0`](https://github.com/fomantic/Fomantic-UI/commit/7e674a0c1f9cc7f3bdca7ff7b85687660282b542)
- Adds new step component, step variables and new themes, adds fixes for icon button alignment, compact labeled icon button, fixes to reset [`d9900b2`](https://github.com/fomantic/Fomantic-UI/commit/d9900b238d7fe7c3759434702f739a09e089a632)
- Adds grid example, adds some fixes for inverted grids [`c146063`](https://github.com/fomantic/Fomantic-UI/commit/c146063608c753e3d185f3c5a6954e78e5af1926)
- Builds version 0.15.0 and updates version number [`a93c45e`](https://github.com/fomantic/Fomantic-UI/commit/a93c45e7ca8d1fec177202211c7e94c440dccad2)
- Rebuilds project files [`f112997`](https://github.com/fomantic/Fomantic-UI/commit/f11299736b9067e532618ff05006725c121b216d)
- Fixes several bugs introduced with menus [`3715c4a`](https://github.com/fomantic/Fomantic-UI/commit/3715c4a0809460ee0ff6726dcca7f04f537f12db)
- Fix issues with safari not automatically sizing icons when given height 0, fixes inputs in menu [`96e1727`](https://github.com/fomantic/Fomantic-UI/commit/96e17273f9efd98161a9b5f30be19cdf08813d62)
- Adds fixes for segment first/last, adds separate variables for attached/block header sizes [`2aeb94b`](https://github.com/fomantic/Fomantic-UI/commit/2aeb94bd72d9b9321fff910b81ad55d5e7107e0f)
- Rebuild and fix valign in icon for zillionth time [`97e155e`](https://github.com/fomantic/Fomantic-UI/commit/97e155e5fbda6744be7b6379527e8657dea89145)
- rebuild files [`64f3f88`](https://github.com/fomantic/Fomantic-UI/commit/64f3f884543a1ada58145a1eac6ac6d339fddba9)
- Themes feed, adds timeline theme for feed [`27e27ee`](https://github.com/fomantic/Fomantic-UI/commit/27e27eefe26ef3bda1be2faa531d33f13d33533b)
- Rebuild files [`de116da`](https://github.com/fomantic/Fomantic-UI/commit/de116da3ba355f305903c98e5082a275c9d7e4b9)
- Adding responsive grid [`785f4c4`](https://github.com/fomantic/Fomantic-UI/commit/785f4c400c7698767bfecddc6c5e34d2d7019b13)
- Fix tabular menu [`8b9e46c`](https://github.com/fomantic/Fomantic-UI/commit/8b9e46c618534fb0a98788ba4b383cfc0faf748a)
- Continue to work on the puzzle that is grids [`8382e2e`](https://github.com/fomantic/Fomantic-UI/commit/8382e2e093e0055c72768456e21653e299874eb4)
- Fix dist versions to remove merge conflicts, fix immediate build on config [`d2dd222`](https://github.com/fomantic/Fomantic-UI/commit/d2dd2228286d0f8c461ea869cbc1aa9957aef91a)
- Fix following menu spacing [`38f8ac5`](https://github.com/fomantic/Fomantic-UI/commit/38f8ac597e477471cabb279095d530341846113e)
- Update label styles [`9dcac21`](https://github.com/fomantic/Fomantic-UI/commit/9dcac212b042492c0c6c056e9250bd3cdcb67217)
- Fix rating example, remove relaxed list header spacing [`16feb95`](https://github.com/fomantic/Fomantic-UI/commit/16feb9565f068e33fff252b629cc2028311d8625)
- Build 1.1.0 for release [`2b2184b`](https://github.com/fomantic/Fomantic-UI/commit/2b2184be73d27d88d91b527ab75fd0923588387f)
- Relase and build version 0.14.0 [`97bcab4`](https://github.com/fomantic/Fomantic-UI/commit/97bcab4b373b1b0adeee287e0233efd1a4def96f)
- Rebuilds files [`b71ec4b`](https://github.com/fomantic/Fomantic-UI/commit/b71ec4b64eb5dfa3170a4c1a08e6eb6f0154453d)
- Update dist/ [`960308e`](https://github.com/fomantic/Fomantic-UI/commit/960308e09c2ab5008240cf019c14e1e1ae2694fc)
- Adjustments to docs for kitchen sink [`1083493`](https://github.com/fomantic/Fomantic-UI/commit/1083493015253bb2e232da45328d268a09fe37b7)
- Rebuild all files [`ed62675`](https://github.com/fomantic/Fomantic-UI/commit/ed626758cdf5d7b436ccf58756a361afc153f569)
- Fixes logged out nav menu on tablet [`3cf4ca7`](https://github.com/fomantic/Fomantic-UI/commit/3cf4ca70f67b7f6f7a54aab40df7941b2f1fe8be)
- Adds preliminary kitchen sink example to dist examples [`6de0030`](https://github.com/fomantic/Fomantic-UI/commit/6de00304c15721cebc74c993559d6fe24b0eddb9)
- Disable ios resize [`2ed6218`](https://github.com/fomantic/Fomantic-UI/commit/2ed6218097cc754ddd10b1e48fe2349aff4024bf)
- Migrates item view to card view, in preperation for a more generic card view, extends docs on cards [`989528a`](https://github.com/fomantic/Fomantic-UI/commit/989528af91093640a20da86bc6fa54016724e053)
- Rebuild files [`f38c58a`](https://github.com/fomantic/Fomantic-UI/commit/f38c58a6969b64d9f7593991f047804edba455e9)
- rebuild project, package.json is now using bleeding edge [`ff2f444`](https://github.com/fomantic/Fomantic-UI/commit/ff2f4447c054fd28d46e3a5181184645b017208d)
- Rebuild files [`0c5bab1`](https://github.com/fomantic/Fomantic-UI/commit/0c5bab1ab43e3ed737d6941fd3294820d94c32e2)
- Themes nag [`a3e974e`](https://github.com/fomantic/Fomantic-UI/commit/a3e974e7c8898b79131e35bdf70a03893d5f785f)
- Rebuild and add comment theme [`b47b394`](https://github.com/fomantic/Fomantic-UI/commit/b47b3947d71a09e99645e910707129a516c6c653)
- Release 1.6.0 [`215368c`](https://github.com/fomantic/Fomantic-UI/commit/215368ccc7f38350b6f18535fa43cae1c3d35ce9)
- Fixes test suite in branch [`f3b4a92`](https://github.com/fomantic/Fomantic-UI/commit/f3b4a9258b5eeb2d3c2798f78ff88b19c7f49033)
- Iterating on sidebar directions, default animations for directions, more features [`d46656a`](https://github.com/fomantic/Fomantic-UI/commit/d46656aee811349d333c0629131692baa2a20d6b)
- Rebuild files [`2814284`](https://github.com/fomantic/Fomantic-UI/commit/28142841365f9ee4f21ddc2404f23fb35e4a263a)
- Modal cache size on load [`5511ffb`](https://github.com/fomantic/Fomantic-UI/commit/5511ffb0a6bc5c7cef96dfbf5475ea29d3f8d049)
- Swaps reveal to use 3daccelerated transform instead of top/left [`161d1b1`](https://github.com/fomantic/Fomantic-UI/commit/161d1b137c2f11836cd14e84c8800dfa5d58bd75)
- Rebuild standard dist/ [`650a0f4`](https://github.com/fomantic/Fomantic-UI/commit/650a0f4e818a3f99e09f312cd0e2ff14f4c048ea)
- Rebuild beta files [`4c9f481`](https://github.com/fomantic/Fomantic-UI/commit/4c9f481f2b1892857d1e45504481428f84ecfc5e)
- Add a couple more themes for fun [`6f35b10`](https://github.com/fomantic/Fomantic-UI/commit/6f35b10e18bdd2d998d6df596f99a25f93e209f4)
- Adds flags to build [`8846e48`](https://github.com/fomantic/Fomantic-UI/commit/8846e487064173115a9a079a9508a38513a8a545)
- Rebuild files [`8ef1496`](https://github.com/fomantic/Fomantic-UI/commit/8ef1496cce7e98f567554bd7c2647bbdd08ce132)
- Fix several examples, and bug in tabbed pages with following menu [`e066be4`](https://github.com/fomantic/Fomantic-UI/commit/e066be47cb68c845a412940ac1683c857319b375)
- Adds variables for UI flags [`eeb6bd3`](https://github.com/fomantic/Fomantic-UI/commit/eeb6bd353b42932fd89295430a0eedf2850272ec)
- Complete item theming and documentation [`1369498`](https://github.com/fomantic/Fomantic-UI/commit/1369498b6cf33ee5db6729ecbfe30973b163efd9)
- rebuild files [`8b4d1ae`](https://github.com/fomantic/Fomantic-UI/commit/8b4d1ae2bc2058556b88246dc74b7ba6b2884073)
- Flag overrides modified [`d3b2005`](https://github.com/fomantic/Fomantic-UI/commit/d3b20059dd033f36e64e2a19e20d939e78a04d25)
- Rebuild files [`89ae340`](https://github.com/fomantic/Fomantic-UI/commit/89ae34031c2e49362923f6991b2a6ea89f53c9ce)
- Rebuild files for beta deploy [`5940c75`](https://github.com/fomantic/Fomantic-UI/commit/5940c75ac7e262df3e01f996dc5f8ce0c22d8b31)
- Fix page minheight with sidebar [`da16fd6`](https://github.com/fomantic/Fomantic-UI/commit/da16fd6fe73d3398a46bbeab2f4f13df232ff653)
- Rebuilds dist [`8c04c66`](https://github.com/fomantic/Fomantic-UI/commit/8c04c66a2c71611d7e3eab4fb5574fc3f9667842)
- Rebuild packages [`f044be6`](https://github.com/fomantic/Fomantic-UI/commit/f044be67e7d6e3d5a2bd36a8b2cc0dff31bed20b)
- Iteration on gulpfile design [`dc5e672`](https://github.com/fomantic/Fomantic-UI/commit/dc5e6724893ad6eb3a8f932daee09144c92d7af0)
- Updating docs pages to reflect correct settings [`0248cff`](https://github.com/fomantic/Fomantic-UI/commit/0248cff0019744262e6ba080b446100e0820b33d)
- Iteration on kitchen [`f4e89fb`](https://github.com/fomantic/Fomantic-UI/commit/f4e89fb86f4c7b85f2daef28b52cc3fbc79c7cf8)
- Complete initial complete rewrite of sidebar [`63d80d1`](https://github.com/fomantic/Fomantic-UI/commit/63d80d1de5bd4939f6acacf0c10e583e56e5ed3b)
- Fixes image labels, begins work on text corner labels [`2b8518e`](https://github.com/fomantic/Fomantic-UI/commit/2b8518e40e10e789d02b1411aa6f5cc946f45afc)
- Rebuilds files [`6f8b526`](https://github.com/fomantic/Fomantic-UI/commit/6f8b526c417e489be5ba858633feb826f3651f52)
- Begin rewrite of icon overrides [`020b9b4`](https://github.com/fomantic/Fomantic-UI/commit/020b9b4c06ca113e87d7e2c4245a196d4b26a00e)
- Iteration on search fixes [`1d8a8e3`](https://github.com/fomantic/Fomantic-UI/commit/1d8a8e3fe74dec8a3b144951b3837e6c1735c44a)
- Update font icons [`8015de1`](https://github.com/fomantic/Fomantic-UI/commit/8015de12149a09024b2bf68b54a0bc52232f133f)
- Remove spaces from md names [`1f31e56`](https://github.com/fomantic/Fomantic-UI/commit/1f31e56227c4a3e798510350684f997f206dc2be)
- Add renamed files [`b6c6916`](https://github.com/fomantic/Fomantic-UI/commit/b6c69163c140e2ad5fe470de1ce5603ae848bf53)
- Tryin to work through all the bugs and gotcha of sidebar with css transitions (headache central) [`c68c668`](https://github.com/fomantic/Fomantic-UI/commit/c68c6685e7740a30e93cf8df319c6214b29a5e75)
- Fixes attached message styles, modifies, info/warning/error colors, fixes error form colors somewhat. Moves list to elements [`8d81e87`](https://github.com/fomantic/Fomantic-UI/commit/8d81e87f16aa59764f790a5173c195b9cd643e3d)
- Rebuild for deploy [`9fcbebd`](https://github.com/fomantic/Fomantic-UI/commit/9fcbebd3b83b3783395357d9364c14f73929b050)
- Fixes issue with caret reset causing no input borders [`68be25f`](https://github.com/fomantic/Fomantic-UI/commit/68be25fcdecd38f833e8d2b6866ca1a7e624f6e5)
- Quick patch [`84acf04`](https://github.com/fomantic/Fomantic-UI/commit/84acf041640f603f0e0884d5320a42ee35511ced)
- Fix transition example page [`63723e1`](https://github.com/fomantic/Fomantic-UI/commit/63723e1bf30a2b5d36181edf4dfda6f1dfe87d24)
- Rebuild dist [`d4919c7`](https://github.com/fomantic/Fomantic-UI/commit/d4919c77607d176ebf2424d6e321f3b71c30bf25)
- Add many new examples using wireframe  content [`5bb7ae0`](https://github.com/fomantic/Fomantic-UI/commit/5bb7ae0ef49966738e491f2ce521d862988034e0)
- Rebuild for deploy [`55d1055`](https://github.com/fomantic/Fomantic-UI/commit/55d105564dc70fe825e44e8e134af4a5094f27f6)
- Beginnig to redo demo content in docs [`4372569`](https://github.com/fomantic/Fomantic-UI/commit/43725695b326b02482684727d4849aa466379534)
- Initial commit of themed dropdowns [`99eecc2`](https://github.com/fomantic/Fomantic-UI/commit/99eecc2ddda9091fbe1b7c78eae8db9643476abf)
- Rebuild dist for next [`5f3bc47`](https://github.com/fomantic/Fomantic-UI/commit/5f3bc4777c5ff8f6a4e61b6dc863472d07e0159a)
- Continuing to expand on examples for list/item/card [`76b8899`](https://github.com/fomantic/Fomantic-UI/commit/76b8899a46d5774de7f95a2efb620e59b6410856)
- Rebuild dist [`0c44430`](https://github.com/fomantic/Fomantic-UI/commit/0c444307d9206f9e307a11c9f8b7bd1bc512eda4)
- Adds docs for selection/search selection in form docs [`7b18040`](https://github.com/fomantic/Fomantic-UI/commit/7b1804018dbaba66c5f0b21bfc5ffc5b19369f8a)
- Updates icon/header inverted colors [`3bcca2d`](https://github.com/fomantic/Fomantic-UI/commit/3bcca2d769701a5d558486248978d3dc4f20d83c)
- Light reskin of beta homepage [`566767a`](https://github.com/fomantic/Fomantic-UI/commit/566767a307202863786e8da67325fb1ad5f6cc5d)
- Fix accidental revert of sidebaR [`33b1976`](https://github.com/fomantic/Fomantic-UI/commit/33b197621cde23df3f9fe3d6aebdf5a03b198ab1)
- Rebuilds dist with fixes [`4f055e1`](https://github.com/fomantic/Fomantic-UI/commit/4f055e162cea18df6c6d032be83ae6882c821ba9)
- Iteration on regex for comment replacement [`958cfcc`](https://github.com/fomantic/Fomantic-UI/commit/958cfcc456151664f137410fdb7735d87fe145df)
- Updates to API docs [`63af84a`](https://github.com/fomantic/Fomantic-UI/commit/63af84ab2eaeb20e5c4c27148ec8331cc93d1ea8)
- Rebuild dist [`6dde801`](https://github.com/fomantic/Fomantic-UI/commit/6dde801222e7a92bc06225db8645fe98f23a6505)
- Update docs for item/card [`9595fc1`](https://github.com/fomantic/Fomantic-UI/commit/9595fc13c9f6d603e720c14093110d7e8d7596a5)
- Fixes form validation, fixes issue with form error color inheritance [`595793b`](https://github.com/fomantic/Fomantic-UI/commit/595793ba61d03f37ed97bd1233be4561774ca5e7)
- Fix double rtl extension, RTLCSS now occurs after prefix/less compilation in watch. #1552 [`56048bd`](https://github.com/fomantic/Fomantic-UI/commit/56048bd514b358ec824c05f172afa22796286c2b)
- Iteration on single component deploys [`8e04de8`](https://github.com/fomantic/Fomantic-UI/commit/8e04de877025dfd204cb48c1fb7dca3f398994ab)
- Committing visit behavior [`278752b`](https://github.com/fomantic/Fomantic-UI/commit/278752b13e4a8d427823b36eb0a7fc1e6a865560)
- Rebuild dist [`3e3c2ef`](https://github.com/fomantic/Fomantic-UI/commit/3e3c2ef12f34c6841896c77487b8ff29cc367505)
- Tweaking feed styles and redoing docs [`a8ec470`](https://github.com/fomantic/Fomantic-UI/commit/a8ec4705532d2ceb9561552f7ae5f159ff2ca823)
- Testing out dropdown errors [`dfcf947`](https://github.com/fomantic/Fomantic-UI/commit/dfcf947facebe7392581fd16648f2260609c3127)
- rebuild for deploy [`be298b4`](https://github.com/fomantic/Fomantic-UI/commit/be298b4ea329774b64711a3acb0641467a8cc009)
- Modify advertisement to be called 'ad' [`8775ba8`](https://github.com/fomantic/Fomantic-UI/commit/8775ba8a6ad4b4213c237eabb30f75bd5731e02f)
- Adds animation support to search, adds less variables to search, fixes some issues with sticky on reposition [`3e8326b`](https://github.com/fomantic/Fomantic-UI/commit/3e8326b91291e7a8c987624f15cc1d42ba56607a)
- Initial work on statistic doc [`d813776`](https://github.com/fomantic/Fomantic-UI/commit/d813776670cf0a202e8c6c02fb52289ab8907515)
- Iteration on API docs [`a0e4dc9`](https://github.com/fomantic/Fomantic-UI/commit/a0e4dc930e03087cdae6009fdff519364398f21d)
- Add stubs for theming of rest of modulles [`2d52218`](https://github.com/fomantic/Fomantic-UI/commit/2d5221804acf68cc7440b3ed38f2be72e88069e7)
- Rebuild dist [`cf80d07`](https://github.com/fomantic/Fomantic-UI/commit/cf80d07f57dcdd8fa2d5a696d14c5e79b8fdf580)
- Add additional button variables for basic inverted [`89f9587`](https://github.com/fomantic/Fomantic-UI/commit/89f9587ea61f8c85c6d50b3abb8da84f1e887fba)
- Rebuild files [`ff4a67d`](https://github.com/fomantic/Fomantic-UI/commit/ff4a67ded9de60d0531fbd8c8f7f01d2b574472a)
- Updates to API docs [`a048660`](https://github.com/fomantic/Fomantic-UI/commit/a048660f2d2e41111a56eaba4c594474eb3815e1)
- Restructure all behaviors in search to be sentence case, remove all proxy calls [`d5632f4`](https://github.com/fomantic/Fomantic-UI/commit/d5632f42eb63c023799873775022122930d35108)
- Moves grouped steps to top of step docs [`7c30b76`](https://github.com/fomantic/Fomantic-UI/commit/7c30b765b6968b58fa10fe101427b82a875c9431)
- Fixes for accordion/statistic/table/label [`7b729b9`](https://github.com/fomantic/Fomantic-UI/commit/7b729b91de51d438c58da94e6e733b2411490744)
- Updates api, state, visibility, visit to latest iteration [`174ea2c`](https://github.com/fomantic/Fomantic-UI/commit/174ea2cc066b80e710b416958df33bcc969390ea)
- Begin theming, updates to ui table [`4d3cebd`](https://github.com/fomantic/Fomantic-UI/commit/4d3cebd38e7d03525452abe7297b986aa5cc1b3c)
- Fix tag label formatting, add form integration with api, add responsive video sizing without js [`3e99424`](https://github.com/fomantic/Fomantic-UI/commit/3e994241ca55ba5eeeece8d345f9d8ce008e31a4)
- Proceed with questions for site variables [`3d3a3fb`](https://github.com/fomantic/Fomantic-UI/commit/3d3a3fbfde31fbcdb2a984814dee85b5914aa628)
- Several fixes for inversion with form, checkbox, segment, header [`4c424c3`](https://github.com/fomantic/Fomantic-UI/commit/4c424c3a795b92021a850cdf0ab6479ce69b5ec1)
- Finish a good portion of grid enhancements, except word order [`1c299d2`](https://github.com/fomantic/Fomantic-UI/commit/1c299d259603a4f538591984aca2d6ef37148278)
- Rebuild dist [`7a691bc`](https://github.com/fomantic/Fomantic-UI/commit/7a691bcf5e0ce7a036fb8d06a83049b9dd0c29b7)
- Remove unnecessary files from dist, fix bower.json to have main [`8d2f6a0`](https://github.com/fomantic/Fomantic-UI/commit/8d2f6a05665bc735145e497b2e24b355f210f25c)
- Iteration on fixing onStart onComplete across all components using transition, trying to solve sidebar still [`98bc6b8`](https://github.com/fomantic/Fomantic-UI/commit/98bc6b82020f3549d536df0708025f59108c9811)
- Semantic.config is now theme.config, makes more sense. Fix comment banners in themes/site files to give context in compiled output. [`c129851`](https://github.com/fomantic/Fomantic-UI/commit/c129851f251941e136dbf32dac4dbe89d80d9ccb)
- Recompile for build [`c7e88c2`](https://github.com/fomantic/Fomantic-UI/commit/c7e88c22252f55f817b5491538f86d441a9d1c6d)
- Update s to form, checkbox, segment. GitHub form and segment theming [`93a6097`](https://github.com/fomantic/Fomantic-UI/commit/93a6097d86968750790d9d786a6b762092bb5d92)
- Build 1.6.1 [`9ad8afe`](https://github.com/fomantic/Fomantic-UI/commit/9ad8afe3aa3b77862fdb5fe3380cc465ce71a328)
- Continuing work on list variables, fixes for icon header alignment with line height [`17e0cdb`](https://github.com/fomantic/Fomantic-UI/commit/17e0cdbbd14c778114a345a0509364522fb7b3c4)
- Rebuilds packages [`07dff14`](https://github.com/fomantic/Fomantic-UI/commit/07dff140766907acf6a7c36e6d4b55e0f888d9c8)
- Begin theming items [`55f51c0`](https://github.com/fomantic/Fomantic-UI/commit/55f51c06eb69804319ac9d953b0e0aeb1bc52e5e)
- more iteration on API docs [`5a00104`](https://github.com/fomantic/Fomantic-UI/commit/5a00104a28396f7d4120317d179c4e9218113878)
- Set up remaining views with variable stubs, add correct copyright notice on all files [`7834c58`](https://github.com/fomantic/Fomantic-UI/commit/7834c584e66250330e4311b17d0ea94b8ed12a07)
- Add composer.json, correct npm packages, more [`6afe874`](https://github.com/fomantic/Fomantic-UI/commit/6afe8741c9429d32cac095bd9965b1bc681e126d)
- Complete user actions in gulp [`877288c`](https://github.com/fomantic/Fomantic-UI/commit/877288c0c4edcaf7a608e107df28ab831a329b00)
- Allow final display state to be specified in transition settings, fixes for search sizes [`779c8cf`](https://github.com/fomantic/Fomantic-UI/commit/779c8cfc19c5f45a47d3d5f7e0a842f29a54adf0)
- Removes all uses of jquery waypoint for SUI sticky module [`e515b99`](https://github.com/fomantic/Fomantic-UI/commit/e515b99c3fb48f7d32e11c0b4115e45a985015f4)
- Build 1.6.2. [`8c80018`](https://github.com/fomantic/Fomantic-UI/commit/8c800180d755c847b7225082225d60d4d74ef71f)
- rebuild dist [`7215454`](https://github.com/fomantic/Fomantic-UI/commit/7215454e23de3bd411694bfb85495eef4088d840)
- Iteration on install process [`627056f`](https://github.com/fomantic/Fomantic-UI/commit/627056f67a1adefa533d12fb9c17775adff005f4)
- Finish variables for table [`26d61fe`](https://github.com/fomantic/Fomantic-UI/commit/26d61febe641ec095deb6d2c766c89321d8e896e)
- Fix modal / sidebar incompatibilities [`12afde8`](https://github.com/fomantic/Fomantic-UI/commit/12afde89d65589ef35c4e2eb0df0d60fff52d161)
- Take border color down a notch [`790f2e5`](https://github.com/fomantic/Fomantic-UI/commit/790f2e5d122535d78b719f8b976344f9938993ea)
- Experimenting with different docs icon, beginning theming of popup [`3750099`](https://github.com/fomantic/Fomantic-UI/commit/37500993652ce5a58f40a2089d01b2a7740d1436)
- Rebuild dist [`ded9e21`](https://github.com/fomantic/Fomantic-UI/commit/ded9e21798d586191a2dfc694738be844fb96a42)
- iteration on setup [`ed261c9`](https://github.com/fomantic/Fomantic-UI/commit/ed261c9627dd3b576971435ad016771e115d2a30)
- Modify header defaults, some docs [`0856ae0`](https://github.com/fomantic/Fomantic-UI/commit/0856ae052df333a7365ac90a49ad8766918dea5b)
- Adds ability to specify sidebar mobile animation [`2314ff0`](https://github.com/fomantic/Fomantic-UI/commit/2314ff02b21d5f54ebccd4b8bc3e6e8ec6d47a80)
- Begin API docs [`d677eef`](https://github.com/fomantic/Fomantic-UI/commit/d677eef3f53d583963a2c582b8280a29c51e96a0)
- Correction for inverted circular icons [`5ea6c1c`](https://github.com/fomantic/Fomantic-UI/commit/5ea6c1cd275461a86594bcfe01df3b0dfeed24e6)
- Adds another theme for steps, adds some new step variables [`3f02c7b`](https://github.com/fomantic/Fomantic-UI/commit/3f02c7ba8abaff87930734c7991baf96624a4684)
- Add fixes for accelerated scrolling on mobile [`89ee0d3`](https://github.com/fomantic/Fomantic-UI/commit/89ee0d34a796e6340ace5aa78446c81275c13047)
- Completes theme/enhancement of comment view [`e037734`](https://github.com/fomantic/Fomantic-UI/commit/e03773481e8aa5e76cb32114a61ca2d565a4cf1b)
- Add theme variables for accordion, restructure accordion so it defaults to unstyled with styled variation [`721d071`](https://github.com/fomantic/Fomantic-UI/commit/721d071fceefaa043b030348368fe0384a60697d)
- Adds several fixes for theming for search [`110ebc2`](https://github.com/fomantic/Fomantic-UI/commit/110ebc28cce057600a7a2d618b10d3549f5dce43)
- Rebuild files [`290b777`](https://github.com/fomantic/Fomantic-UI/commit/290b777fa8c3847f23f53c1a9babcecee23ad05b)
- Redo ui loader to use css only [`9e5816b`](https://github.com/fomantic/Fomantic-UI/commit/9e5816bd73a0ef0b77fd0d4b884bdee176fde394)
- Adds global header sizes for h1-h6, reorganizes site.variables based around work in site ui docs [`5b8c2bb`](https://github.com/fomantic/Fomantic-UI/commit/5b8c2bbae057f4c8e90fdddb41e3cbfc347572ed)
- Themes tabs [`9533858`](https://github.com/fomantic/Fomantic-UI/commit/9533858ef284c46b2eac31a22eaff4bae89173ae)
- Begin themeing of messages [`a83fe9f`](https://github.com/fomantic/Fomantic-UI/commit/a83fe9f9003a6565d58fe69b1e5005ee3ab0a9b4)
- Adds #1535, box-sizing now inherits. removes from site.less (now only in reset) [`0ac98d0`](https://github.com/fomantic/Fomantic-UI/commit/0ac98d0c69e6e55a3ac07321570e79135e451960)
- Work in progress commit of UI list variables [`1b7e00f`](https://github.com/fomantic/Fomantic-UI/commit/1b7e00f96889500d8950cdbe76edd7dc16519640)
- Rename google message theme to gmail (actual source), update dist [`c96f305`](https://github.com/fomantic/Fomantic-UI/commit/c96f3059daf279b87a55689db50102bdc50761c6)
- Updating various examples [`d0d3ac6`](https://github.com/fomantic/Fomantic-UI/commit/d0d3ac66325a414b27c2b8b97fbd44d66f8b48d8)
- Themes UI rating, modifies clearable to be set to true when only one icon is used [`e23f7c5`](https://github.com/fomantic/Fomantic-UI/commit/e23f7c597e8342dd532bfc2bb3c02b6c0c41ff65)
- Remove missing ad dist component [`e820eca`](https://github.com/fomantic/Fomantic-UI/commit/e820ecae82e508a237d57c974ad0b24ceb244849)
- Fixes for card variations, adds in global subtle gradient [`556a957`](https://github.com/fomantic/Fomantic-UI/commit/556a9573c9b30fd2a17a6246d2eab3f203b54735)
- Fixes to definition type dropdown [`7df9685`](https://github.com/fomantic/Fomantic-UI/commit/7df9685d6ad90560b28879ebcb346a864d693072)
- Theme sidebar [`7dfe73d`](https://github.com/fomantic/Fomantic-UI/commit/7dfe73ddb68d6f5e0e86c997d90a2eaafa85577d)
- Updates to many UI components from subrepo [`f951e21`](https://github.com/fomantic/Fomantic-UI/commit/f951e2140c573a022606150bddc789c25bf4a5dc)
- Complete statistics variables [`f49b602`](https://github.com/fomantic/Fomantic-UI/commit/f49b602a4f65fc608b918c7ebc6ee77d5376301a)
- Iteration on sidebar [`7c8e338`](https://github.com/fomantic/Fomantic-UI/commit/7c8e338704f2c63a6bfc9627c81548a18b275914)
- Refactoring release tasks [`e163f20`](https://github.com/fomantic/Fomantic-UI/commit/e163f205d230d6140cdce1eafc4bbe0b68c6c361)
- Fixes issues with touch overflow on ios [`305d19f`](https://github.com/fomantic/Fomantic-UI/commit/305d19fb61bf3f546e1bd5b8ae43de78734ced31)
- Fix paths inside inquirer, updating less vars in install [`e5166aa`](https://github.com/fomantic/Fomantic-UI/commit/e5166aa0502fe943322eb75705bfec69893063e8)
- Attempting to fix overflow issues with sidebar [`cdb0bc6`](https://github.com/fomantic/Fomantic-UI/commit/cdb0bc644b4cc0f15b3720d06623d4b010f7ef05)
- Adds missing override values for new element themes [`f0c28a6`](https://github.com/fomantic/Fomantic-UI/commit/f0c28a633b41203cdcd8d4ba948a190b83e15037)
- Moving more values to config [`ac8d0bc`](https://github.com/fomantic/Fomantic-UI/commit/ac8d0bc00bdc5bccb5a5590f503416d60b98251e)
- Fix inverted button hover state, fix animated buttons not obeying changes in padding variable, fix button docs [`09e4b7c`](https://github.com/fomantic/Fomantic-UI/commit/09e4b7c5ff9d5291b897e75896e21da37a0db0f9)
- Fixes to grid, doubling grid, divided grid, slight changes to message [`7fb2344`](https://github.com/fomantic/Fomantic-UI/commit/7fb2344357f905923a0a0c6dcbe462f306c12d10)
- Fix confusing word order in button [`f9739f3`](https://github.com/fomantic/Fomantic-UI/commit/f9739f32f41a31b07b3bd02338af38f426ff7a9f)
- Remove duplice definition file [`5291278`](https://github.com/fomantic/Fomantic-UI/commit/5291278140d377749fe812ec9508401cc1eacf5b)
- Adds advertising view, that includes common ad sizes and behaviors [`86f5f0a`](https://github.com/fomantic/Fomantic-UI/commit/86f5f0a5b8051612178df5fd121b1109b584573f)
- Updates documentation [`5278d88`](https://github.com/fomantic/Fomantic-UI/commit/5278d88032676f3a18465ce37dfcd99a7f468884)
- Fix code example copy and paste, add more kitchen sink examples [`4754fa9`](https://github.com/fomantic/Fomantic-UI/commit/4754fa97749e4eb9ff92c3cb884c904ccd61992b)
- Nearingly done [`28051f2`](https://github.com/fomantic/Fomantic-UI/commit/28051f212a4688b3578379c9ef814d4ab7a4bf0a)
- Finishing up grid overview [`efd0afa`](https://github.com/fomantic/Fomantic-UI/commit/efd0afa66601452017abe12faa8b443a06fbce60)
- Fixes to sidebar, inverted link lists [`e285c1c`](https://github.com/fomantic/Fomantic-UI/commit/e285c1c68faeb322a91bbf110af0b832f6593ba7)
- Adds new loading style to form, adds loading variation to segment [`947c25a`](https://github.com/fomantic/Fomantic-UI/commit/947c25a1c3879db57fa8e9ce7de30b65ade44abd)
- Popup: Adds better popup positioning, new settings for popup positioning strategy , and a last resort position if it cannot fit on stage [`8e6b5dd`](https://github.com/fomantic/Fomantic-UI/commit/8e6b5ddc0ad25eb873848105add15f6a45dfc2ec)
- Add better doc examples for header and image [`ad6ef93`](https://github.com/fomantic/Fomantic-UI/commit/ad6ef93c86e85bca0a191b71875f9e1e79a07b19)
- Fixes code formatting of table examples [`c564205`](https://github.com/fomantic/Fomantic-UI/commit/c5642056e4fe54a03760f064b76071f1119c0812)
- Rewrite of sidebar to support sidebars visible on load #649 [`fa05065`](https://github.com/fomantic/Fomantic-UI/commit/fa050650133d1ffac697657f2a580a73c741402b)
- Iteration on build deploy, filtering release notes, auto bower update [`8750b1f`](https://github.com/fomantic/Fomantic-UI/commit/8750b1f244f2c3a37396e7c1174f3228c0547dd0)
- main package.js plus assets copy for components [`eb601a4`](https://github.com/fomantic/Fomantic-UI/commit/eb601a41c7ebf168a3ddc54754dce425704f1d15)
- Iteration on setup wiz [`368d6c5`](https://github.com/fomantic/Fomantic-UI/commit/368d6c5afd3424513f55f7919bd7f9cd0a7e716d)
- Finishes list variables, adjustments/tweaks to image variables [`aafa618`](https://github.com/fomantic/Fomantic-UI/commit/aafa618a077ebaa3ee3f0a3922a72383d89ab4f0)
- Continuing to iterate on gulpfile for install process [`71d6563`](https://github.com/fomantic/Fomantic-UI/commit/71d656309b1de9d39a2d79fa85499be572f497ad)
- Fixes sizing of attached headers to match segments [`25403ed`](https://github.com/fomantic/Fomantic-UI/commit/25403edb63473db9a73b00fd0c7555eecbe99a70)
- Fix positive/negative button color regression [`ecbd893`](https://github.com/fomantic/Fomantic-UI/commit/ecbd893ed4e918434bf3d654f6739243b70dccbe)
- This code is bananas [`3000178`](https://github.com/fomantic/Fomantic-UI/commit/3000178c23bcd901de20e4a8ff608d515d898635)
- Enhances grid docs, fixes some consistency issues, adds grid fixed width variables [`0a59fdc`](https://github.com/fomantic/Fomantic-UI/commit/0a59fdc3326dedf881f26225190aa0275d3288fe)
- Continuing to iterate on sidebar [`44daa6c`](https://github.com/fomantic/Fomantic-UI/commit/44daa6ce83ef8ce0f43283d64d7bc08adeba67de)
- Rebuild files [`d14599e`](https://github.com/fomantic/Fomantic-UI/commit/d14599ef7bf1b08f11013d4147a31c750339ab97)
- Adds RTL watch task, modifications to RTL settings [`4fa3100`](https://github.com/fomantic/Fomantic-UI/commit/4fa3100c5838456893e49dba2117a8ae10873147)
- Sidebar now attaches to correct context, works in contexts other than body [`8e775d3`](https://github.com/fomantic/Fomantic-UI/commit/8e775d3e6f3e38ee855b5916bb4d8b7c6e78497b)
- several fixes for checkbox, updated form example [`81fb1e4`](https://github.com/fomantic/Fomantic-UI/commit/81fb1e4745c78eb5806df698be1f596965dbab59)
- Fix issue with responsive column widths [`d32505e`](https://github.com/fomantic/Fomantic-UI/commit/d32505e3b2fd8f505fee356144d4d99cbe3b0caa)
- Add more popup examples, remove icons from rating examples [`4614ac0`](https://github.com/fomantic/Fomantic-UI/commit/4614ac03442aa47166338635b4a044b749828035)
- Add indeterminate loader, theme fixes [`29849ff`](https://github.com/fomantic/Fomantic-UI/commit/29849ff025a87000755f2fbb38177bf2b182f1ba)
- Fix mobile styles on docs [`0175699`](https://github.com/fomantic/Fomantic-UI/commit/01756998b368a3d9ec5376d5270ba5547f27b4bf)
- Latest work [`5999046`](https://github.com/fomantic/Fomantic-UI/commit/5999046530e7eeb001a3b7cad44d7fe3a09b82c6)
- Rebuild dist for jsfiddle [`b0cd15e`](https://github.com/fomantic/Fomantic-UI/commit/b0cd15e2445bb1763bf6a981c07642ad5c26e1d5)
- Adds drop transition [`b452849`](https://github.com/fomantic/Fomantic-UI/commit/b45284904160caa20addcaba9709b8e2c93e361b)
- better tasks for meteor package.js [`322c865`](https://github.com/fomantic/Fomantic-UI/commit/322c86558dedecf5a5c46b317962352e8f2b166b)
- Setting up gulpfile [`6a1c856`](https://github.com/fomantic/Fomantic-UI/commit/6a1c85675f3e011c6cfb0a5d8cc9c56e0615c51c)
- Fix for sub menu zindex, fix for hiding sub menus when menu is hidden if no active item inside, fix for rapid alt tabbing keeps menu open, fix for hiding during show [`3b791db`](https://github.com/fomantic/Fomantic-UI/commit/3b791db69a23da39b64e5fc6bccb5064642a6624)
- Finish card doubling variation [`9fc417f`](https://github.com/fomantic/Fomantic-UI/commit/9fc417f1836d0d9e97652fe3de7fcaa0ee3126d9)
- Rewrites state to remove hover/focus other useless methods, fixes integration with API, removes auto margins on first and last child of some elements [`01e9a41`](https://github.com/fomantic/Fomantic-UI/commit/01e9a418828ab7685a915069641e9277ed3189e2)
- Creates amazon button theme [`3e7eda6`](https://github.com/fomantic/Fomantic-UI/commit/3e7eda690f0c3c2f10e9647451c5e646d3d00ced)
- Rebuild dist #1256 [`1c1e7f4`](https://github.com/fomantic/Fomantic-UI/commit/1c1e7f4ef44e4643c29e61d665b42b49f6989fb7)
- Rebuild dist [`d3dba68`](https://github.com/fomantic/Fomantic-UI/commit/d3dba681a76a1e2dea345524a675447cf7e7f91e)
- Adds missing tag and modal variables, adds css variables for video [`f2dc432`](https://github.com/fomantic/Fomantic-UI/commit/f2dc432feac192724376e54008da7c52db7e36ab)
- Add fullscreen example to modal, fix fullscreen style [`488ff9c`](https://github.com/fomantic/Fomantic-UI/commit/488ff9c235a42da7bc13cbeca425102e07512ef2)
- Adds basic inverted styles, and examples, fixes amazon theme [`f9e2f24`](https://github.com/fomantic/Fomantic-UI/commit/f9e2f243cce52da1b54f7929623b0e93059b0fe2)
- Rebuild dist with all new updates [`e49b31f`](https://github.com/fomantic/Fomantic-UI/commit/e49b31f0e29cc24e6cb9c7445210e6e41854984b)
- update kitchen sink example grid, rebuild dist [`69064c7`](https://github.com/fomantic/Fomantic-UI/commit/69064c718292e7fd90dd7939ee4c173478902d58)
- Add twitter button theme, update button variables slightly [`1f68dae`](https://github.com/fomantic/Fomantic-UI/commit/1f68dae26264aeb24dbf161541cd43e221ee5505)
- Rebuild files [`e426cbd`](https://github.com/fomantic/Fomantic-UI/commit/e426cbd11e213b0742284eb99b418f1d2ba083b4)
- Rebuild dist [`6d3deb0`](https://github.com/fomantic/Fomantic-UI/commit/6d3deb0c26f8e90526073cca1a72bdc1d420ed6f)
- Rebuild dist [`3c26bd2`](https://github.com/fomantic/Fomantic-UI/commit/3c26bd2751089ed4bc97c033388f03c34f2706ae)
- Fixes up dimmer demos, more module demos [`90f0794`](https://github.com/fomantic/Fomantic-UI/commit/90f0794e0749f81dee55c4089797f774a1a20445)
- Comment formatting, rebuild [`f84759d`](https://github.com/fomantic/Fomantic-UI/commit/f84759d0da35bb1004be0faa4c3e3461f7d136b3)
- Updating animation css [`b10eca9`](https://github.com/fomantic/Fomantic-UI/commit/b10eca90db9d6612e057c15670ccc6138e8a8a50)
- Working on sidebar rewrite [`a433a78`](https://github.com/fomantic/Fomantic-UI/commit/a433a781a46010a6f7cfc97520ee6869dabb3a77)
- Add google theme for fun, fix homepage dropdown example [`f4bbea8`](https://github.com/fomantic/Fomantic-UI/commit/f4bbea8f466dc60bdefbde931b889721a2f1850f)
- Updates docs with examples of dropdown validation, fixes input in menu docs [`363fe51`](https://github.com/fomantic/Fomantic-UI/commit/363fe51b78db16f8a05711d4ca9ac757548f753d)
- Fixes to popup documentation, removing several debug: true values and console log [`16545a5`](https://github.com/fomantic/Fomantic-UI/commit/16545a52744b0521a6db8548f9a41e41f0bcb3c8)
- Whitespace in comment banners [`bf8adfb`](https://github.com/fomantic/Fomantic-UI/commit/bf8adfb42d96b39ffe06e8e7d137eb9f41092d56)
- #1309 Progress now continuously updates progress bar labels during animations at 30fps [`5099530`](https://github.com/fomantic/Fomantic-UI/commit/5099530e92cb8b80bd30176675ca2315d71c616e)
- Change default sidebar settings for docs [`4106715`](https://github.com/fomantic/Fomantic-UI/commit/4106715fdea6a71aa627047b53947fd05d7e733f)
- Fixes missing vendor prefixes in injected css in sidebar [`2451986`](https://github.com/fomantic/Fomantic-UI/commit/24519867a5ac0c6acee762954f740abc935acc85)
- rebuild dist version with latest sidebar [`d85d837`](https://github.com/fomantic/Fomantic-UI/commit/d85d83776691a946f8f9ab3df9e96480420845cf)
- Rebuild dist [`458306a`](https://github.com/fomantic/Fomantic-UI/commit/458306a4a6e9843fd0b96e6885c311e33d8f690d)
- mend [`159d22d`](https://github.com/fomantic/Fomantic-UI/commit/159d22d90640bbe5678467f3ddd3b90aa168bf70)
- Adds width and fluid variations to popup, fix issue where popup click events werent being removed on destroy, added several new examples of popup features [`e7b6fa1`](https://github.com/fomantic/Fomantic-UI/commit/e7b6fa119e937ac3246feaabfbc22dfb1bf77db0)
- Remove console.log from dropdown [`38b5431`](https://github.com/fomantic/Fomantic-UI/commit/38b5431aa6c8cfad2254184aaffbcc2d017a4984)
- This will drive me bananas [`7fec295`](https://github.com/fomantic/Fomantic-UI/commit/7fec295c61a2cae7e30c3dba3d08bbd57ad7757f)
- Updates dropdown js to include enhancements from prelease, several bugfixes for dropdown [`1b46c81`](https://github.com/fomantic/Fomantic-UI/commit/1b46c8118d46ed8fa3fd33114b27c4839faf1b7a)
- Adjust example formatting [`f2547b1`](https://github.com/fomantic/Fomantic-UI/commit/f2547b1733f0c6564b6422a40bcb2df5f0a76aea)
- Finishing touches on table variables [`fa273ca`](https://github.com/fomantic/Fomantic-UI/commit/fa273cab8b8ef7c9284dcb5f2274937b3c7ad1dc)
- Update to checkbox/label/image/header, related to spacing and consistency [`127df6b`](https://github.com/fomantic/Fomantic-UI/commit/127df6b443c541a33626b4ca0c1af0ee38916ee4)
- Finish theming popup, fix positioning variations to never escape boundaries of element [`40379b9`](https://github.com/fomantic/Fomantic-UI/commit/40379b9841973143c56fabe58171a060ad3648da)
- Bg pattern on body animate [`88ed78f`](https://github.com/fomantic/Fomantic-UI/commit/88ed78f4932dfc3d5ef86d87b141dac4d4a822c3)
- Updates docs for changes to transition [`12e1c09`](https://github.com/fomantic/Fomantic-UI/commit/12e1c097380ce23d4331e8a4d9785589d35a6c54)
- Add more variables for button colors  #1591 [`fbae360`](https://github.com/fomantic/Fomantic-UI/commit/fbae3603d360e241cc69a332e052cf9f33f5e504)
- Fixes to tasks for serving docs [`d96b19c`](https://github.com/fomantic/Fomantic-UI/commit/d96b19c1481cf6dc90ec6e7e392086496a0b92d5)
- Adds better handling of set.dimmed() when queued animations, now triggers on start of animation using new transition callback [`88a82e5`](https://github.com/fomantic/Fomantic-UI/commit/88a82e5537bb262c2db713968fb3a2c08dfb5a5c)
- Fix gulp issues [`c132434`](https://github.com/fomantic/Fomantic-UI/commit/c13243425d0c16dac06e3655081aca7244bf5903)
- Rebuilds dist [`298fb28`](https://github.com/fomantic/Fomantic-UI/commit/298fb28a8b3f8c1773aff3fd482064cdbc2d9c92)
- Rebuild dist [`2406023`](https://github.com/fomantic/Fomantic-UI/commit/2406023742fd29b827ef3a6aaa87aeea0c72e117)
- Update release notes [`ce49685`](https://github.com/fomantic/Fomantic-UI/commit/ce4968565f1d006f97a8f5230772650dbd10d568)
- Build version 1.0.1 [`a3d33a9`](https://github.com/fomantic/Fomantic-UI/commit/a3d33a95a77373bac58f412dfdac7bef20237880)
- Fixing various issues, moving column count back to global config [`e1ba50e`](https://github.com/fomantic/Fomantic-UI/commit/e1ba50e10669b676395a16f7cd9c0112039b7629)
- Fix paths in gulp build [`beaf102`](https://github.com/fomantic/Fomantic-UI/commit/beaf1020eefdfcabbbcabdfbf7af3710efe5dae1)
- Rewrite gulp rtl build #1552 [`a67de5a`](https://github.com/fomantic/Fomantic-UI/commit/a67de5aad8ff69fcc82d311db6ee4aed5f309b0a)
- Fixes to card docs [`5497524`](https://github.com/fomantic/Fomantic-UI/commit/5497524c3f925d6cec90018786a26c8ef16187c6)
- Rebuild dist [`50f211b`](https://github.com/fomantic/Fomantic-UI/commit/50f211bbdffb75bcce69929c1cfa8e326c39251a)
- Add ability to publish packages from command line [`9b9910b`](https://github.com/fomantic/Fomantic-UI/commit/9b9910b26b54c76f842d37979da1a5a676931386)
- rebuild dist for jsfiddle [`927251f`](https://github.com/fomantic/Fomantic-UI/commit/927251fe01f408e6e41f524c0eeba3edba1bde9e)
- Move column counts to global config, tweak default unselected colors [`d4c4d60`](https://github.com/fomantic/Fomantic-UI/commit/d4c4d6081bd60acc419149383ad83b70f0f8ba95)
- Material design defaults [`075d296`](https://github.com/fomantic/Fomantic-UI/commit/075d2967842524b2d873fc8338081391c1eec310)
- Updates for search docs [`6224439`](https://github.com/fomantic/Fomantic-UI/commit/622443973d2b42c9b8b25e3d42deddab757b1887)
- Fix some issues with scale down animation in sidebar [`4e46bce`](https://github.com/fomantic/Fomantic-UI/commit/4e46bce3911363d17653e737a69a194eafd2fd50)
- Rebuild new var files [`63093b5`](https://github.com/fomantic/Fomantic-UI/commit/63093b5b6d17a502183f9fb99bb426d17f0fce21)
- Adds #947, #1428. Adds unstackable variation, and tablet stackable variation to tables to allow for more granularity in responsive sizing [`dda7ee3`](https://github.com/fomantic/Fomantic-UI/commit/dda7ee36a59d33c757963772b8a6e8225d815dbb)
- Alphabetize and comment out validation rules #1396 [`0de927c`](https://github.com/fomantic/Fomantic-UI/commit/0de927c029d79a115f7c975c3bc92fbf1c7bf063)
- Search dropdown is now more efficient, will only process text content for searching, and values. Not text html values [`7991372`](https://github.com/fomantic/Fomantic-UI/commit/7991372b62a13b8e0c84fd093ec026ac295327bb)
- Adds search variables [`8bfe517`](https://github.com/fomantic/Fomantic-UI/commit/8bfe5175e0652ee004a2422d84cca6e2f011efa7)
- Fixes repo creation issues. [`9acc237`](https://github.com/fomantic/Fomantic-UI/commit/9acc2377cb822e434fb3145233a3fcd0e33a1ca9)
- Add new loader themes, tweak loader variables for theming [`9263ba9`](https://github.com/fomantic/Fomantic-UI/commit/9263ba99b038e9d1fcdfceab9d610a0dcaa746de)
- Adds sidebar widths, shadow by default [`5b664c7`](https://github.com/fomantic/Fomantic-UI/commit/5b664c7114f2740f062ca4ddfd475b8727a1372e)
- Updates to docs [`2321e32`](https://github.com/fomantic/Fomantic-UI/commit/2321e322eb4069ced6dae5100cdea9e3502cc794)
- Fixes issue with popup positioning not adding margins when inline: true, adds ability to detect inline popups if no other content found [`40c0cb5`](https://github.com/fomantic/Fomantic-UI/commit/40c0cb56ea3f78465f4ac195738c794dd97e6167)
- Update GETTING-STARTED.md [`cf42f6d`](https://github.com/fomantic/Fomantic-UI/commit/cf42f6ddff39b087dbcf83e2f1d2560b8b22f116)
- Modifies basic colored style to be neutral before hover [`f9ecd26`](https://github.com/fomantic/Fomantic-UI/commit/f9ecd260c4c3bfbd8de6fb2722df65f581652dde)
- Updates to documentation #1036 [`f5df1e5`](https://github.com/fomantic/Fomantic-UI/commit/f5df1e5e29d0e900bf261de60236f809500c2631)
- Gulping [`bb0d13d`](https://github.com/fomantic/Fomantic-UI/commit/bb0d13d25026599d81458d4c8b7d9f06fb85135b)
- Themes breadcrumbs [`b6a4011`](https://github.com/fomantic/Fomantic-UI/commit/b6a4011ff906136cfd301502fe15878671acd132)
- Search dropdowns now work without using selection dropdown [`1e87f3d`](https://github.com/fomantic/Fomantic-UI/commit/1e87f3d618b0eed2badd93534c37ae4161f36dcb)
- Restructuring site.variables files for easier comphrehensibility. [`acabab0`](https://github.com/fomantic/Fomantic-UI/commit/acabab0c4ebd7458e37c99d4ac1da824cf2bc56a)
- Build missing google assets [`b1dd016`](https://github.com/fomantic/Fomantic-UI/commit/b1dd0163cef93fc5629d48792b361f35223adf9c)
- New additions to ratings, automatic generation of html from template [`d26aaab`](https://github.com/fomantic/Fomantic-UI/commit/d26aaabba6bd62f01a22359b9e1e668f8f33f29a)
- Adds new basic table theme [`11b1bd2`](https://github.com/fomantic/Fomantic-UI/commit/11b1bd2a7b3496d7c3f48ce2780aa3d59e90dc8c)
- Add responsive step stylings #1131 [`44b443b`](https://github.com/fomantic/Fomantic-UI/commit/44b443bcafcbf560dbeb6518e7102d0885350586)
- Rebuild files [`f1feeb5`](https://github.com/fomantic/Fomantic-UI/commit/f1feeb573e2956a0f8db2f4845aca63a553398e0)
- #1417 #1432 #1420, typo in failSafe, should be useFailSafe. Adds animation queueing as a setting for modal [`04b63bf`](https://github.com/fomantic/Fomantic-UI/commit/04b63bfa106a8c4d2e7646390384b62c4e23a76f)
- Add in CSS tab loaders [`d1c9f79`](https://github.com/fomantic/Fomantic-UI/commit/d1c9f79006c1aea2b8048bcbe2a5539137ee94c1)
- Complete component build system [`60d3a0b`](https://github.com/fomantic/Fomantic-UI/commit/60d3a0b5eb9c46a21d78ffbc37f7fbc8f9b396b5)
- Updating docs for card/item/popup [`e6153aa`](https://github.com/fomantic/Fomantic-UI/commit/e6153aa790d79514fb1f39ac7d3b4c5bc190ee9b)
- Fix increase/decrease example in header [`3babd67`](https://github.com/fomantic/Fomantic-UI/commit/3babd676044531673a99ca613df62febf4596eb6)
- Continues adding missing variables from form variations [`7d7500e`](https://github.com/fomantic/Fomantic-UI/commit/7d7500e676a6a548818e27486551dd7f2785396f)
- Update theme.config.example [`7e68941`](https://github.com/fomantic/Fomantic-UI/commit/7e6894196a7fb07cccd0598c88b59e069c06390a)
- Rebuild dist [`d57f92c`](https://github.com/fomantic/Fomantic-UI/commit/d57f92c0ebb5a06adac47129bdc08e90527b0ec7)
- #1214, Adds floated content to dropdown, adds description [`07eaacd`](https://github.com/fomantic/Fomantic-UI/commit/07eaacd1b98a26402f56aea2cb62b7e3dcbc1fdb)
- Fix several issues with selector refreshing in popup [`5cd5ae3`](https://github.com/fomantic/Fomantic-UI/commit/5cd5ae3947a8fe51b57ca6743d7a64f007e5a6c7)
- Fixes loading delay in jq 2.x for API, swaps success, complete, error callbacks for onSuccess, onComplete etc. [`5c2cb03`](https://github.com/fomantic/Fomantic-UI/commit/5c2cb03439eaa532f3b049de9c01fd31e8fb542e)
- Rebuild files for deploy [`9e2cc8a`](https://github.com/fomantic/Fomantic-UI/commit/9e2cc8aebd2342b4ce681793d854dbd0d7f38f48)
- Removes popup from unit tests [`0aa7de2`](https://github.com/fomantic/Fomantic-UI/commit/0aa7de2515f3d0e16c728cd2788cc7667a7207f5)
- Github themes [`df2ab07`](https://github.com/fomantic/Fomantic-UI/commit/df2ab0767bdc602a757d2abf9c05090eb26d7a58)
- Iteration on auto release notes etc [`57171fa`](https://github.com/fomantic/Fomantic-UI/commit/57171fa9f13ffcb417d60dabee16de09d68ddb89)
- Improves vertical padding alignment on inputs, fixes bugs with descendors being cut off [`a784c62`](https://github.com/fomantic/Fomantic-UI/commit/a784c62a464a8b5fdc4ac590e2e87d90c5111cb0)
- Dropdown now uses a loading class to calculate scroll position for active element before showing [`f9d3e54`](https://github.com/fomantic/Fomantic-UI/commit/f9d3e54fc1150cc6a0e4ef05989ad059c3280c86)
- Fixes to popup styles, removing includeMargin from popup settings, docs popup update [`aa29585`](https://github.com/fomantic/Fomantic-UI/commit/aa2958562f62d85fd5f1778ec130ccb66b6c1f28)
- Gulp iteration [`3fe7348`](https://github.com/fomantic/Fomantic-UI/commit/3fe734836348610cad8aa762863bb9b03802f93c)
- Adds fixed-width grid [`df0f717`](https://github.com/fomantic/Fomantic-UI/commit/df0f7174d07fc35b6cfd331f7e22f6b19bb14b07)
- Steps will appear correctly even if each step is a different height #1579 [`80e5495`](https://github.com/fomantic/Fomantic-UI/commit/80e5495d27d90fda9e25b30fbab868cd36bc85f5)
- Adds CSS opacity animations when available #1558. [`9375b1f`](https://github.com/fomantic/Fomantic-UI/commit/9375b1f19f3abb710dca81de6f0297e2b85d17cf)
- Lists use rem for internal spacing (avoid overly padded out lists on large sizes) [`66ad886`](https://github.com/fomantic/Fomantic-UI/commit/66ad886b2c46a3b9e05bbd27a73bcb2b420888f9)
- added package.js files into components repos [`a49bbc3`](https://github.com/fomantic/Fomantic-UI/commit/a49bbc393f22072359ff355e19888f8b10502fac)
- #1252 Add fix for IE not obeying transform context [`753c587`](https://github.com/fomantic/Fomantic-UI/commit/753c587311c1f965c0d87377b6856ecc354e2a86)
- move grid variables into global [`181fd64`](https://github.com/fomantic/Fomantic-UI/commit/181fd64be5295ba1b70b655c9b4eec758f2f8944)
- Adds dimmer settings #1472, refactors init to use new behavior create dimmer [`1edd7e3`](https://github.com/fomantic/Fomantic-UI/commit/1edd7e3a17ed6663f3f5316d8627219dcdee39cc)
- Fix header font inheritance again. [`c3bc2c4`](https://github.com/fomantic/Fomantic-UI/commit/c3bc2c4c6c50314bc66df2697851555d49066d19)
- Remove queuing from modal animations, allow clicks on dimmer to close modal even while showing [`5860d65`](https://github.com/fomantic/Fomantic-UI/commit/5860d65fc24ecdc190e74e4bfdffa8a0fcd8cb2a)
- Add hovered pressed text colors, and replace selected text color, makes easier global theming [`64190b6`](https://github.com/fomantic/Fomantic-UI/commit/64190b678b8c8ebc7eeca66b0f430065e53579c9)
- Modal/dimmer now correctly handle several simultaneous animation conditions, showing while hiding, hiding others while showing, etc. Animations now use failsafe to avoid animationend race-conditions with webkit, and the same duration #1417 #1432 [`51cf4f5`](https://github.com/fomantic/Fomantic-UI/commit/51cf4f5b5888c290446000a2c36da2399fe41c36)
- Fixes issue mentioned by @gabormeszoly #1363 [`1aa8dc1`](https://github.com/fomantic/Fomantic-UI/commit/1aa8dc1598cfe3f64246f7fb6d93b71816d4a34c)
- Updates to API [`40b11b8`](https://github.com/fomantic/Fomantic-UI/commit/40b11b85a223410af09afcb2da97dff4065fa6bf)
- Adds #407, right ribbon label [`164dfb9`](https://github.com/fomantic/Fomantic-UI/commit/164dfb97ca2a3ba62c93391aded45e6d6209510e)
- Adds variables for indicating progress bar [`7976beb`](https://github.com/fomantic/Fomantic-UI/commit/7976beb061491abe0779d85ec67186ba5b428b1a)
- Fix toggle variables, adjustments to theme [`f6a994a`](https://github.com/fomantic/Fomantic-UI/commit/f6a994a288e4e38768d476a517e66886dcd58d31)
- Fix inverted popup headers, working through bugs with multiple popups [`5631dc5`](https://github.com/fomantic/Fomantic-UI/commit/5631dc585fa030b88da953ffca7390736c054b46)
- Themes shapes [`94e9c6f`](https://github.com/fomantic/Fomantic-UI/commit/94e9c6fbbf1e04f5a409f5e2c6ae7b68ad1864cf)
- Adds basic table fix, thead fix [`df424a3`](https://github.com/fomantic/Fomantic-UI/commit/df424a31a0ad0ca7d2abc7401449777707a1bef1)
- simple test files to ship a css pacakge with all UI [`761cc4f`](https://github.com/fomantic/Fomantic-UI/commit/761cc4f19b2d4eab63896577dd90d84e04ce32c6)
- #1380 #1138 Adds better event binding to dimmer for multiple open modals [`6e0fa16`](https://github.com/fomantic/Fomantic-UI/commit/6e0fa165e4899f43398ccda9223b55b695a94ed0)
- Adds global border radius value [`bd12f1c`](https://github.com/fomantic/Fomantic-UI/commit/bd12f1ce497385199bbda05295dd9e20c6a59a17)
- Additional bug fixes and animation tweaks [`f689260`](https://github.com/fomantic/Fomantic-UI/commit/f6892602ff9e5c281974e5acfb2e31c05c258ba4)
- Adds escaped values to search module, fixes extra blank function in popup.js [`161cb7e`](https://github.com/fomantic/Fomantic-UI/commit/161cb7e9183233f43f81838bc9170f24983ef537)
- Move file permission to a setting #1574 [`347a791`](https://github.com/fomantic/Fomantic-UI/commit/347a79104740912f3122b537fb5f83dd910f7994)
- Cherry pick locked down package.json [`201f724`](https://github.com/fomantic/Fomantic-UI/commit/201f724db439d239ef8fa741848540aabe212204)
- Pin dev versions in package.json #1275 [`82ea119`](https://github.com/fomantic/Fomantic-UI/commit/82ea119a583693a8a483a4e7baa8d16be4078933)
- Iteration on list variables [`4f45153`](https://github.com/fomantic/Fomantic-UI/commit/4f4515337d32124a5b54812a24d6a41490632a67)
- Finished modifications to dropdown error states for form/dropdown [`295e225`](https://github.com/fomantic/Fomantic-UI/commit/295e225ae4454c5965184d6de9aae33ead29bfb0)
- Add set/remove tabbable behaviors [`863e14d`](https://github.com/fomantic/Fomantic-UI/commit/863e14d0b389ba67ca4a4f35c841c7318346fd2b)
- Adds input variations for inverted/ css loading [`ce56a5d`](https://github.com/fomantic/Fomantic-UI/commit/ce56a5db7b38657601faa0358f6bdc499c4c7bee)
- Fix issue with creating new repo when adding ui [`7799a80`](https://github.com/fomantic/Fomantic-UI/commit/7799a8085f930a14543b70860c09b9b9249d7706)
- Fixes for icon message, button shadows, adds Lato as default font for docs only [`5f3f44d`](https://github.com/fomantic/Fomantic-UI/commit/5f3f44d05681613f0b24eeca792b843c161c395d)
- Fix issues with fonts on button theming, add bootstrap3 button theme [`0dc157f`](https://github.com/fomantic/Fomantic-UI/commit/0dc157f079fcc7e20f2b804b015b04ff6d1f6115)
- Fix bullet sizing to match chrome native bullets, fix grid responsive style overrides, fix checkbox utf char reference, fix flags [`343af40`](https://github.com/fomantic/Fomantic-UI/commit/343af40625cd7b6cfcac0d3e7d8eef21353c9f64)
- Add variables for zindex and transition for labels [`5787458`](https://github.com/fomantic/Fomantic-UI/commit/578745871969c86bf97a9740b956d039e7923fcd)
- (X) wide buttons no longer need to specify 'fluid' [`87da37b`](https://github.com/fomantic/Fomantic-UI/commit/87da37b1416016dca1d58e4d6fb6d127f90b8e2b)
- Stopping point for night [`074cb71`](https://github.com/fomantic/Fomantic-UI/commit/074cb71a795d2375768eee6089fdb52b7ec22505)
- Updates to allow commit authors in releases [`32ebc68`](https://github.com/fomantic/Fomantic-UI/commit/32ebc6862b1b867fc88c1044be722a4602d8591a)
- Updates grid docs [`1f3b525`](https://github.com/fomantic/Fomantic-UI/commit/1f3b525645527bda87820e54cb613e7ec5fed3c8)
- Adds #1575 Sizing always evaluates to exact pixel values as a ratio of @emSize [`2596dd7`](https://github.com/fomantic/Fomantic-UI/commit/2596dd71b2a9f4113a8397d97f858e95b7a8f64f)
- Adds accordion animateChild option (defaults to true) related to #1558. [`80c7db0`](https://github.com/fomantic/Fomantic-UI/commit/80c7db058d7091f3b344a8b8ebd0d147ebcdace2)
- RTL Gulp Task [`b1d29ef`](https://github.com/fomantic/Fomantic-UI/commit/b1d29ef1bcac282a8e9742494ab84a54b5467d75)
- Adds missing error message for unknown method call (behavior) [`3433381`](https://github.com/fomantic/Fomantic-UI/commit/3433381f5a54129ff7649d95643f498d1f104698)
- Update global emotive colors, fix segment attachment again [`88e53b1`](https://github.com/fomantic/Fomantic-UI/commit/88e53b1b8106bff7ca4ab06f58ab76694427dea6)
- Step: Adds vertical variation to step [`cd2a7d1`](https://github.com/fomantic/Fomantic-UI/commit/cd2a7d16962f8e19feddd32db46c7ca35febb2b4)
- Vertical list sizes are now relative [`6339d6c`](https://github.com/fomantic/Fomantic-UI/commit/6339d6cd7e5ce99f5900c4d042cda6a73cebc3d5)
- Add new features for mobile sidebar, fix issues with gulpfile breaking on js changes [`58c50fd`](https://github.com/fomantic/Fomantic-UI/commit/58c50fdbc37e8f87f7af788434b1c9ffe6b4ca16)
- Fix issue with layering [`35f7a14`](https://github.com/fomantic/Fomantic-UI/commit/35f7a14ca6e45208ac56e22132f20a33fe67971b)
- Refix the transition fix, bobo mistake [`f123839`](https://github.com/fomantic/Fomantic-UI/commit/f1238398c07ec0321acba3fc3d4436644a2a7465)
- Trying to sync animations between multiple [`a0042a5`](https://github.com/fomantic/Fomantic-UI/commit/a0042a5630decd6a75d953c57e37073f97744a67)
- Adds chrome prefixes for pulsar [`bf0796b`](https://github.com/fomantic/Fomantic-UI/commit/bf0796b693dcfe45b54f9177e344098efb65a87d)
- Fix issue with visiblity events refiring when once is true [`b8fe9d6`](https://github.com/fomantic/Fomantic-UI/commit/b8fe9d63dbb890fc5a4c03e1c968d03471601b78)
- Rebuild dist for 1.0 [`c291f4e`](https://github.com/fomantic/Fomantic-UI/commit/c291f4eb3bb117dbf7d2edab5d9d36d064311278)
- Fix issue with modal double showing in chrome [`2324709`](https://github.com/fomantic/Fomantic-UI/commit/232470981e172a075d76251b04d9ea9ace1d8095)
- Popup/dropdown now add debug settings to transition [`bb7ec25`](https://github.com/fomantic/Fomantic-UI/commit/bb7ec259dd687f8e7e911df14479780c7c46dcef)
- Adds #707 pop hideOnScroll setting [`73b60bc`](https://github.com/fomantic/Fomantic-UI/commit/73b60bcc3b8f9ea77019364d0a3d669a337fa41c)
- Shape: Adds feature to not show side if currently active [`5377892`](https://github.com/fomantic/Fomantic-UI/commit/5377892a73b6753ffab3381e574eb49af7b18ccb)
- Rebuild dist [`3c17c12`](https://github.com/fomantic/Fomantic-UI/commit/3c17c122d08fc1d60148667454afa5c03a9067fa)
- Builds 1.3.2 [`222df1c`](https://github.com/fomantic/Fomantic-UI/commit/222df1c5e3c3bd25be0706387ef6d3281480f099)
- Consolidate styling for UUID across modules [`9170fad`](https://github.com/fomantic/Fomantic-UI/commit/9170fad1bd6e1e91c3a78aa391fe8516a32e8aee)
- Add max height only to select dropdown, max-height breaks overflow for menus inside menus [`334e46c`](https://github.com/fomantic/Fomantic-UI/commit/334e46c6f9073229a67fd136ad39d54fce977340)
- Fix vertical input sizes, positioning inside menus. Add strict mode all modules [`06bf302`](https://github.com/fomantic/Fomantic-UI/commit/06bf3023ffda9de658f460b78a06c8fcc59812f3)
- Remove manual offsets for vertically centered buttons, instead use absolute positioning on icon [`609396e`](https://github.com/fomantic/Fomantic-UI/commit/609396eefe2af693ff872df798ba944ac80a5a2a)
- Iterating on install [`3a8cffb`](https://github.com/fomantic/Fomantic-UI/commit/3a8cffba8a3e1ddfca86d1a07bf8e9005b16dc6b)
- Add enhancements to popup [`fd809a1`](https://github.com/fomantic/Fomantic-UI/commit/fd809a133996f738bf225a6baf02e8d4aa77f9d0)
- accessible reveal [`2cfbd6a`](https://github.com/fomantic/Fomantic-UI/commit/2cfbd6a2694686e60b5bcc90b414b99347bf2805)
- Adds progress bar sizes [`97dcc76`](https://github.com/fomantic/Fomantic-UI/commit/97dcc76a0032cf51c4ff8af9a151aa3de9752169)
- Fix dropdown missing some namespaced events, fixes positive/negative/error on table to use site.variables, adds method to auto add tabindex in checkbox [`f1056cb`](https://github.com/fomantic/Fomantic-UI/commit/f1056cbfa0b9948539222a1d4b0c5676c3b37388)
- Fix for API time logging [`20357f4`](https://github.com/fomantic/Fomantic-UI/commit/20357f43e6e80890fa026fa8a2d56748f5ba8f3c)
- Adds category selection with sub-menus #1522 [`199d627`](https://github.com/fomantic/Fomantic-UI/commit/199d627066cd83a2a9f639328932e4d3c08c9625)
- Add components example to semantic.json.example [`6455fce`](https://github.com/fomantic/Fomantic-UI/commit/6455fce0930d012986e9da38b3cad7931af14d6c)
- Increases focused button emphasis [`ecea8a0`](https://github.com/fomantic/Fomantic-UI/commit/ecea8a02acdf3f7f38460b8eb476b4c8d0cc83b2)
- Fix module example text, fix ascending/descending arrows for sortable table [`66f7b72`](https://github.com/fomantic/Fomantic-UI/commit/66f7b724dcc3166dae36b5761397e175f77883d9)
- Porting over $.proxy to native call for performance [`ba6d251`](https://github.com/fomantic/Fomantic-UI/commit/ba6d2514107ac460222580e8ae6f5d2fb9ae02c1)
- Move out theme loader from theme.config, use separate include [`99c80e3`](https://github.com/fomantic/Fomantic-UI/commit/99c80e3ca1b964f1cbbf3639f92c65f05fd9213d)
- Fix some formatting in release task [`3d4610d`](https://github.com/fomantic/Fomantic-UI/commit/3d4610d57346d0467e615733b0754ae82ed8d40e)
- Adds docs for divider [`bd1e0df`](https://github.com/fomantic/Fomantic-UI/commit/bd1e0dfdb5e6631cdb332a5584781a71439f5409)
- Modify some ui descriptions, fix container max-height and spacing [`fc75c80`](https://github.com/fomantic/Fomantic-UI/commit/fc75c809bba75fcc975d468a23559d853827f66a)
- Resolved issues with inputs sizes not matching up due to line-height, several other fixes [`ae89c3b`](https://github.com/fomantic/Fomantic-UI/commit/ae89c3b874eda2326112d73851af35ed08e61e15)
- Fixes modal variables for background color, border. Fixes missing background on modal actions, makes border radius more consistent for different content arrangements [`0e7202b`](https://github.com/fomantic/Fomantic-UI/commit/0e7202b57ad954598c20c1d04311a03175cce0fc)
- Adds transparent inverted input #1346 [`4d4c919`](https://github.com/fomantic/Fomantic-UI/commit/4d4c91933652b875e9b5bc26ddcd9fa41de5cf16)
- Simplify logic with parent context [`d1c47df`](https://github.com/fomantic/Fomantic-UI/commit/d1c47dfa57ebbdd20db74dc586473cd330f6308b)
- Fixes finally checkbox/radio alignment, swaps to using transform for radio checkbox circle [`361a37c`](https://github.com/fomantic/Fomantic-UI/commit/361a37c45570115ae02cea91ee1400118538b214)
- Tinkering with stackable grid [`87c3836`](https://github.com/fomantic/Fomantic-UI/commit/87c38362ef587827c751b220b2ea8006027dc59c)
- Removes awful background animation on sidebar, removes lato from src files [`2b1d585`](https://github.com/fomantic/Fomantic-UI/commit/2b1d585671ad2be95a73fe08dfd11512bfbddc18)
- Updates sticky module, search module is now css variabalized [`3680489`](https://github.com/fomantic/Fomantic-UI/commit/36804897f8bb24c5e8dbf03547cc0334b0f6ae1e)
- Update theme.config to include import directives in separate file [`8d878b6`](https://github.com/fomantic/Fomantic-UI/commit/8d878b64f410ed8a386b04e8d1f260487227147f)
- Add back in email newsletter link [`95881c2`](https://github.com/fomantic/Fomantic-UI/commit/95881c2f0b4474a4087a2441e614f86f6d45fa48)
- Adds responsive breakpoints for dropdown menu height [`29f79ee`](https://github.com/fomantic/Fomantic-UI/commit/29f79ee24d90703e308d5a61a96ad56debaf56b3)
- Fix grouped button aligment, icon message alignment [`7aa345d`](https://github.com/fomantic/Fomantic-UI/commit/7aa345dec7f3342d2c64f133f482b4e82a1ac6a2)
- Adds flag element, adds bordered image variation [`85309d5`](https://github.com/fomantic/Fomantic-UI/commit/85309d5599f84f2f7dd926742a41b6ae3bac4e5c)
- Additional fixes for #649 with multiple sidebars [`9de6cc1`](https://github.com/fomantic/Fomantic-UI/commit/9de6cc1c9c037e53eb2c7ffd0c6c343d80eea9ed)
- WIP transition fixes for detection [`53584d8`](https://github.com/fomantic/Fomantic-UI/commit/53584d83be896ad434fb879f47b99bfe55afdc2f)
- Further sidebar optimizations for mobile [`efac55c`](https://github.com/fomantic/Fomantic-UI/commit/efac55c23cc2724f17f6335b47e0ebfcad1bfea8)
- Fix related to #1495, stackable equal height grid wrong width, add padding to divided stackable grid [`24e0332`](https://github.com/fomantic/Fomantic-UI/commit/24e03320d19d1be689781a0c44c5f16964ec3183)
- assets inside pacakge.js for flag and icon [`33d4cba`](https://github.com/fomantic/Fomantic-UI/commit/33d4cbaf5f363afa1c0c717d0b9ba1a673edb48d)
- Fixes for grouped/inline form label sizes [`a6975a9`](https://github.com/fomantic/Fomantic-UI/commit/a6975a9ee2748ea68462010d88706471a7a81a22)
- Reordering button.variables for legibility [`5e70c1e`](https://github.com/fomantic/Fomantic-UI/commit/5e70c1e2901d7bb6ce1bb84a12298609336baf25)
- Adds border color to ui rating [`2b38956`](https://github.com/fomantic/Fomantic-UI/commit/2b3895666fb3e8d05fafe20403ea3661e280b356)
- Adds light styling to table headers [`6e7d658`](https://github.com/fomantic/Fomantic-UI/commit/6e7d658801bbd6a521eed63f816fe5a5f86bee39)
- Make examples slightly less crappy [`e3822fb`](https://github.com/fomantic/Fomantic-UI/commit/e3822fb7b93d216d342021bda85120887d1502cf)
- Add variables for  largest screen size, instead of using breakpoint minus 1pixel [`37be648`](https://github.com/fomantic/Fomantic-UI/commit/37be648e81cf079a4fa0ce57490f33bc07e61782)
- Update comment banner [`b503b98`](https://github.com/fomantic/Fomantic-UI/commit/b503b987ca8be3e0b3a22c5ac666e79f790c4214)
- Fixes transparent input to align more flushed, fixes transparent icon input [`2739e4a`](https://github.com/fomantic/Fomantic-UI/commit/2739e4a55daba45555d6ce2d28fdcb7821ad89a9)
- Update dist [`69fd681`](https://github.com/fomantic/Fomantic-UI/commit/69fd68100187d9837860bd1a9b2b8d413ce68113)
- Fixes for package.json missing causing issues [`b388af5`](https://github.com/fomantic/Fomantic-UI/commit/b388af58bab1e17dc1b004cdf652e095361c5c8d)
- Verifies context functionality [`738b896`](https://github.com/fomantic/Fomantic-UI/commit/738b8969aee692094f899c3ec77b24c2fb71674b)
- Fix build error in minified css causing doc menus not to appear [`0521467`](https://github.com/fomantic/Fomantic-UI/commit/05214676cf621b85c27c8545667ec65be1347dbf)
- better Meteor README [`8242abd`](https://github.com/fomantic/Fomantic-UI/commit/8242abd012f86e313fb3dc4f5782f08d634a6e64)
- Swap all proxy calls in dropdown [`01fa4fd`](https://github.com/fomantic/Fomantic-UI/commit/01fa4fd8b6979ed621ba3f393b95a116287a850f)
- Update single component readme template [`5eddf50`](https://github.com/fomantic/Fomantic-UI/commit/5eddf509ee3825574a20bd2496b34f6bc741cf43)
- Dropdown: adds compact variation, fixes for specificity on text selector, and better formatting for sub-menus [`80d1c4d`](https://github.com/fomantic/Fomantic-UI/commit/80d1c4dbce79e20935116951f8c75137dced1f8f)
- Fix floated statistic styles [`60f2235`](https://github.com/fomantic/Fomantic-UI/commit/60f2235ac4cf19e9752f24696954d7ee1fd92618)
- Add missing override for card [`f84e97d`](https://github.com/fomantic/Fomantic-UI/commit/f84e97d5e6fb1fe1a44046b94e45829a3e70be9e)
- Add sizing variation for visible sidebars [`0916a63`](https://github.com/fomantic/Fomantic-UI/commit/0916a63c4277e056923d985222a033584d3aa0bb)
- Adds #1503, adds sortSelect option, fixes select to preserve original value order by default [`ce07403`](https://github.com/fomantic/Fomantic-UI/commit/ce0740358050024d9576fa56e1c5bceaf0a074fb)
- Fixes some layout issues with homepage [`2bc0a20`](https://github.com/fomantic/Fomantic-UI/commit/2bc0a2042d8046ce5d1eedcfdb0e9b3c03fda0fb)
- Continued work on sidebar fixes, menu some other stuff [`3434ac8`](https://github.com/fomantic/Fomantic-UI/commit/3434ac83dd1b723d82d76d23fb8a86a76fff6cf2)
- Fix celled/divided ordered lists [`dabed3d`](https://github.com/fomantic/Fomantic-UI/commit/dabed3d61d373ff5b97d867a142e934010ea76a0)
- Add basic material headers [`b442e72`](https://github.com/fomantic/Fomantic-UI/commit/b442e72a976b852abfec731ef5b641b31b298e7b)
- rebuild dist [`ff86695`](https://github.com/fomantic/Fomantic-UI/commit/ff8669520958f83f07d00c177c8aef07e3ca4a92)
- Fixes piled attached #1219 [`eb2e99e`](https://github.com/fomantic/Fomantic-UI/commit/eb2e99eb84623f6890a0d640cf61e73d09051e6b)
- Fix issue with search dropdown not working on menu click [`77e19fe`](https://github.com/fomantic/Fomantic-UI/commit/77e19fe64b89ff3de694294542b04bcba187b24c)
- Add defaults as backup for tasks when not set-up yet [`3645905`](https://github.com/fomantic/Fomantic-UI/commit/3645905f12394b21bb78c1b55c417e182e33c7c4)
- Fix grid example [`92073b6`](https://github.com/fomantic/Fomantic-UI/commit/92073b65207182ecd616b0564061e8950e5690d3)
- Rebuild / fix github theme values [`76302d8`](https://github.com/fomantic/Fomantic-UI/commit/76302d8f5abd462521b36eb65d3f9aa7b4bd5398)
- Fix feed divider [`590701f`](https://github.com/fomantic/Fomantic-UI/commit/590701febe0c634cc4776d3cf5ee8253b3a99efc)
- Fixes inverted header styles [`ab39c63`](https://github.com/fomantic/Fomantic-UI/commit/ab39c6321c71ebd86d603b72580ae3e04c172e92)
- Update jshintrc [`6a7be63`](https://github.com/fomantic/Fomantic-UI/commit/6a7be63b0e12b31de4ef9df2428464d440cbc89b)
- Several more fixes to formatting of standard response [`0f911e1`](https://github.com/fomantic/Fomantic-UI/commit/0f911e16d00d87316f8d6b41a80517ef4bde4689)
- Fix fixed menu stuttering issue [`b30a87f`](https://github.com/fomantic/Fomantic-UI/commit/b30a87f35a155e3ebb09c15ff245aa6009c41681)
- Adds bottom offset value for sticky, zindex [`4790ce1`](https://github.com/fomantic/Fomantic-UI/commit/4790ce1cae646f6a055646de6c43a7f8240d1668)
- Fix succesful indicating progress, rating spacing [`636c8ee`](https://github.com/fomantic/Fomantic-UI/commit/636c8eeccebd731a56eaec232bc1a56ab79efb60)
- Rebuild dist [`ab7bd0c`](https://github.com/fomantic/Fomantic-UI/commit/ab7bd0c1e5408ccd9fbf231741b36f72a6c25460)
- Add allowtab setting, to enable/disable dropdown tabbing [`2277085`](https://github.com/fomantic/Fomantic-UI/commit/2277085fcd75e5d48bf1b4075882a38c62659ea7)
- Allow statistic label to be either on top or bottom [`4dea9ff`](https://github.com/fomantic/Fomantic-UI/commit/4dea9ffaa3fecb3413b52dee502f466cce7c0b98)
- Fixes tab history to work correctly when multiple tab elements must use same history event. Adds tab documentation back into docs [`fd9e766`](https://github.com/fomantic/Fomantic-UI/commit/fd9e766c377be13d304cba51615df29d9a8e84d6)
- Messages no longer use REM, inputs use standard error colors [`1ee8007`](https://github.com/fomantic/Fomantic-UI/commit/1ee80073562ca20e2d7b7bd2045fa9a91884cc2e)
- Build 1.5.1 [`12e1f23`](https://github.com/fomantic/Fomantic-UI/commit/12e1f238a9e0ea197155988a6d15750ac42b6314)
- Adds #1429, dropdown menu left/right position [`826db9f`](https://github.com/fomantic/Fomantic-UI/commit/826db9f18471fc3530fd3607b8d4d070931b8272)
- Config now extends defaults instead of replacing [`c6e11b5`](https://github.com/fomantic/Fomantic-UI/commit/c6e11b5e8030c5491dbea700fa411fe6f4bdf99b)
- Adds grid pairing with divider/other content [`d24a58d`](https://github.com/fomantic/Fomantic-UI/commit/d24a58d67954096e186bcb49ef20987dcd4785ab)
- RTL support for popup/sidebar [`cd13127`](https://github.com/fomantic/Fomantic-UI/commit/cd13127ccbd19eedb67a62b16ff90ecf3b7df0b6)
- Greatly simplify stackable grid [`339b473`](https://github.com/fomantic/Fomantic-UI/commit/339b47398e32ba257f83320a53e53a6e3aedb4c5)
- Fix related to #1199, issue with using scrollbar causing dropdown to close [`c4635a7`](https://github.com/fomantic/Fomantic-UI/commit/c4635a741ee51a7efbb95e11edc2906224470e9b)
- Dropdown: Adds strict type checking as an option for form selection, allowing for better handling of data-value=0, value='' and other ambiguous values [`565e0a0`](https://github.com/fomantic/Fomantic-UI/commit/565e0a075a61bb988d3004ba852a9d8838400d7e)
- Google theme is now material, updates fadeup/down scale transitions to not be relative to size of element. Now specified in rem [`496eb98`](https://github.com/fomantic/Fomantic-UI/commit/496eb988be68d1f3071c4d6ca2d45cfb933300fa)
- Fix errored dropdown styles inside forms [`1d5b258`](https://github.com/fomantic/Fomantic-UI/commit/1d5b25821b56959f3ed102e78a481c7aebfdd7de)
- Updating readme [`95e634e`](https://github.com/fomantic/Fomantic-UI/commit/95e634e046d4d4e0d4ad105b1d07fe13c754134e)
- Fix bottom attached buttons on card margin [`be5786d`](https://github.com/fomantic/Fomantic-UI/commit/be5786d3969fd2c557ef389e8d5b4f85f484c294)
- Add integer range validation to form #997 [`d380502`](https://github.com/fomantic/Fomantic-UI/commit/d38050270b1120589d8d062f9aa096852185798a)
- Fixes doubling grid to be wider in most instances for columns, fixes menu inputs in vertical menu [`d78e6d5`](https://github.com/fomantic/Fomantic-UI/commit/d78e6d5414c03af475d8d5b353600591adb07ef0)
- Build patch 1.5.2 [`6aaa041`](https://github.com/fomantic/Fomantic-UI/commit/6aaa0410c40904e50c07ca0d5f848fc524ca03da)
- Release 1.1.1 [`ff8086e`](https://github.com/fomantic/Fomantic-UI/commit/ff8086ef44681d394994d5c441181d1e9a4b5a12)
- Fix glob matching patterns for concat css [`ab393b3`](https://github.com/fomantic/Fomantic-UI/commit/ab393b3b825835bdca5fc0c82a011b92962be94d)
- Update some global colors for messages [`1978baf`](https://github.com/fomantic/Fomantic-UI/commit/1978baf5aafa716f0c2ef02033292f52d1cf7031)
- Updates to standard list style [`316f008`](https://github.com/fomantic/Fomantic-UI/commit/316f008e80e278e1e21b3417ab7bfb50b06a77f3)
- Remove $.proxy calls from visibility and accordion [`be617da`](https://github.com/fomantic/Fomantic-UI/commit/be617dacd352bf9b27ec44492b0e5f9c88de8b5f)
- fix dist files' permission [`6b8a2e1`](https://github.com/fomantic/Fomantic-UI/commit/6b8a2e15bd4756d060fc1a988d9f194bc648e9a0)
- Build 1.5.0 [`f4a767a`](https://github.com/fomantic/Fomantic-UI/commit/f4a767a682fbced1f32471ba094581120a307bae)
- Add new rail variations [`9ffad67`](https://github.com/fomantic/Fomantic-UI/commit/9ffad672ae8b5b5a3caf997f671a372d27c4e2fc)
- Fix some examples [`365d41b`](https://github.com/fomantic/Fomantic-UI/commit/365d41bae0b905453f856b64cf645189c6d33bf9)
- Fix tab selector [`5b4116c`](https://github.com/fomantic/Fomantic-UI/commit/5b4116c3767b136e40d7d16d4e26ab5eec6ce1aa)
- Rebuild files [`7f40996`](https://github.com/fomantic/Fomantic-UI/commit/7f409962bd944ed1316b6a746ae328cae52ecd3a)
- Fix target of child animate [`fbce1f1`](https://github.com/fomantic/Fomantic-UI/commit/fbce1f1c7c6f6a5f84c5d9bb123410f843b3c948)
- Corrections for submenu show while animating hide #1288, adjustments to failsafe [`f16131b`](https://github.com/fomantic/Fomantic-UI/commit/f16131b85b6340b6dbf9bd2eb2892e27dfd064fa)
- List: bulleted/ordered now display correctly centered, reduced ordered list indent on sub-list [`dc7e403`](https://github.com/fomantic/Fomantic-UI/commit/dc7e4030138cc2e3447dd93f0dd11d5c5c71eca1)
- Fixes issue with step theme overrides for some reason being in wrong file completely [`53b2f04`](https://github.com/fomantic/Fomantic-UI/commit/53b2f04e1e1d97133c09ec13fbbea26ab4f9a468)
- Messing with gulpfile [`c25fbcf`](https://github.com/fomantic/Fomantic-UI/commit/c25fbcf5a0e1f5312f017dd3f683a92dbe442788)
- Make label sizes resolve to full pixels [`b13e0ca`](https://github.com/fomantic/Fomantic-UI/commit/b13e0ca205193dec56320c23a457a0f068bdf9ca)
- Adds #316 default select stylings now included in form [`ecc4d1e`](https://github.com/fomantic/Fomantic-UI/commit/ecc4d1ed271e0fd77151a6419fac0566241c23e1)
- Fixes inverted divider color css specificity, fixes bug in vertical divider [`05e7b32`](https://github.com/fomantic/Fomantic-UI/commit/05e7b323e5ebe3eef44f20e4a6092918e96c671a)
- Fix some popup examples [`9e5aacd`](https://github.com/fomantic/Fomantic-UI/commit/9e5aacd02536aa825c00bdb1fbca80fd2c3bf90c)
- Add continuous/once parameter to visibility api [`8aa1926`](https://github.com/fomantic/Fomantic-UI/commit/8aa1926f04551b637fb1a3d4fdd59cf822fa26eb)
- Fix accordion transition in webkit to use useFailSafe [`71d8659`](https://github.com/fomantic/Fomantic-UI/commit/71d8659758b426c8e90c192f2c0bc601600c8464)
- Update all misuses of regexp test [`cd9f4f9`](https://github.com/fomantic/Fomantic-UI/commit/cd9f4f9e58992930e52d5d77440961c21a5f71cd)
- Simplify input button/labels inside menus #1289 [`2391c7c`](https://github.com/fomantic/Fomantic-UI/commit/2391c7cb0c5e3793518a5724780198d1f0acd26a)
- Adds fitted list variation [`f76e297`](https://github.com/fomantic/Fomantic-UI/commit/f76e2974c58d4df3947d3d25c0c2ec67f2cc2c2e)
- #1495, stackable grid no longer uses negative margins. [`bac826a`](https://github.com/fomantic/Fomantic-UI/commit/bac826a5a2e55b20acf2ce9e218221ffc0b9c4c8)
- Adding debug statements to detachable #1472 [`a1b2733`](https://github.com/fomantic/Fomantic-UI/commit/a1b273300acb9cb8b6d3f59e4d5750baa06c72c7)
- Fixes issue in #1344, gulp watch causes error when adjusting theme.config [`e2adad8`](https://github.com/fomantic/Fomantic-UI/commit/e2adad8147362bbac61751af8dcfb1fcd8ed374e)
- #1425 adds svg to all image variations [`d912d06`](https://github.com/fomantic/Fomantic-UI/commit/d912d06eeb2fe298220f9baa11f9f441877cd6ab)
- Header/button inherits fonts from global instead of redefining inside def [`32cfe8a`](https://github.com/fomantic/Fomantic-UI/commit/32cfe8a85a429cd7a86457cb2ab2dcc4fb89c691)
- Fix issue with animations sometimes sticking due to restore conditions [`ec249ad`](https://github.com/fomantic/Fomantic-UI/commit/ec249ad00a56bf5a5a585ca12120dd9852b21029)
- Organizing some settings objects [`ef0945f`](https://github.com/fomantic/Fomantic-UI/commit/ef0945fe4e1b1d1d04c786a140910f3808bd1d35)
- Fixes to visit and visibility [`9a37e7c`](https://github.com/fomantic/Fomantic-UI/commit/9a37e7cd9fac0dd0da9cc7ce20e9d07335c9d078)
- Remove $.proxy calls from popup [`122a0e7`](https://github.com/fomantic/Fomantic-UI/commit/122a0e768444f784e3047fb00e15cc37b1a06c09)
- Rebuild source [`2d6ac51`](https://github.com/fomantic/Fomantic-UI/commit/2d6ac51356458c0fb967504ffa9a4cbc3e17626d)
- Revert transition changes, causes overlap issues in some animations like popup. [`60e1fa1`](https://github.com/fomantic/Fomantic-UI/commit/60e1fa13d06234ff2a7f9e7fdc78b5b437b3631b)
- Adds further fixes for lists inside menu, adds nested grid coupling with popup [`126ecf5`](https://github.com/fomantic/Fomantic-UI/commit/126ecf5598eab1371de44071dc0164cbbf0ba04a)
- Adjust card default theme, move github theme to classic, makes more sense [`f3f1ab8`](https://github.com/fomantic/Fomantic-UI/commit/f3f1ab82d052a56303a82fbea04dba9bafe855f5)
- Modify fade up/down to be % based [`7a314d1`](https://github.com/fomantic/Fomantic-UI/commit/7a314d197c986a5bc73315dc3e8d7682ad7f5d4f)
- Update release notes for 1.x [`65f5791`](https://github.com/fomantic/Fomantic-UI/commit/65f5791690d62b13ebf984862a4b2f81c77c4cd0)
- Fix issue #1569 #1564 #1560 - Popup issues in 1.5.x [`625ef8f`](https://github.com/fomantic/Fomantic-UI/commit/625ef8ffc06ba7b21f083728930e0a8d8f1d44a7)
- Fixes required form checkbox [`8cbaa0f`](https://github.com/fomantic/Fomantic-UI/commit/8cbaa0f63ab4925a51fcc8e7b92da6983e5d2cd5)
- Backport fix to message from 0.x.x [`874f4cf`](https://github.com/fomantic/Fomantic-UI/commit/874f4cfe840e6d8129c438f030134ea6cbb58acd)
- Fixes for reveal [`07b801c`](https://github.com/fomantic/Fomantic-UI/commit/07b801cfb3e8893596e6be7def297769b1efce46)
- Fix missing variables in input, updates bower.json [`c1a44b5`](https://github.com/fomantic/Fomantic-UI/commit/c1a44b5a5c54a63970d123ce8613acec3c88ff39)
- Fix typo referring to gulp, add error for missing semantic.json [`168437c`](https://github.com/fomantic/Fomantic-UI/commit/168437c0b0cdb01cc8d788b92415b31736f45500)
- Update language dropdown [`7200be6`](https://github.com/fomantic/Fomantic-UI/commit/7200be604aa42f3f8d6658bc513d82a9c7de7d6e)
- Add requestanimationframe to shape [`0267dee`](https://github.com/fomantic/Fomantic-UI/commit/0267dee0d3148a75a973b07da24266841da48fe5)
- Rebuild files [`e1d56b6`](https://github.com/fomantic/Fomantic-UI/commit/e1d56b62b9857b8f631e24b04d5716ca790e09f3)
- Fix typo in grid docs, and adds more doc notes [`03df25b`](https://github.com/fomantic/Fomantic-UI/commit/03df25b75f4ebbae428bcce1c83dd21436194475)
- Light updates to video and accordion styles [`1ed3fdc`](https://github.com/fomantic/Fomantic-UI/commit/1ed3fdcf275627d68e720325687883438a9cd088)
- Adds tiny size, updates loaders [`2e27f9f`](https://github.com/fomantic/Fomantic-UI/commit/2e27f9f50b408b3cdbeba071fce95e5f18c27dad)
- Rebuild dist [`8c9bdc8`](https://github.com/fomantic/Fomantic-UI/commit/8c9bdc886a6c2ab797e43c52956a73489d94c561)
- Consolidate block rules #1428 [`0e645b2`](https://github.com/fomantic/Fomantic-UI/commit/0e645b23d10b5ad688a12440399c78cadfc50c0b)
- Fix transition duration in ui input to use site defaults [`0c3f5f4`](https://github.com/fomantic/Fomantic-UI/commit/0c3f5f4405da71200cc1c7df20dc4c36f4ee61f2)
- #1273, loosen strictness of floats in list. Require word order, stat, header, list [`b59ac59`](https://github.com/fomantic/Fomantic-UI/commit/b59ac593b89136504ca24653615620ad83e0e68c)
- Sidebar: swaps to single RequestAnimationFrame, updates release notes [`e97582c`](https://github.com/fomantic/Fomantic-UI/commit/e97582c588507a1147b712c4c12cd2c2b3a3e67c)
- Iterating on gulpfile [`fc2b545`](https://github.com/fomantic/Fomantic-UI/commit/fc2b545f361c69631b46261f71051d9290168749)
- Increase contrast on rating icons, hitbox on heart, remove console log [`f600977`](https://github.com/fomantic/Fomantic-UI/commit/f6009776edb4fdbb5c0c8e0213bcbde64764f3cf)
- Darkens global blacks [`ad13b92`](https://github.com/fomantic/Fomantic-UI/commit/ad13b92d25750f1ca748cfb5065e4feda1e2a2b4)
- Fix accordion menu formatting [`1eeb0c2`](https://github.com/fomantic/Fomantic-UI/commit/1eeb0c28409f541fbfe322d6f4bac264351ae917)
- Removes debug from behaviors, adds new visit behavior [`5f90a01`](https://github.com/fomantic/Fomantic-UI/commit/5f90a01da42eac423149500e8ad1bd1958c8f7ea)
- Remove proxy calls from tab and visit [`87a11d6`](https://github.com/fomantic/Fomantic-UI/commit/87a11d6772909af55151bc98ab11820da199ef55)
- Add RTL theme #1552 [`2ac7a86`](https://github.com/fomantic/Fomantic-UI/commit/2ac7a869b07177d8a0f0804cdaa16eed1ae169d7)
- Removes undocumented loading class for menu [`3582a5a`](https://github.com/fomantic/Fomantic-UI/commit/3582a5a35a349e3acb2f2beabca95b4856f326cf)
- Header UI now inherits from site.variables [`6e474fb`](https://github.com/fomantic/Fomantic-UI/commit/6e474fb9c36825667500f991f2a2ac3c9dd2f45f)
- Add several new progress callbacks [`b4dc362`](https://github.com/fomantic/Fomantic-UI/commit/b4dc3624acdc1439c8792ea1d9299bfe4174e569)
- Tweak some ui loader settings [`f32e7ed`](https://github.com/fomantic/Fomantic-UI/commit/f32e7ed21f3304958363b305ff3d04c5404b20dd)
- Rebuild for deploy [`d8affd0`](https://github.com/fomantic/Fomantic-UI/commit/d8affd058dcfc8ff0ac5f2ac9cabfacbb84309f3)
- Adjust icon header formatting, more visible icon, better alignment with text. Recalculate max icon width size [`e41820c`](https://github.com/fomantic/Fomantic-UI/commit/e41820c623cb2e8bd0d4fd1c108e0376aec9bb69)
- Updates several component definitions [`9f84330`](https://github.com/fomantic/Fomantic-UI/commit/9f8433026cdcc38fbe68644751bb2fca20deeba1)
- Modify use of $.proxy in checkbox [`74f3eeb`](https://github.com/fomantic/Fomantic-UI/commit/74f3eebd571242cb3af57999f0f3218973ec2937)
- Build patch 1.4.1 [`f751dfb`](https://github.com/fomantic/Fomantic-UI/commit/f751dfb68c034681433c479db34922666eafa6ce)
- Ad test advertisement [`77ab04e`](https://github.com/fomantic/Fomantic-UI/commit/77ab04e05100fa5cf970c28119de067a1b71a878)
- Some more doc fixes woo [`a253b0d`](https://github.com/fomantic/Fomantic-UI/commit/a253b0d348e9e242c7c884b2104ddce8b40f9e12)
- Make stackable/mobile page grids use same gutter width as columns [`275eed5`](https://github.com/fomantic/Fomantic-UI/commit/275eed5d96b515d1b6f3284c7345a02d9e805f48)
- Fix flag collision with ui flag, fix attached label borders [`5d7459b`](https://github.com/fomantic/Fomantic-UI/commit/5d7459b5e5df2516494a062425cf015c28155a5f)
- Adds support for legacy/new complete/success/failure callbacks [`88c6861`](https://github.com/fomantic/Fomantic-UI/commit/88c68610c2cc4aaefefd147c2d4afb380cbbc230)
- Slight formatting fixes table, fixes doubling grid spacing [`664e352`](https://github.com/fomantic/Fomantic-UI/commit/664e3522907f0a0cb1e8b43220244965ee9d7c50)
- Adds alt tag to search templates, fix for sticky menus in Safari [`261d86b`](https://github.com/fomantic/Fomantic-UI/commit/261d86bc79c01e7fd2f56f38461b19c9ba971b97)
- rtl hints updates [`c545fbe`](https://github.com/fomantic/Fomantic-UI/commit/c545fbe72025d60bffc4673e2b0ce14c2723ce01)
- cleanup [`7b8621e`](https://github.com/fomantic/Fomantic-UI/commit/7b8621edcb862e424a5773715bf088f14d42527e)
- Modify use of $.proxy in sticky [`d5a32a0`](https://github.com/fomantic/Fomantic-UI/commit/d5a32a01915840ab00b9f30a1bd04e948023e11a)
- Alternate fix for #1587 Attached tabular menu [`26ac8fd`](https://github.com/fomantic/Fomantic-UI/commit/26ac8fda32cc2bc207dbf6b614d9d07db1e410f6)
- Rebuild dist [`a86b5de`](https://github.com/fomantic/Fomantic-UI/commit/a86b5de33a9ceeab08c455ac4bb92c7ad6057c69)
- Fix specificity of icon in list #1514 [`0a32e35`](https://github.com/fomantic/Fomantic-UI/commit/0a32e3551f4fef5bb65557a8dcd0c377ccbf8e3d)
- Update links to live site from beta [`ec4213f`](https://github.com/fomantic/Fomantic-UI/commit/ec4213fd511896c52e1980b816691c595940a045)
- Adds material modal theme [`f1b269d`](https://github.com/fomantic/Fomantic-UI/commit/f1b269d5b15de6773c3be2fd53ec8a3a38ac3d74)
- Add csslintrc [`f574053`](https://github.com/fomantic/Fomantic-UI/commit/f574053dae49f6d0771ece4ec6e4b7fc9a988a6c)
- Update popup example [`38ef225`](https://github.com/fomantic/Fomantic-UI/commit/38ef2258d3929e554264cb9bdbc851d3b3a37803)
- Add line height offset to headers [`ffb5b50`](https://github.com/fomantic/Fomantic-UI/commit/ffb5b50ee716b72967d2a78d4984d78c129a34fa)
- Fixes warning/info/circle icons to point to correct iconography [`33f0054`](https://github.com/fomantic/Fomantic-UI/commit/33f00545837895c70549547a2274ec20d79a6803)
- Fix table active hover color, fix top/botom margins [`3c0931b`](https://github.com/fomantic/Fomantic-UI/commit/3c0931b95beea160b36b3f74af752a5b336878f7)
- Use grunt-newer to quickly package and minify modified watched files [`0d19a18`](https://github.com/fomantic/Fomantic-UI/commit/0d19a1890ba16b9fd0fee4c569bbd6e1d94b752c)
- Fix valign of icon message [`93aa4b9`](https://github.com/fomantic/Fomantic-UI/commit/93aa4b9a1a2f1647b56330fda1a6a24ca274efb7)
- Remove proxy calls from API, update release notes [`f08a6c0`](https://github.com/fomantic/Fomantic-UI/commit/f08a6c06f9d4becf3289767b1710b2a4b7c08f1b)
- Fixes bug in modal hide, dimmer not hiding [`042e6c9`](https://github.com/fomantic/Fomantic-UI/commit/042e6c93cc13b11a7b148a14fa8b35e9864d92b5)
- Modal should clear screen height, updates release notes [`6db67c4`](https://github.com/fomantic/Fomantic-UI/commit/6db67c42d8f5879020c28a4b7362496b224a11d4)
- Fix bug in shape when passing jq object [`a4b6a79`](https://github.com/fomantic/Fomantic-UI/commit/a4b6a798ce5117f24ca7008274a62022e9043307)
- Fix package.json to point to 1.0 branch [`81df5ab`](https://github.com/fomantic/Fomantic-UI/commit/81df5abb1494d929e819e1e28916bca05cdbd660)
- Fix label to use rem [`e5a64dc`](https://github.com/fomantic/Fomantic-UI/commit/e5a64dcad19414fdaea83cfa9a84c611526c41aa)
- API Styles moved over from broken git repo [`9a0ba72`](https://github.com/fomantic/Fomantic-UI/commit/9a0ba7275061013b73b010f94b242314e24468ca)
- Fix hoverable on inline content [`e085804`](https://github.com/fomantic/Fomantic-UI/commit/e08580498d03935758e95bac29ac84fa6bf071b2)
- Move some variables over to bordercolor [`672413d`](https://github.com/fomantic/Fomantic-UI/commit/672413dfa24b6eb7069449e24d6e072a49cb3e37)
- Add relaxed/very-relaxed versions of celled grid [`c0bc6a1`](https://github.com/fomantic/Fomantic-UI/commit/c0bc6a16971da5ffff41d2a5beab76679b241706)
- rebuild for deploy [`3eca9e2`](https://github.com/fomantic/Fomantic-UI/commit/3eca9e2d40cdf01ce55172200fee574bc152fdd0)
- Definitively fixes weird circular issues with radio checkboxes, fixes label alignment [`52d93fd`](https://github.com/fomantic/Fomantic-UI/commit/52d93fdd15f27b45e0498328742bf9ded14212b8)
- Adds success message on form, grid fix for max-width on table-cell [`5c1ca30`](https://github.com/fomantic/Fomantic-UI/commit/5c1ca30891bb5804d387453f3ce958b14774a5f4)
- Adds accordion easeOutQuint easing equation. [`79b6ed1`](https://github.com/fomantic/Fomantic-UI/commit/79b6ed1d43602144d3ffca4c6e341736e19a054a)
- Labels now work inside attached segment [`48193f3`](https://github.com/fomantic/Fomantic-UI/commit/48193f37c2a017edc016a90796d8dddce920cd90)
- Fix responsive sizing of definition table #1428 [`cf5e4b4`](https://github.com/fomantic/Fomantic-UI/commit/cf5e4b4da25d3a7ec284738bf328353f0f0f6bff)
- Update material defaults [`a2cd01e`](https://github.com/fomantic/Fomantic-UI/commit/a2cd01e2cdadad49584c69396a3702442eb7fa03)
- Sort out global variables to be in intuitive order and match definition, move font loading to theme.config (this means users might need to re-install) [`37202a5`](https://github.com/fomantic/Fomantic-UI/commit/37202a56a221854f828732e31f1fae339e9ffd2f)
- Remove paragraph font size, not necessary, can cause inheritance issues [`3ef464f`](https://github.com/fomantic/Fomantic-UI/commit/3ef464fb81cd567563491a26bdd69f48fb76e73a)
- Popup: adds several new callbacks [`9f38f48`](https://github.com/fomantic/Fomantic-UI/commit/9f38f483f7998c18bb6712db061f4b18dc6f6dfb)
- Fix border-top on accordion to not be removed with wrapping div [`0ce7eca`](https://github.com/fomantic/Fomantic-UI/commit/0ce7eca5d618fd1e96e47a611b52c0c4cfa36fa9)
- Fix tiny little bug with overlay in sidebar [`0e8129f`](https://github.com/fomantic/Fomantic-UI/commit/0e8129f94938c27c84cb4c71d9bfa139cc2d2b9b)
- Add plumber back into gulp [`17c7a52`](https://github.com/fomantic/Fomantic-UI/commit/17c7a5262e9349fd298123ae6148d1baf5deffb3)
- Removes unnecessary animation checks from dimmer, now handled in transition [`ef8a8ae`](https://github.com/fomantic/Fomantic-UI/commit/ef8a8ae6f4df3c31594dbeac61c180eb1f514a8d)
- Update to google theme, fix input button alignment [`495d116`](https://github.com/fomantic/Fomantic-UI/commit/495d1162d205a28ec3fad25ca4493903ab4a3b13)
- Change default star rating to use unfilled stars instead of empty stars [`4d9cad3`](https://github.com/fomantic/Fomantic-UI/commit/4d9cad397e918d24a63cddb628c6820c1ec6c71a)
- Add auto spacing of extra content on items [`f9b632b`](https://github.com/fomantic/Fomantic-UI/commit/f9b632bcad5b8312b39f000e9c502938dd494482)
- Stackable grid now only has horizontal padding on page grids [`d817a9c`](https://github.com/fomantic/Fomantic-UI/commit/d817a9cc76b016941ffb2217d04ef5c28b961c75)
- Leet fix for #1337, checkbox now supports multi-line label [`aac00f1`](https://github.com/fomantic/Fomantic-UI/commit/aac00f123b4740cd816cb4fba0d25afaa0c773ff)
- Update release notes [`a5865c4`](https://github.com/fomantic/Fomantic-UI/commit/a5865c4d676f0acd285edb67dfd38295dc3f5ab3)
- rebuild dist [`a2f2b4e`](https://github.com/fomantic/Fomantic-UI/commit/a2f2b4e080f5a3e9f7a0daa220fb95dcc1abea23)
- Tab css loader variables [`799e00f`](https://github.com/fomantic/Fomantic-UI/commit/799e00f62b1dc829748c895a22a4af0112ec76fa)
- Fixes possible issue preventing compilation when missing package.json [`d59f336`](https://github.com/fomantic/Fomantic-UI/commit/d59f3366544361572aade1fc567127c9f7c682bf)
- Fix icon message sizing [`a847e9c`](https://github.com/fomantic/Fomantic-UI/commit/a847e9c3bac88ba0dc011a0994b1d4247c912f10)
- Adds additional button variables, basic styling for google buttons [`a7be087`](https://github.com/fomantic/Fomantic-UI/commit/a7be08710472e4f976c0e53762cc3649e8e9ddd7)
- Tweak dropdown example [`3582404`](https://github.com/fomantic/Fomantic-UI/commit/358240468032a65b2f2cc0d5b0e787ee417600db)
- Fixes a couple step variables [`3a3566a`](https://github.com/fomantic/Fomantic-UI/commit/3a3566adce1781677030502392d33a2fc4a17c77)
- Fixes amazon themed buttons [`c621722`](https://github.com/fomantic/Fomantic-UI/commit/c621722e0706cc48f7005ed79ec19e712a70dc35)
- Form: Fixes input, dropdown, form field to have consistent sizes and 1em font [`b1ea5ca`](https://github.com/fomantic/Fomantic-UI/commit/b1ea5caa2bdf9899803949c03032ba16496d6c82)
- Add watch/build task hook for rtl task with setting #1552 [`ebda601`](https://github.com/fomantic/Fomantic-UI/commit/ebda601ab36147700c50183031aa5aae1e6f1bba)
- Update release notes [`a35fc8b`](https://github.com/fomantic/Fomantic-UI/commit/a35fc8bdc666d41a39a8b881fd8efbc1b2dbc2f9)
- Adds #1377 fix to card as well [`50c9357`](https://github.com/fomantic/Fomantic-UI/commit/50c93574f46062204553d0e81a642a6c758e72e3)
- #1355 breaks up input variables [`1e2caa1`](https://github.com/fomantic/Fomantic-UI/commit/1e2caa10298bd569391f3b2a66c07f5920a7df99)
- Updates release notes [`faed2fd`](https://github.com/fomantic/Fomantic-UI/commit/faed2fdf2f9ee99d2cef073682db9d30dafca026)
- Fix webkit bug causing transitions not to occur due to translation of animationduration to animation shorthand [`395dfbb`](https://github.com/fomantic/Fomantic-UI/commit/395dfbbe635b83177835d38278cc2b64c9680ae9)
- Remove input blur on selection, breaks tabbing in webkit based browsers #1253 [`af1ba23`](https://github.com/fomantic/Fomantic-UI/commit/af1ba235ed1e02f80c947070daf43e6fc0bb7759)
- Fixes issue with items selecting element even if touchmove #1199 [`b1676ea`](https://github.com/fomantic/Fomantic-UI/commit/b1676eab4530485d5918a16871bba5b67feb469e)
- Adds warnings if sidebar layout has to be created on load [`a5fe508`](https://github.com/fomantic/Fomantic-UI/commit/a5fe508c57f9d8e2112eae452884b006a25c9c3b)
- Rounding some header values [`24f1367`](https://github.com/fomantic/Fomantic-UI/commit/24f136794b8c6ed47264a82e9e20da185fa2edaa)
- Iteration on searchable blur fix [`f34b952`](https://github.com/fomantic/Fomantic-UI/commit/f34b9521bb313879dd44fcc16b09f2d1bbb3522d)
- Fix homepage animation [`5abd650`](https://github.com/fomantic/Fomantic-UI/commit/5abd65033008ffd3522290f5d666d1992dc4a143)
- Fixes formatting on image labels, increases label font-size [`59a7b94`](https://github.com/fomantic/Fomantic-UI/commit/59a7b9411af5b23a326f7798ad1fd02d78b29cd6)
- Slight tweak to attached header padding [`dd212ac`](https://github.com/fomantic/Fomantic-UI/commit/dd212ac40815b953adc317e27d5d147b8f0222a9)
- Updates package.json to hopefully clear up dependency issues on CI [`3cd5cee`](https://github.com/fomantic/Fomantic-UI/commit/3cd5cee3273bb2821ece8fc0e0ec199106f9c6bf)
- Modal now uses requestAnimationFrame, properly detects for dimmer dependency [`71e6d3c`](https://github.com/fomantic/Fomantic-UI/commit/71e6d3c49cb5d86bc89566dd143d5865da0c30fb)
- finalized package.js templates [`2a0c628`](https://github.com/fomantic/Fomantic-UI/commit/2a0c628d5f6e579f1618f4fc7ff914f6377a972f)
- Rebuild 1.6.0 update release notes [`d4569ef`](https://github.com/fomantic/Fomantic-UI/commit/d4569efa1c365312c1ba9433b27d4e8200fb8f29)
- Fixes very basic table padding issues [`7412467`](https://github.com/fomantic/Fomantic-UI/commit/74124671122728f674169479bbb194d1f37064ee)
- Update release notes [`bd8ee7e`](https://github.com/fomantic/Fomantic-UI/commit/bd8ee7ea7ab781ae49d3573a979c0c909def5691)
- Leaving search midway will now preserve filtered results, fixed issue with IE11 when all results filtered [`be99866`](https://github.com/fomantic/Fomantic-UI/commit/be99866ffaf40e4d46a3191fae7160a9c333382f)
- Transition hide now works correctly during an animation [`f7052b5`](https://github.com/fomantic/Fomantic-UI/commit/f7052b52fcd8a9296a776ab627c66669afe703e1)
- Update 1.0 release notes [`32e1284`](https://github.com/fomantic/Fomantic-UI/commit/32e12846c46b6bf88fed4d1bb06e9a02af3744eb)
- Expanded some list vars, content can now be top aligned #1273 [`0c4ae6c`](https://github.com/fomantic/Fomantic-UI/commit/0c4ae6c04567f7ad0e4446f009573f9b460a6a5c)
- Adds accordion/header coupling [`b889a41`](https://github.com/fomantic/Fomantic-UI/commit/b889a41dbd86babc3b1ce56b0ee6cfa5b626dcf5)
- Adds basic variation on popup, adds reposition behavior [`28ea752`](https://github.com/fomantic/Fomantic-UI/commit/28ea7521135289601dd63f45ca5eeb8817914f5c)
- Popup now doesnt queue animations, #1062 [`3d50353`](https://github.com/fomantic/Fomantic-UI/commit/3d503536afc814e700a6a0e03ae7d6b02252bc25)
- Fixes issue with stackable grid row spacing, adds padding to vertically divided stackable grid #1161 [`cf8105f`](https://github.com/fomantic/Fomantic-UI/commit/cf8105f285b41bf19242d7295e22f1af8c0b4092)
- Fixes position fixed inside sidebar [`72368fc`](https://github.com/fomantic/Fomantic-UI/commit/72368fc83458fe7124655967011d70b4824b44f6)
- Fix basic table segment [`6a42e3d`](https://github.com/fomantic/Fomantic-UI/commit/6a42e3dfb1434aaa1e5b5561b3f00a9ea2e43557)
- Simplifies header [`3c2158e`](https://github.com/fomantic/Fomantic-UI/commit/3c2158e662e63f93be8183b143e329f6b1c74b81)
- Fixes vertical dividers [`def6d2a`](https://github.com/fomantic/Fomantic-UI/commit/def6d2a00225cd52aacf272ac797a8c06ec15baa)
- Fixing image label [`6e1d77c`](https://github.com/fomantic/Fomantic-UI/commit/6e1d77c0ddf47a2f3b25b680c1a4b71956275131)
- Adds explanation in settings for delay/trigger [`5848239`](https://github.com/fomantic/Fomantic-UI/commit/5848239ebaecae62f90001a1154b0c8e0561719c)
- Make travis only email on success/failure change [`773e100`](https://github.com/fomantic/Fomantic-UI/commit/773e100a337d2dd85ab679e748cb46edcb845662)
- Finish breadcrumb theming [`f675f02`](https://github.com/fomantic/Fomantic-UI/commit/f675f0206511ab3a45428671080e8af94a6d69f1)
- Move around some icons in docs [`3a7f115`](https://github.com/fomantic/Fomantic-UI/commit/3a7f115f1073a543cc4e4350f58e7943f21c68db)
- cleanup [`bef92fd`](https://github.com/fomantic/Fomantic-UI/commit/bef92fdbdc957d735bf590a8b6f886d808928729)
- updated [`8d46150`](https://github.com/fomantic/Fomantic-UI/commit/8d46150c6efbf911a9d209512d88e7f884cab7b0)
- Remove proxy calls from state [`b7db66b`](https://github.com/fomantic/Fomantic-UI/commit/b7db66bc6400e827aece08aa224a1188b418b5f3)
- Remove proxy calls from form [`b2ccf06`](https://github.com/fomantic/Fomantic-UI/commit/b2ccf06b950b7b669d1a341fd67d329e9dea5c1d)
- Fixed menu now fixed top by default [`a11427a`](https://github.com/fomantic/Fomantic-UI/commit/a11427a43d24d0477033c236386fbf8bcc604b30)
- Fix several references to this in proxy to use variable 'element' to avoid keyword issues [`b30779e`](https://github.com/fomantic/Fomantic-UI/commit/b30779e3713907952eaf1528a50708237cb94d0a)
- Fix ordered step alignment [`c885e97`](https://github.com/fomantic/Fomantic-UI/commit/c885e971f7e68a7f563a9e56f962b7b96095886c)
- Finish release notes [`db15a9a`](https://github.com/fomantic/Fomantic-UI/commit/db15a9ab24a578144be2abd44d80a76dc48cafe3)
- Dimmer now can be clicked even before element has finished animating in, #1363 [`75b4f57`](https://github.com/fomantic/Fomantic-UI/commit/75b4f578ae9666fa8e3fbe8a2c15bfe15dc55a19)
- Adds #1396, Adds optional parameter to form validation [`b493f13`](https://github.com/fomantic/Fomantic-UI/commit/b493f1350494abaa7e7499052e8aa2f3dfde83b9)
- Fix for clickaway unbinding if clicked during animation [`a791177`](https://github.com/fomantic/Fomantic-UI/commit/a79117742426c4204d8fb0a155470626fc1b01d1)
- Remove travisCI integration until we have tests for 1.0 [`a5e8a9b`](https://github.com/fomantic/Fomantic-UI/commit/a5e8a9b8f00b987d410f1d1fffaa2a2809c9fdb7)
- rebuild dist one last time [`6ee17a7`](https://github.com/fomantic/Fomantic-UI/commit/6ee17a7988e1f2d902eb1f9f20da3747670233b1)
- Fix init issue when  is undefined #1272 [`6af1ba5`](https://github.com/fomantic/Fomantic-UI/commit/6af1ba5ffa9b9d3deb2fe72af99cbefcb66a9949)
- Icon header is now back to inline-block with clearing [`0adf1f1`](https://github.com/fomantic/Fomantic-UI/commit/0adf1f10a8cd8fe10bf93eea3d1f51177d1de6d6)
- Fix debug statements in shape [`638b42b`](https://github.com/fomantic/Fomantic-UI/commit/638b42b5510bf39fbe356770afef51898f40065c)
- Fix trailing slash detection in install [`c91f962`](https://github.com/fomantic/Fomantic-UI/commit/c91f9628f281a4823adfafd37fd185a50d67aaf2)
- Fix rating example, darken default page color [`8d2b9fc`](https://github.com/fomantic/Fomantic-UI/commit/8d2b9fc829ac06290596bb4a26b136faf7aef21b)
- Modify page bg default [`73a5578`](https://github.com/fomantic/Fomantic-UI/commit/73a5578cfdf81339f6053ffd38d93dc39009facd)
- Add scroll to top [`542f455`](https://github.com/fomantic/Fomantic-UI/commit/542f455de9e92e05f518858004ff1cd31eff8e15)
- Remove some debug, minor adjustments [`d317b5d`](https://github.com/fomantic/Fomantic-UI/commit/d317b5d682702bca5596a07acdcbd24f6c80eb1c)
- Fixes several spacing issues in item [`3bbc88d`](https://github.com/fomantic/Fomantic-UI/commit/3bbc88dd6a9292e60c3426561413b87fb685307a)
- Fix rating vertical alignment [`12d90eb`](https://github.com/fomantic/Fomantic-UI/commit/12d90eb5d35daad9d8a5312b373d91d8517d2fc5)
- Remove proxy calls from dimmer [`b7b4e31`](https://github.com/fomantic/Fomantic-UI/commit/b7b4e310a15510ba2a207481a99b0ffb360c94b7)
- Padded grid no longer needs special rules for stackable #1495 [`cbe1fa0`](https://github.com/fomantic/Fomantic-UI/commit/cbe1fa0ab2be4328b1b22c64afe5a247ba95d59b)
- #1476, maintainer: watch now watches for changes in definition (regression in 0.13.0) [`ef2cfc4`](https://github.com/fomantic/Fomantic-UI/commit/ef2cfc4c3d72902c35b4dbbf833b03bbe3241a55)
- Update github links in markdown. [`c4c8396`](https://github.com/fomantic/Fomantic-UI/commit/c4c8396bb49d6866450461bb41898d06aac9d935)
- #1377 Fixes link formatting inside item to be less broad [`650a882`](https://github.com/fomantic/Fomantic-UI/commit/650a88208cf685948a7db25f44db22ade6168920)
- Update github theme [`62e961f`](https://github.com/fomantic/Fomantic-UI/commit/62e961fdf5cdd694b78e43f702b61a6e8bf1c841)
- Fixes for full screen mobile position [`e2085ea`](https://github.com/fomantic/Fomantic-UI/commit/e2085ea17e4e02164d5015743defcac34243403d)
- Fix loading styles to descend from site.variables for buttons, add back in conditional text fixes [`838ee42`](https://github.com/fomantic/Fomantic-UI/commit/838ee42d481f8908277bbdb9b9385106e217b843)
- Fix mistaken variable in popup [`5550ba6`](https://github.com/fomantic/Fomantic-UI/commit/5550ba6e38f989755dda60dfaaf239f51521553b)
- Resolve issues with line-height in ui input [`50dcb5e`](https://github.com/fomantic/Fomantic-UI/commit/50dcb5e35d083cd4ba5f9150b158339dd4851a88)
- Fix incorrect css property, attached label segment coupling [`44ed053`](https://github.com/fomantic/Fomantic-UI/commit/44ed0534b8e84d49b60ed206fb8c4a43b0865f07)
- Move all callbacks to native js for slight performance increase [`d971ac6`](https://github.com/fomantic/Fomantic-UI/commit/d971ac6dc51b85cc3b4014eee6039ef402a85807)
- Fix transition sometimes keeping inline style unnecesarily [`30e6cb3`](https://github.com/fomantic/Fomantic-UI/commit/30e6cb3cc23c2b00334e9721fdf0dfab51adb957)
- Messages are now relative em [`befef72`](https://github.com/fomantic/Fomantic-UI/commit/befef72ebdc545ceeb887ff11e41a9b8b15fc1b2)
- Remove custom image font sizes [`672646b`](https://github.com/fomantic/Fomantic-UI/commit/672646b4505a9e76b85c7d83b2bf2c451dd5a5cd)
- Better fix for search input blur bug [`09f8ff0`](https://github.com/fomantic/Fomantic-UI/commit/09f8ff00548d2e7fafd3b9a050e9e4a73f157ce6)
- Fix ui list inside menu [`f52e2c7`](https://github.com/fomantic/Fomantic-UI/commit/f52e2c787aaf986b7984dbd0fd34073b3bf11826)
- Readme adjustments [`9a413cc`](https://github.com/fomantic/Fomantic-UI/commit/9a413cc136d5e1c2f75104f68b53d13c425a7cb8)
- removed assets list [`7f34ff2`](https://github.com/fomantic/Fomantic-UI/commit/7f34ff23fd968732a02a688b9310ef1c9213ed1a)
- Formatting for popup #1550 [`604ed9b`](https://github.com/fomantic/Fomantic-UI/commit/604ed9b6b63597fa16607f654b289714dce3f93e)
- Update release notes [`1d29584`](https://github.com/fomantic/Fomantic-UI/commit/1d295846e58295d84fa67ae182fc74df43496dcb)
- Updates release notes [`f5442a7`](https://github.com/fomantic/Fomantic-UI/commit/f5442a79bd9d16c0163f8d54d5afa8f2a3652402)
- Fix border radius on dropdowns in vertical menus [`85c73ab`](https://github.com/fomantic/Fomantic-UI/commit/85c73ab953de3449f1532fbef81f0a2e3e2e6f8f)
- Adds inverted accordion variation [`8195230`](https://github.com/fomantic/Fomantic-UI/commit/8195230837fd1659fa4d338a1b226a593c3bb5ea)
- Fix FF dimmer issues with preserve-3d, horizontal/vertical flip work with just perspective prop anyway [`e674afa`](https://github.com/fomantic/Fomantic-UI/commit/e674afa101c4b59aa39a5f8f2863aa64046a32f0)
- Fixes isssues with full screen modal positioning on mobile [`094a2b7`](https://github.com/fomantic/Fomantic-UI/commit/094a2b7b7fcfe9da341ffc1d0a406057e18c44f8)
- #1395, adds setting for limiting values above/below bounds [`1c3f4f0`](https://github.com/fomantic/Fomantic-UI/commit/1c3f4f0a09a99af9edb0c68d57ad987ee5cfa0e8)
- Fix release notes formatting [`94c574c`](https://github.com/fomantic/Fomantic-UI/commit/94c574cece5fdb9038f0e3aceae129aa524b238b)
- Update release notes [`61b2fa6`](https://github.com/fomantic/Fomantic-UI/commit/61b2fa6e09aa79dcc396cdcdd6bdc17747178249)
- Fix bug with mobile grids that arent stackable or doubling [`773dd3a`](https://github.com/fomantic/Fomantic-UI/commit/773dd3a566cd1f9f4a02676a9474e7fcc461fac6)
- Fix top border on icon header [`ba47485`](https://github.com/fomantic/Fomantic-UI/commit/ba4748514ed541e2c17d6111c749d30089d31a8d)
- Fix labeled input in form examples [`376bb8d`](https://github.com/fomantic/Fomantic-UI/commit/376bb8d9bbc133212d0a0c3a2e87e5ec8dc7f3af)
- Fixes inputs inside vertical menus, fixed black variable usage [`51f5a24`](https://github.com/fomantic/Fomantic-UI/commit/51f5a24fd4cc4f36a30d26b402a480496e6e674f)
- Fix collapsed comment state [`927b5c1`](https://github.com/fomantic/Fomantic-UI/commit/927b5c1db1cd1a99099b8a04a019cc5436cda56d)
- Adds breadcrumb less to docs [`b0fce52`](https://github.com/fomantic/Fomantic-UI/commit/b0fce52bf4174265da766578c88566c0d08804dd)
- Fixes search destroy method to remove all events [`28545c5`](https://github.com/fomantic/Fomantic-UI/commit/28545c5b99f2ce14c1a4513f95bd19fa49e1d6e4)
- Updates form variables for state [`d34034e`](https://github.com/fomantic/Fomantic-UI/commit/d34034e8139276cb644bf841316dbdb1f375999f)
- Fix fluid text menu [`281d3a4`](https://github.com/fomantic/Fomantic-UI/commit/281d3a4de25d9205089c9441b68dcb93b2293b7f)
- Fix some old comment banners pointing to wrong repo [`b5e73f7`](https://github.com/fomantic/Fomantic-UI/commit/b5e73f715f5f2d3a6721cecf66df3955f2c628fe)
- #1509 remove media query from ios scroll to support landscape ipad [`2ca95bb`](https://github.com/fomantic/Fomantic-UI/commit/2ca95bb4e8a97a76ca4f0eb8cd35b8b5646f98f3)
- Position "or" vertical aligned. [`c93e5c2`](https://github.com/fomantic/Fomantic-UI/commit/c93e5c2088fa1eafcd04d576c41971a4b557c9f7)
- Update notes [`411d52f`](https://github.com/fomantic/Fomantic-UI/commit/411d52f89e4d62144c3cfe5301fba9e8dd459f9a)
- Update release notes [`4d8d3bd`](https://github.com/fomantic/Fomantic-UI/commit/4d8d3bdfcdb6aa79f7d2948adde69f5a0ee931db)
- Default to uncover for sidebar [`b257c39`](https://github.com/fomantic/Fomantic-UI/commit/b257c39820528947fe4a1cb2a8462bf75ad14735)
- Search selection now allows re-searching after selection [`05178b8`](https://github.com/fomantic/Fomantic-UI/commit/05178b8de231b73c246412f8ecdd5183d7d48266)
- Fixes multiple hide on scroll [`4fb6f80`](https://github.com/fomantic/Fomantic-UI/commit/4fb6f80f7fedda426bfdff5c536f67f674e279e5)
- Add variables for basic text colors [`493d5cb`](https://github.com/fomantic/Fomantic-UI/commit/493d5cbb39d0a9987dcc2758505b9db7336c39f5)
- Fix mutation observer check to not produce errors [`1711069`](https://github.com/fomantic/Fomantic-UI/commit/17110696b402cc63b81a381269f81ec73ee07e13)
- Adjust min width of progress bar [`c0f64a1`](https://github.com/fomantic/Fomantic-UI/commit/c0f64a12691d1eb90dc2b50f4c08efbe8e3c4f6b)
- Fix callback names for start, complete in transition [`33b08e0`](https://github.com/fomantic/Fomantic-UI/commit/33b08e028da47a4b09cf59baa3c9a7e641e7cb00)
- Horizontal dividers now have letter spacing variables, can use em spacing around text [`d20bff5`](https://github.com/fomantic/Fomantic-UI/commit/d20bff56df1a4296544896f5fd997cf93f691f12)
- More fixes for #1173 [`56dd55f`](https://github.com/fomantic/Fomantic-UI/commit/56dd55fe08e8e1949083a07289e0ada5affc510c)
- Fix language modal reappearing [`fd88c30`](https://github.com/fomantic/Fomantic-UI/commit/fd88c30ab1384409d174fb0f74c0f1b04bf24d6f)
- Fix regression, causing dimmer not to cover whole page when on mobile or scrolling dimmer content. [`f6b0155`](https://github.com/fomantic/Fomantic-UI/commit/f6b015564e10c52393626eb197e668949af402ac)
- Fix table margins, border radius on colored [`facedc3`](https://github.com/fomantic/Fomantic-UI/commit/facedc3f8471136f98a53d4fb01948841f192b70)
- Removes pointer events from disabled buttons, adds icon distance to labels, removes margin from bottom floated images [`7a165e8`](https://github.com/fomantic/Fomantic-UI/commit/7a165e87498c5cfb9fec10211b0a263f2a20e4e1)
- Updates some package defaults [`7ff8419`](https://github.com/fomantic/Fomantic-UI/commit/7ff841907fb6ea44da3c0f7d5427fc31eb40958d)
- Fixes some issues with tab formatting [`2ee5369`](https://github.com/fomantic/Fomantic-UI/commit/2ee53691f1c1d393bc65cdf2e5c19927b4d28d65)
- #1587 Fix bottom attached rule to only apply to next bottom attached, or multiple bottom attached [`d8bb137`](https://github.com/fomantic/Fomantic-UI/commit/d8bb1379c176c6bedc2a7b6777fa933cca7fc357)
- Update release notes [`f0def9b`](https://github.com/fomantic/Fomantic-UI/commit/f0def9bb6abafabe2bda1ed3d05b65008b249e66)
- Remove debug statement from dropdown [`39b375f`](https://github.com/fomantic/Fomantic-UI/commit/39b375f550bc9a695ec6d22ae4db7071cac554f3)
- Cleanup code [`578b630`](https://github.com/fomantic/Fomantic-UI/commit/578b630cbaa4ace30ac1a2e170ac3dda3edd4294)
- Adds material modal theme changes [`906daf0`](https://github.com/fomantic/Fomantic-UI/commit/906daf0c391029acdf2ca84b8baa48c719034ba6)
- Spruce up some styles in search [`846ee11`](https://github.com/fomantic/Fomantic-UI/commit/846ee11cd875023614cfec51ba644b82c557fe82)
- Fix color tween loading issue with dropdowns [`9037829`](https://github.com/fomantic/Fomantic-UI/commit/90378294a2f4cd02f51e8e14eb6f3327f030f1ec)
- Removes body margin fix, adds padding to vertically divided stackable [`b89aa28`](https://github.com/fomantic/Fomantic-UI/commit/b89aa28e4e5c96717e07027d2f4c5fd13fa5ac53)
- Mobile fixes [`622b16f`](https://github.com/fomantic/Fomantic-UI/commit/622b16f6dabf5de03dcd047ae639494b47e7a24c)
- More intelligent handling of multiple attached segments [`c52c4ee`](https://github.com/fomantic/Fomantic-UI/commit/c52c4ee4e745112f9a0334d8f956c30a11e33030)
- Remove api doc draft, fix formatting [`d073c36`](https://github.com/fomantic/Fomantic-UI/commit/d073c368f6c4c94e6cf950577218537f91fd21d3)
- Fix statistic border [`4ac91a2`](https://github.com/fomantic/Fomantic-UI/commit/4ac91a2ebb8ea15e987285bb661c3bd70def557f)
- Fixes basic table bottom row padding issue [`ac076ac`](https://github.com/fomantic/Fomantic-UI/commit/ac076ac23c81dbae5ca2b5f2da6bed89e70223ee)
- Build .less file when relevant .overrides or .variables file is modified [`0336c4a`](https://github.com/fomantic/Fomantic-UI/commit/0336c4aef450e0e4858836bd2adf1705b808b419)
- Light default formatting changes modal [`0466002`](https://github.com/fomantic/Fomantic-UI/commit/0466002f03e9ae03ea011dcc85bc54d5435946d1)
- Update list docs [`69f174e`](https://github.com/fomantic/Fomantic-UI/commit/69f174e9c121b29538ea2e54ee5963d587e99826)
- Fixes karma test runner to not run Gruntfile, fixed missing destroy method on checkbox [`cd98d58`](https://github.com/fomantic/Fomantic-UI/commit/cd98d5866f35eb2b0d3ac16785dae8c3d1797181)
- better order [`01a1e1c`](https://github.com/fomantic/Fomantic-UI/commit/01a1e1c52d46fb00ad5a34c34fbe86528c38345f)
- added instruction to install under Meteor [`5425804`](https://github.com/fomantic/Fomantic-UI/commit/5425804cffd295bac74922cc5edbca009d25a69e)
- Move animating back to original position [`196197b`](https://github.com/fomantic/Fomantic-UI/commit/196197b736d55105315c501f0b6ea2c28841aa49)
- Formatting for sidebar #1550 [`7d9f50a`](https://github.com/fomantic/Fomantic-UI/commit/7d9f50a451ca02e1facb96a0dcb033c5088779ca)
- Fixes min-width on fluid labeled icon menu [`d3b3ea3`](https://github.com/fomantic/Fomantic-UI/commit/d3b3ea387facaa6bed132ffcd8b1b713cbec81e9)
- Adds #1562 version number to dist/ [`39aba91`](https://github.com/fomantic/Fomantic-UI/commit/39aba912abdbc1972e12a46e9056e31d374df0e5)
- Add @inputFont variable, remove @pageFont from input default theme vars #1487 [`dd4ccb3`](https://github.com/fomantic/Fomantic-UI/commit/dd4ccb3b26ef832de0a6f209effa19c39b5de039)
- Update release notes [`4d52983`](https://github.com/fomantic/Fomantic-UI/commit/4d5298377057ecc12c9bce5d05d4c65c957fe1a8)
- Update release notes [`319a0c3`](https://github.com/fomantic/Fomantic-UI/commit/319a0c320d6cc2077eba29ee99725b8afdba8c4b)
- Add form disabled check [`43e9113`](https://github.com/fomantic/Fomantic-UI/commit/43e9113d5574392962af0b07b549c0b2f1f03e93)
- Merges in #1453, or line height [`8ec88c9`](https://github.com/fomantic/Fomantic-UI/commit/8ec88c9f2c05077dd1308ce4dedb4db069502b14)
- Add support for `input[type=datetime-local]`. [`ab06636`](https://github.com/fomantic/Fomantic-UI/commit/ab06636e42a74efd91d2e52b4070b9cb1b6deaba)
- Updates to ver 1.1.2 [`e0cfdc8`](https://github.com/fomantic/Fomantic-UI/commit/e0cfdc83ca929979dd98a77306dfb709795728cd)
- #1372 Better fix for rem/em issue [`308bf2b`](https://github.com/fomantic/Fomantic-UI/commit/308bf2b9fa0d2005592b26a810a618785017ad45)
- #1277 remove cookie.js inlined dependency [`344870b`](https://github.com/fomantic/Fomantic-UI/commit/344870be142c89f90bed2acfd96ac474b5d92150)
- Fixes table transitions #1236 [`24b1ab1`](https://github.com/fomantic/Fomantic-UI/commit/24b1ab10caa6ddeb2e46f0944263848d6d33fceb)
- Update examples [`df79422`](https://github.com/fomantic/Fomantic-UI/commit/df79422c2750010f96a3ff4b5a4267f62d6b7aa4)
- Adds on scroll auto [`d59dd64`](https://github.com/fomantic/Fomantic-UI/commit/d59dd648ad21242e24f97636e12d8895e75474c9)
- Fix fullscreen modal left margins [`17cfe99`](https://github.com/fomantic/Fomantic-UI/commit/17cfe99eed3a1d6adfbda90ff9a87c85ec6d80e7)
- Fix build script for deploying repos to use correct url #1250 [`3280b21`](https://github.com/fomantic/Fomantic-UI/commit/3280b21891745ae3fd297530d031b50f1feca6f8)
- Update GETTING-STARTED.md [`fbfe258`](https://github.com/fomantic/Fomantic-UI/commit/fbfe258a0fb8bd74da74d050ba6490152db2d354)
- Fixes for extra content v-align in items [`f3c8add`](https://github.com/fomantic/Fomantic-UI/commit/f3c8add6f016fd48a454c4f53ed7c4be4ce92a1d)
- Fixes 1233 Issue with base64 encoding on steps [`f6f7707`](https://github.com/fomantic/Fomantic-UI/commit/f6f7707c062a7f36dddb8459cc0263e185514f95)
- Fix issue with checkbox src #1197 [`030aa39`](https://github.com/fomantic/Fomantic-UI/commit/030aa396075f13e86083d853d7e2c54e44d26e41)
- Update readme [`74fa4e6`](https://github.com/fomantic/Fomantic-UI/commit/74fa4e6cddce571b5765939d4ec46ab6abce1b4f)
- Fix dropdown examples [`9aa2a9b`](https://github.com/fomantic/Fomantic-UI/commit/9aa2a9bdc61d805d5df85d882e6facba4ed9c784)
- Remove right padding from list items [`b54f6df`](https://github.com/fomantic/Fomantic-UI/commit/b54f6dfc298e5d8ad2e691fab7db46b2129a712d)
- Fix default blacks to be more consistent [`08cdd9e`](https://github.com/fomantic/Fomantic-UI/commit/08cdd9ef9d0cf59043b56e289f4c3e475066b77b)
- Adds header font variable, fixes secondary segment text color [`b597165`](https://github.com/fomantic/Fomantic-UI/commit/b597165d3b3119caa406d06715133e4c98f96d56)
- Add form, state, visibility components to gulp install [`6d6138f`](https://github.com/fomantic/Fomantic-UI/commit/6d6138f484d308d4a52327ad97f89c0315b5efbd)
- Related #1501 Gulp build now only builds files specified in setup [`62c3e1d`](https://github.com/fomantic/Fomantic-UI/commit/62c3e1d7cc6b4e1c5611d28e04a3949369d4623e)
- Fixes centered row inside centered grid [`6c75d36`](https://github.com/fomantic/Fomantic-UI/commit/6c75d3668ebb2e6b544e7ce35c08444acf9018a5)
- One last typo in release notes [`9d04273`](https://github.com/fomantic/Fomantic-UI/commit/9d042736b2a661c739b57630c192384613dec9fd)
- Update release notes for 1.1.0 and package.json [`da844bf`](https://github.com/fomantic/Fomantic-UI/commit/da844bf6a000547525beb0505deeb2a11c1fd87f)
- Remove empty rules from example [`512c3f5`](https://github.com/fomantic/Fomantic-UI/commit/512c3f578625d70df52044e4eb9baf89a93e0537)
- Fix twitter theme icon colors [`5b32423`](https://github.com/fomantic/Fomantic-UI/commit/5b324236a53fd333a2164522f945b7665ab20c71)
- Modify transition hidden to force display none [`e3b0a9f`](https://github.com/fomantic/Fomantic-UI/commit/e3b0a9f06da1e78294562aad81a491cd2ca5bd30)
- Remove error message for when popup cant find a position, its not really an error [`6576f0d`](https://github.com/fomantic/Fomantic-UI/commit/6576f0d59c4c8d2f40c41026cf4e985b4dc821d9)
- Fix horizontal icon alignment with statistic [`e4e8aa5`](https://github.com/fomantic/Fomantic-UI/commit/e4e8aa5d1141370fdacc6b6a3aebd61c79d84b53)
- Fix description spacing without meta on item [`29e0507`](https://github.com/fomantic/Fomantic-UI/commit/29e05073d9779b24ff192f3a344f72b16bd9e442)
- fix debug settings for sidebar [`0bc4de0`](https://github.com/fomantic/Fomantic-UI/commit/0bc4de0b737802cdfcc98eb9184aeecd20e88834)
- Iteration on git automation [`7881197`](https://github.com/fomantic/Fomantic-UI/commit/78811974e83dd655221f7b007b07136647adcbe8)
- Fix some paths [`a7b8beb`](https://github.com/fomantic/Fomantic-UI/commit/a7b8beb8bc2b823a2d47d5f82eceaa9b473b3bdc)
- Circular images now have overflow [`a84ed02`](https://github.com/fomantic/Fomantic-UI/commit/a84ed020452b267a261e200a9a2ddef421fbdb5d)
- Submodules now receieve same debug setting [`68ea260`](https://github.com/fomantic/Fomantic-UI/commit/68ea26012d5f0fad0b02594efdefcbcf0165bca3)
- Fixes overflow issue [`0e40315`](https://github.com/fomantic/Fomantic-UI/commit/0e40315dce849bf374d44843a1b78455ce2bb12e)
- Fix flash of double scrollbar on modal #787 [`644e2c6`](https://github.com/fomantic/Fomantic-UI/commit/644e2c69b137fa76848bff80552133f43254c720)
- Fix typo in timeline feed [`5a39510`](https://github.com/fomantic/Fomantic-UI/commit/5a395103c4240d315810af6a88055cfcfad429ad)
- Add variables for stackable cards [`49a4c76`](https://github.com/fomantic/Fomantic-UI/commit/49a4c7694a1b44c32826a3b1cdb442e20e2542f2)
- Fix stackable card margins [`4a731ef`](https://github.com/fomantic/Fomantic-UI/commit/4a731ef7bb0f90c56e3064a3fd91e5ea244ff975)
- Fix dimmer from blurring on webkit [`07f0faf`](https://github.com/fomantic/Fomantic-UI/commit/07f0faf1c780865e07485ac17e12040fa7202fc0)
- Remove $.proxy from shape [`7ba4d5f`](https://github.com/fomantic/Fomantic-UI/commit/7ba4d5fb9be08f5c4af093b946af47c482aee43d)
- Ensure animation order matches previous version to avoid regressions [`972e942`](https://github.com/fomantic/Fomantic-UI/commit/972e942d64f7a78da9289651f926a19176a2749e)
- Make useLegacy more obvious in sidebar, default to auto [`1a701e2`](https://github.com/fomantic/Fomantic-UI/commit/1a701e20ab6725c346376dab282b01b52ab3920b)
- Update release notes for 1.5.0 [`da3e8cd`](https://github.com/fomantic/Fomantic-UI/commit/da3e8cda522a9e801d292ce54d5ed34771f395eb)
- Remove console.log from tab [`0fb14e1`](https://github.com/fomantic/Fomantic-UI/commit/0fb14e107211b8ca155220e937f707249d0e340f)
- #1501 semantic.json.example components should be absent not empty [`e38b77a`](https://github.com/fomantic/Fomantic-UI/commit/e38b77ab7f698cdb1d2ed8e033c6777e4105d864)
- Fix selection dropdown inside menu [`484c282`](https://github.com/fomantic/Fomantic-UI/commit/484c282dab453931d1d0ff4f405c3ec045ae1f7a)
- Fixes z positioning issue with forced layering inside sidebar #1492 [`3d438ee`](https://github.com/fomantic/Fomantic-UI/commit/3d438ee1bde8363e06b16c5b42e271f5a27c3c38)
- #1470, remove popup should not error if called without popup [`135ff9e`](https://github.com/fomantic/Fomantic-UI/commit/135ff9ee0ee94b117ac53341b2a254a48d312318)
- Fix typo from replace on svg image [`096f130`](https://github.com/fomantic/Fomantic-UI/commit/096f13071c5b096a97a5b200649c7214ea754333)
- Fixes floating dropdown menu child position [`9686fae`](https://github.com/fomantic/Fomantic-UI/commit/9686faed1b884bf4e2d67ef5ad3f6a9bfc79a8ae)
- updating form.js [`a2e8638`](https://github.com/fomantic/Fomantic-UI/commit/a2e863829d3c52a7b3052d43f7987d20c69aa29b)
- Fixes em units breaking steps #1372 [`6bca1a4`](https://github.com/fomantic/Fomantic-UI/commit/6bca1a410ae1654864a46920d6e0790bfaa10623)
- Fix npm package name to match 0.x.x branch [`7cb8f52`](https://github.com/fomantic/Fomantic-UI/commit/7cb8f52e09ddf2349ada597f9ff4b2dfb321905d)
- Fix for #1299 [`e6fc690`](https://github.com/fomantic/Fomantic-UI/commit/e6fc690165ec3a02cab846c1d16e3b29170fc7d9)
- Examples [`ae8db4e`](https://github.com/fomantic/Fomantic-UI/commit/ae8db4e2efbc978e954d399bcac758af8559c64d)
- Backport fix in form validation [`291a2cd`](https://github.com/fomantic/Fomantic-UI/commit/291a2cd305e8abd9e2a33a1a01b9d507a66fee0c)
- Fix material theme radius [`1a40b83`](https://github.com/fomantic/Fomantic-UI/commit/1a40b83c88cdfb76c2eb3f9d4402ac2ecd5ac881)
- Missing comma in list #1273 [`ddee7f7`](https://github.com/fomantic/Fomantic-UI/commit/ddee7f70ea5f2b0cbcb85c552c9a30a2925681c1)
- Reverts change to hidden transition, hidden transitions should not be removed from page flow [`157af2d`](https://github.com/fomantic/Fomantic-UI/commit/157af2df5aceabce0d016ca18ddea988ddfe8ade)
- Normalize paths for *nix #1264 in gulpfile [`d44d41e`](https://github.com/fomantic/Fomantic-UI/commit/d44d41e822fd0018584c5a3bcdadd388c7751fcd)
- fix misspell of enable and disable method name [`bf367dc`](https://github.com/fomantic/Fomantic-UI/commit/bf367dc830c1e70cad3f59cca2a69f388c1346b0)
- Add better error when API module not included [`c2dfe45`](https://github.com/fomantic/Fomantic-UI/commit/c2dfe4521a507e046fc7caa955786ae090122dda)
- Several more possible issues with missing package.json [`367ffb9`](https://github.com/fomantic/Fomantic-UI/commit/367ffb9fe5d3ca20de938dd5c7539dd5bbf46e53)
- Fix shape not removing clone [`2bc5c2e`](https://github.com/fomantic/Fomantic-UI/commit/2bc5c2e14de6c703793cf51c95785e35026157ad)
- Add oauth example file for maintainers [`842f946`](https://github.com/fomantic/Fomantic-UI/commit/842f9469afc321ded9c6abe6fe298bc7d6dda56b)
- Fix in menu searchable from clearing text [`fd158c6`](https://github.com/fomantic/Fomantic-UI/commit/fd158c6c780edb9211638994f10bc2ceca3755d0)
- Fixes issue with defaults not loading when no config file [`483ba73`](https://github.com/fomantic/Fomantic-UI/commit/483ba73247e87c500f8cab1ca4b76566aca524f6)
- Update gulpfile [`8a7071d`](https://github.com/fomantic/Fomantic-UI/commit/8a7071d03321210cbce8c6aa92b3cc0609778fa5)
- Update docs for dropdown [`7c191b1`](https://github.com/fomantic/Fomantic-UI/commit/7c191b1bd9314f3e986daccc5b5e2c0d8cf6cb89)
- Fixed issue with stackable grid [`f8d6b7c`](https://github.com/fomantic/Fomantic-UI/commit/f8d6b7cca7554dd62a4c77b66d5e493ae15031cb)
- Better errors for attach events [`625ea52`](https://github.com/fomantic/Fomantic-UI/commit/625ea527eec9032ae1825bebeb743e8cd8fb51e6)
- Fix for multiple labels again [`6fc8fb6`](https://github.com/fomantic/Fomantic-UI/commit/6fc8fb6b4f9bc63674b02fac4cbb18f2e211ecb1)
- Fix toggle height [`670f4f7`](https://github.com/fomantic/Fomantic-UI/commit/670f4f71fc7fcfe8cbb60fb84a565dcb485fc832)
- Fix margin on header [`c4111c7`](https://github.com/fomantic/Fomantic-UI/commit/c4111c726666a95e642756af54b871fd9e7f5cc5)
- Fix celled grid width [`3a00b94`](https://github.com/fomantic/Fomantic-UI/commit/3a00b9409b4420f6ab76eb13018e5a2452aec054)
- Fix another example bug [`00f2be0`](https://github.com/fomantic/Fomantic-UI/commit/00f2be048afec9cfd59477aafffbea9935bc5a1b)
- Fix logo link, anchor links [`398cbcb`](https://github.com/fomantic/Fomantic-UI/commit/398cbcbcb98f004d202a4fa1ba39e78980d6a742)
- Fix missing variable in menu.less [`c8e41de`](https://github.com/fomantic/Fomantic-UI/commit/c8e41defbd97f69e259ff25c9cc008327e5f3bb7)
- Fix issue with clickaway not closing sidebar on mobile [`eff5613`](https://github.com/fomantic/Fomantic-UI/commit/eff5613d263a300e3c404d012b99b6eafa7f3bc9)
- Removes debug info from module [`5abf0b4`](https://github.com/fomantic/Fomantic-UI/commit/5abf0b4e278610edf19e680ab0b657282371b633)
- Fix table footers to not be italic [`8a4a7fe`](https://github.com/fomantic/Fomantic-UI/commit/8a4a7fe9d8618347e19884237a6ca6c6e37dac1d)
- Fix ad placement [`3fe8e84`](https://github.com/fomantic/Fomantic-UI/commit/3fe8e84fe23cfb5228bfb5da366d1241ffdcec7d)
- Correct watched path for .variables and .overrides files [`369817a`](https://github.com/fomantic/Fomantic-UI/commit/369817aa72a07831978ffd91f229c20840d9c436)
- Convert backslashes to slashes for Windows compatibility [`e69bfaa`](https://github.com/fomantic/Fomantic-UI/commit/e69bfaa3530c0d004b83132c9276c1ce5c0271ef)
- Fixes icon header opacity [`dbc3f17`](https://github.com/fomantic/Fomantic-UI/commit/dbc3f17e6bcc17924706d8a2a098ffbd1ca9ac58)
- Add legacy params error [`d1520b7`](https://github.com/fomantic/Fomantic-UI/commit/d1520b7ae7c2694704ca3a558c1a0742525e3042)
- Typo in semantic.config.example [`4a5e5cc`](https://github.com/fomantic/Fomantic-UI/commit/4a5e5cc457309abee56b90429c5b2d67cf0d3619)
- Adds ribbon distance to labels [`891cab5`](https://github.com/fomantic/Fomantic-UI/commit/891cab5acfb8fe4a4e5124947aa306bb3bac9f8f)
- Add a Bitdeli badge to README [`9d0b507`](https://github.com/fomantic/Fomantic-UI/commit/9d0b50714a2b3cddf369a781b677e607637eeb31)
- Update release notes [`513c3a5`](https://github.com/fomantic/Fomantic-UI/commit/513c3a523387648564e821bff00ffb0a82985dbf)
- Removes negative margin on adjacent segment #1587 [`fef80ad`](https://github.com/fomantic/Fomantic-UI/commit/fef80ad974f36f18cd41ec0d60e862f595bdca49)
- Remove unnecesary border radius rule from ui menu item [`789dc0b`](https://github.com/fomantic/Fomantic-UI/commit/789dc0b1cb7560dddefa9556e7a88bb9d7a70c35)
- Removes popup console.log from debug #1470 updates release notes [`487f7b0`](https://github.com/fomantic/Fomantic-UI/commit/487f7b09659d31a2912281125b7af44b1758d4c5)
- #1476, adds error on no src path, gulp watch [`7234d60`](https://github.com/fomantic/Fomantic-UI/commit/7234d604ccd2a7c2d2607fef8564d5d57c8cd390)
- #1425 Add svg compatibility with ui image [`b53f2d1`](https://github.com/fomantic/Fomantic-UI/commit/b53f2d1fcb0b2c297d2bc453d17f494ebc3fc154)
- Release notes [`2df1eeb`](https://github.com/fomantic/Fomantic-UI/commit/2df1eeb174e291173c522694812aba98d056633d)
- Fix action input to allow for themes that change button padding [`e9d2f22`](https://github.com/fomantic/Fomantic-UI/commit/e9d2f22a6ce4c99d0ab5d6836caa905b0cadb1fd)
- removed forgotten block [`52e7762`](https://github.com/fomantic/Fomantic-UI/commit/52e7762b2501a1c31bb1a307828cc996e7007bb6)
- Adds ignore, possible #1310 fix [`ab9bbd5`](https://github.com/fomantic/Fomantic-UI/commit/ab9bbd5322cfdfa234078fbf7b5eca8edc7bf0cd)
- Add attached bg variable, fix em rounding [`3d31733`](https://github.com/fomantic/Fomantic-UI/commit/3d3173339d5b27c1cb6082971c6752c5fae4bb70)
- Add linking icon opacity variable [`bc852b6`](https://github.com/fomantic/Fomantic-UI/commit/bc852b60269dccd5119c3fc43e73244d458ecddd)
- Update GETTING-STARTED.md [`8481ae8`](https://github.com/fomantic/Fomantic-UI/commit/8481ae8fd2b783348bd82c64a3133a7e6bfcd280)
- Remove error when updating semantic.config during watch [`2478b77`](https://github.com/fomantic/Fomantic-UI/commit/2478b7768c609d60ecd71ca4c20a953ff7e1ff16)
- Fix bower.json [`a67e1db`](https://github.com/fomantic/Fomantic-UI/commit/a67e1db355817185f0d5e12c22203d14ec415d72)
- Remove console.log from dropdown [`2fb23b3`](https://github.com/fomantic/Fomantic-UI/commit/2fb23b317945f4956a9deac9767dda573632d464)
- Fixes fiddle link [`3e1d163`](https://github.com/fomantic/Fomantic-UI/commit/3e1d163196796dc0f6bf3f2f56205754c6ad0185)
- Fix for multiple labels [`6f70bd9`](https://github.com/fomantic/Fomantic-UI/commit/6f70bd9dc718d6cd8121e7a6d69f51acf0d7cd71)
- Fix inline dropdown alignment [`b1d8d03`](https://github.com/fomantic/Fomantic-UI/commit/b1d8d03ba933f0ab86572db44b010dfe9936c1e7)
- Fix weird 1px content issue with display: table in chrome on modal, #787 [`c46531d`](https://github.com/fomantic/Fomantic-UI/commit/c46531d2f869864437ad088dbdd9b8a695bdffc5)
- Remove kitchen sink link from css branch [`ff2b5de`](https://github.com/fomantic/Fomantic-UI/commit/ff2b5de6e9ff333ed2908205acaf1f1841b17f45)
- Update release notes [`68d9bc9`](https://github.com/fomantic/Fomantic-UI/commit/68d9bc9ba2441fab119f8f93087a40343ed33cc4)
- Adds bordered image [`88855b8`](https://github.com/fomantic/Fomantic-UI/commit/88855b8d044cb9ed51b768ef761c1d81d632e161)
- Adds sticky variable stubs [`8b13c35`](https://github.com/fomantic/Fomantic-UI/commit/8b13c35594937ed1740fe995ae0d1f09135ba766)
- fixed version [`357c2a3`](https://github.com/fomantic/Fomantic-UI/commit/357c2a3165d5d79dabbce9cf3d42bf1f27c9c7fb)
- removed typo [`ed45c2a`](https://github.com/fomantic/Fomantic-UI/commit/ed45c2a842ec54f9a7def54de907fb7463ddd93c)
- added link to Meteor README [`178a79d`](https://github.com/fomantic/Fomantic-UI/commit/178a79d23ba6532d94bb62fc12555e0a52385943)
- Replace proxy calls in rating [`91d7163`](https://github.com/fomantic/Fomantic-UI/commit/91d71639aa8d99ef6306d764289f1248272e7d00)
- Typo in popup check for existence [`160e5ac`](https://github.com/fomantic/Fomantic-UI/commit/160e5ac935f7cf68235db7ec58dcf053acaa6116)
- Fix debug comment #1552 [`b6732c0`](https://github.com/fomantic/Fomantic-UI/commit/b6732c07fa787aed9f07b8b91ea57afc496091da)
- Fixes typo in top of label file [`c165d6d`](https://github.com/fomantic/Fomantic-UI/commit/c165d6da2ba22d91d6f9e3f0ab9902ffe198a249)
- Update release notes [`4045c83`](https://github.com/fomantic/Fomantic-UI/commit/4045c83435c07283109f26340505f061ffb87875)
- Adds #1533 focus background to input default theme [`dda61fd`](https://github.com/fomantic/Fomantic-UI/commit/dda61fd14ef1ca4e1628d967b33490e805aa096a)
- #1501 Fix componentGlob when no components set [`7860d1c`](https://github.com/fomantic/Fomantic-UI/commit/7860d1c6fe5c0c65797b70c600f559731e0ba020)
- Update release notes [`1b02501`](https://github.com/fomantic/Fomantic-UI/commit/1b02501f86e837f67e1560a70884bebcc6be53e5)
- Update release notes date [`d501f88`](https://github.com/fomantic/Fomantic-UI/commit/d501f88cf2134cbd0bb84edda0cf86acd5f96dd6)
- Update release notes [`505fba2`](https://github.com/fomantic/Fomantic-UI/commit/505fba298213ea4e29539e7e08c5bbab933f2237)
- #1484 #1403 #1261, default to HTTPS [`f771e31`](https://github.com/fomantic/Fomantic-UI/commit/f771e315da3c1d2c9405852921d23105f39e3789)
- Enables API debug by default [`41790b2`](https://github.com/fomantic/Fomantic-UI/commit/41790b2a1978fa557ac2f7c99dc6cb66c171b582)
- Adds new debug to popup for positioning [`bbf6a49`](https://github.com/fomantic/Fomantic-UI/commit/bbf6a49f0cb08de246c1de2684a35bbc0bfd68ab)
- Update npm version [`8f838a3`](https://github.com/fomantic/Fomantic-UI/commit/8f838a35e324048a4290e59c97fcd23dad6627eb)
- No event from watch [`14739ed`](https://github.com/fomantic/Fomantic-UI/commit/14739edbcdf5ca9bf9480cb1a5f5dc1c2902b875)
- Disable modal debug: [`46f14ab`](https://github.com/fomantic/Fomantic-UI/commit/46f14ab0e0a022f8960fca50822d779ed16369d5)
- Wrong boolean #1432 #1417 [`20316e7`](https://github.com/fomantic/Fomantic-UI/commit/20316e73c4d73a8ed53f83085fdd62ef37847758)
- Adds debug line to transition [`f5ffe9b`](https://github.com/fomantic/Fomantic-UI/commit/f5ffe9bfe91064109fcf23ab7b96ea4e1fee90cc)
- Update release notes [`a6aa91c`](https://github.com/fomantic/Fomantic-UI/commit/a6aa91c121a6e3b92774f3f1ce96a2c9481d190e)
- missing else [`a659a4a`](https://github.com/fomantic/Fomantic-UI/commit/a659a4a20d74ab267bd8f97f90a97df3ae578d71)
- Disable progress debug [`4176c58`](https://github.com/fomantic/Fomantic-UI/commit/4176c588e9862efb0407fdab804d7d4c7930e4a0)
- Making JSHint happy [`1d5ee28`](https://github.com/fomantic/Fomantic-UI/commit/1d5ee28bb90c4ca45dcb049e889b436f107f7016)
- Set path im example file to default install path [`9255603`](https://github.com/fomantic/Fomantic-UI/commit/9255603605007ea537c6d5f9b25cc204421688b9)
- Updates wording on release notes [`77883d8`](https://github.com/fomantic/Fomantic-UI/commit/77883d8b7de0293a132a03452f7673534e2b640a)
- Fixes date [`39ad6e4`](https://github.com/fomantic/Fomantic-UI/commit/39ad6e4f4a023a429372cbcc098bb19d9757c5d3)
- Sidebars: Fixes typo when checking for other active  sidebars [`7bb88ce`](https://github.com/fomantic/Fomantic-UI/commit/7bb88ce0cf0c4822b1ca5a4a4e4e478af07fc7bf)
- Removes debug from popup [`88a6dc6`](https://github.com/fomantic/Fomantic-UI/commit/88a6dc652c84c9babaf78997b4aa8bf3d5211546)
- Slightly increases transparent icon spacing #1346 [`95e183e`](https://github.com/fomantic/Fomantic-UI/commit/95e183e5c782d9c4d92fdf1c80cb64c02be95a87)
- Adds #1351, set selected triggers onChange callback [`35f349f`](https://github.com/fomantic/Fomantic-UI/commit/35f349fbb62f0fbc72585b5157e2abcea9826fa8)
- minor fix [`22f4f5f`](https://github.com/fomantic/Fomantic-UI/commit/22f4f5f9e6778554479fdeb050b3535fa745d816)
- Typo in transition causes unknown animations to not be correctly caught [`5de9b72`](https://github.com/fomantic/Fomantic-UI/commit/5de9b72e3e8a91ef7fe54757fa14bb092dcf201f)
- Fix circular icon centering [`1764809`](https://github.com/fomantic/Fomantic-UI/commit/1764809062a3b067570c96b50634a4bdcbf69f3c)
- Fix typo in css declaration for .vertical.flip.transition.in [`f08ce76`](https://github.com/fomantic/Fomantic-UI/commit/f08ce768ea851f71f03aca95ae95ce79b534101a)
- Fix typo in Release Notes URL [`4fae429`](https://github.com/fomantic/Fomantic-UI/commit/4fae429d0f26ee4a25663fb0ac4d78f45d13c38d)
- Update logo [`c2a24df`](https://github.com/fomantic/Fomantic-UI/commit/c2a24df07f01f26455f22634e6c69c50a7655437)
- Reduce secondary menu item horizontal padding [`a09ef01`](https://github.com/fomantic/Fomantic-UI/commit/a09ef0179c23908eca821e6336062b71f026528e)
- Update error message for missing dependency in tab [`8ce2a3c`](https://github.com/fomantic/Fomantic-UI/commit/8ce2a3c611077eeab044618bd0439eb010444155)
- #1272, another typo (too long a day) [`a28c218`](https://github.com/fomantic/Fomantic-UI/commit/a28c218ca366d831a2d927a056ef4acd93139ae7)
- Fix typo in popup [`b5fefb5`](https://github.com/fomantic/Fomantic-UI/commit/b5fefb578e0efdb491451623b41b7698a604a17a)
- #1261, remove protocol from font loader [`327c9a6`](https://github.com/fomantic/Fomantic-UI/commit/327c9a6f2eaf036c7e9ee5e98a154b80e13aa029)
- Fix gulp install to add new files inside directories (was avoiding overwritin dir) [`53265f7`](https://github.com/fomantic/Fomantic-UI/commit/53265f76728b903f55be999b8a52c9704e68cfc5)
- UI Header inherits header font weight [`409f527`](https://github.com/fomantic/Fomantic-UI/commit/409f527eca21a4084e89460c11eea7f4883a4d3a)
- Error message variables, popup [`68b19d0`](https://github.com/fomantic/Fomantic-UI/commit/68b19d09a679552e64eccb4531321ae7e9093e04)
- Adds request #1243, fix for disabled checkbox [`3f6c472`](https://github.com/fomantic/Fomantic-UI/commit/3f6c472cfe9a870bb184bce9242d89a547bc2d9b)
- Fixes next top attached segment missing border #1219 [`43b4622`](https://github.com/fomantic/Fomantic-UI/commit/43b4622410dd5a921007f089eee411d37d40a804)
- Fix shimmering on basic modal in FF [`7b03c7e`](https://github.com/fomantic/Fomantic-UI/commit/7b03c7e870c383d0dfb5fed29fbf29cb899f6fee)
- Fix inverted popup box shadow issue [`90e0553`](https://github.com/fomantic/Fomantic-UI/commit/90e05532a529673e00ec1028f0de6dce82d41da4)
- Remove unnecessary ui from fixed sidebar elements [`d9d9b98`](https://github.com/fomantic/Fomantic-UI/commit/d9d9b98371effeb84ead2feadae116454c676424)
- Fix critical typo breaking SUI [`65c3c94`](https://github.com/fomantic/Fomantic-UI/commit/65c3c94e74db539281f810c29ca019acaa928430)
- Remove travis, no testing hooks set into gulp yet [`431086f`](https://github.com/fomantic/Fomantic-UI/commit/431086f8def3dc3aaddb482dd9f3564296d479b3)
- Shape: Fix size calculations in loading to use better strategy (similar to popup) [`c6d6d22`](https://github.com/fomantic/Fomantic-UI/commit/c6d6d2296c56465f3757cdf7c0df80ea90bc4bbb)
- Increase default message header spacing [`9276782`](https://github.com/fomantic/Fomantic-UI/commit/927678274ec98c8dfa67aecc199a28bfbb29f482)
- Fix message header distance [`fd16dd2`](https://github.com/fomantic/Fomantic-UI/commit/fd16dd2e6cf11fef71a6f453399cbda7a4a34c25)
- Fix regexp for theme changes [`13b62a9`](https://github.com/fomantic/Fomantic-UI/commit/13b62a9096c0e81efeaabfe7f603051a246fd22d)
- Fix some example links [`c10dce7`](https://github.com/fomantic/Fomantic-UI/commit/c10dce7d125ca211a6d757550cf416d10381ff44)
- Remove some console logs [`77247a5`](https://github.com/fomantic/Fomantic-UI/commit/77247a510e11cfbc1303503c4e0b6e21f6f18cb4)
- Fix border radius to be absolute in labels [`c2000bc`](https://github.com/fomantic/Fomantic-UI/commit/c2000bc8d9a853f11ad875781951f5d3661901a3)
- Fix button loading style demo [`ab0aab4`](https://github.com/fomantic/Fomantic-UI/commit/ab0aab400709c4d2ed0bf93e678415678f0a0ffd)
- Reduce delay for popup show [`4b8b699`](https://github.com/fomantic/Fomantic-UI/commit/4b8b699375e1b28a7799be81b745c11a43db914f)
- Add callback before animation start, useful for queued animatinos [`70a125e`](https://github.com/fomantic/Fomantic-UI/commit/70a125ecc39dc5bf5fde2768362af7896c729bf8)
- Reduce selected border color [`201e4b7`](https://github.com/fomantic/Fomantic-UI/commit/201e4b72fab94a52622054de9ab8bbd8d62b7cb0)
- Visible transition can now be triggered by class name only [`2671fff`](https://github.com/fomantic/Fomantic-UI/commit/2671fff60b17fcc1db148a907b25878b6cb0b937)
- Add API docs to beta docs [`e9fad63`](https://github.com/fomantic/Fomantic-UI/commit/e9fad6318d3bb4efb1dc81d60433efcf998ab6f9)
- Fix for non stackable grid at mobile width [`9e8975d`](https://github.com/fomantic/Fomantic-UI/commit/9e8975d797ba92382c10891b262c2100a7b482cb)
- Typo in progress [`5844e6b`](https://github.com/fomantic/Fomantic-UI/commit/5844e6bf41458408bf9034b8e6a690a4309dd308)
- Avatar spacing fix [`c6a8864`](https://github.com/fomantic/Fomantic-UI/commit/c6a8864cec159e6a37f946ee1c72d295a8494029)
- Fix button docs header [`22653d7`](https://github.com/fomantic/Fomantic-UI/commit/22653d75dbe681f5489463bf1deaf0ddb326e369)
- No longer translate anchors [`be67a87`](https://github.com/fomantic/Fomantic-UI/commit/be67a8728ce64b949a4af893194521e3fd28930b)
- Fix typo in header [`9d494d5`](https://github.com/fomantic/Fomantic-UI/commit/9d494d539db3eee3305e1d279a13101718fbfee3)
- Fixes responsive grid mobile gutter [`95eba37`](https://github.com/fomantic/Fomantic-UI/commit/95eba377b23ea5fc44e3397af054e7011d3bd7ce)
- Slightly increase sidebar animation speed [`32327b4`](https://github.com/fomantic/Fomantic-UI/commit/32327b45e77039a00c196ace408ed5702b22c73d)
- typo in property name [`2081967`](https://github.com/fomantic/Fomantic-UI/commit/2081967faf0ae2fac35cd99637e54f2dc9672672)
- Fixes content not scrollable after dim typo #787 [`e24a439`](https://github.com/fomantic/Fomantic-UI/commit/e24a439ee4feb2f4fb24caf6c25a5baae3075db1)
- Fix attached label element pading [`512e7ad`](https://github.com/fomantic/Fomantic-UI/commit/512e7ad288c5a9a37a8a64ce8ed1aeb3b9ea8846)
- Fix popup example [`6d870c1`](https://github.com/fomantic/Fomantic-UI/commit/6d870c11d7ec8d4d6b5092832f9cb3a50eb7c398)
- Update sidebar description [`ea51714`](https://github.com/fomantic/Fomantic-UI/commit/ea5171452d686cb26ad8b58de97cbc705f29a0e1)
- Fix inheritance of fonts in doc [`aa10511`](https://github.com/fomantic/Fomantic-UI/commit/aa1051137709a3a6e3db5875e9a2fe073b9e3dd9)
- Fix bordered image selector [`547e8c5`](https://github.com/fomantic/Fomantic-UI/commit/547e8c551f0ce4a7be641740199574ad37d5b80f)
- Typo in checkbox lineheight [`7b9e800`](https://github.com/fomantic/Fomantic-UI/commit/7b9e800efcc1a8b71301327fe3d234bca322f79d)
- Tab: Fix bug when tab initialized with 0 elements [`cf10c84`](https://github.com/fomantic/Fomantic-UI/commit/cf10c84cb2ad2e7c44664093d2e4689b498fb201)
- Fix issue with 100% width on equal height row [`b756009`](https://github.com/fomantic/Fomantic-UI/commit/b756009ea578f0a5a2760f7da599b357b84f65fe)
- Update 1.0 notes [`6f6b079`](https://github.com/fomantic/Fomantic-UI/commit/6f6b079f3b92175520f4348ba5e1cf3877528905)
- Increase row spacing slightly [`9536dd4`](https://github.com/fomantic/Fomantic-UI/commit/9536dd49c3fbc7118a410527c7128f2dfc25ae6b)
- Removes css comment [`f51f3e9`](https://github.com/fomantic/Fomantic-UI/commit/f51f3e9224ad8c308052bc7be7ad8a401def8f17)
- use :only-child instead for tfoot fix [`cad08c5`](https://github.com/fomantic/Fomantic-UI/commit/cad08c555fb489839e29087830cf5dcac27d5157)
- Removes empty rule [`532b904`](https://github.com/fomantic/Fomantic-UI/commit/532b904637cbcec5733627b44be738bde0c3cf9d)
- Remove will-change from transition, causes 3d context to be created on element in chrome breaking position: fixed [`e442885`](https://github.com/fomantic/Fomantic-UI/commit/e4428857d56aa9791950f8dcd7913978be33e2d5)
- Rebuilds files with new dropdown component [`2e83691`](https://github.com/fomantic/Fomantic-UI/commit/2e8369173e0ae78ff8aa3045984eb70055f467bd)
- Removes node_modules [`f5b5079`](https://github.com/fomantic/Fomantic-UI/commit/f5b50794453904c2538cebaf426c519ded8cd9b0)
- Fixes some orphaned files [`fd01f24`](https://github.com/fomantic/Fomantic-UI/commit/fd01f246a251599b6663b07bc050ac7f94c30ba0)
- Removes grunt build files from /node/src/files, instead compiling grunt [`9ee858f`](https://github.com/fomantic/Fomantic-UI/commit/9ee858f94978c403d8ed2e0e883d4d83fb255d3a)
- update release notes and uptick [`be1dab9`](https://github.com/fomantic/Fomantic-UI/commit/be1dab97235299cb71ec919ac767dd591db3a26e)
- Finishes rewrite of modules [`5542128`](https://github.com/fomantic/Fomantic-UI/commit/5542128edfb77ad5d7871451bf0fa339a9d84e26)
- Version uptick and build [`efcf2ea`](https://github.com/fomantic/Fomantic-UI/commit/efcf2eabab3dc3a543c8e724b778bff40df11aec)
- rebuilds [`886e28e`](https://github.com/fomantic/Fomantic-UI/commit/886e28ed008a1cf0545079bd35bb374efb7f10f3)
- Build and version uptick [`026b789`](https://github.com/fomantic/Fomantic-UI/commit/026b78932166d7beda7f8bb5fe59545ed1dcc363)
- Adding more examples of module [`66c09f6`](https://github.com/fomantic/Fomantic-UI/commit/66c09f6ea8c933d7fd6115cb7085b34a4f8d054a)
- Adds commented modal docs [`5fca489`](https://github.com/fomantic/Fomantic-UI/commit/5fca4893cbfcf958974a780e8ba376aa7bfb3d29)
- rebuilds package [`b0d9127`](https://github.com/fomantic/Fomantic-UI/commit/b0d9127c1a2491e010f39df0d00a2ef8c4dfec20)
- Removes prefixes from transition.less [`c2f7407`](https://github.com/fomantic/Fomantic-UI/commit/c2f7407ac379489344fd2475070c86c6f801d494)
- rebuild for final 0.8 [`9d57229`](https://github.com/fomantic/Fomantic-UI/commit/9d5722909aca49cf488197b0acecbee77f680028)
- Duration now available in shape, rewrite of core animation [`d5f4a3a`](https://github.com/fomantic/Fomantic-UI/commit/d5f4a3a43d65cca2ae07373f624d57712019b821)
- Adds animated button styles, fixes basic button [`567fe60`](https://github.com/fomantic/Fomantic-UI/commit/567fe60718f5bbc8366f274d4bbabe7390642dbd)
- rebuilds [`da7a686`](https://github.com/fomantic/Fomantic-UI/commit/da7a6861631250720beb1dc954368b262517e6db)
- Fixes issue with module pattern setting/internal method [`72e2226`](https://github.com/fomantic/Fomantic-UI/commit/72e222626597d674319af187cb3fef3796f7eaef)
- Renames invoked response to returnedValue for clarity, fixes issue when non string values are returned in array [`032871e`](https://github.com/fomantic/Fomantic-UI/commit/032871e045649d4dad88c543264ae5af2d4f7b9b)
- Restyle of basic buttons to be more tactile [`5b0682d`](https://github.com/fomantic/Fomantic-UI/commit/5b0682d664e3f770e8679e82f6517b67a0ab952d)
- Beginning to redo button with new variables [`57dd4e7`](https://github.com/fomantic/Fomantic-UI/commit/57dd4e77f8f1fbe14880508bfe2109ac1ab5eea4)
- Adds new sidebar types, variations, and proper animation queuing [`f97ef3c`](https://github.com/fomantic/Fomantic-UI/commit/f97ef3c7f4efcffb403cd21948a4386bd4368f82)
- build and version uptick [`fe8c88f`](https://github.com/fomantic/Fomantic-UI/commit/fe8c88f4c5e473c9e41d209093378d652f809d1b)
- updates release notes [`ff95241`](https://github.com/fomantic/Fomantic-UI/commit/ff95241a18578207392a9ae911a00a94175d2d81)
- updates docs [`045879b`](https://github.com/fomantic/Fomantic-UI/commit/045879b0363bcca324d7187a9a370e04afa4ba7a)
- Updating docs [`3287164`](https://github.com/fomantic/Fomantic-UI/commit/32871640c2c1314241438d0345b38e7796aba04a)
- Fixes a few missing html tags from docs pages [`fd199b0`](https://github.com/fomantic/Fomantic-UI/commit/fd199b00f5180fe56410503aaf2dfbf7007f5775)
- updates contributing guide [`de4ec5d`](https://github.com/fomantic/Fomantic-UI/commit/de4ec5d143d3eee87b83c3065c2de89bf92d967d)
- Updating docs for contributing, fixing various bugs on pages [`38e7783`](https://github.com/fomantic/Fomantic-UI/commit/38e7783bfcddf4c9b3571cb022b091a7854862ad)
- Fixes queuing of dimmer with settings.on hover [`5a1140f`](https://github.com/fomantic/Fomantic-UI/commit/5a1140f2404253d9e3bc7b0e3986866159493079)
- Adds new social button types, adds margin bottom (tentatively) to buttons [`383a105`](https://github.com/fomantic/Fomantic-UI/commit/383a105ab69bb330d393d491db6a40913b2c67bd)
- moves animate events into animate.show/animate.hide for popup [`97a09c3`](https://github.com/fomantic/Fomantic-UI/commit/97a09c3034c61312480026a1c51725b1621c28b3)
- Adds homepage as introduction link, adds whatsnew, fixes some broken links [`889fccd`](https://github.com/fomantic/Fomantic-UI/commit/889fccd695a99af2b669dd59849493835d54bc7c)
- Version uptick [`b7bc2bc`](https://github.com/fomantic/Fomantic-UI/commit/b7bc2bce8f79d9b875d8e3e19b81ff40de21a01d)
- Fixes disabled style of colored buttons [`61cc40a`](https://github.com/fomantic/Fomantic-UI/commit/61cc40a4bbc7e991a0e225dbef3c0cf5485d2e0c)
- updates release notes [`324cc3a`](https://github.com/fomantic/Fomantic-UI/commit/324cc3a81c6d0a79279bf41c286d61b3704e7b36)
- final build [`7e34c17`](https://github.com/fomantic/Fomantic-UI/commit/7e34c175f5c9314fbecc21a601254aa9280056e7)
- Update and package for release [`bd4682b`](https://github.com/fomantic/Fomantic-UI/commit/bd4682b9ad018637e916b4bf14bed02a387c946a)
- Updates homepage examples [`1c59cf8`](https://github.com/fomantic/Fomantic-UI/commit/1c59cf8e97a1f5254468a3b8650ba1811be54d69)
- Enhances appearance of action ui input [`a930cd9`](https://github.com/fomantic/Fomantic-UI/commit/a930cd92f28217b47bc8563456e3cb045e2245bc)
- Fixes typo in onApprove/deny changes [`786d303`](https://github.com/fomantic/Fomantic-UI/commit/786d3034f52558fe32d65297ae03a26baa9f2e5c)
- ran spellcheck on docs :) [`40d9d00`](https://github.com/fomantic/Fomantic-UI/commit/40d9d001344d7c1728f2a64d38c9c718a37ef2c1)
- Adds links to behavior docs in module docs [`71fa0e8`](https://github.com/fomantic/Fomantic-UI/commit/71fa0e8ccd7e5a849344b8530b972b0de69709f3)
- build an d uptick [`9e17d07`](https://github.com/fomantic/Fomantic-UI/commit/9e17d078dda7800c593ee25c64afa5ede8eb317d)
- Clean checkbox code [`c63a348`](https://github.com/fomantic/Fomantic-UI/commit/c63a348b4eb74aa076e45e6168a8dd3ffadb1484)
- Fixes broken gradient selector [`1624a52`](https://github.com/fomantic/Fomantic-UI/commit/1624a527611f9e541033160d48d74c8a2a928694)
- Fixes celled table headers and darkens headers across ui table [`11153b0`](https://github.com/fomantic/Fomantic-UI/commit/11153b04e104048e7ba350a6b545d979cca5098f)
- Adds onApprove/deny callback can cancel hide [`eca00d8`](https://github.com/fomantic/Fomantic-UI/commit/eca00d8fce1e46799ffa9cf2071dfe6075200831)
- Fixes border-radius on dropdowns that are not selection [`285e0e2`](https://github.com/fomantic/Fomantic-UI/commit/285e0e2abf09021e60854e6ddda0f1661e571251)
- Updates docs for button example [`8d9350a`](https://github.com/fomantic/Fomantic-UI/commit/8d9350a2cdaad3a9ce1ed6db7a41945c14685577)
- Fixes doc broken link [`546568a`](https://github.com/fomantic/Fomantic-UI/commit/546568a9e2b284867d5f06379ce5a86978040a1b)
- Fixes onApprove/deny callback to close when no value returned. IE only now uses javascript animations for dimmer [`67dd6d5`](https://github.com/fomantic/Fomantic-UI/commit/67dd6d5dd2c9ac7f3cb9a3b53ca77ccf6ab0dd3f)
- Sets a default flip for flipped icons [`b6f8784`](https://github.com/fomantic/Fomantic-UI/commit/b6f87847b0361c23b4d9932398afc400a8378f1e)
- icon inputs, and corner labels now color when field is errored [`f4f7a32`](https://github.com/fomantic/Fomantic-UI/commit/f4f7a3295179003dece392da6e4086637705a014)
- Fixs modal media [`27f3a07`](https://github.com/fomantic/Fomantic-UI/commit/27f3a07c8314a2d26ab284fc22ffb4d1e475ccf0)
- Updates browser coverage for prefixer [`8089d21`](https://github.com/fomantic/Fomantic-UI/commit/8089d21bd33956331716535950b3a3b7f9210b78)
- Fixes transform jump on animated buttons [`068aa93`](https://github.com/fomantic/Fomantic-UI/commit/068aa936c08305e4a9284b5f6660575bc08b56ff)
- Makes border radius integer for 15px font-size [`afc7a6e`](https://github.com/fomantic/Fomantic-UI/commit/afc7a6e39e3d8923020bd6a867f74a60e86dd5a8)
- more on icon spacing for list [`06473a2`](https://github.com/fomantic/Fomantic-UI/commit/06473a2872795ca829f336b048e0f92ef4a8711c)
- adds package repository field [`033a316`](https://github.com/fomantic/Fomantic-UI/commit/033a316143c4bc213e6351802ea14a6053b8a093)
- Adds beforechange callback to shape [`15408ec`](https://github.com/fomantic/Fomantic-UI/commit/15408ec3ed6d59cc0f406eb5c5a0110cc356cc0d)
- Fixes issue with icon not clearing properly [`d838601`](https://github.com/fomantic/Fomantic-UI/commit/d83860167002175a74c90e071b38f0ccb753bc0b)
- remove karma task [`dffc420`](https://github.com/fomantic/Fomantic-UI/commit/dffc420d59bf4325b62c680e5e36ab87d61c54ad)
- Trying to fix travis [`7ecc868`](https://github.com/fomantic/Fomantic-UI/commit/7ecc868850b91ae4fe66ac68737dedd6d7cc7c49)
- mofo travis dying [`346cac5`](https://github.com/fomantic/Fomantic-UI/commit/346cac5bdb559df86a7abaa3d592dbad164dc285)
- updates prefixer depend [`2903c65`](https://github.com/fomantic/Fomantic-UI/commit/2903c65d469636ae87abbbf209ae6fcd11480002)
- Fixes popup not opening when inline:false after first time, due to unrefreshed selector cache [`9fdf8cb`](https://github.com/fomantic/Fomantic-UI/commit/9fdf8cbbbc3573a5212f594a14a77a9cdc4344e5)
- Removes square icon middle alignment [`c4cd2fd`](https://github.com/fomantic/Fomantic-UI/commit/c4cd2fd09637d1a10a32dda6ce402adbc2178286)
- Vertical padding on basic accordion [`bb9bfba`](https://github.com/fomantic/Fomantic-UI/commit/bb9bfbab1dee5e21635e2f550f22274ed15e43b1)
- Fixes arrow direction for vertical menu dropdown [`6479a0e`](https://github.com/fomantic/Fomantic-UI/commit/6479a0e09625a4b733bca457dc387ef24fbec26b)
- downgrade to node 0.10 to deal with karma incompat [`f687041`](https://github.com/fomantic/Fomantic-UI/commit/f6870412153ab8850cb96ed5de114a9dde62551b)
- derping on travis [`2edc95e`](https://github.com/fomantic/Fomantic-UI/commit/2edc95e7756fbd9a9560645406b244f789569ab4)
- black button missng hover styles [`a58539d`](https://github.com/fomantic/Fomantic-UI/commit/a58539d94a45ec2047cad9d0af67f04290689b78)
- updates travis node v [`fe9d842`](https://github.com/fomantic/Fomantic-UI/commit/fe9d842b13260531aae4628ac3dfed577a152fe7)
- Font size is no longer 0 inside reveal when rem0 [`e5dfded`](https://github.com/fomantic/Fomantic-UI/commit/e5dfded813daf4774846566e7e0d450d67a20b11)
- fixes issue #274 modal hides twice [`6077e0f`](https://github.com/fomantic/Fomantic-UI/commit/6077e0fadf760453391835943378cd7ae7a985f3)
- Fixes typo in commented modal [`2a1b8d0`](https://github.com/fomantic/Fomantic-UI/commit/2a1b8d0b220bc3f72b4906477d52ccf43ad3fd6b)
- Lightnes table headers again somewhat [`926b6f9`](https://github.com/fomantic/Fomantic-UI/commit/926b6f9ab0b68c1cf936f5717141effb4f810795)
- Removes opacity tween from action input to make colors match [`6bf33d2`](https://github.com/fomantic/Fomantic-UI/commit/6bf33d27a448c3ea3551c4b2c28b248013bb2ce6)
- Increases list item margin on message [`212935c`](https://github.com/fomantic/Fomantic-UI/commit/212935c0c619ba019a280ed79cbddebb67df4e58)
- Units for margin on rating [`c749bf2`](https://github.com/fomantic/Fomantic-UI/commit/c749bf2593d30a3be957e2d28df07ef7856747a2)
- Fixes stackable grid #271 [`e585d0a`](https://github.com/fomantic/Fomantic-UI/commit/e585d0ad3bd3b43e05b38c1b1373ac075e2014b0)
- Removes margin from buttons, messes with vertical align [`896a34e`](https://github.com/fomantic/Fomantic-UI/commit/896a34e57309500640814e865a8e94550f9d4c95)
- Fixes issue with icon buttons being different vheight than buttons [`0526f7c`](https://github.com/fomantic/Fomantic-UI/commit/0526f7ca3ca18f99148880318b7816a6b5e351c7)
- removes console.log [`7c13229`](https://github.com/fomantic/Fomantic-UI/commit/7c13229c339b0cd3ba84ae3d7164713e50952d18)
- fixes loading state on colored buttons [`8d33446`](https://github.com/fomantic/Fomantic-UI/commit/8d334466b93bcaaf799de9f094451258b30dab5d)
- Fixes fluid vertical buttons [`657e9e3`](https://github.com/fomantic/Fomantic-UI/commit/657e9e3b935612d39d74b4e405f6f8a80a81056e)
- Fixes queued animation not waiting [`fe3eb9c`](https://github.com/fomantic/Fomantic-UI/commit/fe3eb9c994503b078d2c78ecd3872c02f12436f7)
- rebuilds, fixes headings in popup docs [`f28bfd6`](https://github.com/fomantic/Fomantic-UI/commit/f28bfd676d8399d580e1e35bc4a2888051542e7a)
- updates release notes [`354d62b`](https://github.com/fomantic/Fomantic-UI/commit/354d62b7e1d47d8a991e721180118678546405d1)
- removes any reference to old release/ directory, rebuilds files [`75e8b27`](https://github.com/fomantic/Fomantic-UI/commit/75e8b27ae96b0830337c45f15a523373aca3745f)
- Renames /release/ folder in docs to /build to match folder structure [`5e9fc72`](https://github.com/fomantic/Fomantic-UI/commit/5e9fc724c654d467b6b6f98040c99348534a0270)
- missing files [`8379559`](https://github.com/fomantic/Fomantic-UI/commit/83795598e3d31a622b43f0863b918d56844d0069)
- removes double directories [`dc6c25e`](https://github.com/fomantic/Fomantic-UI/commit/dc6c25ee7812cf03ac0f6778d937f6510be77e21)
- Updates docpad/node, adds override styles for quirky [`f457c16`](https://github.com/fomantic/Fomantic-UI/commit/f457c1621e61e4bc3789e0842a1943d33c04dd73)
- Adds RTL support to build script [`b0a0d14`](https://github.com/fomantic/Fomantic-UI/commit/b0a0d14c8e39851bdc646bd34e323daea09e8950)
- Updates docpad, ports some reveal code left in branch (still fucked) [`71de148`](https://github.com/fomantic/Fomantic-UI/commit/71de1487eb8ab897e4eaf2ac27433cec2675d626)
- Missing node module updates, adds missing intro docs [`bb69c0e`](https://github.com/fomantic/Fomantic-UI/commit/bb69c0e8aafadf94f26867e6688ae55acbfcafe6)
- Build release [`a88cd7d`](https://github.com/fomantic/Fomantic-UI/commit/a88cd7d0e9bb86d403766fa7574ba88d959bc825)
- Adds build gruntfile [`d940440`](https://github.com/fomantic/Fomantic-UI/commit/d940440fdae4a8388bce3d9da26e3bd0929c1a8a)
- rebuilds release package with missing files from grunt bug [`4357fef`](https://github.com/fomantic/Fomantic-UI/commit/4357fef535d1ceea79f7272cba6cb5a748d25d4c)
- fixes less files getting into wrong folders of grunt build, fixes text on variations page [`bed70aa`](https://github.com/fomantic/Fomantic-UI/commit/bed70aa84501318bdc068365876c8727a2201252)
- Removes learn-semantic content from docs, redoes folder structure of project, adds grunt config [`1eefa16`](https://github.com/fomantic/Fomantic-UI/commit/1eefa169ff31b17bc6483b98b9c4229b411af6b7)
- Fixes merge conflict in segment docs, adds missing build files [`e6a4e7d`](https://github.com/fomantic/Fomantic-UI/commit/e6a4e7d47125315596f553bd5a7fb504967ce53b)
- Fixes issue with uncompressed source appearing in minified build dir [`1839cc7`](https://github.com/fomantic/Fomantic-UI/commit/1839cc75797471a894a4db7cf2570f4c2a59b8e0)
- Missing updates from home lost during last sick week [`171f433`](https://github.com/fomantic/Fomantic-UI/commit/171f433ed3c19095c281563c4f811aa5832e713b)
- fixing issues with grunt not building due to ENOENT [`7d82653`](https://github.com/fomantic/Fomantic-UI/commit/7d82653d61925967220cd03d21c1d413632f2abe)
- makes icon word order normal english word order, adds less build dir [`31265aa`](https://github.com/fomantic/Fomantic-UI/commit/31265aa18bccfbc14a2e9ae450a18e4abb33b17e)
- adds zipping into grunt process, adds less files into release zip, moves release zip to release folder [`4a8390a`](https://github.com/fomantic/Fomantic-UI/commit/4a8390a0de2cf433fd0a934b7584f3b3dffe2817)
- some build files missing 0.8.3 [`bcf5af0`](https://github.com/fomantic/Fomantic-UI/commit/bcf5af0064b97e30b5775476390dd9caf12d5bc5)
- Language on grid [`b80f5a9`](https://github.com/fomantic/Fomantic-UI/commit/b80f5a9e939dee3f8e0cb9667084d2dbf0fdf347)
- removes old files [`be6a9f8`](https://github.com/fomantic/Fomantic-UI/commit/be6a9f89b806c6d699d5f6052f3c942463a506a5)
- Adds justified to header, segment, grid [`ddaff60`](https://github.com/fomantic/Fomantic-UI/commit/ddaff6065d60849266bf3ee1c6673303a5c1e9ef)
- Removes docpaddb file [`a0eb2f3`](https://github.com/fomantic/Fomantic-UI/commit/a0eb2f30526337125dbd5118d7ff11c02470ab67)
- Adds node modules to gitignore too much issues [`f9b4e3b`](https://github.com/fomantic/Fomantic-UI/commit/f9b4e3b5d12a5e96f0d2af2883e100ba7bcc52a3)
- Removes completely broken components, adds release distro to build, adds [`01e39d8`](https://github.com/fomantic/Fomantic-UI/commit/01e39d8014edae0dcc38055b2804c18f5dfe3829)
- Updates all templates to use ECO instead of html. Adds partials for page [`c4b41e8`](https://github.com/fomantic/Fomantic-UI/commit/c4b41e8d9f4955be10feced1a04eed95af1948b4)
- Somehow lost all docs? Fixed. Revisions from buglist [`5a41a62`](https://github.com/fomantic/Fomantic-UI/commit/5a41a62c4455252081278a4fb8869e373942e1e3)
- Begin write of additional transitions, and example builder [`af02229`](https://github.com/fomantic/Fomantic-UI/commit/af022293ab42ff0ea36ae982c0f78cdafdf782c9)
- Updates to modules [`3d0e52b`](https://github.com/fomantic/Fomantic-UI/commit/3d0e52bb3905f3ab0362e8e630b2f301be68b81d)
- Working on cards [`42bf450`](https://github.com/fomantic/Fomantic-UI/commit/42bf450d279b523824f7189293ee7e8a7adb86ed)
- Updates cards [`3abbe00`](https://github.com/fomantic/Fomantic-UI/commit/3abbe00622cd451bd44c683b64045b969a068812)
- Adds new accordion module and docs for it [`b017c14`](https://github.com/fomantic/Fomantic-UI/commit/b017c1430e6d4dbe7272175c5cafeb5fadac44a0)
- Adds card module first working pass [`2931641`](https://github.com/fomantic/Fomantic-UI/commit/2931641296e49ecc0d336df9608ad919a2206c18)
- updates to dimmer, card work [`6709595`](https://github.com/fomantic/Fomantic-UI/commit/67095954fcf549fed013f1f0fcdd8155e18c9b78)
- Adds breadcrumbs, images, and PROPER divider styles. Re-exports icon fonts [`52a09c3`](https://github.com/fomantic/Fomantic-UI/commit/52a09c3d9b272e458bcba0d50a386c502f3d4cff)
- Fixes shape module, finally [`cd3de8b`](https://github.com/fomantic/Fomantic-UI/commit/cd3de8bb2a461f03031de2590d61f65babfd4ab5)
- Adds documentation and new version of popup [`b19b66a`](https://github.com/fomantic/Fomantic-UI/commit/b19b66a9bd6a094ddf5f4ccd6f0bb56f588cb8b0)
- Adds start for idea cards, and docs [`e2e0c44`](https://github.com/fomantic/Fomantic-UI/commit/e2e0c443ddaea5432d58e0d8f7482a8f84c3dcbb)
- Fixes to sem-ui [`0eae196`](https://github.com/fomantic/Fomantic-UI/commit/0eae196bbbb56a397949301eb455c9385e7c0cde)
- Updates to semantic from todays work [`07604d6`](https://github.com/fomantic/Fomantic-UI/commit/07604d6b0d5866d317f4148d6873b85850e7a5b5)
- First commit reveal and docs [`46cd5ee`](https://github.com/fomantic/Fomantic-UI/commit/46cd5eefdb3cd4dd56d04d74ad0e2bab2d32ee57)
- adds new examples to homepage [`d533214`](https://github.com/fomantic/Fomantic-UI/commit/d533214932271cb0b22363f33642f4cda4a178e6)
- Updates tab module, example on homepage, fixes 404 [`e72b829`](https://github.com/fomantic/Fomantic-UI/commit/e72b829ba9729943200e624f02933be796d441c0)
- revisions from working on quirky platform [`3a31239`](https://github.com/fomantic/Fomantic-UI/commit/3a31239ca268e89678c1570dc0f25c705e0d188b)
- Update node [`10a80d8`](https://github.com/fomantic/Fomantic-UI/commit/10a80d852ac1b23dbfa8bd348d4e53dd88cde86c)
- Removes quirky styles from sem-ui standard branch [`91941b5`](https://github.com/fomantic/Fomantic-UI/commit/91941b558561c5c871be09c86c1be075802a7e38)
- Adds new quirky content group, adds pagination variation of menu, adds changes to messages, buttons, new success style, toggle styl [`65ff5f4`](https://github.com/fomantic/Fomantic-UI/commit/65ff5f4eb09aa55679b848640e399d64de57ab77)
- missing changes to reveal from before break [`5e424c6`](https://github.com/fomantic/Fomantic-UI/commit/5e424c665f714cb41d7dd4db834cdcc58bc0a0b7)
- Adds new dimmers and dimmer docs [`50fd78d`](https://github.com/fomantic/Fomantic-UI/commit/50fd78deb0fa8fef14dc0484052b7d43ad971a92)
- stuff jack forgot to commit [`ca51582`](https://github.com/fomantic/Fomantic-UI/commit/ca51582bebb1a80058b26da8b60cb7090c89cf08)
- Updates padding in grid to be based on EM not percentage, fixes for minheight in menu, fixes to item top margin [`ff28ee3`](https://github.com/fomantic/Fomantic-UI/commit/ff28ee39db760f1f4bf9d4e8242e71c72c01493d)
- Adds profile image reveal [`a17dc16`](https://github.com/fomantic/Fomantic-UI/commit/a17dc16249e4d7b69fb7474e8a36d35dd51a5f67)
- updates accordion to be more robust [`0ce9425`](https://github.com/fomantic/Fomantic-UI/commit/0ce942521f490f1bf6b255d88b2ba988a249105f)
- updates cards more, fixes labels, voted state [`54e0270`](https://github.com/fomantic/Fomantic-UI/commit/54e0270cd92a035935504e6cee65d564c62e9d73)
- Updates to dropdown, checkbox, examples, forms [`8ef774a`](https://github.com/fomantic/Fomantic-UI/commit/8ef774a513205ea531dad37c1ac0fb9225c6ec20)
- fixes closing div [`0ff3077`](https://github.com/fomantic/Fomantic-UI/commit/0ff3077b6e91be3d21605f085fd4f0bb4a45ea27)
- Updates attached buttons to not lose border on loading [`9e6cc59`](https://github.com/fomantic/Fomantic-UI/commit/9e6cc5930c9f4beb41bbdd944086cd5af55aa22b)
- Updates dropdown to fix pointing menus, fixes bug in inverted menus [`2855ba6`](https://github.com/fomantic/Fomantic-UI/commit/2855ba60f4db07bcb02954cb03da7d311e08ad00)
- updates icons, comment, feed [`adf07c6`](https://github.com/fomantic/Fomantic-UI/commit/adf07c6e31434f0a8672206f85c447db3835feb0)
- updates while working on live site [`e3da524`](https://github.com/fomantic/Fomantic-UI/commit/e3da524d4d3b946e544544978b44e07859898f5e)
- Type changes to docs [`9528bc5`](https://github.com/fomantic/Fomantic-UI/commit/9528bc594e278402cb5bfe46996f24e791143909)
- Updates tab module [`5ee2456`](https://github.com/fomantic/Fomantic-UI/commit/5ee24561bb3093a03183d6d0ced25a9c8c957518)
- fixes to forum new post page, adds sticky db migration to allow for sticky posts, updates ui [`ed9a3b1`](https://github.com/fomantic/Fomantic-UI/commit/ed9a3b14fd80e6070ea9832c1aeae4dfd68f9ee8)
- minor fix to margins on menu [`1c5f269`](https://github.com/fomantic/Fomantic-UI/commit/1c5f269870cc895b323696da5fcb88ae9cf0a7f1)
- Fixes dropdown in forum, fixes issue with html formatting in forum posts [`3c19465`](https://github.com/fomantic/Fomantic-UI/commit/3c194658f104c68488a565f624f1b635864fc716)
- adds delay for hover intent, refactors delayed hide [`14fa263`](https://github.com/fomantic/Fomantic-UI/commit/14fa2637698f8f7967de162fe08d578c2ad6218b)
- fixes overrides on menu [`00c945b`](https://github.com/fomantic/Fomantic-UI/commit/00c945ba7dc46dd1276ff0dbcd1f86fc3d5c273d)
- Adds more new icons [`52c5e6d`](https://github.com/fomantic/Fomantic-UI/commit/52c5e6de47e40ac5d17e83fa802b3ebdc6c8b56b)
- Adds sitemap, updates from today [`8d64ba6`](https://github.com/fomantic/Fomantic-UI/commit/8d64ba61a09488d39f77589f2f3a1f91f1544297)
- Fixes to label and shape [`bcfa78a`](https://github.com/fomantic/Fomantic-UI/commit/bcfa78ad7dc6f731e85bc97ecb890a651a94345a)
- Updates popup title style, card [`3f531ea`](https://github.com/fomantic/Fomantic-UI/commit/3f531ea5ecd2a3a91b38ad304dddae21b6cd1fc3)
- fixes steps [`e62d154`](https://github.com/fomantic/Fomantic-UI/commit/e62d154d941f657d5335cd20816dd3dabc8070f8)
- missing build files [`a4e9f1f`](https://github.com/fomantic/Fomantic-UI/commit/a4e9f1fd5846e35ed50b084c77284fdcd252d9ac)
- adds last style updates [`44116e6`](https://github.com/fomantic/Fomantic-UI/commit/44116e694220fd5a5c3cf46cc612820f7fead0ec)
- updates accordion again, typo in feed, fixes shared pagination to use guide style [`1e63ddd`](https://github.com/fomantic/Fomantic-UI/commit/1e63dddb7249ddfe78138e6a934ad5d8bbdb5fa7)
- updates to feed when fixing pagination [`d7e81b0`](https://github.com/fomantic/Fomantic-UI/commit/d7e81b03e50f2e102ce4ba68b19857141f94907d)
- more attemps to fix below/above reveal [`33dc001`](https://github.com/fomantic/Fomantic-UI/commit/33dc001333e409deeb82f7939e9dc014859be522)
- Moves some important logic from toggle to show in popup, so it can be called programmatically [`609b540`](https://github.com/fomantic/Fomantic-UI/commit/609b540117301209189b34f266c42bb91ac1e534)
- switches grid back to start of day (% based gutters) [`5658b10`](https://github.com/fomantic/Fomantic-UI/commit/5658b10d1d69ed87d6947b0fc10410457c403c26)
- adds max width to carousel [`34d5cfd`](https://github.com/fomantic/Fomantic-UI/commit/34d5cfd64fa196000836b9ccef8948d4f8f915ac)
- moves usage first for dimmers [`599e278`](https://github.com/fomantic/Fomantic-UI/commit/599e278455c7019f14fd60141cd9ba978496714b)
- changes to comment [`9a5875d`](https://github.com/fomantic/Fomantic-UI/commit/9a5875d2b9760d9e1242647ef8a98f664e3d328c)
- fix example [`1247082`](https://github.com/fomantic/Fomantic-UI/commit/12470826c6cb97a45fedf5591ca60ca7ce539abe)
- tertiary button borders [`64d4284`](https://github.com/fomantic/Fomantic-UI/commit/64d4284866f761475622c440074a3a1e480b661f)
- fixes for pointing dropdown [`2991efe`](https://github.com/fomantic/Fomantic-UI/commit/2991efe93c0e5fa07673aabd0c04b79402e82ab0)
- revisions to css guide [`2130e96`](https://github.com/fomantic/Fomantic-UI/commit/2130e9644444452935591da9110210c1d38ef12c)
- Add support for onHide callback in nag.js. [`d6425b3`](https://github.com/fomantic/Fomantic-UI/commit/d6425b3d5c36bedab145c1eb84b00271ad546eb7)
- updates icon docs [`b21ecfd`](https://github.com/fomantic/Fomantic-UI/commit/b21ecfde7af7fcbea6029295e55f285b233b106b)
- Updates cards [`5fea8f0`](https://github.com/fomantic/Fomantic-UI/commit/5fea8f010085736c2a946a106a2328e9662e1930)
- fixes silly menu thing [`d812ff5`](https://github.com/fomantic/Fomantic-UI/commit/d812ff5a3fa25b94f72c6cffc6f3f341dec7b1f5)
- changing colors of positive and negative btns [`71fd496`](https://github.com/fomantic/Fomantic-UI/commit/71fd49608bf1beda9215eddfad6abbef09a3870a)
- text on grid [`4ea100b`](https://github.com/fomantic/Fomantic-UI/commit/4ea100bdda83453976a5b161c17a7e7992da8217)
- default margins message [`8eb3f2c`](https://github.com/fomantic/Fomantic-UI/commit/8eb3f2c762444d7e61706e43577565762378d24c)
- removes bold headers [`ee660d3`](https://github.com/fomantic/Fomantic-UI/commit/ee660d3a4c933cddeb40ed6c529367ae86278dce)
- homepage language [`3589b4c`](https://github.com/fomantic/Fomantic-UI/commit/3589b4ccb7d622388a1f1aad8ca95b0547540eed)
- one last typo example fix to dividers [`5b48158`](https://github.com/fomantic/Fomantic-UI/commit/5b481583ea1d6fbc839d76d2f3996098455e77c3)
- Reveal updates [`fee61b0`](https://github.com/fomantic/Fomantic-UI/commit/fee61b073c0bd38da857817ed0c51f53b8082ff1)
- moves grid over to % based row height [`0e0c721`](https://github.com/fomantic/Fomantic-UI/commit/0e0c721647151c40539a2d7634869a6fcfa3ebbe)
- updates cards [`5a70f38`](https://github.com/fomantic/Fomantic-UI/commit/5a70f38fefa528ad378adb9cd44e4fac1e5425ce)
- Updates grid to fix margins on divided grids [`f486aab`](https://github.com/fomantic/Fomantic-UI/commit/f486aab11c431b35ce8a4fddca3cb7faf64bf42f)
- Fixes menu [`8ebe67d`](https://github.com/fomantic/Fomantic-UI/commit/8ebe67dbc49a3b34d49a34716a5e81f8bf1ef850)
- missing closing tag [`638bfc0`](https://github.com/fomantic/Fomantic-UI/commit/638bfc0aa7512d8b83da7f2979b1fd79dbad38fc)
- typo [`d66ccdd`](https://github.com/fomantic/Fomantic-UI/commit/d66ccdda4224c57cabf2e19611ce6abd85c7197a)
- removes debug statement [`b0c656a`](https://github.com/fomantic/Fomantic-UI/commit/b0c656a736f134b65955797332bf1b654db137bf)
- adds sketchy icons in proper way to semantic [`6142a52`](https://github.com/fomantic/Fomantic-UI/commit/6142a52a4a15116d8b6a5a8e1af2941738f607a7)
- Fixes issue with accidental submodule [`58d39d2`](https://github.com/fomantic/Fomantic-UI/commit/58d39d258a2b31c9accc604afbc8a61794c5b12e)
- grunt -- update and add bower and watch. [`4995a68`](https://github.com/fomantic/Fomantic-UI/commit/4995a687612037468325bd16ce041401a95dff80)
- Finishes grunt config, sets up less config, makes everything super pretty, adds grunt tasks [`5fe4310`](https://github.com/fomantic/Fomantic-UI/commit/5fe4310126fa96b86010eebcbc22668b686894c6)
- removes redundant flat directory from bower/node component, and from src folder. adds boilerplate folder for future boilerplate code [`e8432f3`](https://github.com/fomantic/Fomantic-UI/commit/e8432f3841586de4f92bdb75806ad1ec3f5445a5)
- structure -- include semantic bower package in docs. [`be91265`](https://github.com/fomantic/Fomantic-UI/commit/be912653bf015def4da657296980b8a901eed457)
- fix accidental merge of orphaned docs branch [`3ef3295`](https://github.com/fomantic/Fomantic-UI/commit/3ef3295247e98af663f1e3660f32bb31dc35670d)
- 902e63b Merge branch 'master' of github.com:quirkyinc/semantic [`f7ae6ae`](https://github.com/fomantic/Fomantic-UI/commit/f7ae6ae7a0d3734916ddedd72d8b98a750fbb5cb)
- Adds docs gitignore, removes docs from repo [`cda3135`](https://github.com/fomantic/Fomantic-UI/commit/cda31355f0bffb78cd20c4580ae41d4945737f9e)
- Initial setup of docpad server in node [`375337c`](https://github.com/fomantic/Fomantic-UI/commit/375337ccc1d0b09c22b46cb7fe5ef8e365cbd59b)
- hey i got it all running! [`0d99acc`](https://github.com/fomantic/Fomantic-UI/commit/0d99accbb4667f681f6dceabc797bbd8d07a89ad)
- adds working grunt config, sets up process to minify, concatenate, add banners and package to release directories. starting less setup [`b6ea926`](https://github.com/fomantic/Fomantic-UI/commit/b6ea9269e86fe967a3bf16a3a6277dc46fdb5057)
- adds created docs [`c42dd05`](https://github.com/fomantic/Fomantic-UI/commit/c42dd056e648fbf81e01d3a95b8c32f9eaf25ac2)
- matches classic to flat folder structure, removes shaded cause.. its too damn early to do a third theme [`cbaf271`](https://github.com/fomantic/Fomantic-UI/commit/cbaf271d85981a5277039b3b228f6143655a0e68)
- Adds back missing src dir [`cfd7fe4`](https://github.com/fomantic/Fomantic-UI/commit/cfd7fe4ec8869f75636c54c3a5bb3a18d158849c)
- structure -- take out components folder. [`b8609a5`](https://github.com/fomantic/Fomantic-UI/commit/b8609a5f9dbd4c4f980112ab87eaa19f976b21f7)
- structure grunt watch task. [`e9f5d6e`](https://github.com/fomantic/Fomantic-UI/commit/e9f5d6eebc64f5b265742e34d15279c4e030432a)
- docpad: updates to lastest version [`45dcf00`](https://github.com/fomantic/Fomantic-UI/commit/45dcf00f30cdc678568906484acea8bee9d55c0f)
- a day of work.. menus, fixing sidebar floating menu, additions to labels, working labels to integrate with menus. stub for grid [`d293ce9`](https://github.com/fomantic/Fomantic-UI/commit/d293ce95133d6d9673a92f9cac17b230f247452e)
- missing files for flat [`596ef48`](https://github.com/fomantic/Fomantic-UI/commit/596ef48f3fa008fb14bd9f024984f380e1b5b377)
- tweaks on menus, removes flat legacy [`5cc1c2d`](https://github.com/fomantic/Fomantic-UI/commit/5cc1c2d834ea7e092a47b0f9a39a4cfe058a2c43)
- structure -- moved src from node project to main project. [`056ab46`](https://github.com/fomantic/Fomantic-UI/commit/056ab468f88994dc8bcfc623bd472b8268e4016a)
- Adds clean module, adds dir cleaning on rebuild [`77b98a6`](https://github.com/fomantic/Fomantic-UI/commit/77b98a6c4a2caed10fb66ac560fe3d849e12720c)
- Adds new src [`da6b789`](https://github.com/fomantic/Fomantic-UI/commit/da6b78993a114bfff576870b8e7ecc921ddcae37)
- missed committing some files [`d38d5eb`](https://github.com/fomantic/Fomantic-UI/commit/d38d5ebc66f75ef7a79b909551acb6e3abd52f85)
- Hey we got it all working again! [`ae60b15`](https://github.com/fomantic/Fomantic-UI/commit/ae60b15302733ff96efa3668c925ae5421196e6b)
- Modifies structure of package include [`7d4fdbe`](https://github.com/fomantic/Fomantic-UI/commit/7d4fdbe66384449a8952351d3654d43f9762c75b)
- fixing the folder structure for docpad [`80863a8`](https://github.com/fomantic/Fomantic-UI/commit/80863a8aa9c0cf88f326cd966341156c90bbdd9f)
- regenerating [`208b235`](https://github.com/fomantic/Fomantic-UI/commit/208b23571c83b085e3d2188dfda72cf16953c415)
- Adds new styles and documentation for generic item view [`e5b847c`](https://github.com/fomantic/Fomantic-UI/commit/e5b847cb00651997aae167a54f4a24c75172b8f7)
- massive revisions to menu [`1cac5f5`](https://github.com/fomantic/Fomantic-UI/commit/1cac5f52c3ae19315dffd0472c3cf3a05da1ed04)
- structure -- grunt watch and upgrade. [`3957c5a`](https://github.com/fomantic/Fomantic-UI/commit/3957c5ac3c287026e6e05e1233a373c5ea656066)
- adding more variations and docs for menu, adding badge type [`a2001c6`](https://github.com/fomantic/Fomantic-UI/commit/a2001c63b4dab2f51652ae69357a2197bb8699a8)
- iteration on icons [`6104ab5`](https://github.com/fomantic/Fomantic-UI/commit/6104ab5783a429d7c6a8fa5e17fe0304caaa6899)
- lots of iteration [`7ad57f1`](https://github.com/fomantic/Fomantic-UI/commit/7ad57f1eaefde9fbccea8824b2d77c2e214ec48e)
- Fixes mediaqueries once and for all, adds stacking demos to items, grid [`82f01a0`](https://github.com/fomantic/Fomantic-UI/commit/82f01a024a5700ac99d1631c698db41d8a517791)
- moves button and form to ems, NO MORE PIXELSgit status. Redoes checkbox class [`b2c751d`](https://github.com/fomantic/Fomantic-UI/commit/b2c751d9481537ed3370de420f0b93ad6eb04f9a)
- adding progress/header docs, iteration on ui [`766dd02`](https://github.com/fomantic/Fomantic-UI/commit/766dd023d9d68d006d291572bc5aa5937683bd66)
- adds back in spec, iteration on ui module order [`1578e02`](https://github.com/fomantic/Fomantic-UI/commit/1578e02a390e6ca9a0997ebd321588b235219556)
- ui: tweaks with tables and some other stuff [`4fe2263`](https://github.com/fomantic/Fomantic-UI/commit/4fe22637dda9f8730537bfbf1594914fa5261318)
- Adds fixes/updates for radio buttons with checkbox.js, adds fixes to gruntfile so it watches js file changes, adds fixes to menu dropdowns, adds fixes to menu labels, adds fixes to segment variations, adds fixes to header spacing and new header variations [`7f77b72`](https://github.com/fomantic/Fomantic-UI/commit/7f77b7220b9b91d017c815d544a5fe9e8d2116fa)
- days work on messages, icons, segments [`5cd94a1`](https://github.com/fomantic/Fomantic-UI/commit/5cd94a1ad14d5f519599572d24cd358a94564c76)
- iteration on all the stuffs [`9fe6db4`](https://github.com/fomantic/Fomantic-UI/commit/9fe6db47dfef1e4e0763949320ace4be92f1d95d)
- grid: iterating on grid docs/ui [`8273423`](https://github.com/fomantic/Fomantic-UI/commit/82734238a78e5fc9a54e2698622f36e06ebf0705)
- Adds activity feed, adds fixes for segment, menu, missing demo images [`a54b138`](https://github.com/fomantic/Fomantic-UI/commit/a54b13859fa0ad9eb6a209a13ef27a2d4acd62e1)
- Adds comment view [`15dca67`](https://github.com/fomantic/Fomantic-UI/commit/15dca673e8d42a47191c0f6d6c2a69ef042bb5c0)
- Beginning comment view, fixes to message colors [`912960c`](https://github.com/fomantic/Fomantic-UI/commit/912960c5c3adbac45943452a3e5f7e9992beac3c)
- fixes OR to be em based, adds some variations to grid [`7d7e040`](https://github.com/fomantic/Fomantic-UI/commit/7d7e04000a0f4d845c43bf36eca929e34c07dee2)
- added first pass at dropdowns, modified forms to include new styles [`90687e5`](https://github.com/fomantic/Fomantic-UI/commit/90687e527869283b714383afc68b99cd72ca1818)
- Renames UI Block to message to be more explicit` [`87a8221`](https://github.com/fomantic/Fomantic-UI/commit/87a8221073c79725ec9ef05dd225d9d8a6e11998)
- iteration on feed, menu fixes for icons [`fc265d0`](https://github.com/fomantic/Fomantic-UI/commit/fc265d0dc194c7616c129e650a027f0f8f68a067)
- headers: working on new header styles [`d2d4831`](https://github.com/fomantic/Fomantic-UI/commit/d2d483163749d6acb2259d8c00cbdee2922df1c0)
- Renames boilerplate to spec folder, adds commented and uncommented module spec [`76a424f`](https://github.com/fomantic/Fomantic-UI/commit/76a424f6857795c79038fe01ccfdc8194df754e0)
- adding definition page and many variations to segments [`2fe762c`](https://github.com/fomantic/Fomantic-UI/commit/2fe762c317f25507321e955ee7bc6ac687795f1e)
- working on tags, fixed all the old menus. 3am on a friday yeahh [`bdf6bad`](https://github.com/fomantic/Fomantic-UI/commit/bdf6bad38ddb5ce465c5d6793c230c7bafc93776)
- fixes up grid examples a bunch, adds more module docs [`19d2143`](https://github.com/fomantic/Fomantic-UI/commit/19d214382f7b96a9d0ae31fb145b650f272a94b1)
- coding a storm up the ui menu class [`cff2724`](https://github.com/fomantic/Fomantic-UI/commit/cff27242f91e01e09a7c5a1fba9740d8b3b1b451)
- additions to label, icon, header, button. near finishing comments [`c0d68e3`](https://github.com/fomantic/Fomantic-UI/commit/c0d68e3000e9f794b74ff96bf7bc4a7a83b090bf)
- lots of new stuff [`8f63998`](https://github.com/fomantic/Fomantic-UI/commit/8f63998a42f72378f167ca2ae7125094c2acc41b)
- changes to items [`b26e325`](https://github.com/fomantic/Fomantic-UI/commit/b26e3256eed25257cfdea52b684f1432245d0837)
- day of iterating on header variations, tweaks to homepage, icons, menus [`1443aa6`](https://github.com/fomantic/Fomantic-UI/commit/1443aa6350ebf36f983b20e2deac025ed02a790b)
- finishing up comments [`8f4f838`](https://github.com/fomantic/Fomantic-UI/commit/8f4f838d18a65b06b95ee26f1455ccd835a38db4)
- Fixes top level categories some [`b4c959e`](https://github.com/fomantic/Fomantic-UI/commit/b4c959e163f7294e956682946a46fc1866cb80bb)
- starting on text blocks [`aa2a200`](https://github.com/fomantic/Fomantic-UI/commit/aa2a2003ccaba6e0b7f447e5c65922cc6112c428)
- iteration on text menus, label menus [`859f61d`](https://github.com/fomantic/Fomantic-UI/commit/859f61d57260a0bd215ccd42f6dc3867378d4c74)
- added basic steps, tweaks on icons [`bc5e192`](https://github.com/fomantic/Fomantic-UI/commit/bc5e192a607756b2591ae4908d9b8587e16032c8)
- Adds more menu examples, fixes some issues with pointing menus, fixes [`5971811`](https://github.com/fomantic/Fomantic-UI/commit/59718117007b5a34a73aff08ac2c1636544d5667)
- finally fixes the top menu, issue with getCollections [`a618eda`](https://github.com/fomantic/Fomantic-UI/commit/a618eda91c451fc16418cee641cbcd063f91ee4b)
- labels: finishing up work on labels [`b690f5b`](https://github.com/fomantic/Fomantic-UI/commit/b690f5b2bed06ce932b5da0a10ea6761145a6515)
- iterating on checkbox/module design pages, form fixes, table fixes, progress fixes [`53df49a`](https://github.com/fomantic/Fomantic-UI/commit/53df49a4c5c157c0dc2f62cf4f78f89ed55476ef)
- lots of fixes to form and button, adds beginning of checkbox docs [`5f8d295`](https://github.com/fomantic/Fomantic-UI/commit/5f8d2956a8bac66e34431e683685987cde913e75)
- fixing some issues with form,menu,segment [`b16049a`](https://github.com/fomantic/Fomantic-UI/commit/b16049a2ba98705a19032f52a97628fa46076099)
- updating structure of docs [`ed4f872`](https://github.com/fomantic/Fomantic-UI/commit/ed4f872ffc971e9d64666bea753d3db3a8dd6bd5)
- Adds more examples to groups [`8f74ceb`](https://github.com/fomantic/Fomantic-UI/commit/8f74ceb2e5d486c6729c068b6e35195f98c4aced)
- adding more needed styles to segment [`014fff3`](https://github.com/fomantic/Fomantic-UI/commit/014fff326c309f6550f952eef311c942202eb2a4)
- work on grid [`1f4a1db`](https://github.com/fomantic/Fomantic-UI/commit/1f4a1dbee4588c59da7df3434f51a178080a0886)
- adds kitchen sink start, adds google doc calendar into kitchen sink [`17b4a69`](https://github.com/fomantic/Fomantic-UI/commit/17b4a699e2a8cdf61139d8748873af5d0cf23639)
- fixing performance logging [`f0cce6c`](https://github.com/fomantic/Fomantic-UI/commit/f0cce6c9cd2af1372d3e268ba8531d56ec4f2258)
- iterating on text size issues, rem/em/px [`7bed0a8`](https://github.com/fomantic/Fomantic-UI/commit/7bed0a8aa1080114503e895ff9d44e326571f096)
- moving steps over from em [`538694a`](https://github.com/fomantic/Fomantic-UI/commit/538694ace421a7b9ff45198ce2af99ce5deed73e)
- adds colors to menu, without inversion [`9c3943e`](https://github.com/fomantic/Fomantic-UI/commit/9c3943edaef921cdbfd0f6f3c72e7f9661960aeb)
- Fixed pointing menu to not use border radius, started work on items [`ae58ad2`](https://github.com/fomantic/Fomantic-UI/commit/ae58ad20045672557d956d2e78433d088b062977)
- first commit dropdown js [`77dd489`](https://github.com/fomantic/Fomantic-UI/commit/77dd489a7a84d2bc39254ee58db6810b7c20b8c3)
- adds lots of new variations to menus [`181860c`](https://github.com/fomantic/Fomantic-UI/commit/181860ce7ecafc3a2fdd477f33647ae74767acf4)
- grid changes [`9767c87`](https://github.com/fomantic/Fomantic-UI/commit/9767c87f9c0383f177a1bbe6b043f1e42e4e3a01)
- swaps all docs to use ui headers instead of h1-h6 [`6454356`](https://github.com/fomantic/Fomantic-UI/commit/64543560ffa84ba1d0f61eaa38a44b14c9d95481)
- fixes issue with peek [`2e18a95`](https://github.com/fomantic/Fomantic-UI/commit/2e18a955577130d75795f0779ae2f0aecc5a87d8)
- reworking tags as ui label class [`4137024`](https://github.com/fomantic/Fomantic-UI/commit/41370242a301540fbaa7a720d34ccdb5d3dd512a)
- minor menu issues [`92bfaa3`](https://github.com/fomantic/Fomantic-UI/commit/92bfaa378535103b8ad4d1cf636a90b28bdeb15f)
- Various fixes to grid/menu [`d1c5672`](https://github.com/fomantic/Fomantic-UI/commit/d1c5672befe9dbc6c88943a53fb7e525c3fce7f3)
- finishing up the text block page [`92d3bd6`](https://github.com/fomantic/Fomantic-UI/commit/92d3bd6fb3b66f0393b618501e361ac6ef76d196)
- iteration on intro page [`a4fad21`](https://github.com/fomantic/Fomantic-UI/commit/a4fad21ea7535d1acd2532194d1c631420f66c8a)
- fixes to menu style, fixes to checkbox docs, removes weird outline in chrome for checkbox [`fb083b6`](https://github.com/fomantic/Fomantic-UI/commit/fb083b6aa145decb89720ddab5d40ea2db3944f0)
- segment: adds stacked  segment, fixes some examples [`2108cb4`](https://github.com/fomantic/Fomantic-UI/commit/2108cb4626612373a528f8c33dd5924ee0fd4177)
- grid: iteration on docs [`d231c15`](https://github.com/fomantic/Fomantic-UI/commit/d231c15528df488de08a6c0e01c372cc7bb9bc25)
- removes legacy column.css, adds page grid [`fc3aa3a`](https://github.com/fomantic/Fomantic-UI/commit/fc3aa3ac7ecdefc9a11316038975249f114d6232)
- structure -- altered component.json to match new file structure. [`ca5821a`](https://github.com/fomantic/Fomantic-UI/commit/ca5821a3ef2f081024f848e73ce7c44d9b901883)
- fixes redundant rules and vertical spacing [`131d4b2`](https://github.com/fomantic/Fomantic-UI/commit/131d4b242c6024a66325d16a3fee1d05857e055f)
- fixes to menu dropdowns, fixes to icons, added new circular variation to icons [`eb3a628`](https://github.com/fomantic/Fomantic-UI/commit/eb3a62846918d5c10452687f4e4dbd1b85002d09)
- header: adds colors to docs [`eb11fe5`](https://github.com/fomantic/Fomantic-UI/commit/eb11fe59912812a5ea8f58f36d821ddc96460acd)
- latenight coding iuno why [`3a699d2`](https://github.com/fomantic/Fomantic-UI/commit/3a699d29d764290bc1ce1bbbc2a8f76d31ca2d4f)
- fixes to button icons, secondary/tertiary buttons. fixes to circular icons [`d0c5af7`](https://github.com/fomantic/Fomantic-UI/commit/d0c5af79be7015a9ce8d46824cb9a9114878bbfc)
- adds more calendar time to kitchen sink [`34a7f20`](https://github.com/fomantic/Fomantic-UI/commit/34a7f20994631f3c6cd287284f1910caa2c2bbf1)
- work on menu docs [`9f4427d`](https://github.com/fomantic/Fomantic-UI/commit/9f4427d075049d48f800204339f7e72610668cad)
- adds sub menu animating [`84e3e31`](https://github.com/fomantic/Fomantic-UI/commit/84e3e31cd1332a9d4c957c44fe054f5f122568a3)
- adds elastic grid padding [`0649bd5`](https://github.com/fomantic/Fomantic-UI/commit/0649bd54ef1d203557f58aef6e8ffd4951cd0344)
- fixing hover/active states of colored buttons [`062064c`](https://github.com/fomantic/Fomantic-UI/commit/062064cde537a7d1dc4220bcbf987c6f679cf7be)
- fixes row width [`4803dfd`](https://github.com/fomantic/Fomantic-UI/commit/4803dfd424361e51ae42165db22a596c443d1e8a)
- adding more examples for checkbox, fixes to menu [`2bef400`](https://github.com/fomantic/Fomantic-UI/commit/2bef4005c67598b114357223ec549d4274722b84)
- modifies doc 'peek'  menus to use &lt;a&gt; tags, so they can work with submenus [`750edf3`](https://github.com/fomantic/Fomantic-UI/commit/750edf3e21d04c72ddc02946b23b1d3614096f2f)
- Fixes some broken icons, example content [`7470b94`](https://github.com/fomantic/Fomantic-UI/commit/7470b9433696902e77eaa7e6e645d20e7afd966d)
- fixes broken a tags [`e1eaa04`](https://github.com/fomantic/Fomantic-UI/commit/e1eaa043190bae338b8dfd34bb2aefba1b73c866)
- fixes to item layout on overview [`975e591`](https://github.com/fomantic/Fomantic-UI/commit/975e5915e7a1e6e6b2ce7bd648011d2fd4df8e4a)
- iterating on grid [`93fea69`](https://github.com/fomantic/Fomantic-UI/commit/93fea6995a6ff251d5dab78f1d3f2f89ed250601)
- fixes button dividers between groups, fixes resizing of homepage [`e6d964c`](https://github.com/fomantic/Fomantic-UI/commit/e6d964c999e097ff2e13d20f7890b9046cc8870f)
- table: fixes namespace issue with grid [`8639ff2`](https://github.com/fomantic/Fomantic-UI/commit/8639ff2931af096fb9930ee38f9313a00bb8020c)
- fixes rounding error in popup, adds fixes to messages, start of index [`582f34f`](https://github.com/fomantic/Fomantic-UI/commit/582f34fcfabceb37590974c68dcca973751f7ed7)
- adds fix for grid padding, adds comment view [`bd9aa54`](https://github.com/fomantic/Fomantic-UI/commit/bd9aa5452b5f93f4953e6f7d9b5f081d3c5f9958)
- fixes example [`792eba4`](https://github.com/fomantic/Fomantic-UI/commit/792eba4a872c80cc4cdd3f70865bbf3c08f2680e)
- change header on toc [`b920fbe`](https://github.com/fomantic/Fomantic-UI/commit/b920fbe2d658d73c2098d374c4651faf3e69e144)
- fixing some bugs [`e722e1f`](https://github.com/fomantic/Fomantic-UI/commit/e722e1fc243180526445606299e08d0c45e66056)
- shape: missing files [`dcf0b8f`](https://github.com/fomantic/Fomantic-UI/commit/dcf0b8f21b5414761967f7eec7e83f6d8898ba3b)
- classname fix [`a540d37`](https://github.com/fomantic/Fomantic-UI/commit/a540d37d4ebe8c029f3aee0aa91226a587d765b6)
- grid fixes [`8bb2f32`](https://github.com/fomantic/Fomantic-UI/commit/8bb2f325724c68608846c44bb5fb7ffb173e43ee)
- fixes gradient definition for webkit [`be532ee`](https://github.com/fomantic/Fomantic-UI/commit/be532ee9011fac865dd9beedee29beffe479ee30)
- updates [`b0d76f9`](https://github.com/fomantic/Fomantic-UI/commit/b0d76f95b36d88a0a99fb266dc2a4b3e6996983c)
- more updates to menu [`5fefaaf`](https://github.com/fomantic/Fomantic-UI/commit/5fefaaf8303f8d4d82d89367bc2745991b763a57)
- icons, capitalizations [`bba24b0`](https://github.com/fomantic/Fomantic-UI/commit/bba24b009229e53012545304cad9428d760cf1da)
- icon side [`3addcf6`](https://github.com/fomantic/Fomantic-UI/commit/3addcf6029c8d03545585922844e611dc0a554b9)
- fixes paragraphs in messages [`650c0d0`](https://github.com/fomantic/Fomantic-UI/commit/650c0d09e094071f4532a68574a5c1e5bf558eda)
- tiny example fixes [`d9dc4ca`](https://github.com/fomantic/Fomantic-UI/commit/d9dc4ca5e78ea6586c493ba2111e2a96be3a0cf0)
- block: adds new sizes [`c54b5f5`](https://github.com/fomantic/Fomantic-UI/commit/c54b5f57189507284f426985567dff79f2a3d2b3)
- missing files [`bc39e63`](https://github.com/fomantic/Fomantic-UI/commit/bc39e63dbac33690e840fa625b8fec4b93f271b6)
- iterating on this ish [`cd72369`](https://github.com/fomantic/Fomantic-UI/commit/cd723696cb4bcd36260d8e3e95346f96a30dd622)
- fixing menus for contrasting [`3cc0a41`](https://github.com/fomantic/Fomantic-UI/commit/3cc0a41531c2481455c45dbc71dde9f2a430968f)
- fixes inline fields [`dbbdd7b`](https://github.com/fomantic/Fomantic-UI/commit/dbbdd7bebe85fe12808585419d35b0f746ac472a)
- tweaks sizes of icons [`385bf69`](https://github.com/fomantic/Fomantic-UI/commit/385bf698991eae2a9704864f1aba9cfd06fa7159)
- adds borderless variant [`2c1dc49`](https://github.com/fomantic/Fomantic-UI/commit/2c1dc496bb31fb3cb044fb8b8100bc77852dab67)
- fixes some broken images [`45de779`](https://github.com/fomantic/Fomantic-UI/commit/45de779db681c7bbe4806379b94eda740334f9c2)
- fixes menu button [`165a17c`](https://github.com/fomantic/Fomantic-UI/commit/165a17ca85d768fbe76b414631a6ef3f4bfb9aee)
- fixes menu button [`dd25a39`](https://github.com/fomantic/Fomantic-UI/commit/dd25a39c341f96b59ee7f324290884d867842842)
- fixes issue with icon alignment [`56890f2`](https://github.com/fomantic/Fomantic-UI/commit/56890f2d682759279b2c7b1179e433554b632c10)
- menu: tiered menu bug [`e40bc14`](https://github.com/fomantic/Fomantic-UI/commit/e40bc14acdeecbdae848b938e0c1f79e954e9999)
- header tweaks [`d3c7f19`](https://github.com/fomantic/Fomantic-UI/commit/d3c7f1955ebb2d2cddcd4704757af50e0eb26436)
- item formatting [`fa9667a`](https://github.com/fomantic/Fomantic-UI/commit/fa9667a6b19ce10cc3ad6c6fdfb4a3a3e1b4c9c4)
- label demo fixes [`facfef8`](https://github.com/fomantic/Fomantic-UI/commit/facfef86422620c56b59fb69b1da50d2ede7919f)
- structure -- c style comments not part of json spec. [`0d94703`](https://github.com/fomantic/Fomantic-UI/commit/0d9470307e1ca10d285189b55c99bc335c645021)
- fix for menu flyout [`6100429`](https://github.com/fomantic/Fomantic-UI/commit/610042936ab7bf12affbf3a436d5adb3010b2908)
- structure -- slashes out of component. [`8e8a20b`](https://github.com/fomantic/Fomantic-UI/commit/8e8a20b713b8b5c89cff00f44ecf05948c68ac86)
- fixes relative image path [`faea265`](https://github.com/fomantic/Fomantic-UI/commit/faea26577307d23c9377b4d42f6a8af35df4a553)
- adds shadowing for floated shaded menu [`c4724cc`](https://github.com/fomantic/Fomantic-UI/commit/c4724cc2147796374d1fb89e41e938a80b178152)
- updates item example [`8b83fa5`](https://github.com/fomantic/Fomantic-UI/commit/8b83fa5b81aa43c6caa9e32d083f52d3e9c8c2d8)
- structure -- ignore non source files. [`9aa4c0c`](https://github.com/fomantic/Fomantic-UI/commit/9aa4c0c3ea6b553ba63d1f40db1ffe7182a94410)
- classname changes to docs [`6752cc2`](https://github.com/fomantic/Fomantic-UI/commit/6752cc26a32b0c79169635224b98d19d69b72216)
- labels [`6c03da4`](https://github.com/fomantic/Fomantic-UI/commit/6c03da4b5c2b1808de7799c837d7f2ffb1d0b6a7)
- formatting fix [`4a1ad7c`](https://github.com/fomantic/Fomantic-UI/commit/4a1ad7c34d70c6be640ca859755c21679b8f8c7c)
- fixes commenting [`67397a0`](https://github.com/fomantic/Fomantic-UI/commit/67397a0cf42ccbbba783e31ca9fc6886739a8060)
- Fixes docpad to add CNAME file on gh-pages create [`b52e6ce`](https://github.com/fomantic/Fomantic-UI/commit/b52e6ce8c2a72f9e6a7ba3c5d56de5576f9c0210)
- removes design/develop mode from pages that arent ui [`9bf6414`](https://github.com/fomantic/Fomantic-UI/commit/9bf64142ad91036d4a02d4d258ea364dbafc49f7)
- fixes menu button [`4510e47`](https://github.com/fomantic/Fomantic-UI/commit/4510e476951d6c2b2f35bc4d32a46ebad22e5352)
- reverts dropdown menu shift [`96b46a8`](https://github.com/fomantic/Fomantic-UI/commit/96b46a8de056a589cb74ccba2b46694265ad6cf4)
- structure -- typo in component. [`9cdee47`](https://github.com/fomantic/Fomantic-UI/commit/9cdee479187fcc36e66c006e67b304d8d6f04bea)
- structure -- getting odd error about library name [`bf15586`](https://github.com/fomantic/Fomantic-UI/commit/bf1558685b14e0ebc530c3c5fb0cc6c5a74c7488)
- missing slash [`511f9d0`](https://github.com/fomantic/Fomantic-UI/commit/511f9d0c98dc30808c07d7492006f70025648f77)
- adds cname file [`dd1764b`](https://github.com/fomantic/Fomantic-UI/commit/dd1764b75e5d32ea944549883d1dd80381a65343)
- language on module [`60d9dfe`](https://github.com/fomantic/Fomantic-UI/commit/60d9dfe19a963cb1b8ff652fce63c7f3e3b5f0b9)
- menu fixes [`9d4d1e2`](https://github.com/fomantic/Fomantic-UI/commit/9d4d1e21c4adef16324aa7e85ec490d687e9b591)
- missing files [`8e647bf`](https://github.com/fomantic/Fomantic-UI/commit/8e647bf0e17a3a1d3d903871c5166b4a418b3b1b)
- missing files [`e5beeca`](https://github.com/fomantic/Fomantic-UI/commit/e5beeca26f3dc702b39af344c57093d212a72799)
- Fixes modulename in some modules, adds new font awesome icon port, removes down class from menus, fixes input positionining again, adds new coupling for tabular menu with attached segments, fixes attached tabular segment formatting [`49a8609`](https://github.com/fomantic/Fomantic-UI/commit/49a8609f65e454dcbaf6f0fd2d94f75b88a25dff)
- Adds missing build files [`cf904d2`](https://github.com/fomantic/Fomantic-UI/commit/cf904d2618e333e4c30a0b1097fe62d85b3aa89a)
- src [`619bee1`](https://github.com/fomantic/Fomantic-UI/commit/619bee1fa41ce26a6b5e21502735b08d97aa18a1)
- Builds latest version [`b2f6a08`](https://github.com/fomantic/Fomantic-UI/commit/b2f6a08af3586e654c073084d217dbd3974d8c2e)
- Version uptick and rebuild [`e563826`](https://github.com/fomantic/Fomantic-UI/commit/e5638265927bf385dfec7b294ad3669f2725709c)
- adds a couple new log lines for modal [`4d9dc3f`](https://github.com/fomantic/Fomantic-UI/commit/4d9dc3f264cabda9d9c3385123b97b8490faf0ff)
- Renames behavior dir to plural [`7b6f73c`](https://github.com/fomantic/Fomantic-UI/commit/7b6f73cc449a7dcbba11403a36b0f6e176dca681)
- Adds new style directory: "shaded", old site style is now classic. the idea is, to have same UI as flat but with subtle shading and box shadow, basically a really simple fork. [`64c131f`](https://github.com/fomantic/Fomantic-UI/commit/64c131f731b1e441e099f2db6993ac173c490976)
- Beginning to write alternative themes to menus [`640355c`](https://github.com/fomantic/Fomantic-UI/commit/640355c61039f74de8ef83088717e8948f990466)
- Fixes performance logging in several modules. Fixes some consistency issues in dropdown [`6d92d72`](https://github.com/fomantic/Fomantic-UI/commit/6d92d728d9d8bcf2cdb79eb0258623b77e0e5b05)
- attempting code restructuring [`c359d4d`](https://github.com/fomantic/Fomantic-UI/commit/c359d4d30eed28b7d18f1587c6e44efa6031568c)
- Near complete rewrite of popup [`2928c95`](https://github.com/fomantic/Fomantic-UI/commit/2928c95f785dfd5354438152441e0af439e455a3)
- Updates to chat, homepage [`fe6810a`](https://github.com/fomantic/Fomantic-UI/commit/fe6810ae668b701f563bb242693040333d5281ae)
- fixes work on importing font awesome icon [`b96e862`](https://github.com/fomantic/Fomantic-UI/commit/b96e8628eb85aa0a0595a1db8f9a9b1f2e586f84)
- Updates video component, fixes some issues with inverted secondary menus [`22d3540`](https://github.com/fomantic/Fomantic-UI/commit/22d354057760f64a03903f1f59e930c4f4a9f38e)
- adds docco grunt task, setting up docco to build automatically [`6a30cea`](https://github.com/fomantic/Fomantic-UI/commit/6a30ceaedabf3ccd6e8003d1959712088978f130)
- Removes references to performance.display(), out of scope! [`557163e`](https://github.com/fomantic/Fomantic-UI/commit/557163e48153eaed96a4696ea9b4b0faa3b0293c)
- writing docs for modules, fixing paths [`9d7f6cc`](https://github.com/fomantic/Fomantic-UI/commit/9d7f6ccda9bb5c11901112368e7866cbc9f553fd)
- text menu: fixes box shadow from appearing [`75b69ce`](https://github.com/fomantic/Fomantic-UI/commit/75b69ce5cde4f815d42771615090a43d9ac4b84f)
- removes incomplete modules from download package [`730376b`](https://github.com/fomantic/Fomantic-UI/commit/730376b513a37bbd3955fe8d38b4244e6ef242d1)
- Builds version 0.11.0 for release [`232dd22`](https://github.com/fomantic/Fomantic-UI/commit/232dd22d1aa54607289e5391a2cb04380bdfce4e)
- Updating many components over weekend. [`eda1bd2`](https://github.com/fomantic/Fomantic-UI/commit/eda1bd2b139d977952daea90c06a2401c4ebe21c)
- Adds theming example to docs [`e3a7b24`](https://github.com/fomantic/Fomantic-UI/commit/e3a7b242ddf2b27a0cbc0bff4c2d5abc8fcf0948)
- Adds some test coverage, sets up fixtures for testing [`f0466ef`](https://github.com/fomantic/Fomantic-UI/commit/f0466efbdf6fdd55562fd91689a5d3f46f31f8f5)
- Adds updated homepage, lots of fixes to button, adds basic buttons, new [`a6ef2a4`](https://github.com/fomantic/Fomantic-UI/commit/a6ef2a43e6ad19f15da25758d5c880b566702cc9)
- Finishing first pass on css transition module, needs docs. Some animations need debugging. [`a1e1dd7`](https://github.com/fomantic/Fomantic-UI/commit/a1e1dd7ec6162183994dbe91985372722f15730e)
- Adds new files to build [`fc37553`](https://github.com/fomantic/Fomantic-UI/commit/fc375530bc2735afa01eaa8b09ec1658a4ece8e5)
- Updates module performance to show the total init count [`351f712`](https://github.com/fomantic/Fomantic-UI/commit/351f71262713894a72cff6b5ab1c471133ebc360)
- Adds new modal, fixes to dimmer and transition [`61fb46f`](https://github.com/fomantic/Fomantic-UI/commit/61fb46f88ac2124afe798753de7751e73d380c9a)
- Adds lots of new stuff. Chatroom first pass, rating, updates to checkbox [`c197568`](https://github.com/fomantic/Fomantic-UI/commit/c1975689f49ab20626e0d7f93f87bbc98eaf7d8d)
- Version uptick and build [`060a3f3`](https://github.com/fomantic/Fomantic-UI/commit/060a3f3b91d59b4d4aa9e41a43acad18a3c24520)
- Rebuilds packages [`30c5409`](https://github.com/fomantic/Fomantic-UI/commit/30c54097ece9525c3b10f1e7bd1c3a340de00ccd)
- Invoke now can translate ('make money') to makeMoney or make: { money: function(){}} [`036bce4`](https://github.com/fomantic/Fomantic-UI/commit/036bce4aa6294c013f0054725fc35393cd7e0786)
- font awesome files [`dd977b6`](https://github.com/fomantic/Fomantic-UI/commit/dd977b67d6842886509f52c16170d352aa96262d)
- updates comment banners to be consistent across project [`a159535`](https://github.com/fomantic/Fomantic-UI/commit/a159535bf1d7735e67b5bf4edc1ba5e4aeb24585)
- Rebuilds src [`1387bfa`](https://github.com/fomantic/Fomantic-UI/commit/1387bfab7c655151e0677d8ff2914c49220f9b17)
- Holy calamity animations up the wazoo. Integrating transitions lib into [`ed6c935`](https://github.com/fomantic/Fomantic-UI/commit/ed6c93518dd004d2999cbf4e1de1981fe881703e)
- Adds first docs for modal, adds revisions to modal and dimmer [`294fa68`](https://github.com/fomantic/Fomantic-UI/commit/294fa68f83690070f63b9710e591d7cf5a2ea61a)
- adds inline form validation, default validation types, validation on input change [`b41d6d9`](https://github.com/fomantic/Fomantic-UI/commit/b41d6d96f4d24c037520500fceaeac13fda7ec44)
- Start coding simple dimmer [`eb9fe18`](https://github.com/fomantic/Fomantic-UI/commit/eb9fe1815d17226aea839377add958278fc555da)
- Updates release notes and creates release package [`364625f`](https://github.com/fomantic/Fomantic-UI/commit/364625f91f0c8e295b9f26e7f9fed0f438928cf0)
- updates build files [`b8755b0`](https://github.com/fomantic/Fomantic-UI/commit/b8755b0735f89f907bd41e55b3d5cb43a107e2df)
- origami: origami is now SHAPE. Working on new button styles to match new GE page. Added doc page. Working on default doc styling for 'semantic' [`cca7fdd`](https://github.com/fomantic/Fomantic-UI/commit/cca7fddd96a91277d862f2bf4324e2d4d3a9544f)
- Iterating on module design pattern. Fixes to performance logging. Much work on dimmer class, new thoughts on fusion of dimmer and modal [`a4332c6`](https://github.com/fomantic/Fomantic-UI/commit/a4332c6095ac0e3576e73098a886210a7608b799)
- Builds packages with new themes [`4cb05d0`](https://github.com/fomantic/Fomantic-UI/commit/4cb05d0b29a6f8283b308255619e3f84250ef8f2)
- Adds missing files to src [`0ad6a4f`](https://github.com/fomantic/Fomantic-UI/commit/0ad6a4f0ecd9864cf982210768a6c18ff90c0f8c)
- Iteration on sidebar and other fixes [`745232d`](https://github.com/fomantic/Fomantic-UI/commit/745232d626964aa5a39bdb36c9bd7156985e7dc0)
- Restructures theming folder to be more structured, renames user themes site theme. Fixes up semantic.config to only give example config with instructions to avoid overrwrite on update [`527dfe0`](https://github.com/fomantic/Fomantic-UI/commit/527dfe0202607ddc70197f175af226a417d21c6b)
- Modifications to grid, addition of new container class. Variable fixes [`a18186b`](https://github.com/fomantic/Fomantic-UI/commit/a18186b57c38458bd0cdfcc5ada7eb09766bd415)
- First version of dimmer added [`1415a1a`](https://github.com/fomantic/Fomantic-UI/commit/1415a1a1bd7fff32cb6c3fb4fe14144d705a0af6)
- Builds version 0.13.0 updates release notes [`3f7e69d`](https://github.com/fomantic/Fomantic-UI/commit/3f7e69de765e045a198abb285a6e44bc29157ce8)
- removes undocumented error state for buttons, adds in draft components [`0be2499`](https://github.com/fomantic/Fomantic-UI/commit/0be249972d16701473a0ad8a200412eb8cab24fd)
- Adds first draft of sidebar (blind coded) [`242f661`](https://github.com/fomantic/Fomantic-UI/commit/242f6617dd17c31f6f99c1331a975da2f0b322e3)
- This is the time where i need to go to bed` [`82746f9`](https://github.com/fomantic/Fomantic-UI/commit/82746f90c9fe1ac8c03aedb2d484e5f4c2701761)
- updates version number and creates release [`b80b438`](https://github.com/fomantic/Fomantic-UI/commit/b80b43893fe15720764d1e57a62afa9afeb71059)
- Fix homepage menu [`5c18db1`](https://github.com/fomantic/Fomantic-UI/commit/5c18db157242f7b168182e17edb3da425fc4b81d)
- rebuilds assets [`6d319b3`](https://github.com/fomantic/Fomantic-UI/commit/6d319b3925fe159c1bc182cc9b43d2ff2c910a31)
- Rebuild files [`ba1f8b0`](https://github.com/fomantic/Fomantic-UI/commit/ba1f8b060d49fa67842169482e815d6383adf8c4)
- builds, packages, ticks up release # [`7877088`](https://github.com/fomantic/Fomantic-UI/commit/78770887176524e7379d6e59094dcb698da946a8)
- ui: wrote a first pass at a menu, created an all new layout for docs with top fixed nav. wired in some spying menus that follow you around [`c13af2f`](https://github.com/fomantic/Fomantic-UI/commit/c13af2fed72391f75460d88ea091e3c602422290)
- labels: adds corner labels, refactors corner labels out of items, adds start of input docs [`a4faa1e`](https://github.com/fomantic/Fomantic-UI/commit/a4faa1ed2cf1c3b8723e0c5250c0440a4b244ace)
- Rebuild files [`4787a70`](https://github.com/fomantic/Fomantic-UI/commit/4787a70ffeeafd3e6906724b0de6c9e270aa9e8b)
- sub classes basic icon set to avoid issues with concatenated version icons not working [`68f4dfb`](https://github.com/fomantic/Fomantic-UI/commit/68f4dfb15ef5c4dafde66b04fc10c2ae03ba1990)
- Builds version 0.12.0 [`8e154a8`](https://github.com/fomantic/Fomantic-UI/commit/8e154a88214636c69895dd084df6e07cdcbadd58)
- fixes bug in first error/log not displaying. work on docs for transition [`f665960`](https://github.com/fomantic/Fomantic-UI/commit/f665960bbe1c4892bc1f89e86394b663f9585485)
- icon, adds plus alias, builds files [`ac29c0e`](https://github.com/fomantic/Fomantic-UI/commit/ac29c0ede81a93faa21dba43b1c9afb4ff05eb4a)
- Blind coding of css animation module [`2004e65`](https://github.com/fomantic/Fomantic-UI/commit/2004e65cebcbe9258e1bee20457ae164726ff7d1)
- First rough non-working pass at rapid writing carousel module [`d268212`](https://github.com/fomantic/Fomantic-UI/commit/d268212d9236837aa300a508ba6aba2e1580de33)
- Updates to header, button, and lots of updates to dropdown [`bf06ceb`](https://github.com/fomantic/Fomantic-UI/commit/bf06cebc8ba55c19b0d835f2f2fb16199e4c4997)
- updating form/block class [`a8a36f0`](https://github.com/fomantic/Fomantic-UI/commit/a8a36f093914748ed9d937f9848ac866bff59586)
- fixes to icon menu and some other variations [`2035fc2`](https://github.com/fomantic/Fomantic-UI/commit/2035fc29332b4385e06c68e13221897809dca20b)
- Completes theming director and include setup [`61d07e9`](https://github.com/fomantic/Fomantic-UI/commit/61d07e91a1c61a6d07716424b778ca718c284393)
- Rebuilds release packages and upticks version [`f62e81d`](https://github.com/fomantic/Fomantic-UI/commit/f62e81d07b6d83a5f6b9ff0bc8bdc1e83269914e)
- Adds release notes [`2772caa`](https://github.com/fomantic/Fomantic-UI/commit/2772caab89795b04054b6cb0c07e4709f6517241)
- Updating docs to include more tabbed navs [`2090798`](https://github.com/fomantic/Fomantic-UI/commit/20907985576547fd772e5fd6ba2eb4e223b4df56)
- Updates build [`18fe1e7`](https://github.com/fomantic/Fomantic-UI/commit/18fe1e79082019ebb6506f2812a45e255f436dd8)
- Builds 0.10.0 release [`fc30ff5`](https://github.com/fomantic/Fomantic-UI/commit/fc30ff5cb66e409e350410fb2abc642ea2d90ce1)
- Fixes basic icon path in docs [`785007a`](https://github.com/fomantic/Fomantic-UI/commit/785007a3cc6f4f4447e3c55fb080400b2ac278e4)
- Packages version 0.10.3 for release [`f4309e4`](https://github.com/fomantic/Fomantic-UI/commit/f4309e439eb1af89eba1717743c7de8ce6e189d0)
- Finishes new nav menu for docs [`c28dcfb`](https://github.com/fomantic/Fomantic-UI/commit/c28dcfb92c329aa78cd7699fa8070386bce54890)
- Attempting to move basic icon set to separate theme instead of subclassed [`743c721`](https://github.com/fomantic/Fomantic-UI/commit/743c7212e7d726288b9a6aac6385d6be6407b5d5)
- rebuilds package [`5859744`](https://github.com/fomantic/Fomantic-UI/commit/5859744faceb3b452f00e5e5aef686996fe6f467)
- Updates widget factory to be more consistent accross modules [`fdea309`](https://github.com/fomantic/Fomantic-UI/commit/fdea3091b79b06139354449d214b388171ba8a69)
- Fixes from today to semantic [`8c78ac2`](https://github.com/fomantic/Fomantic-UI/commit/8c78ac273ab42b60c3ebf9fb629444b6ca6dff24)
- adds docs for ui table [`72577ad`](https://github.com/fomantic/Fomantic-UI/commit/72577ad974e76209492e52eed8390f210b40f485)
- iterating on icon font work [`2d43eb3`](https://github.com/fomantic/Fomantic-UI/commit/2d43eb3bc90d72fad6f04ef4f20deaeabc5d9e6a)
- Changes to homepage mockup [`ea2313d`](https://github.com/fomantic/Fomantic-UI/commit/ea2313db44dc88ffa97ebb7e220792fd054c67e7)
- builds and tags new version [`2af3b73`](https://github.com/fomantic/Fomantic-UI/commit/2af3b73fbcec6bd36c000833403fdb1d4451c2e8)
- Origami: Initial commit of origami module [`e767422`](https://github.com/fomantic/Fomantic-UI/commit/e7674226de29124a423f9158a2f089e28ca0776a)
- Add proper console output for jasmine tests and proper include. Creates new test for running with continuous integration or for local watch [`eb6ed4b`](https://github.com/fomantic/Fomantic-UI/commit/eb6ed4befc32d88f0881167ce704aec1adb88fdb)
- Fixes less build causing error. Missing container from semantic.config [`7b8996b`](https://github.com/fomantic/Fomantic-UI/commit/7b8996b5b2b95e7543da8c8045ca8dd0e83abaa0)
- Rewrote a ton of shit in a ton of modules. [`82b4144`](https://github.com/fomantic/Fomantic-UI/commit/82b4144bca0739640d17997ef39206b9de4bbaf1)
- Adds list style, docs [`55c4436`](https://github.com/fomantic/Fomantic-UI/commit/55c443684acdeaec8740c39029258e54c092b2b7)
- Adds variables for labels, adds some new loader styles using css animations [`98292d8`](https://github.com/fomantic/Fomantic-UI/commit/98292d853c410c96d8b6727a65c90b023045b768)
- builds package [`d8aaf50`](https://github.com/fomantic/Fomantic-UI/commit/d8aaf5059e05d0c8ad7dcda9abce3cfa8178d439)
- Initial write of progress module [`07ea079`](https://github.com/fomantic/Fomantic-UI/commit/07ea079fb54bac99a49ced8e3ecbe50d0f29fa96)
- Iterating on homepage [`bb1be57`](https://github.com/fomantic/Fomantic-UI/commit/bb1be57d6fef0a4990e5fe290241d244a479d56d)
- Changes from yesterday [`0983ee0`](https://github.com/fomantic/Fomantic-UI/commit/0983ee03b4b5012e901cc972e9ad81113f0f36bf)
- Adds first working pass of dropdown js [`f932da4`](https://github.com/fomantic/Fomantic-UI/commit/f932da4f08b16ac07bb89ae4029bca8cf4ad66fd)
- adds pointing style to dropdown menu, fixes issue with vertical min height in menu [`bb16f2b`](https://github.com/fomantic/Fomantic-UI/commit/bb16f2b77ce64a8d25e4ffd9b315bf44a0ca5786)
- Near complete with theming structure [`19e1e81`](https://github.com/fomantic/Fomantic-UI/commit/19e1e817625965996af1c34f03d6db2a4886b20b)
- Rebuild for beta docs [`48cc788`](https://github.com/fomantic/Fomantic-UI/commit/48cc78884ae946217a8c7145651c8683e7925e5c)
- Fixes some error messages in API, updates from branch [`fb97f98`](https://github.com/fomantic/Fomantic-UI/commit/fb97f984917efd3bea78c0b988b5d432436b72d6)
- Updates docs to include new tab layout, adds sortable tables [`52f1a87`](https://github.com/fomantic/Fomantic-UI/commit/52f1a87114abad01065ba111542f9470aa72b845)
- adds a host of new options to dropdown class, fixes to menu, stuff [`39199fe`](https://github.com/fomantic/Fomantic-UI/commit/39199fe9fd829d218dc9f13690c8071adc42fdce)
- Added many new content types inside dropdowns [`c5490a4`](https://github.com/fomantic/Fomantic-UI/commit/c5490a4a32270e9e28782db841556786ad27e412)
- late night changes [`491a3a3`](https://github.com/fomantic/Fomantic-UI/commit/491a3a39946bf44379265d616a8d20a7b9fd6811)
- Revise segment docs, fix zindex issue with piled segment and add disclaimer [`5bcff31`](https://github.com/fomantic/Fomantic-UI/commit/5bcff317bc105628650734b80c254325e6f0a77e)
- Work on rating and tab updates. Tab documentation [`90b9f81`](https://github.com/fomantic/Fomantic-UI/commit/90b9f818c9e8294e0ff065eee3208d913ad4eb98)
- Adds semantic standard explanation page, adds first spec page for button. Continues to modify button class for new ui buttons [`55abf36`](https://github.com/fomantic/Fomantic-UI/commit/55abf36b66f8e23d2853d1a377b6cf23a3780fb2)
- Iteration on design for customize/build page, first passs [`abe546b`](https://github.com/fomantic/Fomantic-UI/commit/abe546b22076b93b1bbe218b0935e8de7bac64b7)
- Fix modal mobile sizes, add several new variables, add modal header lineheight [`7e1c9d4`](https://github.com/fomantic/Fomantic-UI/commit/7e1c9d41114a8e36f64c22e4049826c30e82e734)
- Adds stub for progress bar theming/enhancements [`b77136d`](https://github.com/fomantic/Fomantic-UI/commit/b77136da1fc95750e00063c319f955c8b6f06809)
- Adding partials for each UI element in prep for kitchen sink, updatings language menu [`4980437`](https://github.com/fomantic/Fomantic-UI/commit/4980437db6a96ee9a43f8741ad13f485020bee00)
- Builds version 0.12.5 and adds release notes [`b2b876f`](https://github.com/fomantic/Fomantic-UI/commit/b2b876f4f7f26425e4a5b15f304ee50b1324fe10)
- Redoes icon docs, adds internal grid example, adds social circular icon example [`e28814b`](https://github.com/fomantic/Fomantic-UI/commit/e28814b1276a070e4e280624bc8d06e2a36bc2e6)
- Rebuilds release package for deploy [`616aa6b`](https://github.com/fomantic/Fomantic-UI/commit/616aa6b07ed7f6cc6926026bdd6fd984fa4ef5ec)
- Mergest master into css [`08d179c`](https://github.com/fomantic/Fomantic-UI/commit/08d179c6be3e782e7efc7692d1e733d314f7db5b)
- Updates message, table, working on fixes for transition with dropdown [`4b3cf08`](https://github.com/fomantic/Fomantic-UI/commit/4b3cf08757c6c484921608367c2bb96920e8ec63)
- Rebuild packages for beta docs [`7cc44e3`](https://github.com/fomantic/Fomantic-UI/commit/7cc44e36cdc04fc6aa62b857b8d480621b86a967)
- Adds input, divider variables. Recoded header and segment variables [`13b8d93`](https://github.com/fomantic/Fomantic-UI/commit/13b8d93193feac6fd78ca1d16369b6579575958f)
- lazy commit of semantic module spec inside shape.. will edit out later [`efc8bdc`](https://github.com/fomantic/Fomantic-UI/commit/efc8bdc920ca4d87f4ab5972127664db6b5c9895)
- Rebuild files [`8fa5538`](https://github.com/fomantic/Fomantic-UI/commit/8fa55382b2819a8726806a1efd119fe156a7be35)
- updates built version, ticks up minor version [`193e1ea`](https://github.com/fomantic/Fomantic-UI/commit/193e1eaadf4951f2e7584359769891e81fcf1d8d)
- lists like a baller [`82ba843`](https://github.com/fomantic/Fomantic-UI/commit/82ba84308a822bd1c05023dfd2c91fb73ef554dd)
- fixes bug in dimmable where multiple dimmers might show [`addba19`](https://github.com/fomantic/Fomantic-UI/commit/addba19dfea9dd371fdd4578659f0f97a8d19204)
- Adds our custom fonts, fixes to menu inversion issues [`54a5bf7`](https://github.com/fomantic/Fomantic-UI/commit/54a5bf7400149be0f7689f5ef2e69742b2186710)
- missing files [`79cdbd4`](https://github.com/fomantic/Fomantic-UI/commit/79cdbd4f650ddf9c209bc4d309f5320eaf8d1e60)
- Rebuild files [`2b6b909`](https://github.com/fomantic/Fomantic-UI/commit/2b6b909df00576e77ef6f8cf423db72ebbaf7df0)
- Fixes word order on buttons [`64f33a4`](https://github.com/fomantic/Fomantic-UI/commit/64f33a479504bc1f4db2a1329f6aa49d4409dfab)
- Fixes to loader, label, menu, grid [`2a75faa`](https://github.com/fomantic/Fomantic-UI/commit/2a75faa2666f4ac27a8a8258a6387f703df835c6)
- Adds page overflow to site variables, to allow top level grids to use negative margins which might create scrollbars [`7413e7a`](https://github.com/fomantic/Fomantic-UI/commit/7413e7a0f1c627303de79f0466c63775117d7437)
- last update to sidebar before kaputz [`b5c248c`](https://github.com/fomantic/Fomantic-UI/commit/b5c248c59a2ad34bb5b0e22905dbc70d82bd1534)
- Builds 0.12.2 release version [`9f3027e`](https://github.com/fomantic/Fomantic-UI/commit/9f3027e24ced25b3cd2c0f1bdf450e6601364984)
- adds code samples to all ui currently defined [`4511940`](https://github.com/fomantic/Fomantic-UI/commit/4511940b18d5eb33c22319efa83b2579cda01360)
- Bundles version 0.13.1 and adds release notes [`237fe65`](https://github.com/fomantic/Fomantic-UI/commit/237fe655765a90411d2fc299528cff0399b49bba)
- swapping over sidebar to use touch events, no longer sidr lib [`b042bb4`](https://github.com/fomantic/Fomantic-UI/commit/b042bb478e8a3f6c3952a8cd5967cae4e8f35468)
- Updates tone and clarity of language on introduction pages, adds [`2c6b8fb`](https://github.com/fomantic/Fomantic-UI/commit/2c6b8fb8caf27a3090e21677601707d2a2bc7207)
- Updates with some new google pasta images, updates list view examples, [`e9b7e0c`](https://github.com/fomantic/Fomantic-UI/commit/e9b7e0c668747a6057116f621d9de6c5c89624a4)
- Rebuild files [`d839949`](https://github.com/fomantic/Fomantic-UI/commit/d839949c4485528957ede029429cd71ed459f87f)
- Adds transition lib to dropdowns! [`42035d7`](https://github.com/fomantic/Fomantic-UI/commit/42035d7ac810ef8999c606b3f45a5cf8fb83bfae)
- Experimenting with theme loading structure [`843f140`](https://github.com/fomantic/Fomantic-UI/commit/843f140554729b89246aa840449139068645bdd6)
- Adds font awesome icon port [`1fef8b7`](https://github.com/fomantic/Fomantic-UI/commit/1fef8b7f750308a1f30fc161d0b866501de26123)
- Begin work on wizard, which means writing out variations/states as YAML [`1924b69`](https://github.com/fomantic/Fomantic-UI/commit/1924b69e2ffd19d2f6f4890c40b3ec3dd9b8e204)
- Fixes accidental commit of themes to master [`647f4c9`](https://github.com/fomantic/Fomantic-UI/commit/647f4c9916297fd9c750bba97ecf219866a85241)
- Fixes casing of theme to match other folders [`d88b931`](https://github.com/fomantic/Fomantic-UI/commit/d88b9314afe569301779489cb169a5695f02606f)
- Fixes to button and dimmer [`20e07c3`](https://github.com/fomantic/Fomantic-UI/commit/20e07c3f6b045404d01e5d2070728653fcca8df1)
- Move reset variables to overrides to provide support for multiple reset styles [`760b216`](https://github.com/fomantic/Fomantic-UI/commit/760b2165d50bf9074060a83f2df3d99da8628dd0)
- adds new example directory with layout and code examples [`b42f907`](https://github.com/fomantic/Fomantic-UI/commit/b42f907d2ba0b3431f72e836b7785d2975dbc1c3)
- form: working on form restyling. [`ed52b42`](https://github.com/fomantic/Fomantic-UI/commit/ed52b42cc8d213a90e3979dad0d6320bc19e00cf)
- Fixes actions inside items [`7600cac`](https://github.com/fomantic/Fomantic-UI/commit/7600cacf25d1f26f85e6fbaaea7a4706f63d8362)
- Dont initialize menu on mobile/tablet, fixes for responsive [`1767d93`](https://github.com/fomantic/Fomantic-UI/commit/1767d93bc2b06370473d9c82031be0ce1f2ccfe8)
- iteration on module docs [`23b82eb`](https://github.com/fomantic/Fomantic-UI/commit/23b82eb51570ddd444fa5dfe8d79535a06d7bb31)
- the fallling asleep commit [`0879886`](https://github.com/fomantic/Fomantic-UI/commit/0879886a5e3294c73a56d0be13fa125bb028c6b3)
- Creates release notes and package for 0.12.1 [`35342a4`](https://github.com/fomantic/Fomantic-UI/commit/35342a4979312989697d9d53a0460df784a418da)
- First pass at flags documentation [`2df6241`](https://github.com/fomantic/Fomantic-UI/commit/2df62411338cfaaf0ce85296517fa7a7d97d6a44)
- Fixes for grid, accordion, sidebar, button attachment [`e6637eb`](https://github.com/fomantic/Fomantic-UI/commit/e6637ebb4fab32db48d1e94907844e905693566d)
- removing all dropdown class from menu, changing automatic menu (without js) to be simple menu variation [`2c9cc46`](https://github.com/fomantic/Fomantic-UI/commit/2c9cc46bb982f3f5a231a3402cd12849f31ce2d1)
- Rebuild files [`3fdbf32`](https://github.com/fomantic/Fomantic-UI/commit/3fdbf32719e58a85a3a13938ce4d49fa1f64712c)
- finishing up dropdown module [`5a4e295`](https://github.com/fomantic/Fomantic-UI/commit/5a4e2954d4332ff7286f0acc87b08db492056ad1)
- Complete rewrite of dropdown to support searchable dropdown, optimizations, better scroll selection, easier to fix tab index [`f56d415`](https://github.com/fomantic/Fomantic-UI/commit/f56d41575ab01b20869c0cba0fb3890fa5260d39)
- Bunch of new doc writing [`c6c5040`](https://github.com/fomantic/Fomantic-UI/commit/c6c5040315f85d93866cf6ea6b09ce08f521795e)
- adds fixes to inline validation [`74335dc`](https://github.com/fomantic/Fomantic-UI/commit/74335dc4e32e7858dd942347c43461e8eca29dad)
- continues to make modules conform to design pattern [`f48e3c8`](https://github.com/fomantic/Fomantic-UI/commit/f48e3c851f9d888c4e7847f5ffdf9525e17ee9fd)
- Fixes to headers, redoing colored headers to divide below, fixes to [`739e1cb`](https://github.com/fomantic/Fomantic-UI/commit/739e1cbffc42699f2f7851e82f9b339ac6c13e21)
- Build and version uptick [`ab5fd15`](https://github.com/fomantic/Fomantic-UI/commit/ab5fd157be9e4c99d409be7430635051570d45c2)
- Adds test coverage for all of javascript modules [`639ee62`](https://github.com/fomantic/Fomantic-UI/commit/639ee62b784ffa519f6eae5601ed5336b6c276cc)
- Repackages files and version uptick to 0.10.2 [`8714d7b`](https://github.com/fomantic/Fomantic-UI/commit/8714d7bfae3d4d2476e6e6fdde53a619115be78b)
- Fix overlap on basic grouped buttons so that hovered element always appears on top, fixes to progress docs [`914d262`](https://github.com/fomantic/Fomantic-UI/commit/914d2622ca0ce0c5cacd91a58bb449d9615b19de)
- Major updates to segment, header, table. [`ce405c6`](https://github.com/fomantic/Fomantic-UI/commit/ce405c60180ce018dc8b75d5d3b52f91bc759f43)
- removes commented module definition until can rewrite with latest code [`9d69172`](https://github.com/fomantic/Fomantic-UI/commit/9d691724e1e8dd725b633c9f48c5d2e9aff17883)
- Updates form validation features and docs [`8314297`](https://github.com/fomantic/Fomantic-UI/commit/83142970e92838365708e91bf217c054156fed96)
- Updates gruntfile [`df44bac`](https://github.com/fomantic/Fomantic-UI/commit/df44bac39b9bf0908f90ba372faa51911d3ea124)
- Rebuild files [`9544933`](https://github.com/fomantic/Fomantic-UI/commit/954493353f0c61aa3567cdaf20693bf39c88658a)
- Fix mobile padding [`7ef4110`](https://github.com/fomantic/Fomantic-UI/commit/7ef41104da5dec159c3593a04bfdcf5203e0a92c)
- Add more examples to homepage [`966e354`](https://github.com/fomantic/Fomantic-UI/commit/966e354bbc8c0e4dcdcd33093fb5e27078ba00df)
- Adds sticky module [`12da803`](https://github.com/fomantic/Fomantic-UI/commit/12da80344061670f461e17c88940fc51da808628)
- modules: iteration on docs [`6b145c2`](https://github.com/fomantic/Fomantic-UI/commit/6b145c23f52259c2544649cf298791f6d2ba33d9)
- finished form validation [`55b3712`](https://github.com/fomantic/Fomantic-UI/commit/55b3712847ea06ed28b5bf5a8b7b7bd6ee022c98)
- Rebuild files [`6e07d1b`](https://github.com/fomantic/Fomantic-UI/commit/6e07d1b14c1c98dfb64a86f437ecbe93ac673554)
- Gets progress module to a point where it is ready to be published [`41f2d01`](https://github.com/fomantic/Fomantic-UI/commit/41f2d0123ae372755d1089f8b5952f1dff3b0685)
- Partially converted menu variables [`95b8802`](https://github.com/fomantic/Fomantic-UI/commit/95b88026e510c76ad2b0bf43efca2bfd3afb8502)
- Tweaks for undocumented nag component, add indicators for incomplete components to menu, updating incomplete component docs [`ad6c5ed`](https://github.com/fomantic/Fomantic-UI/commit/ad6c5eddde0b6f01fc964c29ebac376b3a6a9ed8)
- Adds more sidebar examples, adds css technique for fixed position [`9920b85`](https://github.com/fomantic/Fomantic-UI/commit/9920b8546f2570eff75e514032383f182354a98b)
- Iteration on buttons [`d373f1c`](https://github.com/fomantic/Fomantic-UI/commit/d373f1c3e4e4d2974c9e5a05209713fd1efa4348)
- #396, add word order dependency to all grid variations with multiple words [`18106ae`](https://github.com/fomantic/Fomantic-UI/commit/18106aee384fe8ac1781a3029af2f2035f2f2146)
- Update home examples so they work with 1.0 [`301744b`](https://github.com/fomantic/Fomantic-UI/commit/301744b32a1d77b41ffdc5e10e4625a0662c6570)
- comitting failed 3dtransform attempt for posterity [`9751764`](https://github.com/fomantic/Fomantic-UI/commit/97517646bc3fe75940e09e271f16cdf494913cec)
- New input stylings and other things [`a7aafe4`](https://github.com/fomantic/Fomantic-UI/commit/a7aafe47657d8544fa2535c79cc9debdcd1d58f0)
- Fixes to docs [`7ae8f77`](https://github.com/fomantic/Fomantic-UI/commit/7ae8f777a1dfda5fefc6bb88b7b0d4ec75fd27f4)
- Updates all checkbox examples to use new style [`8a1e2e5`](https://github.com/fomantic/Fomantic-UI/commit/8a1e2e5229c82ff5c6699a419fe47ae655726d66)
- adds new files missing from git. [`2a364ce`](https://github.com/fomantic/Fomantic-UI/commit/2a364ce96c6aaffa85086224715ded3cbde64836)
- build and uptick [`f5cda7d`](https://github.com/fomantic/Fomantic-UI/commit/f5cda7d4c68b87a472412d95f18d7a27e36db840)
- fixes issue with some files missing overrides, begins adding output grunt task [`19e8a8c`](https://github.com/fomantic/Fomantic-UI/commit/19e8a8ce1919919b8af19db08848a1fc86e618dd)
- Adds site definition, adds button margins, fixes and new variables [`d953c53`](https://github.com/fomantic/Fomantic-UI/commit/d953c5369e10a83c46aead2835d2e07b97daaa4e)
- Fixes bug in activate class on checkbox [`fe33570`](https://github.com/fomantic/Fomantic-UI/commit/fe335709199056c8ecef3e860da376f2a4d5d519)
- adds new source files from docs [`ea6e507`](https://github.com/fomantic/Fomantic-UI/commit/ea6e507df56b8ccac5b574e3755486d144912dfd)
- Updates commented module pattern, moves spec json files into appropriate [`23706d1`](https://github.com/fomantic/Fomantic-UI/commit/23706d1e7c40f317c3a45ab6d6dc6660669c4702)
- Bug fixes for grid, popup, adds visibility module [`6bc576e`](https://github.com/fomantic/Fomantic-UI/commit/6bc576e4311966c52bd45ba24602bee83a6b4520)
- Fixes to label/table [`7742e62`](https://github.com/fomantic/Fomantic-UI/commit/7742e626a9af53554f3b58abc7260b240a12fe08)
- moves examples into release [`a00d893`](https://github.com/fomantic/Fomantic-UI/commit/a00d8938a8823c44d7b05fce76cc941fc030d284)
- Several fixes for ui list, formatting changes. Redid list documentation [`4d0b8e5`](https://github.com/fomantic/Fomantic-UI/commit/4d0b8e565ed9ae8869d260ca8175edaabb8dfdcb)
- iteration on docs [`3761273`](https://github.com/fomantic/Fomantic-UI/commit/37612730d68e05adf07178abc0c5b685470df61b)
- begin importing font-awesome [`50ef73c`](https://github.com/fomantic/Fomantic-UI/commit/50ef73c00a7318ebdeb7e354ab3d6208f6d87d78)
- rebuilds package and updates version [`8b1f8ba`](https://github.com/fomantic/Fomantic-UI/commit/8b1f8badcf53b5bfb5d0efd989844c228086427f)
- Adds more variables to menu, continuing to iterate on themeing [`a80fe92`](https://github.com/fomantic/Fomantic-UI/commit/a80fe922813c0943d4382d3ce81e9ae1f988fd06)
- Iterating on variables in menu/button and themes [`d521324`](https://github.com/fomantic/Fomantic-UI/commit/d5213249400c44738a0ed7800d798af51c83a628)
- Dropdown: Fixes positioning, adds example of icon toolbar. Fixes destroy method [`ee629e5`](https://github.com/fomantic/Fomantic-UI/commit/ee629e5f1a32ba6f767624124ba8839f61e1c671)
- Builds version 0.12.3 and updates release notes [`5298489`](https://github.com/fomantic/Fomantic-UI/commit/5298489e2caedd723885d8ae03e941ca774526e3)
- Modifies watch tasks, fixes paths in grunt [`12f9a03`](https://github.com/fomantic/Fomantic-UI/commit/12f9a039a7d5f1e0834736e25da11ab4443eb075)
- Code samples should now automatically resize when browser resizes, code samples now generate on first mousemove so as to avoid changes in html markup from interacting with examples [`74fe4a2`](https://github.com/fomantic/Fomantic-UI/commit/74fe4a28d7963f79f11a69237d3ed76d7095aaf3)
- Rebuild files for beta docs [`20663f7`](https://github.com/fomantic/Fomantic-UI/commit/20663f7b66fe5f480fe6686840257ad6dc3ee9b8)
- Move section specific css into separate files [`8f7e0a9`](https://github.com/fomantic/Fomantic-UI/commit/8f7e0a9a1948d192b042e02b90ae42e34447365e)
- Adds travel distance for shadow, removes shadow by default [`fa911cc`](https://github.com/fomantic/Fomantic-UI/commit/fa911cc290796b8adb0714e585a5137aeaee1346)
- adding types of actions to dropdowns + more functionality [`5f15c16`](https://github.com/fomantic/Fomantic-UI/commit/5f15c164c3c56ff71f5ad0f7e9b845b2643153eb)
- Version uptick and build [`7bcb150`](https://github.com/fomantic/Fomantic-UI/commit/7bcb150e042f1f50a1ce815b93c6ae6ed3010b67)
- Extends dropdown to set default form value, more fixes [`4d0bfb2`](https://github.com/fomantic/Fomantic-UI/commit/4d0bfb2ef68eb8626defb73fd21a37d9c52e7d47)
- Tab: begin tab documentation [`1efb58c`](https://github.com/fomantic/Fomantic-UI/commit/1efb58c31fca7bc012f6acfc404899420b19ab63)
- Triaging some bugs, adding homepage animation stops when out of view [`6c7f3b8`](https://github.com/fomantic/Fomantic-UI/commit/6c7f3b8ce6804e73ece8706e626d9adc46eec2de)
- Begin work on customizer [`b7d243c`](https://github.com/fomantic/Fomantic-UI/commit/b7d243c1af49e47f38b8704ad11778f337264c31)
- iteration on button variables [`542d206`](https://github.com/fomantic/Fomantic-UI/commit/542d20651c1a37ff28ddcee8f552710a013c5cb8)
- Fixes to table, fixes to labels, segment fixes, added button json spec [`d2eb894`](https://github.com/fomantic/Fomantic-UI/commit/d2eb8947d57c251792f76c37fcad9efe870cb33c)
- Finishing colored row/columns [`682a723`](https://github.com/fomantic/Fomantic-UI/commit/682a7231ed6dbcad001493e3174e864a4807f84f)
- fixes shape examples [`26259e9`](https://github.com/fomantic/Fomantic-UI/commit/26259e98daa75dae4ddc653b558a882dd1e26306)
- Package and rebuild [`84ec273`](https://github.com/fomantic/Fomantic-UI/commit/84ec273d8ace3c39874f8d4aa47e1f221f7e3121)
- Adds basic colored buttons, lightens light colors [`ca5a4f3`](https://github.com/fomantic/Fomantic-UI/commit/ca5a4f3055de21579be78e9ccc0bd67809d54e6c)
- A lot of indecisive work on homepage [`b0dbdfe`](https://github.com/fomantic/Fomantic-UI/commit/b0dbdfe5a25ae6d40b2777011a259b5f0a13b563)
- Adds back in modal [`c2c3ec5`](https://github.com/fomantic/Fomantic-UI/commit/c2c3ec5c558488c6cde6be4b5439f6809b8fac6a)
- Updates nag, tab. Fixes body end tag on some docs [`d907e76`](https://github.com/fomantic/Fomantic-UI/commit/d907e762fd2bcf699929a99c3f47fdb20f7e7752)
- Version uptick and package building [`fa114f2`](https://github.com/fomantic/Fomantic-UI/commit/fa114f2c43d81db1eaa679c8eeb8c13ea06b9b0e)
- Finishes homepage example [`1295e35`](https://github.com/fomantic/Fomantic-UI/commit/1295e35a30f5cae7c7545f8dc251662526ca2c56)
- fix to floated items in menu, other fixes to docs [`8ed2b7c`](https://github.com/fomantic/Fomantic-UI/commit/8ed2b7c2d577e248e266199cde615fed81ad91d2)
- Responsive grids are now deprecated, all page grids are now responsive. [`60c00a6`](https://github.com/fomantic/Fomantic-UI/commit/60c00a60783132edb48c987c357c783a67224c17)
- Updates release notes and builds [`f1c9203`](https://github.com/fomantic/Fomantic-UI/commit/f1c92035349aa967a22a9f52fb19a3474a9916e7)
- Fixes to localization modal, progress [`2149998`](https://github.com/fomantic/Fomantic-UI/commit/21499982cbef844e3f8d3c2ca1ef0879d15c0629)
- Rewrite of sticky's crucial 'stick' function to be more coherent, deal with scrolling better. Fixes to grid/menu/list. Demo page footer [`1758250`](https://github.com/fomantic/Fomantic-UI/commit/1758250f399de14afcc60c3fc7081ec16cac3b23)
- Add ui rail, begin debug of sticky modules on docs [`33367b9`](https://github.com/fomantic/Fomantic-UI/commit/33367b9b38bcaa0c18137e075ddd117aa1942e6c)
- Packages version 0.12.4 and creates release notes [`6092478`](https://github.com/fomantic/Fomantic-UI/commit/6092478ad6f6284e0003ca94b4f214c0512801f7)
- adds tab draft docs [`02e2204`](https://github.com/fomantic/Fomantic-UI/commit/02e220490e6b5ddba77eeb9d01dc91f3a8d1bc94)
- Fixes for responsive style on modal, issues with swapping between fixed and absolutely positioned modal [`fe420da`](https://github.com/fomantic/Fomantic-UI/commit/fe420da6c50baa3b76a70f1794adcf180c1ca8f8)
- Finish homepage mobile tweaks [`a0aac4e`](https://github.com/fomantic/Fomantic-UI/commit/a0aac4e92da0ef4d028504464ed1dea56d698249)
- Fix issues with transition docs [`157bd3d`](https://github.com/fomantic/Fomantic-UI/commit/157bd3dc6092929e004cb5c37362e67091120345)
- Attempting to fix min-size issues with selection dropdown [`cd2a39a`](https://github.com/fomantic/Fomantic-UI/commit/cd2a39ac7ad42a55879981a3ec7dca6acafa9e2c)
- Shapes: working on example for shapes [`b33867f`](https://github.com/fomantic/Fomantic-UI/commit/b33867ff22ac5e7379816cb6cab8351353234677)
- Remove excess icons, finish homepage tweaks [`0a270a5`](https://github.com/fomantic/Fomantic-UI/commit/0a270a5d55d9be9ff063dab18bec000239c9043d)
- adds sexy rotating arrows to accordions, renames carets to triangles in icon font [`ad0e9e8`](https://github.com/fomantic/Fomantic-UI/commit/ad0e9e83b51b992b27b276475f8f03df9c58a8b1)
- Adds lots of docs for styleguide, first draft [`2bbb156`](https://github.com/fomantic/Fomantic-UI/commit/2bbb156db52b1b25502c9d75162a5a896662b90a)
- Github button theme [`5884a4b`](https://github.com/fomantic/Fomantic-UI/commit/5884a4b3e9ec4903bf7f25dbe226c96e56d1e7a8)
- updates shape with new high res images [`b061ebe`](https://github.com/fomantic/Fomantic-UI/commit/b061ebe6bb8a96f4dd7d881bb48dc228542c7061)
- Reverts menu system to sidr, too many overflow issues with using faked [`8855220`](https://github.com/fomantic/Fomantic-UI/commit/8855220d653ea00b8b0204316b0dd181658d8754)
- rebuilds package and upticks version [`826bfe7`](https://github.com/fomantic/Fomantic-UI/commit/826bfe795f3f53ba39d83ad45a8161215fd07423)
- additional test helpers [`aea7a22`](https://github.com/fomantic/Fomantic-UI/commit/aea7a22a8d892e39a626788cb8ac7e721d6fa55a)
- working on fixing sidebar with new menu [`26c2fa8`](https://github.com/fomantic/Fomantic-UI/commit/26c2fa850e3254ac5515f2552805ce0efb6b4790)
- Adds definition style example to tables, fixes and adds examples of [`76a30be`](https://github.com/fomantic/Fomantic-UI/commit/76a30beef9128ff12ff15a247ffe9c212a4f546d)
- Begin writing of css and style guide [`81349d7`](https://github.com/fomantic/Fomantic-UI/commit/81349d711a68e1d47b1f02dbaf1107b758cbe890)
- Rewrite of checkbox, new styles, css variables, font file embeds for legitness [`a30baa3`](https://github.com/fomantic/Fomantic-UI/commit/a30baa3bb015a3d7c4fe1aab833ec1242f137800)
- Complete rewrite of transition module, adds requestanimationframe, more granular behavior control, and caching optimizations for display/animation lookup [`b80c3a5`](https://github.com/fomantic/Fomantic-UI/commit/b80c3a5231207ffd926541ca31ce8b705d9294bc)
- Adds feed example starter [`dabbfa4`](https://github.com/fomantic/Fomantic-UI/commit/dabbfa488b708d44eb7f14a9a563c6a8e8adb909)
- Updates to the kitchen sinks [`c262792`](https://github.com/fomantic/Fomantic-UI/commit/c2627927ec466080af67dba8b54fd7dc8f46ef91)
- checks in dropdown changes from iphone branch [`a84d57d`](https://github.com/fomantic/Fomantic-UI/commit/a84d57dcaccdb8a9389e0de1bea504cb5f79a512)
- Fixes some issues with grids insided of grids, fixes issues with header [`0001e9d`](https://github.com/fomantic/Fomantic-UI/commit/0001e9d7483efa820f105ba883c4ac9505240dc0)
- Adds option of invoking methods with either spaces or dot notation. fixes tabs to allow for refreshing current tab [`01c25a0`](https://github.com/fomantic/Fomantic-UI/commit/01c25a093600fa41e585b5539c86c5f779b60d8b)
- Add stubs for several new UI components [`53df215`](https://github.com/fomantic/Fomantic-UI/commit/53df2153d8d0e3d7d654f53dfe508fe40c1f3ebf)
- Add country example, fix filtered to be removed after hide [`23ea44a`](https://github.com/fomantic/Fomantic-UI/commit/23ea44ac148162da5cbab5de1a95ceeaa6229d3a)
- cleans up docs on accordion settings [`bd65c26`](https://github.com/fomantic/Fomantic-UI/commit/bd65c2622e721c10e16f25c930feb62f1428dd17)
- Fixes some formatting on grid/list [`e14b9c3`](https://github.com/fomantic/Fomantic-UI/commit/e14b9c33694c62f13352219a856def9de12fb11f)
- Build and uptick [`43271a9`](https://github.com/fomantic/Fomantic-UI/commit/43271a9337f34cb211535da3d282f8b288b2e4f1)
- Removes animation-direction, adds in transitions for both directions for safari support [`bc865f0`](https://github.com/fomantic/Fomantic-UI/commit/bc865f0c8c050ca3bb8e11dc5d0fc7e417c83368)
- Adds docs for new changes to checkbox, table [`e0a8326`](https://github.com/fomantic/Fomantic-UI/commit/e0a8326118f2a8ae3039e80ee54974d0587a8a91)
- continuing to fix ui input [`8029035`](https://github.com/fomantic/Fomantic-UI/commit/80290352b9c625349a8f0d91dac253780fa7b47d)
- Fix release notes link [`959c93d`](https://github.com/fomantic/Fomantic-UI/commit/959c93d96c9d9784be4bec6cc8800326f3e409f1)
- Adds proper folder cleaning to grunt to avoid issues with changing branches causing orphaned files, adds examples to rtl [`ccd3df1`](https://github.com/fomantic/Fomantic-UI/commit/ccd3df1c8dc98d954c2aec285d667ae8e81f14cc)
- adds code highlighting and authoring with ACE editor [`72dfb0e`](https://github.com/fomantic/Fomantic-UI/commit/72dfb0e9fa068d00405b417699433ba0b243036d)
- Update build [`21870dc`](https://github.com/fomantic/Fomantic-UI/commit/21870dca52b53f9f8c6eb41d0712d7843ddbbb0b)
- more dropdown examples, tweaks to code [`459c5c7`](https://github.com/fomantic/Fomantic-UI/commit/459c5c70e839e07e854e8af690e2c138efe2fa07)
- Updates to homepage [`d471f61`](https://github.com/fomantic/Fomantic-UI/commit/d471f611cb3998a2964ec9f440a67d91292da5a3)
- updates invoke to never return the function called, adds hide dimmer to modal [`e1c8d11`](https://github.com/fomantic/Fomantic-UI/commit/e1c8d1170affd227623dc07cfea609a7cc319670)
- Begin work on global variable list and starting to replace variables in button.less [`911ca00`](https://github.com/fomantic/Fomantic-UI/commit/911ca00dce11bc0dd557131dd1d216f7e467ba41)
- Remove definition button from wrong pages [`dacbfb6`](https://github.com/fomantic/Fomantic-UI/commit/dacbfb61c55e0d2695c8934d8580537df6942a42)
- Finished &lt;select&gt; generation for searchable dropdowns, bug fixes, docs changes [`f2d7d0c`](https://github.com/fomantic/Fomantic-UI/commit/f2d7d0c2446485d540b07b1d70154419bd1d34b6)
- Fixes invoke function in all modules to avoid instance rewrite outside of scope [`56a621d`](https://github.com/fomantic/Fomantic-UI/commit/56a621d60aad3005d5e5821e4922b4d3839496c8)
- language changes, sidebar fixes [`a486469`](https://github.com/fomantic/Fomantic-UI/commit/a486469211b3a99bf75c48afcf46292dde0f4776)
- Rebuild files for beta [`fe2647c`](https://github.com/fomantic/Fomantic-UI/commit/fe2647cd76e71197a0914cf560b568a0012bd9d5)
- modal fixes for css animation and other stuff [`184ad5a`](https://github.com/fomantic/Fomantic-UI/commit/184ad5adbc219d0340261efa6490052bfc724143)
- Fix advertisement overflow on mobile [`e19e801`](https://github.com/fomantic/Fomantic-UI/commit/e19e80173ebaeedc1c952f385a4c3e34e758fe69)
- Solidfying format of usage/settings tabs of module. Beginning verification all settings objects and behavior lists are up to date [`9831699`](https://github.com/fomantic/Fomantic-UI/commit/983169980fc86dc00fa99230bd540c0241084f89)
- rebuilds [`9aed109`](https://github.com/fomantic/Fomantic-UI/commit/9aed109da90345e91bc15693d73f1275575efbc1)
- Updates ACE editor [`1c57854`](https://github.com/fomantic/Fomantic-UI/commit/1c57854a5dc58ba57214c4957050002d1df1ad99)
- Updates to checkbox [`5565a4a`](https://github.com/fomantic/Fomantic-UI/commit/5565a4a22518bb44a5b5bea9327fd999bd94bcb1)
- Updating modal/button variable defaults [`70ec2d9`](https://github.com/fomantic/Fomantic-UI/commit/70ec2d9e1f5fcbc9e2471464c9ca29c3a139979b)
- working on homepage example [`513c182`](https://github.com/fomantic/Fomantic-UI/commit/513c1828c5ea3520da4082a90588583df32c588a)
- Fixes to progress bar [`33068c4`](https://github.com/fomantic/Fomantic-UI/commit/33068c4ddb16f0c4d73447df8cfd6018d2ad38fe)
- Adds tabs to icons, fixes some doc text [`9c3dbd4`](https://github.com/fomantic/Fomantic-UI/commit/9c3dbd4a9bd6b08ac3e1ea2ff83372ee7d5930bf)
- removes box shadow from small sizes [`2512678`](https://github.com/fomantic/Fomantic-UI/commit/2512678168f033cb5abdb3e3c5958ce2e01fc502)
- updates checkbox to include formatting for both inline labels and labels outside [`ae8c754`](https://github.com/fomantic/Fomantic-UI/commit/ae8c7540124bca00751383dd34b9783c29f54ae5)
- Adds callbacks for reverse conditions in visibility, finish nav menus, fixes for sticky. Fix card size to fit on mobile [`d2c7d71`](https://github.com/fomantic/Fomantic-UI/commit/d2c7d7193dde1436227b6d54aea3973d61d9992a)
- preserves variable name styles for dropdown [`b4636cb`](https://github.com/fomantic/Fomantic-UI/commit/b4636cb1bc043974163d9f83304bea67973a5cba)
- Add missing theme to build [`fffe4e5`](https://github.com/fomantic/Fomantic-UI/commit/fffe4e59f691646a3cdb0182a71e5d7869232b57)
- Fixes rating example [`efc073e`](https://github.com/fomantic/Fomantic-UI/commit/efc073e9764e909a5e2597173fb1af015afb9e72)
- table: formatting table for flat [`f93cf13`](https://github.com/fomantic/Fomantic-UI/commit/f93cf131f011fe2ca9dfbd2ca4dec301c386e140)
- Add ability for accordions to open element from jq object and not just integer index, adds flat theme for forms, breaks out several form variables into new variables [`3bc0131`](https://github.com/fomantic/Fomantic-UI/commit/3bc0131d2854b1ce86ab1cd303721923efdc4c74)
- Big upgrades to checkbox, attach events, read-only, disabled, dom mutations [`2448b1f`](https://github.com/fomantic/Fomantic-UI/commit/2448b1f45a571a307d406f4196f94902101b17e6)
- Rebuilds files for beta docs [`9c0bbda`](https://github.com/fomantic/Fomantic-UI/commit/9c0bbda58ef0d027251ea4cc444b6ff8482db621)
- Remove tertiary colors, update dropdown vars [`8a54c1e`](https://github.com/fomantic/Fomantic-UI/commit/8a54c1ebb93852e6ff4788a1cb5baa1c23c421dd)
- adds behavior/settings documentation to transition [`0ba6a87`](https://github.com/fomantic/Fomantic-UI/commit/0ba6a87fb950a555a32b684053e1bc237cef8bd0)
- updates docs for button/grid [`aa93191`](https://github.com/fomantic/Fomantic-UI/commit/aa93191dae2fbd09f341eceb387565313de6278f)
- updates version and builds packages [`1166a3a`](https://github.com/fomantic/Fomantic-UI/commit/1166a3ac61fc830b0c227fa603069c4b685150c1)
- Fixes sidebar direction issues [`c67d97d`](https://github.com/fomantic/Fomantic-UI/commit/c67d97d9fa9083f8f13b8fc9200acb60d65e62a4)
- fixes false responses from invocation not reeturning response [`e3284fd`](https://github.com/fomantic/Fomantic-UI/commit/e3284fdd39fe8a9e40b1fa161e45c612e463dba7)
- More examples, and more themes [`a810d65`](https://github.com/fomantic/Fomantic-UI/commit/a810d654840091e5583fe4dcf1216833f8722717)
- Segment: Adds LESS variables to segment [`58959a5`](https://github.com/fomantic/Fomantic-UI/commit/58959a5c15d44c8b82cb65a3577c175b07a0f325)
- Fixes to transition on inline-block element transitions [`af1eb0e`](https://github.com/fomantic/Fomantic-UI/commit/af1eb0ec890342c7110e97e8242c5c23124f7149)
- transition buildP [`4305f72`](https://github.com/fomantic/Fomantic-UI/commit/4305f7232febeed02eb45759db05f434c7408ac9)
- updates columns to sixteen [`f38d8c7`](https://github.com/fomantic/Fomantic-UI/commit/f38d8c74a3abdeb84b6f98e1471522550577dbba)
- adds responsive styles to modal, collapsing when mobile, keeping 5% gutters on responsive grid all other sizes [`bc19bf6`](https://github.com/fomantic/Fomantic-UI/commit/bc19bf66cb9d1edf31abc9ccf1a0e35fd537da1f)
- Moves gruntfile to top of project, adds testing to package.js for travis [`2f279aa`](https://github.com/fomantic/Fomantic-UI/commit/2f279aa589c4fd2ddcb89faecd521f2a05ce834b)
- adds circular icons to inputs, fixes circular inheritance. fixes  #51 [`558f81f`](https://github.com/fomantic/Fomantic-UI/commit/558f81f53153ab18bc61b83dd0e28e9273cc45b9)
- Fixes link item variation [`25bd920`](https://github.com/fomantic/Fomantic-UI/commit/25bd920f615f86e5af6327e74c828881688471bb)
- fixes dropdown icon fuck up [`71a125e`](https://github.com/fomantic/Fomantic-UI/commit/71a125e394db01f0c00c094f0f609c58224d80ed)
- The great button escapade of friday [`7c1b82f`](https://github.com/fomantic/Fomantic-UI/commit/7c1b82f1e2391580aa475c03d111ea832e7942ea)
- Adds fluid enhancement to accordion, cleans up css comments, fixing #167 [`f404220`](https://github.com/fomantic/Fomantic-UI/commit/f4042201244544967868b33b588bd529f6d40765)
- weekend updates [`cd94238`](https://github.com/fomantic/Fomantic-UI/commit/cd9423827ef6947eec84eedf8a6a67a3d3253f8f)
- adds code example style [`f499919`](https://github.com/fomantic/Fomantic-UI/commit/f4999197a9662b11779ceb287eb1ebde7b303327)
- Adds active state and active state examples for button [`d9c959d`](https://github.com/fomantic/Fomantic-UI/commit/d9c959d016a87b676117760cf7f887eceb5e0eac)
- Adding more grid documentation [`f4523de`](https://github.com/fomantic/Fomantic-UI/commit/f4523dea41ef79e904947817e8a47a9eb81a1361)
- builds and version uptick [`521279a`](https://github.com/fomantic/Fomantic-UI/commit/521279ab17ee4ebd8e9dd0763564c64ad851586c)
- updates getting started docs [`05c76a6`](https://github.com/fomantic/Fomantic-UI/commit/05c76a6d3194d2d076e7c2c3f18f5c7e0af6703f)
- Got that ish perfect [`72ce657`](https://github.com/fomantic/Fomantic-UI/commit/72ce657ffa368290b4b12bf3241b1f38234b885a)
- fixes to dropdown, hiding other dropdowns when open [`49a8755`](https://github.com/fomantic/Fomantic-UI/commit/49a87557a3575f4a0c2668f9fcdd071009cd9b2c)
- rebuild packages [`f205f48`](https://github.com/fomantic/Fomantic-UI/commit/f205f48c1f0e6faf63107ceaf710dc7eb11fb2e1)
- Rebuild files for deploy [`d5db942`](https://github.com/fomantic/Fomantic-UI/commit/d5db94277e6c43b8bfeac8c8eb8ee1eb7be6e5a5)
- adds flipped and rotated variations to icons [`b3b9459`](https://github.com/fomantic/Fomantic-UI/commit/b3b9459d25cbcbd7674965d322a7545e5a01f137)
- Homepage good enough to publish for now.. [`29a10aa`](https://github.com/fomantic/Fomantic-UI/commit/29a10aa367827712034ebca5e72ae40458d3405d)
- Swaps hover/down color to lighten [`2e79701`](https://github.com/fomantic/Fomantic-UI/commit/2e79701187ed0f5b6d4e51aa407975d32c40de0f)
- Fixes on all modules where settings were shared across elements initialized at the same time instead of each module [`9b8d3bd`](https://github.com/fomantic/Fomantic-UI/commit/9b8d3bd55e3083d78648f72eae517fe59312c65b)
- rebuilds zip, adds prerelease ver to homepage [`8351ce0`](https://github.com/fomantic/Fomantic-UI/commit/8351ce007e3f826bd58e199169446f52f795e7c2)
- rebuilds package [`d685f1a`](https://github.com/fomantic/Fomantic-UI/commit/d685f1a716e7ddaf840b262f90fae258d7ca57ed)
- completion of viisibility module [`9c49fa4`](https://github.com/fomantic/Fomantic-UI/commit/9c49fa433547cc9d66a96182376a0f5b97e0f665)
- fixes rating padding [`099e71a`](https://github.com/fomantic/Fomantic-UI/commit/099e71a6fde09fbe0571cfbcfeb8a69a87bfa158)
- Additions to homepage design [`0f5f63b`](https://github.com/fomantic/Fomantic-UI/commit/0f5f63b1abd9adc043a7dd1dff20968e707c30c9)
- Fixes issue where camelcase methods were not being returned if first word matched a method [`4ea8e2e`](https://github.com/fomantic/Fomantic-UI/commit/4ea8e2ed4c94684bea0a4995050af2adf64f9105)
- Add Contributor License Agreement [`ecedb7a`](https://github.com/fomantic/Fomantic-UI/commit/ecedb7af1d2b1b89945bc3444c9507bd6af199c2)
- adds changes to release [`5297d3e`](https://github.com/fomantic/Fomantic-UI/commit/5297d3ea65860ba5c4f0ffd56d605a01d3f473f4)
- Additions to button and sidebar docs [`9b7e5e3`](https://github.com/fomantic/Fomantic-UI/commit/9b7e5e354b1b3d2f046a96c3b61f154fee5519b6)
- moves example handlers to appropriate location, fixes swap style button [`0a19da0`](https://github.com/fomantic/Fomantic-UI/commit/0a19da0e61afb92c1da86a69eb3cbe3064c5500f)
- Adds more comments to grunt file, fixes comment banners and some [`adeef8f`](https://github.com/fomantic/Fomantic-UI/commit/adeef8ff9cd47131829675144f6ddcc81d83c93e)
- added animation queueing to shape plugin [`f831f17`](https://github.com/fomantic/Fomantic-UI/commit/f831f17fadca577c6c2a010689c325210d72d2f2)
- Lots of fixes, new homepage [`3663a59`](https://github.com/fomantic/Fomantic-UI/commit/3663a5930babddca9eb10ac297119ecc22f218eb)
- Adds release notes and repackages for 0.9.4 [`5ac9161`](https://github.com/fomantic/Fomantic-UI/commit/5ac9161165b4e9b3d6933d5e065962fd48ea3a9f)
- hey hey actually working late at night on this, i must really like it [`d9115b7`](https://github.com/fomantic/Fomantic-UI/commit/d9115b7ee9bc821f8c58f6f77f62f73e8cfcaff5)
- updates release notes for next v [`f4d3836`](https://github.com/fomantic/Fomantic-UI/commit/f4d3836bdd02b72332654ff3fbc483c81e9892d1)
- adds attached progress bars and striped bar no longer does active animation [`5c2c389`](https://github.com/fomantic/Fomantic-UI/commit/5c2c38960abb6218111882cfe8fc6aa1d9dd33b3)
- fixes to dropdown docs [`acf30ae`](https://github.com/fomantic/Fomantic-UI/commit/acf30aee0146dfd8e0fbe9d377828a9da238c13e)
- Adds inverted list styles, fixes styling of lists inside horizontal lists [`217dc74`](https://github.com/fomantic/Fomantic-UI/commit/217dc7404da1bd29bd67a38e5a7f218e59e6818d)
- adds settings/behavior docs for sidebar [`7f56c4f`](https://github.com/fomantic/Fomantic-UI/commit/7f56c4f28e0be130e4c8e6167b25bf5c6ca3d65f)
- Update grid docs on colored variations [`b912441`](https://github.com/fomantic/Fomantic-UI/commit/b912441a4d29fd005b500674a7fe207388ce915d)
- support advertisement added to homepage [`c230fc0`](https://github.com/fomantic/Fomantic-UI/commit/c230fc039d258419fc216de2bf00e8c9a2e629c7)
- Additional info on dropdown init [`7cf520c`](https://github.com/fomantic/Fomantic-UI/commit/7cf520c0b85c2d1551b529f388c8a23ac0dd7d39)
- rebuilds [`10cb943`](https://github.com/fomantic/Fomantic-UI/commit/10cb94357977854c20c89d6ce6ecd783f1d89624)
- Version uptick [`046c562`](https://github.com/fomantic/Fomantic-UI/commit/046c5623b6e4ab0dc4f18da6d21eea49e2595820)
- Iteration on homepage animations [`beb1689`](https://github.com/fomantic/Fomantic-UI/commit/beb1689b196777a00b0edd3262ecb28f6a383f35)
- Tiered menu: fixes active items to have top border like rest of menus [`0f2d33b`](https://github.com/fomantic/Fomantic-UI/commit/0f2d33bb1c91bb501333d3c41b49e684f4a9a566)
- added side menu [`30f0fbd`](https://github.com/fomantic/Fomantic-UI/commit/30f0fbdf68b05a11de002bf26736979d29370f11)
- Adds active state for inverted buttons [`b8fb332`](https://github.com/fomantic/Fomantic-UI/commit/b8fb3328a36680456402a03396316b650cd6672e)
- Rebuilds package [`005e58f`](https://github.com/fomantic/Fomantic-UI/commit/005e58fed27e716fdbf7d6d778516d21dc138510)
- Add variables for UI Reveal [`98e3db6`](https://github.com/fomantic/Fomantic-UI/commit/98e3db6542629db17b28941d926ac7e3964d8814)
- Fix some layout issues [`97833c4`](https://github.com/fomantic/Fomantic-UI/commit/97833c449c4984e0d4cf61a031358e9bfa12554a)
- Reorder site.variables for easier scannability, adjust highlighted text color [`3f14564`](https://github.com/fomantic/Fomantic-UI/commit/3f14564bfcff4c171a8b564aee234dc2d9e312c9)
- Swaps transition calls to consistent format across modules, looking into issues with dimmer/modal when hiding during show [`05a8671`](https://github.com/fomantic/Fomantic-UI/commit/05a8671fcef1be5ec81cc801cdf0d08d412d5624)
- adds more examples of modules [`6eecbd7`](https://github.com/fomantic/Fomantic-UI/commit/6eecbd7e302d846ef6f46efb439e888002016f60)
- fixes to buttons and headers [`15e87e7`](https://github.com/fomantic/Fomantic-UI/commit/15e87e76259aa9b24d434297cd5c9f5b2f35f5e1)
- adds equal height grid row, and fixes to menu [`ce54c63`](https://github.com/fomantic/Fomantic-UI/commit/ce54c630f80d34ebb0824ea387fb178ac91084ba)
- Add CONTRIBUTING.md file [`ce5a5e1`](https://github.com/fomantic/Fomantic-UI/commit/ce5a5e1476fc4641e0091651a4837f1cb625d8a4)
- Adds localization dropdown, and nag [`c7ed094`](https://github.com/fomantic/Fomantic-UI/commit/c7ed094fdb4343225165ff0a58f67b43d97cfa79)
- Changes grids to allow padding for rowless columns, adds doubling variation [`3e5852e`](https://github.com/fomantic/Fomantic-UI/commit/3e5852e5be1a6065073d3c9881640913bf4ca573)
- rebuilds release [`4e2334a`](https://github.com/fomantic/Fomantic-UI/commit/4e2334a9e12a75dd9dbc1ea5ad12f7eb25e56f44)
- fixes call to invoke [`a511fa4`](https://github.com/fomantic/Fomantic-UI/commit/a511fa40ac58febaadec53494f862d8c34f20ad1)
- Redoes ui definition table as a type, adds much better formatting. Removes classic styles from table and ports to theme [`e8950b6`](https://github.com/fomantic/Fomantic-UI/commit/e8950b6c24b762a9d7060c39abc7385134a9ca2c)
- rebuilds semantic lib with patched changes to dropdown [`e223c82`](https://github.com/fomantic/Fomantic-UI/commit/e223c824ad74ab79f66aa73e1e845c0c6b7884b3)
- fixes some language [`33a2bda`](https://github.com/fomantic/Fomantic-UI/commit/33a2bda19d474b3626c70ca7e7007ee579277a84)
- iteration on forms, and overall conformity of docs [`4b7c06e`](https://github.com/fomantic/Fomantic-UI/commit/4b7c06e6de84dc2f6f44a664535d5ba659eef5fa)
- Adds more attached label styles [`c276634`](https://github.com/fomantic/Fomantic-UI/commit/c276634239eed17323307979d9501543b46e9973)
- rebuilds packages [`249d255`](https://github.com/fomantic/Fomantic-UI/commit/249d255f96789df29120668fe17d5f0aa7ca0c9b)
- Fixes for fixed elements used with sidebars [`a24115c`](https://github.com/fomantic/Fomantic-UI/commit/a24115c4d857c8a18d1d003d6bc61b229f170a25)
- updates release notes and rebuilds [`210b942`](https://github.com/fomantic/Fomantic-UI/commit/210b94261d714f4e6518f103fe9311b9a303d29d)
- Refactors dimmer, adds 3d animation by default [`5f4522c`](https://github.com/fomantic/Fomantic-UI/commit/5f4522c182e98e31df1ae8276bdbe6c013244c7a)
- Fixes image paths, swaps to shaded as default [`4a7524e`](https://github.com/fomantic/Fomantic-UI/commit/4a7524ee3fbcaf9fa08bb78945d3a74871a408e9)
- Add colored row/column variations [`f3097e3`](https://github.com/fomantic/Fomantic-UI/commit/f3097e3d5b3fb75ed6814a796618e9cb1b10a2db)
- Adds LESS variables to images [`7cb9b92`](https://github.com/fomantic/Fomantic-UI/commit/7cb9b92d87ee3e1e57f8384ab0ba773495ed5791)
- Removes container element [`9d8db12`](https://github.com/fomantic/Fomantic-UI/commit/9d8db1205d0d30c7a494c572b58741f8e92c79ab)
- Adds some new button themes [`1012f94`](https://github.com/fomantic/Fomantic-UI/commit/1012f948e95e95fe0aeb1bcaf766426ad4195631)
- Tweaks to vertical steps, docs [`0342517`](https://github.com/fomantic/Fomantic-UI/commit/03425174289520ffa8c09d594288b759e82454b5)
- Refactors modal plugin, modals now have icons auto formatted. Removes selector count from popup [`df0777b`](https://github.com/fomantic/Fomantic-UI/commit/df0777b0daca01e154f4bf3c3a96cb4bf8a8bbae)
- Fixes some doc issues, adds inverted button example [`c6f5537`](https://github.com/fomantic/Fomantic-UI/commit/c6f5537d16f2d639fd3e950555b729c662faf2b4)
- Rework card to be more neutral base theme, add GitHub theme. Fix list selection spacing [`e559707`](https://github.com/fomantic/Fomantic-UI/commit/e559707f89af47bd2e6c6b03c6af434c467ac5f5)
- Adds initial write of container element [`f55520b`](https://github.com/fomantic/Fomantic-UI/commit/f55520b2778fea9457155054e375ac73dfaf432e)
- Retheming of checkbox to use inline font file, and new styles for slider and toggle [`a26ab14`](https://github.com/fomantic/Fomantic-UI/commit/a26ab147439c70d0f4b36b6401f94654dc8039aa)
- Minor update to release [`16f522e`](https://github.com/fomantic/Fomantic-UI/commit/16f522e6bf0d07dbd7b0e323a54d4961d411a028)
- dramatically rewrites watch task to boost doc compile performance [`23698de`](https://github.com/fomantic/Fomantic-UI/commit/23698de03fc212bd64008ac3b75990bd6db09145)
- Real 0.9.5, adds circular segment variation [`391e90b`](https://github.com/fomantic/Fomantic-UI/commit/391e90ba8cf1bcffe47a1b2720a8b41a6717ed34)
- Continuing to fix tertiary buttons [`4d1b784`](https://github.com/fomantic/Fomantic-UI/commit/4d1b7849393b9be3c94dbe64490f225d5fd62a31)
- Adds first demo examples of transition, adds self running code samples [`18692ae`](https://github.com/fomantic/Fomantic-UI/commit/18692aea0931c8aa54e10ebd29e04cf3a88fa104)
- Adds docs for doubling grid, grid changes [`06bd65f`](https://github.com/fomantic/Fomantic-UI/commit/06bd65f44127d24ea7127704addb20cc2da499a6)
- Typo in docs [`9386477`](https://github.com/fomantic/Fomantic-UI/commit/9386477bbd7e3547370354fc95944d6ca22df6f5)
- Have to run, commit msg later [`bf8144c`](https://github.com/fomantic/Fomantic-UI/commit/bf8144c8e81d8fa6fbb66e4faa720d16d1625c2f)
- fixes bug in select dropdown [`32ec2ca`](https://github.com/fomantic/Fomantic-UI/commit/32ec2caac7eab3088596280c576718bb8899b9cc)
- Fixes comment banner repository link [`87b7007`](https://github.com/fomantic/Fomantic-UI/commit/87b7007e4f66807cdfe5c7d9071239890e79285c)
- Iterating on word order dependencies across all UI #396 [`b07fab0`](https://github.com/fomantic/Fomantic-UI/commit/b07fab059a3e89463a1c4ecc02967a408e85ba8e)
- Fixes issues with source not minifying correctly in release, segments up grunt tasks [`00a38f3`](https://github.com/fomantic/Fomantic-UI/commit/00a38f3975d238142eb90d94164389232db8651c)
- Actually fix the language modal not to show twice [`798fbe0`](https://github.com/fomantic/Fomantic-UI/commit/798fbe0e67b00803c4ad61ab0ebc48b1a4c4a7d4)
- adds starter page for dimmer [`566e14b`](https://github.com/fomantic/Fomantic-UI/commit/566e14bace1e2a847189453ea5b1b40cc6f00f8b)
- fixes to responsive layouts [`d4adba8`](https://github.com/fomantic/Fomantic-UI/commit/d4adba8e7dbf29f358f3184b5c20832d908b2413)
- Rebuild and update card examples [`739c361`](https://github.com/fomantic/Fomantic-UI/commit/739c3611a2bbcf50e9a1be1055e09da8adfc13be)
- rebuilds and upticks version [`36504f8`](https://github.com/fomantic/Fomantic-UI/commit/36504f83592fe28b7bbfffede493ef2aa5ded1dd)
- fixing issues with form/input [`8daaf34`](https://github.com/fomantic/Fomantic-UI/commit/8daaf34e2b39b223157b2cca736e0d6ff2159c04)
- Fix feed example [`9fc83fe`](https://github.com/fomantic/Fomantic-UI/commit/9fc83fe758d0490ffd2f1a30752a255a06d0c854)
- Updates menu less slightly to include css with similar rules #553 [`cfb320e`](https://github.com/fomantic/Fomantic-UI/commit/cfb320e44e75063e00ddeed9bdeff00eb28560f7)
- Fixes responsive/ad styling on homepage [`98f08ee`](https://github.com/fomantic/Fomantic-UI/commit/98f08ee37fa1b84b8d27c6f715acb7afb69ec1a5)
- Rewrite of intro docs [`8906cba`](https://github.com/fomantic/Fomantic-UI/commit/8906cba6a607efdb1631d61817c7f7666bb2d9c1)
- Add more examples to grid, fix divided header colors to use header colors [`2eba92e`](https://github.com/fomantic/Fomantic-UI/commit/2eba92ea3589ec043fa0c7a1709db987bad2ac1f)
- updates dimmer docs [`cb52e65`](https://github.com/fomantic/Fomantic-UI/commit/cb52e65fe6419a0b900b6d1a4a160b1f9cac3232)
- completes button variables [`75b047b`](https://github.com/fomantic/Fomantic-UI/commit/75b047b7f4c62f2e14aa9336b622ed8448b95bfc)
- Adds responsive styles for tablet/mobile on item view [`047f900`](https://github.com/fomantic/Fomantic-UI/commit/047f900b45fcef068251fbd6933708edfffc1314)
- Adds indicating progress bar [`0947740`](https://github.com/fomantic/Fomantic-UI/commit/0947740fd520a7a8685b4f19559fecdc55487f0d)
- fixes docs on items, updates item view to fix margins on stackable [`9e1a685`](https://github.com/fomantic/Fomantic-UI/commit/9e1a685bc01c8af9a2746fa223a59736bdb5aca3)
- Adds build docs [`9fd780f`](https://github.com/fomantic/Fomantic-UI/commit/9fd780fb7e1e2229367c1756db066fd224e807b9)
- fixes issues with tabular menu movement on active [`cbaa5df`](https://github.com/fomantic/Fomantic-UI/commit/cbaa5df551e01b15388af5bc5cdb03999d946a28)
- Iterating on header theming [`2d12d33`](https://github.com/fomantic/Fomantic-UI/commit/2d12d33c56d128d46e0db8d58beaaa17bc5c4c04)
- Adds fitted checkbox variation [`c40eab3`](https://github.com/fomantic/Fomantic-UI/commit/c40eab34cec011c2b887d93ea591ff7f121db0fe)
- Additions to docs [`8816a61`](https://github.com/fomantic/Fomantic-UI/commit/8816a610c8aeef2f8ac3ec309159babe25a06a7b)
- Modification to modal to account for changes in transition rewrite [`cdacbab`](https://github.com/fomantic/Fomantic-UI/commit/cdacbab2046d14bee8ecf4aabf43416d618544cb)
- adds link list type, fixes modal docs disappearance [`27941a1`](https://github.com/fomantic/Fomantic-UI/commit/27941a1798ff2e4c10b0ad7ca04ca996acc872c8)
- Adds travel distance to button active state, fixing issues with uneven padding [`7995bd8`](https://github.com/fomantic/Fomantic-UI/commit/7995bd8150f55e4f9acb7011e848645896d169e8)
- Fix doubling stackable grid, text alignment on some elements [`f6b55de`](https://github.com/fomantic/Fomantic-UI/commit/f6b55debf696a704a8a54c6ad553b46eab6fc0b2)
- move karma config to top level [`679abd3`](https://github.com/fomantic/Fomantic-UI/commit/679abd34985686f3fe392c6a63f775d6664903d2)
- horizontal and vertical flips were reversed [`532d6fb`](https://github.com/fomantic/Fomantic-UI/commit/532d6fb6173fd7e0b8a1d3abcbac47e6ce7d1a78)
- late night changes [`3e7d3c7`](https://github.com/fomantic/Fomantic-UI/commit/3e7d3c7c710b3b43a5adc48e536c15f1d2206f23)
- Modal: adds support for multiple visible modals #491 [`4b6b2da`](https://github.com/fomantic/Fomantic-UI/commit/4b6b2dad3a4c7eec51a1488cbd82c35f5030dbe8)
- Fixes issues with alignment sometimes not overriding correctly when included on both column, row, and grid [`10c9a9a`](https://github.com/fomantic/Fomantic-UI/commit/10c9a9a9f121f4c439cf8ec31b6022abfc1f9634)
- adds disabled state for reveal [`8b26d36`](https://github.com/fomantic/Fomantic-UI/commit/8b26d36d9f04988cc038059f103ca1c801f3c3dd)
- Adds stats back in, adds star button to menu, removes definition button [`f43fc04`](https://github.com/fomantic/Fomantic-UI/commit/f43fc044b177ee4857e23e8637dafcec40099d1d)
- changes from live site [`9ed768a`](https://github.com/fomantic/Fomantic-UI/commit/9ed768a0ee870d7e499a0db069d8008adfab0a0f)
- Fixes visibility conditions missing exact equality, fixes divider font size in relative unit, fixes visibility throttle setting, disables API debug by default~ [`41353d6`](https://github.com/fomantic/Fomantic-UI/commit/41353d6194fb0746c0963008b8d2d541031ee307)
- Fixes accordion display issues [`20f9a1a`](https://github.com/fomantic/Fomantic-UI/commit/20f9a1a2e3c52049155c43263ff3002da9b79776)
- updates rating to include fixes and new features [`60abcf8`](https://github.com/fomantic/Fomantic-UI/commit/60abcf8ac73f88b3b41d9cea349f9cadd337e07e)
- modal fixes [`ed4c1fc`](https://github.com/fomantic/Fomantic-UI/commit/ed4c1fc550126eaf6c7342935ee21712ff3187d6)
- button changes, default now dark [`8bc437b`](https://github.com/fomantic/Fomantic-UI/commit/8bc437b09caf1da2daba4520e5610d0842a9d167)
- updates form, dropdown , and accordion docs [`73d28b3`](https://github.com/fomantic/Fomantic-UI/commit/73d28b34de708d8e75f87343cd0ed5069e98ef9e)
- Code samples should now automatically resize when browser resizes, code samples now generate on first mousemove so as to avoid changes in html markup from interacting with examples [`9fedc3b`](https://github.com/fomantic/Fomantic-UI/commit/9fedc3b1687e13ff5a29810a97c4fa8cb8a71f0f)
- compiled build version [`bf5e986`](https://github.com/fomantic/Fomantic-UI/commit/bf5e98606811959f731a9bea1a562c7a89fe96e6)
- fixes bug in testing for transitions in transition.js [`735be91`](https://github.com/fomantic/Fomantic-UI/commit/735be913e3fe4a694f7897a74eeb9038071b54c8)
- updates to documentation [`a4033ee`](https://github.com/fomantic/Fomantic-UI/commit/a4033eeeb0475826b66032c94de7375b0c294ae6)
- Updating doc header to create theme button [`4215da2`](https://github.com/fomantic/Fomantic-UI/commit/4215da2ef4bf795fbe5bd6f5a9bb00f69537fe2c)
- fixes to step display [`402ac20`](https://github.com/fomantic/Fomantic-UI/commit/402ac2040fb3906ec6d4f277de7854e5b20ae4d4)
- first pass variable substitution for headers [`470c22e`](https://github.com/fomantic/Fomantic-UI/commit/470c22e1fcb22737c85315bc3fe4c35b18c1aea8)
- Begin copy writing for contributions [`9a9c4b9`](https://github.com/fomantic/Fomantic-UI/commit/9a9c4b9d0d53e02ebd8a33e97c25e264e6cfabaf)
- reskinning of panel for menus [`93a94f5`](https://github.com/fomantic/Fomantic-UI/commit/93a94f5c90bae909c612bdb7f504f1d79393d82c)
- Updates to sticky menu module [`efafa3a`](https://github.com/fomantic/Fomantic-UI/commit/efafa3ae9b4c0f2df6da7647c4f9614256fd292b)
- Fixes issue with reverse visibility callbacks not firing if normal callback not present [`cdede15`](https://github.com/fomantic/Fomantic-UI/commit/cdede1506ebd1d5530bc29bba5e4ceb61fa0ee51)
- updates a couple typos [`c153b93`](https://github.com/fomantic/Fomantic-UI/commit/c153b9386f280c98a0e7756028f30471cbea59b9)
- fixes issue with determining click target on modal content [`d4c7824`](https://github.com/fomantic/Fomantic-UI/commit/d4c7824576b1a6d53a413bcab3d0037ea4ecd23c)
- Optimizes modal display for mobile [`2f98471`](https://github.com/fomantic/Fomantic-UI/commit/2f984712cba926d14843f098669c14a208cd03e6)
- Added styles for dropdown warning state [`0a28508`](https://github.com/fomantic/Fomantic-UI/commit/0a28508f679632f6b2a728b6ee3b6b77e864a76b)
- Removes important from theme overrides [`3d40e98`](https://github.com/fomantic/Fomantic-UI/commit/3d40e98ae4ba10e55998fbb2739e08162bf49435)
- Update RELEASE NOTES.md [`09aad52`](https://github.com/fomantic/Fomantic-UI/commit/09aad527b18817a2fe3e4159b372be5a847b8084)
- Fix several bugs in inverted tables with celled, disabled content [`1b4ca20`](https://github.com/fomantic/Fomantic-UI/commit/1b4ca20721d57b1fd87b767dec8b9a07d6b07297)
- Add some checkbox example stylings [`28791b2`](https://github.com/fomantic/Fomantic-UI/commit/28791b2b391a09a6edfbf5be8f350a402f0ce8e6)
- Fix avatars in list example [`b61f395`](https://github.com/fomantic/Fomantic-UI/commit/b61f3953ad2b51c0180ea2a2baec7fb1cb4950fe)
- Removes semantic.config from tracked files [`2aa16fb`](https://github.com/fomantic/Fomantic-UI/commit/2aa16fbba8b57725a972c8b399ed9a97443977c0)
- Removes vendor prefixes from checkbox source, adds transform: none to avoid GPU acceleration triggers which might cause rendering issues with radio box circles [`0f742b7`](https://github.com/fomantic/Fomantic-UI/commit/0f742b7f8e8579799c3a843af4f1572f438402aa)
- update to inline fields [`24fbf83`](https://github.com/fomantic/Fomantic-UI/commit/24fbf83a2c25ed971c0dde524764c6b483b96f17)
- Adds attached header style, updates some doc styles [`cbecc88`](https://github.com/fomantic/Fomantic-UI/commit/cbecc8831919275ce2a37fcee077389013a742fe)
- updates dropdown.js to use latest invoke [`0e7c128`](https://github.com/fomantic/Fomantic-UI/commit/0e7c128adba0999a922e76846566d51c5cc4c91c)
- Adds page dimmer text styles, fixes shape not initing, removes logs from transition [`aff57cc`](https://github.com/fomantic/Fomantic-UI/commit/aff57cc2dca9c0008a81e8249488453377736513)
- Adds #570 labeled inputs [`1b489cb`](https://github.com/fomantic/Fomantic-UI/commit/1b489cbde8b3d2fbeb81cd2f91b80bbc9dcfcd4b)
- finish writing dev guide [`b75487d`](https://github.com/fomantic/Fomantic-UI/commit/b75487d544b0c24cf7927923f0da53a4f51d8a9d)
- Finally fixes css animations, fill-mode was being overwritten by using shorthand in other rules [`25ab448`](https://github.com/fomantic/Fomantic-UI/commit/25ab44822fd132c6a2ac880d7cdd2c0d5184ee7a)
- fix similar problems some more [`8534da8`](https://github.com/fomantic/Fomantic-UI/commit/8534da878d351d268d5db2ea9d4b1635eff3624b)
- Adds enhancement #518, option to close nested accordion menus [`0f32fd7`](https://github.com/fomantic/Fomantic-UI/commit/0f32fd7a730ff7d41818957d7461883dc4b41041)
- Updates modal examples to have html [`41d7a25`](https://github.com/fomantic/Fomantic-UI/commit/41d7a250b99f58410752dbd8f244654528a24a6c)
- Adds example test, adds karma config [`4fc93b5`](https://github.com/fomantic/Fomantic-UI/commit/4fc93b5dd850570568ff76ce4dfe5402dc8646d6)
- Continuing to tweak corner label positions, fixes flud input example [`2cc9f06`](https://github.com/fomantic/Fomantic-UI/commit/2cc9f0696b39e27d57de77cc60dffd2d3417234c)
- Fix some dropdown example inits [`df21c1a`](https://github.com/fomantic/Fomantic-UI/commit/df21c1a0eb49578d7c062e60a52b349534f43930)
- Fixing formatting issues in doc [`bcddad5`](https://github.com/fomantic/Fomantic-UI/commit/bcddad568701a535b1eac1fcce8a565fd9a4afe4)
- Updates docs for rating, dropdown [`9c146f6`](https://github.com/fomantic/Fomantic-UI/commit/9c146f6ac61c0a8ed0f293e8c58d2128f55a23aa)
- Switches attached segment/header to border from box-shadow [`5c7d5f1`](https://github.com/fomantic/Fomantic-UI/commit/5c7d5f13d83b25ec93b538f46e75835e1d7c2d98)
- Adds disable/enable to ratings, fixes spacing and other goodness [`db4d495`](https://github.com/fomantic/Fomantic-UI/commit/db4d49508eb3c86dbc3e8dd9c7c34f7de33922d7)
- Add new variables for segment, better explanation of horizontal and vertical segments, additional height of raised segment [`ecb953d`](https://github.com/fomantic/Fomantic-UI/commit/ecb953d0dd3050bb9eac3c4e58822978f4167067)
- iterating on header themes [`b04914c`](https://github.com/fomantic/Fomantic-UI/commit/b04914ca9e14cb7a8463a88676786490c142c0d1)
- Continuing to iterate on theming [`3025f72`](https://github.com/fomantic/Fomantic-UI/commit/3025f72a1e244c0544bf1d28352db7694030b763)
- Fixes github paths to no longer use jlukic [`b7f88bb`](https://github.com/fomantic/Fomantic-UI/commit/b7f88bbf55d2db83af03e59988d40d3cab15839e)
- updates menu and item docs [`a1fafbb`](https://github.com/fomantic/Fomantic-UI/commit/a1fafbb45ee1e38fbf3121431a4ac4b47f4b71fd)
- fixes icon rotation on accordion in chrome [`30b76ae`](https://github.com/fomantic/Fomantic-UI/commit/30b76ae23bb606d4bb110b595a3161387ba3207e)
- Adds collapsing, aligned, attached tables. [`68c5805`](https://github.com/fomantic/Fomantic-UI/commit/68c58055f978248d8cad5b78b107bbada9d89164)
- Adds responsive styles to table [`5fe1240`](https://github.com/fomantic/Fomantic-UI/commit/5fe1240d5d850ca6a9d2d30fd19a013131b3cec2)
- Updates examples for popup [`23b0ab5`](https://github.com/fomantic/Fomantic-UI/commit/23b0ab5dd4934ebd05d2912e5d8b58950f353beb)
- Grunt: Adds docco generation of spec files to grunt build [`bc0386c`](https://github.com/fomantic/Fomantic-UI/commit/bc0386c63f4b1c546f56ea36d4c9685b14f920ff)
- table: removes bolding from pos/neg [`df884e0`](https://github.com/fomantic/Fomantic-UI/commit/df884e050ee0032dd06d1643999f581288d37a13)
- Fixes bug in popup causing variations to be overriden [`237765d`](https://github.com/fomantic/Fomantic-UI/commit/237765df3d8c9f4bd60473b656b4963d4da7af8d)
- updates formatting of form validation docs, modifies definition table to not use outer border [`5548d35`](https://github.com/fomantic/Fomantic-UI/commit/5548d3592ace1fc5b1fac43230677287d6d8b255)
- tweaks to corner labels [`6a21d09`](https://github.com/fomantic/Fomantic-UI/commit/6a21d09cb439e04ba7b7b1cf82f461b9eda4a4f0)
- Fixes regex matching on css variables [`1357ccf`](https://github.com/fomantic/Fomantic-UI/commit/1357ccf882ea8c1fd30345299b1a01641aa22999)
- Updates semantic.config example to use latest version [`a6d5902`](https://github.com/fomantic/Fomantic-UI/commit/a6d59024e8b4ab1ba9ba6ffa9afe07c1ad024658)
- menu, last checkin then hitting hay for real [`ecf8ac0`](https://github.com/fomantic/Fomantic-UI/commit/ecf8ac0ada815f1e9ab58bfc40218a8b281a3bae)
- Adds internally celled grid, adds fixes for divided, and equal height, adds fixes for doubling divided/celled [`3b617b4`](https://github.com/fomantic/Fomantic-UI/commit/3b617b40f835dfb097885bfd69b16178a23744d9)
- Working on solve for IE11 dropdown issues, adding test case [`d772cd8`](https://github.com/fomantic/Fomantic-UI/commit/d772cd85c4400f04e8091805f04de32d8efa98af)
- Continuing to write copy [`d1c77d7`](https://github.com/fomantic/Fomantic-UI/commit/d1c77d72a952ad7b22cdea13c7b12bd3f46a4c1d)
- updates version number, adds release notes, builds package [`f390faf`](https://github.com/fomantic/Fomantic-UI/commit/f390faf20c5e8ffb5f79cc210f3b37f8c1d0b87f)
- Improves queueing efficiency [`4a79213`](https://github.com/fomantic/Fomantic-UI/commit/4a7921398cd9ac1759d744f4be64d3b0b240965b)
- Fixes to examples, remove progress debug [`34d47f0`](https://github.com/fomantic/Fomantic-UI/commit/34d47f046f4f4fc57a8039870817f56b3bf6d4d3)
- Fix progress text multiline flow, make default style more flat, fix some conditions on 100% complete [`514641e`](https://github.com/fomantic/Fomantic-UI/commit/514641ec8d2069ed30d606bc54574d790aa2825c)
- add some HTML5 input-type support / fix date.field append icon / create select.field hability without using dropdown [`642e3d4`](https://github.com/fomantic/Fomantic-UI/commit/642e3d429322c6869f7ead19a6e895505d51ecf2)
- tiered menu: fixes sub menu active item color [`f8f530c`](https://github.com/fomantic/Fomantic-UI/commit/f8f530ca99776b655694fd62e56cf8d0a666045e)
- Remove remaining HTML from CONTRIBUTING.md [`fd2fae5`](https://github.com/fomantic/Fomantic-UI/commit/fd2fae53482a38d6dc640aa66da816d8fbb8eea8)
- Doc: Synchronized icons label and class word order [`441dd63`](https://github.com/fomantic/Fomantic-UI/commit/441dd6344f5b5d8877faa0cfa6dfd9f2ccd530dd)
- removed quotes from keyframes icon-loading [`97e1e6e`](https://github.com/fomantic/Fomantic-UI/commit/97e1e6ea81c6105f4d9bb3961c878c237ad329a2)
- adds more examples, fixes to input [`5fd4ef9`](https://github.com/fomantic/Fomantic-UI/commit/5fd4ef9dba970f0fa3ebb09f97f42e1a1a857c9c)
- fixes to form [`0b45bfc`](https://github.com/fomantic/Fomantic-UI/commit/0b45bfc4329489e455c5c22d8d85c7c4475fb2df)
- shapes fix [`03ec02b`](https://github.com/fomantic/Fomantic-UI/commit/03ec02b9fa248951b0b5d03cbdc4c6e960ccd9c3)
- Fixes dropdown formatting and icon buttons formatting inside menu #641 [`5a58814`](https://github.com/fomantic/Fomantic-UI/commit/5a5881447fbbeaa7dc322128ee77343ebe9090e2)
- Updates docs on transition to include new content, updates version [`9131ab6`](https://github.com/fomantic/Fomantic-UI/commit/9131ab6aa63890a2ac1ba52a4f26efd31c92d669)
- minor modifications to variations doc [`aacc6da`](https://github.com/fomantic/Fomantic-UI/commit/aacc6da7b013bdb25efbaaefb64cb615dc3d9745)
- fixes dividers to not use % width [`594f19e`](https://github.com/fomantic/Fomantic-UI/commit/594f19e0572fe7c02b72f012b5894614c7e93555)
- fixes shape page [`40eadce`](https://github.com/fomantic/Fomantic-UI/commit/40eadce99f871608882973a3a6ac456ae3613803)
- Fixes issues with accordion rules being too specific. Regression caused by #599 [`320e0d8`](https://github.com/fomantic/Fomantic-UI/commit/320e0d869fd183828ce1034cd2257729feb7146b)
- Fixes bugs introduced in transition module, sets allowMultiple to false by default [`f250a86`](https://github.com/fomantic/Fomantic-UI/commit/f250a86ead59a86cb778dc0e8d5bc1806cc94a4c)
- All tests  for modal/dimmer should now be passing again [`c535a77`](https://github.com/fomantic/Fomantic-UI/commit/c535a77dcb5476278e885dbfa2422f17f4df9e4b)
- Moves test runner into grunt task for travis [`60fcad3`](https://github.com/fomantic/Fomantic-UI/commit/60fcad33ca0584ca2ffff160881776e911578f59)
- iterating on intro docs [`f672b07`](https://github.com/fomantic/Fomantic-UI/commit/f672b074d94f66b346333af19990428b9738a1b1)
- adds example of attach events to modal [`8481701`](https://github.com/fomantic/Fomantic-UI/commit/84817016b457e6557f756d1eaf7f70d306118dd6)
- Fixes anchor links in code samples, some doc styles [`a87a49f`](https://github.com/fomantic/Fomantic-UI/commit/a87a49f323667be401ceae515a7c048fc7ae65ce)
- Adds coloredboxshadow variable for buttons [`6c8956e`](https://github.com/fomantic/Fomantic-UI/commit/6c8956ed86820c38aad93cf265b575a95963f390)
- continuing work on ui input positioning [`3d3c513`](https://github.com/fomantic/Fomantic-UI/commit/3d3c51389713158280725b6b1cfc9b14aa44f1d0)
- adds web kerned neutraface [`f1b6a52`](https://github.com/fomantic/Fomantic-UI/commit/f1b6a52bf03df16373109e8728225e196f6f8db3)
- working sidemenu iphone style [`51cf3f3`](https://github.com/fomantic/Fomantic-UI/commit/51cf3f355e41f0ad19d9cc4145d328fe344f5734)
- Fix doubling grid overrides [`920b432`](https://github.com/fomantic/Fomantic-UI/commit/920b4327920be970a926d922c19f7bbdd7f30b27)
- Fixes for pointing dropdowns in menus [`92daf45`](https://github.com/fomantic/Fomantic-UI/commit/92daf45345538670a617f067bfa9c0b7ffe7728c)
- Fix bug in right labeled icons [`acd73ce`](https://github.com/fomantic/Fomantic-UI/commit/acd73cec414523f315415b47543cff60b2614223)
- Adds #1133 left action input [`fab20ac`](https://github.com/fomantic/Fomantic-UI/commit/fab20ac37428ba64a40655acaaa42f843a594014)
- Beginning progress bar variables [`2a6c613`](https://github.com/fomantic/Fomantic-UI/commit/2a6c61330a9b214e0a891046e01f2cbe7a7d2d06)
- Created custom collections to hopefully avoid the performance issues you were facing [`8b780ea`](https://github.com/fomantic/Fomantic-UI/commit/8b780ea7f3120f410bfda0eda6a8b68cbd6a2577)
- adds tabular menu and example [`3fc3e8b`](https://github.com/fomantic/Fomantic-UI/commit/3fc3e8b0f2f0c5a7e44de432262a5078e9908314)
- why am i working on this all night [`0294abd`](https://github.com/fomantic/Fomantic-UI/commit/0294abd5f1eb5f3d1be7ea6314529387c4605aa0)
- Adds two themes to progress [`500aadb`](https://github.com/fomantic/Fomantic-UI/commit/500aadbeba96baadf51a228d83c4a624053acbb3)
- Updates feed example [`c934d48`](https://github.com/fomantic/Fomantic-UI/commit/c934d4840ad04d6f18a4d239d86e45214fb4e28f)
- feed: adds more fake js to example [`b9bd731`](https://github.com/fomantic/Fomantic-UI/commit/b9bd7316327d217da2a093ab3f9ddeeaf80582ca)
- fixes issue with overflow on attached proress [`f17989a`](https://github.com/fomantic/Fomantic-UI/commit/f17989af174eb376678b12d50f7fe5af869dee0f)
- Update docs for breadcrumb [`7347a2e`](https://github.com/fomantic/Fomantic-UI/commit/7347a2ebc29c0948099191afcae18a43cd2c239e)
- removes float from selection dropdown icon, adds setting for touch delay [`2ea17ab`](https://github.com/fomantic/Fomantic-UI/commit/2ea17abdc5bad0822a5cb209db52a68b6957a28d)
- adds more examples [`efce4b8`](https://github.com/fomantic/Fomantic-UI/commit/efce4b8c278bf2a1abf2c5849336571da9cd0127)
- Adds delegated events and mutation observers #1117 [`48451c5`](https://github.com/fomantic/Fomantic-UI/commit/48451c5427c346bebe6e9c97288a2e14c5bc0938)
- rtl hints [`c2a2138`](https://github.com/fomantic/Fomantic-UI/commit/c2a2138b5a67cc1e8fc4ebd852f67353ec516975)
- Adds basic icon theme, adds some more button variables [`1b70b0e`](https://github.com/fomantic/Fomantic-UI/commit/1b70b0e2ee2ae584a42c8698a4792ba1372ad634)
- Fixes issues in invoke [`f69bf77`](https://github.com/fomantic/Fomantic-UI/commit/f69bf771a09936d6624a70639f8d67a71435196f)
- Updates version # and builds [`459ed2d`](https://github.com/fomantic/Fomantic-UI/commit/459ed2d038ce1363cd0b47cbca276d0cd7e9bc62)
- removes default select receiving text input stylings [`01e24b4`](https://github.com/fomantic/Fomantic-UI/commit/01e24b4b668f560b720762ed7b97287213843fd5)
- corrections to settings object [`29420f4`](https://github.com/fomantic/Fomantic-UI/commit/29420f42c8dfde0214bdde274ecc7ad3fc02c789)
- builds release [`204674d`](https://github.com/fomantic/Fomantic-UI/commit/204674d8980368a30df05c32451d6b53ad37fbb6)
- fixes name conflict with url icon and link variation. formatting on popup module [`66669ca`](https://github.com/fomantic/Fomantic-UI/commit/66669cae34247cfd09222d67cd092b71ec55fc13)
- Fix row padding on divided forms, remove console log, remove date fields from form [`5ba43c9`](https://github.com/fomantic/Fomantic-UI/commit/5ba43c9a35d0ecf31cc0867cd25e0bcf141870ca)
- Adds easing equations to accordions because accordions suck without easing [`dbe1d0b`](https://github.com/fomantic/Fomantic-UI/commit/dbe1d0b7eb3e59c7ba4b3a3239950833eac369af)
- fixes issues with buttons using &lt;button&gt; tag, fixes form formatting for input type=Button [`09e326e`](https://github.com/fomantic/Fomantic-UI/commit/09e326eee30ce7d9e4f2f14149e354234a30d932)
- Begin progress bar theming [`1833bc4`](https://github.com/fomantic/Fomantic-UI/commit/1833bc445797ec6f9d07022c002d4f7d9260a58b)
- Fix site min-width issue [`970820e`](https://github.com/fomantic/Fomantic-UI/commit/970820ea5460f8ccbe3543f8e4243a9a2df0653f)
- Fixes issue #599. Accordion title and content selector are too generic [`ec029e3`](https://github.com/fomantic/Fomantic-UI/commit/ec029e3275d4a0c117b1b157e753e414f237abbf)
- Updating menu doc formatting for comprehensiveness [`85eee7d`](https://github.com/fomantic/Fomantic-UI/commit/85eee7d1340f2d737a745fb1d64d64c081bfbe8f)
- Dropdown: adds ability to restore default value, text #492 [`b4ae26d`](https://github.com/fomantic/Fomantic-UI/commit/b4ae26d24f75886c3d5f6fc4f00e176f09705a13)
- accidental console.log in callback [`85bf31c`](https://github.com/fomantic/Fomantic-UI/commit/85bf31c7c3635464e3966eee5d08c6c829750743)
- tick up version [`c24b1df`](https://github.com/fomantic/Fomantic-UI/commit/c24b1df124afa2ddc8c8304777b9ab36f37015a9)
- Fix mobile styles on homepage [`941c167`](https://github.com/fomantic/Fomantic-UI/commit/941c1674829204f27c7faf4e5538f81c489c7ee3)
- Fix or variables to all be derived automatically from button padding, more or fixes [`62c0883`](https://github.com/fomantic/Fomantic-UI/commit/62c08830c531be8fede077cfb1a31d1d9ae6938c)
- Examples with dropdown error state added to the documentation [`28709c6`](https://github.com/fomantic/Fomantic-UI/commit/28709c6c39c76790a801cd80ecf6721677ed3e4f)
- aesthetic changes, adds responsive styles [`a3725d6`](https://github.com/fomantic/Fomantic-UI/commit/a3725d692832ea737f50d0e19b81ea12123bd465)
- Customization page revisions [`855551e`](https://github.com/fomantic/Fomantic-UI/commit/855551e3ea6657af012ba631f5dd2b24d2d4f00c)
- Adds ability to have filter menus inside normal dropdowns [`d15a5fd`](https://github.com/fomantic/Fomantic-UI/commit/d15a5fd4ee192a1362c236be4ca6d72346ed23d4)
- Fixes for hybrid style initialization [`e8295fd`](https://github.com/fomantic/Fomantic-UI/commit/e8295fdb6f77f1dcd90ee7eb89314d2b18e2ba21)
- Fix some weird edge cases in sticky when doesnt fit [`e1cb9dd`](https://github.com/fomantic/Fomantic-UI/commit/e1cb9dd3140b4b15b6906429fd5e92a5d7867090)
- Adds checkbox user override, adds border box as required reset to avoid some issues with library [`69ba43d`](https://github.com/fomantic/Fomantic-UI/commit/69ba43daac3868b211c1e73db34de5fc8942e8e9)
- Readme header consistency [`49c488b`](https://github.com/fomantic/Fomantic-UI/commit/49c488b95325705163621d58a27a7efcdbe103b1)
- modal: makes dimmer appear before modal, for extra sexyness [`0cd0b67`](https://github.com/fomantic/Fomantic-UI/commit/0cd0b67d04cfcf876e603687f0c2e005aaa8d59a)
- removes some inline debugging left in modal [`91577de`](https://github.com/fomantic/Fomantic-UI/commit/91577de9ce637a3e564b3b3669f777c8dcd343b7)
- fixes issues with stacked and basic segments, text fixes to segment [`c4c68ff`](https://github.com/fomantic/Fomantic-UI/commit/c4c68ff9632006b31e6b4e7937c6cba344ac8ae1)
- Fixes and updates to some elements [`5f812c5`](https://github.com/fomantic/Fomantic-UI/commit/5f812c53cf242c89d8964343b2a2a169cad04b89)
- Modifies transition repaint event [`e50a261`](https://github.com/fomantic/Fomantic-UI/commit/e50a2614289b71dc384fbaa30feb3b703c66b738)
- Fixes inheritance issues in grid, adds justify aligned [`5eaa970`](https://github.com/fomantic/Fomantic-UI/commit/5eaa97077d7cde015f86ea594fe9aa6ea2f55656)
- Adds inverted basic button style, removes button shadow [`64d2386`](https://github.com/fomantic/Fomantic-UI/commit/64d23867adaffceb4965d0c22770c64d1ac24b24)
- Updates performance logging to show the event name first in table [`885260c`](https://github.com/fomantic/Fomantic-UI/commit/885260c2bb244b9785099b92bacf7a06d6f9861e)
- Working on inheritance flow for themes [`c0863a2`](https://github.com/fomantic/Fomantic-UI/commit/c0863a2a9c1b82af30352d1960a9e52f2babac9e)
- fixes some issues with menu [`2f8f574`](https://github.com/fomantic/Fomantic-UI/commit/2f8f5748207b25d6bbdc05d5cf63991440527626)
- Removes vendor prefixes grid [`85c3a8e`](https://github.com/fomantic/Fomantic-UI/commit/85c3a8eb8e56e30155e67065b4c1a76d91d2405c)
- Doc: Matched icon labels with classes [`b13e6b8`](https://github.com/fomantic/Fomantic-UI/commit/b13e6b8f33c5afa350cc5a6fbb89986b41d11362)
- Updates docs to reflect changes in 0.12.0 [`b230d08`](https://github.com/fomantic/Fomantic-UI/commit/b230d08c614fa7059dd23017502dfd4ad366209b)
- modal: fixes modal content not taking full width when less than a line of content [`3743099`](https://github.com/fomantic/Fomantic-UI/commit/37430996c3e1da27c9d8c7563bfdfe93bafc1db4)
- Removes button travel distance, f that ish [`b4c01a0`](https://github.com/fomantic/Fomantic-UI/commit/b4c01a077387b19a9b4f88aa206a8d29cfe0d0a1)
- moves attach events in sidebar to top level [`f78fc41`](https://github.com/fomantic/Fomantic-UI/commit/f78fc416fa0c43b50017ea33a53820d39a77cc8d)
- updates packages [`b8ba684`](https://github.com/fomantic/Fomantic-UI/commit/b8ba6840397cf9111b4f2d1b080d4a40d84de897)
- fixes heinous error in double headers on style guides [`911cd9d`](https://github.com/fomantic/Fomantic-UI/commit/911cd9d982b1967e863f8ee7a55b64bdd778ae43)
- Fixing bug in teal labels [`906fe62`](https://github.com/fomantic/Fomantic-UI/commit/906fe62535a581abd782ce62b2c51f28a4d52784)
- Adds mutation observers, event delegation for accordion. Fixes callback context [`e4a3905`](https://github.com/fomantic/Fomantic-UI/commit/e4a3905c2bb613236fd932f3132e521343009c29)
- Fewer hints the better [`5c4a75a`](https://github.com/fomantic/Fomantic-UI/commit/5c4a75ad95b9693c9f0bcf20bbd119472b06ce65)
- Fixes sticky columns in docs once and for all [`a8fa41f`](https://github.com/fomantic/Fomantic-UI/commit/a8fa41f23ede849a30bfa3eb4b5f160694f9d63f)
- Adds onapprove and ondeny callback to modal, and doc info #241 [`5e2d38f`](https://github.com/fomantic/Fomantic-UI/commit/5e2d38f7b7a7130cbe437b0d52a6528d4c68a360)
- Adds docs for in-menu searchable [`3b982a9`](https://github.com/fomantic/Fomantic-UI/commit/3b982a9121e202361ad23a55705a3d45ae031880)
- Fixes scrolling modal margin on mobile, fixes fullscreen on mobile, fixes header overlaping inline close icon [`aa4a1c2`](https://github.com/fomantic/Fomantic-UI/commit/aa4a1c20475469c895a66c179aadbae5b6df23d6)
- fixes formatting from pull request for popup [`1e0eeab`](https://github.com/fomantic/Fomantic-UI/commit/1e0eeab1e83c66aeb9da01481cce349728358aae)
- avatar uses image spacing [`a1ffd02`](https://github.com/fomantic/Fomantic-UI/commit/a1ffd02e875688be475b9d294c9d6b2bc2018a2f)
- Adds duration object for dimmer, modal now always appears quicker than and hides later than modal preventing issues with callbacks [`b5912ae`](https://github.com/fomantic/Fomantic-UI/commit/b5912ae81972b2743d8b5dda06877c29e97e8940)
- fixes up button page some [`8394754`](https://github.com/fomantic/Fomantic-UI/commit/8394754ec6644af11a557cd05768e7208907d7a2)
- Accordion docs had extra closing tag, adds progress docs for warning, updates details of development docs [`ea2adf9`](https://github.com/fomantic/Fomantic-UI/commit/ea2adf9e78a43d38356301520cb2925adf1aecbc)
- Fixes issues with vertical alignment of checkbox between fonts [`c9f6028`](https://github.com/fomantic/Fomantic-UI/commit/c9f6028972014b6bda41eb4d10faf61f71429538)
- rebuilds packages [`30d4725`](https://github.com/fomantic/Fomantic-UI/commit/30d4725c65c1fb4645f4cc3c60e15b3bbf61d253)
- fixes to inline fields [`d96a824`](https://github.com/fomantic/Fomantic-UI/commit/d96a82475306958ffdfd512e2a9bd36741193017)
- Tweaks to footer [`049d65a`](https://github.com/fomantic/Fomantic-UI/commit/049d65a414055279d7f2ba883a286b9639a8d241)
- Fix attached tabular menu spacing, pointing active header color [`6ba4506`](https://github.com/fomantic/Fomantic-UI/commit/6ba4506300fd1f08f1641580f268759e04021cfa)
- Setting up some more directory structure for tests [`d0f9d5f`](https://github.com/fomantic/Fomantic-UI/commit/d0f9d5fd13866db3f2bc9f3cd64569f826d05a23)
- fixes heart rating color [`bff808c`](https://github.com/fomantic/Fomantic-UI/commit/bff808cec2cabb6d3dbe4f18452bd6e01fa27e19)
- Working on fixes for sidebar animations on mobile with changes to fixed. Updating breadcrumb docs [`9a1e04b`](https://github.com/fomantic/Fomantic-UI/commit/9a1e04bc08c9632230aa4b31613fff7139e1b1bc)
- Rebuilds package for 0.12.3 with missing pull request from origin [`715b178`](https://github.com/fomantic/Fomantic-UI/commit/715b1780ba6cdc8860dd1d714495b36076531890)
- Adds setting for type of history event to use, adds set state behavior [`262aa13`](https://github.com/fomantic/Fomantic-UI/commit/262aa1306533aa26bb806859752b8c9c410f96c2)
- refactors icon sizing to allow for more variety [`d3eb647`](https://github.com/fomantic/Fomantic-UI/commit/d3eb647a95fe0e53c34424fc535c9628c2b4a412)
- Modifies attached header styles to be neutral, block header is now flat. Border used instead of box shadow due to issues with 1px box shadows looking like crap [`a623e44`](https://github.com/fomantic/Fomantic-UI/commit/a623e4411c1ff958610e7b9da2d84ef55ecd4ec9)
- Several docs fixes to formatting, changes to raised button theme [`149cd66`](https://github.com/fomantic/Fomantic-UI/commit/149cd66b45a0ea3193e06a8889d83e88437cbe19)
- Menu: removes vendor prefixed properties [`9f78a2d`](https://github.com/fomantic/Fomantic-UI/commit/9f78a2da2f3a3302d34e78ff227d7edaf4892a76)
- Adds title example to popup fixes typos, removes transition warning about looping [`c86132d`](https://github.com/fomantic/Fomantic-UI/commit/c86132d8764f5a976fb21deb4c0cb837215d50dc)
- writes release notes and version uptick [`f2e3a55`](https://github.com/fomantic/Fomantic-UI/commit/f2e3a55f5b2538c2423a53548e5ba36c5994ec6a)
- Fixes Bug foud in semantic module format, settings shared across initialization instead of instance [`8e03b66`](https://github.com/fomantic/Fomantic-UI/commit/8e03b661021b84c1215f6ee932b2c65c4673186c)
- Index updating [`f5be0a5`](https://github.com/fomantic/Fomantic-UI/commit/f5be0a5942cffe62dc5cd5668ac3129a4d33ede7)
- fixed font-size-adjust, adds some header styling [`0485163`](https://github.com/fomantic/Fomantic-UI/commit/0485163b8156ae315fc62659198648ca7b8e200a)
- Fixes shadow on ribbon labels to be more pronounced and use vars [`81c0510`](https://github.com/fomantic/Fomantic-UI/commit/81c0510843d9fee4c452391e69086c2ebd299000)
- Adds accordion icon positioning into variables [`1c82537`](https://github.com/fomantic/Fomantic-UI/commit/1c8253725d3e776ca854e9540cb85115a72ef926)
- Modification to popup to account for changes in transition rewrite [`6f4f52c`](https://github.com/fomantic/Fomantic-UI/commit/6f4f52c852603e7df6302fd6788b846ab667cbbd)
- fixes missing semicolon [`bc17764`](https://github.com/fomantic/Fomantic-UI/commit/bc17764833c4b600c11f20443c50481bf402c530)
- fixes icon issues in buttons and circular [`cbd33e1`](https://github.com/fomantic/Fomantic-UI/commit/cbd33e169172f5dd5eb3fbc39986e2bed970168a)
- fixes bug in shape module that fucked with queued animations, adds large size to button because why wasnt there one? [`8c1a03b`](https://github.com/fomantic/Fomantic-UI/commit/8c1a03ba514c9d6f824e09ab5f2bc3260d67e0d4)
- Tweaking some variables for button themes [`48fbde5`](https://github.com/fomantic/Fomantic-UI/commit/48fbde5557b6ea1e9126498c28d7c278acf93f72)
- Fixes inverted pointing secondary menu colors on submenus [`eeb7272`](https://github.com/fomantic/Fomantic-UI/commit/eeb727213dd1954bfc63d03335df90f750fc377d)
- Ignoring some files types [`92701c5`](https://github.com/fomantic/Fomantic-UI/commit/92701c544f869603d99efe9a7edea6eb9903ebcc)
- Adds default looping to transition [`936949a`](https://github.com/fomantic/Fomantic-UI/commit/936949af207c93e10bf7eb5302764838a3cee280)
- fixes navigation issues at small sizes [`6d8b8e8`](https://github.com/fomantic/Fomantic-UI/commit/6d8b8e8bb58cde7ec0b294c6ddf99aa658ef7dbe)
- Adds full-width definition table variation, adds footer formatting [`43ec6dd`](https://github.com/fomantic/Fomantic-UI/commit/43ec6dd346922cf1cb887880a0465e5a0f0b5a06)
- Fixes right labeled to be word order dependent [`f0be8ec`](https://github.com/fomantic/Fomantic-UI/commit/f0be8ec7ec63d056346179c357e18fffa8b56d64)
- Fix mispelling, and adjusts homepage animation [`d4da386`](https://github.com/fomantic/Fomantic-UI/commit/d4da3862380c6e6a407cdcfe74c6c54628d45a15)
- Docs for hybrid style init [`afe0754`](https://github.com/fomantic/Fomantic-UI/commit/afe0754f4a87371aeb56923ff9d59b231e34bec6)
- fixes some broken examples on form [`bb7e1ba`](https://github.com/fomantic/Fomantic-UI/commit/bb7e1ba1e9143cc433e26ec9d912c4fc37ff82a8)
- updates version number, builds package [`d9e8ee4`](https://github.com/fomantic/Fomantic-UI/commit/d9e8ee45efe775b076f2b4f8596b1a210106902f)
- typo in js [`c6ad59d`](https://github.com/fomantic/Fomantic-UI/commit/c6ad59d28b6498c98e2a9d67d08cd7e6e465a670)
- Adds support for buttons in menus fixing #150, fixes dropdown formatting shadow, and positioning to be more precise [`a3ccf61`](https://github.com/fomantic/Fomantic-UI/commit/a3ccf612e365ecbf233cb3bda3c0186f3bcda925)
- Updates some typos as pointed out by Nathan Soliz [`f8b5318`](https://github.com/fomantic/Fomantic-UI/commit/f8b5318b50c7a750767177b843c7d02c80b0d38d)
- Adds rail padding variations [`a151ace`](https://github.com/fomantic/Fomantic-UI/commit/a151acef6d823030427810301615e9838c3fa99b)
- Updates to new themed elements [`8d7da99`](https://github.com/fomantic/Fomantic-UI/commit/8d7da990d5499d63abfcc4fc9be7d1c31faeba4f)
- Adds composer.json file for composer [`0fa945c`](https://github.com/fomantic/Fomantic-UI/commit/0fa945cde3bba27403566296ae95a30336b49ba6)
- adds contains rule for form validation, updates example [`33b7f45`](https://github.com/fomantic/Fomantic-UI/commit/33b7f45966684bf59cb57431a62d1ab71caf435b)
- Add google font loading into the library as site.variables [`f7e9e6e`](https://github.com/fomantic/Fomantic-UI/commit/f7e9e6e70ca7d2e477c55d3af5a5963705494d55)
- make size variables usable [`0a15792`](https://github.com/fomantic/Fomantic-UI/commit/0a157922b6a05220265da5bf5b7ad5e2f3c0620d)
- Fixes regression with page grid [`bf14784`](https://github.com/fomantic/Fomantic-UI/commit/bf147840fff62af45642a72206fe9fe33c2880e7)
- Temporary fix for paging (show all in dropdown) [`89a14c4`](https://github.com/fomantic/Fomantic-UI/commit/89a14c4ffb36dedc5641ef53ddf21fe999d1def0)
- fixes settings tables [`9248041`](https://github.com/fomantic/Fomantic-UI/commit/9248041e2d1e8a88a5998d29c8f3c1579774dea5)
- Fix occurred being reset on browser resize [`c60cf06`](https://github.com/fomantic/Fomantic-UI/commit/c60cf0625727e930504ef1d52f7d11e2d4558420)
- Adds ability to swap borders with 1 variables in buttons [`231b64c`](https://github.com/fomantic/Fomantic-UI/commit/231b64c5aae03ff6ace9fc34135e5ef2158b936d)
- Add mobile scrollback as setting for sidebar [`7f9579b`](https://github.com/fomantic/Fomantic-UI/commit/7f9579bcc73bd89053433bbcbc695bc3551af764)
- Adds automatic action detection to dropdown, select dropdowns now can use default action and update form fields. Improvement #171 [`ef1e91c`](https://github.com/fomantic/Fomantic-UI/commit/ef1e91caa643467e69c4b37e420582497ac54507)
- lost pull-requests [`128e2f5`](https://github.com/fomantic/Fomantic-UI/commit/128e2f5a13dc5eb821cdf73981debd63ce374ba1)
- fixes link namespace collision with link icon [`a3b649b`](https://github.com/fomantic/Fomantic-UI/commit/a3b649b5b0400715f0726962ff5162bb9a40c663)
- fixes regression in circular icon [`0d926d1`](https://github.com/fomantic/Fomantic-UI/commit/0d926d161edcae3f0bb00bf71acee85791eb34bd)
- updates collection index page [`dc733c2`](https://github.com/fomantic/Fomantic-UI/commit/dc733c2a07267e30a802659f639e8709d0eea4f2)
- rebuilds packages [`0b05be5`](https://github.com/fomantic/Fomantic-UI/commit/0b05be52f39c11c1f881fcc74aed340e6b417a63)
- fix to steps [`af4b7dc`](https://github.com/fomantic/Fomantic-UI/commit/af4b7dc6d38b018561a9474d0517d914c4e32f5b)
- Wrong date in release notes [`fa617f6`](https://github.com/fomantic/Fomantic-UI/commit/fa617f6ba35e57185d6ac56d8c544995462a330c)
- Initial test commit of travis.yml and node package [`8a93ee9`](https://github.com/fomantic/Fomantic-UI/commit/8a93ee9eb581441d2ebd9340d6dba3b1c58d1241)
- Updates vertical alignment of checkbox [`b143bd5`](https://github.com/fomantic/Fomantic-UI/commit/b143bd587aeaf5e4a897170aac1c1a94f60d245e)
- adds active striped example, rebuilds package [`fb124c9`](https://github.com/fomantic/Fomantic-UI/commit/fb124c95e7e62cea3cb814e07814e4899971100a)
- Fixes inverted text menus [`72fc690`](https://github.com/fomantic/Fomantic-UI/commit/72fc6902f3429980d45ffe30c635c834b26c3546)
- Remove ui namespace from dimmable, now transition, dimmable, and pushable are the only 3 free floating class names [`ebf3441`](https://github.com/fomantic/Fomantic-UI/commit/ebf344199436d0b13e6539b42ac2180d448a3b96)
- Adds image alignment options to modal, adds autofocus port from 0.x.x #836 [`68cad01`](https://github.com/fomantic/Fomantic-UI/commit/68cad017dc266c7c10a7a8adac365a4db7826e35)
- Fixes up some formatting on github menu theme, fixes some input variables in menu [`7658150`](https://github.com/fomantic/Fomantic-UI/commit/765815086b1436319ce7b0c17d4cdd42ba610f70)
- removes 3d translate from final state of animatino to avoid rounding errors [`f523784`](https://github.com/fomantic/Fomantic-UI/commit/f523784638f9b8befa58a5ebb3aca902c1f46726)
- example fix [`ce956ac`](https://github.com/fomantic/Fomantic-UI/commit/ce956ac169be2627972d0ddad676f4e15e8c60e3)
- Form: fixes issues with ctrl + enter triggering form submit [`1f1a1da`](https://github.com/fomantic/Fomantic-UI/commit/1f1a1da21d2f352ec4019484dc72c219ff08242c)
- docpad update [`3242a8f`](https://github.com/fomantic/Fomantic-UI/commit/3242a8fed843599cd809622aebf8224c83511ceb)
- fixes media queries [`e6fef93`](https://github.com/fomantic/Fomantic-UI/commit/e6fef935e0da84c5ebc08d9dafd6c91f84081dec)
- fixes icon paths [`b0bb9fd`](https://github.com/fomantic/Fomantic-UI/commit/b0bb9fd18828b4c30f571442d52785bf94433ebd)
- Add field divisions &gt; 6, fix last fields field margin [`ede80fd`](https://github.com/fomantic/Fomantic-UI/commit/ede80fd18c8217622ecddcccd4574b024d4e7fcc)
- Restructuring readme [`b35dfca`](https://github.com/fomantic/Fomantic-UI/commit/b35dfca49f37e7ac9480ff73728ed37034111bd4)
- updates gruntfile for theme paths [`63ba7b0`](https://github.com/fomantic/Fomantic-UI/commit/63ba7b0459b15b0bd172d419c641f95fc5e5dded)
- updates styles for link list [`9d6217c`](https://github.com/fomantic/Fomantic-UI/commit/9d6217cc6ea0e0eb5c23c6ffc42bbdb108d43016)
- new intermediate size for icons [`7e49f3b`](https://github.com/fomantic/Fomantic-UI/commit/7e49f3be1db848cbf615519aacf1bfcad73be8bd)
- makes mobile responsive grid integer [`b11541c`](https://github.com/fomantic/Fomantic-UI/commit/b11541c1085c3dd33911607755b568ca001ffd11)
- added queue setting to transition module [`2c05cb6`](https://github.com/fomantic/Fomantic-UI/commit/2c05cb6150b9512d2d991c7e97efff8a0b19bde5)
- adds transition to form doc, changes default to scale [`437df4a`](https://github.com/fomantic/Fomantic-UI/commit/437df4aadc137a0814454b95e48d1490ce9f1f66)
- adds thesis [`40a3ee7`](https://github.com/fomantic/Fomantic-UI/commit/40a3ee7c653f334d709c72924f7545a8ed216a34)
- Fix border radius transitoning on dropdown [`9edb9b4`](https://github.com/fomantic/Fomantic-UI/commit/9edb9b4c6dfe778eafeeea3cf2d5d3dbeaf10fd3)
- fixes some broken paths, fixes some variables in menu [`93fd677`](https://github.com/fomantic/Fomantic-UI/commit/93fd67785d9fd7fa720385a79da41c3f549a9313)
- Removes force repaint of dropdowns due to fixes in transition module [`be8dd23`](https://github.com/fomantic/Fomantic-UI/commit/be8dd23b3b2570ed58341e15644e1ce16ba22862)
- Updating homepage example [`9bf762e`](https://github.com/fomantic/Fomantic-UI/commit/9bf762e357663dff1365bcccbd87fc43a2be66d1)
- Optimizes modal dimmer init for performance [`1d9e140`](https://github.com/fomantic/Fomantic-UI/commit/1d9e14063c7fc294faa5b30e5174bb08a5aa8266)
- added a concatenate uncompressed css file to build - semantic.css [`096edff`](https://github.com/fomantic/Fomantic-UI/commit/096edff787d156560b9f24d3122bb34a0efc85f4)
- Adds back in animation reset on transition [`d26f7bc`](https://github.com/fomantic/Fomantic-UI/commit/d26f7bca16d97fd55129cfe44bfa86c1f9a110e7)
- Fixes to the localization nag [`11497b4`](https://github.com/fomantic/Fomantic-UI/commit/11497b407e653e1044b050a557a766c7844f8da2)
- Fixes issue with modal sometimes caching sizes when hidden #895, #951 [`ddc5f63`](https://github.com/fomantic/Fomantic-UI/commit/ddc5f636bf89f15ed69d6701814ac7c942706f4d)
- Transition: prevents same animation from occurring twice by default [`4dcfe8a`](https://github.com/fomantic/Fomantic-UI/commit/4dcfe8aa40b703666c90e52bf12bac2f3acb1131)
- swaps disabled/enabled state on rating [`7c4e053`](https://github.com/fomantic/Fomantic-UI/commit/7c4e053c153527cd69558de91a39b02d63cac1ce)
- updates header icon padding [`9a074aa`](https://github.com/fomantic/Fomantic-UI/commit/9a074aab21b9efc2754ff404257c156ebbbe292d)
- fixes issue in displaying some code example without class uI [`805ebba`](https://github.com/fomantic/Fomantic-UI/commit/805ebbaba56a4b4f57cb4a16a712fdb5bf8aa443)
- performance improvements to dropdown [`4aa4583`](https://github.com/fomantic/Fomantic-UI/commit/4aa45834f57cd0e1eacd3f56dc466354e1bba43d)
- Adds vertical spacing support for both rows and grids when doubling #1107 [`ea8ee43`](https://github.com/fomantic/Fomantic-UI/commit/ea8ee430f4e34428a514a3c741bfbbd17137f7bd)
- Fix bug in mouseclick on menu item [`90d1215`](https://github.com/fomantic/Fomantic-UI/commit/90d1215f48a338d9167c25a7b2761a090f270082)
- Fix github message theme border colors, fix tabular segment spacing [`91939aa`](https://github.com/fomantic/Fomantic-UI/commit/91939aa4bc709c6b366ae8983b7b9416027f5120)
- updates to button/divider/header variables [`6900ed9`](https://github.com/fomantic/Fomantic-UI/commit/6900ed99c72b7334efe4840ee3b13a944264bca6)
- Fixes issue with star vertical alingment [`c905768`](https://github.com/fomantic/Fomantic-UI/commit/c9057682a5c1aceb4a0a549cc3a899e295a0db13)
- Removes old theme.include [`354afdd`](https://github.com/fomantic/Fomantic-UI/commit/354afddab5f343c5c9466aa59db8cb6b8fe649d0)
- increase size of attached label padding [`a80e831`](https://github.com/fomantic/Fomantic-UI/commit/a80e831e9d6ed685589ac29c3dce2acd828cf083)
- rebuilds packaged release [`bc3c4f2`](https://github.com/fomantic/Fomantic-UI/commit/bc3c4f241e1f31a4a13c94d3f35e3d6904f80018)
- adds work from svenkatreddy to fix ios form fields [`7c350de`](https://github.com/fomantic/Fomantic-UI/commit/7c350ded0b4ab01d2f4319d7b62e9438a06062f4)
- builds release version [`84c4c9b`](https://github.com/fomantic/Fomantic-UI/commit/84c4c9beab692ead983015e6a3d687c46a2c2ae4)
- build new version of zip [`f3c87c2`](https://github.com/fomantic/Fomantic-UI/commit/f3c87c28c38d5b1dbfcb7550f050076137bfaf1e)
- Fixes module name param in some outdated docs [`3fd212b`](https://github.com/fomantic/Fomantic-UI/commit/3fd212bbb15781b026db99c754455f4fcc37ddf4)
- copy fixes [`6252ac5`](https://github.com/fomantic/Fomantic-UI/commit/6252ac5b707fad927856a6b9c75993b5ccada9be)
- tightens up modal so it sits now 4% inside of a page grid instead of flush along edge [`3dd8d94`](https://github.com/fomantic/Fomantic-UI/commit/3dd8d94af1c79b939b55d6fece14530bf8a25bf5)
- add doc for select fields [`bf4099e`](https://github.com/fomantic/Fomantic-UI/commit/bf4099e7bda1d27da78e6830b063e16f86dc83b0)
- Updates commenting in gruntfile for new pull request concat task [`b8f5895`](https://github.com/fomantic/Fomantic-UI/commit/b8f589515fdfdd9034b0d43e55689d646168dc7a)
- Fixes bower json [`b606c50`](https://github.com/fomantic/Fomantic-UI/commit/b606c50f954dabfac0319abc0563c08f0199290c)
- Tweaks to homepage [`2db558c`](https://github.com/fomantic/Fomantic-UI/commit/2db558cb02143334d4572ef34ef33ae520632506)
- Fix inverted bordered icons [`b133398`](https://github.com/fomantic/Fomantic-UI/commit/b13339845c83e145fca342d35e0369a9a824cab8)
- Adds namespaced events to transition [`b5217ae`](https://github.com/fomantic/Fomantic-UI/commit/b5217ae8e5526943da8a8c38ad2db9e70f59999d)
- Add support for in-page anchor links while using anchor link history [`70fe470`](https://github.com/fomantic/Fomantic-UI/commit/70fe470fdd5e84f6b478e2d169c99ea77223bea9)
- Form: Adds responsive mobile styling for grouped form elements fixes [`1d0d398`](https://github.com/fomantic/Fomantic-UI/commit/1d0d3983df98020296faa8de7a10268ac94e6ec4)
- Fixed colors repeating in items [`a6476f0`](https://github.com/fomantic/Fomantic-UI/commit/a6476f01c9286460b208b4014f2496cc39f73bcf)
- Removes previous changes for modal detachable to segment/dimmer. Fixed transition error message to make more sense [`9b2afb7`](https://github.com/fomantic/Fomantic-UI/commit/9b2afb7dacea610443a056b96a25278f599eb481)
- Fixes font paths, missing comma [`a833407`](https://github.com/fomantic/Fomantic-UI/commit/a8334073d89fb14a264d44393e7826772a56c163)
- Delete theme.less [`f606373`](https://github.com/fomantic/Fomantic-UI/commit/f60637375694808225946328aa1d797f0d932391)
- fixes dropdown example [`e05b82b`](https://github.com/fomantic/Fomantic-UI/commit/e05b82bcec3c7a45a01a0b79d0546b0fd441272b)
- fixed bug with css concat and switched to concat instead concat_css grunt task [`136037d`](https://github.com/fomantic/Fomantic-UI/commit/136037d7fdecdcf6c554eaaac89f0136762009ec)
- typo [`f90fdcd`](https://github.com/fomantic/Fomantic-UI/commit/f90fdcd2878282cfc0a1b94ad5b3b34b6cfbe39f)
- code samples easier to see [`937bfcf`](https://github.com/fomantic/Fomantic-UI/commit/937bfcf75ca4b014077c80e8124ae45813022ece)
- Update README.markdown [`fa7eecb`](https://github.com/fomantic/Fomantic-UI/commit/fa7eecb16858c89f21d6c3a8495a6e19bdb7bec2)
- Fixes inverted form formatting for checkboxes #661 [`3310d87`](https://github.com/fomantic/Fomantic-UI/commit/3310d87cdb2b0fd2556297c6e296861836f1570b)
- moves clickaway event till after show to prevent bubbling from toggle to doc [`c0c4690`](https://github.com/fomantic/Fomantic-UI/commit/c0c46909c8d7ec87247f5360806c18ef880a9ddc)
- adds sizing  menu formatting for input and dropdown fixing #173. Improves centering of input in chrome [`e5f63c9`](https://github.com/fomantic/Fomantic-UI/commit/e5f63c9fb3f0d307cbec86f76d4dff1f999261a5)
- add date&email types for inputs [`3df5f04`](https://github.com/fomantic/Fomantic-UI/commit/3df5f046c54d6ca7fb22cac1d338adec9748fb53)
- removes double headers on styleguides [`80817a7`](https://github.com/fomantic/Fomantic-UI/commit/80817a7ffa5437f809bda8953501cf8ed05df6b8)
- Fixes definitions appearing improperly on some pages [`379edde`](https://github.com/fomantic/Fomantic-UI/commit/379edde6223fd3ffd2ddd31aaf6f1e1afcbc2f2d)
- Update RELEASE NOTES.md [`5abbc13`](https://github.com/fomantic/Fomantic-UI/commit/5abbc13dcd5d6b8acdae25a70bca57358bc154cc)
- fixes bug in invoke in transition [`fe9ab4b`](https://github.com/fomantic/Fomantic-UI/commit/fe9ab4be3b2a4bee4a8679291d581ade44cb484d)
- Adds more sensible global sizing values that default to exact pixel values in default theme [`1d2b3bf`](https://github.com/fomantic/Fomantic-UI/commit/1d2b3bf5f619fa12faad40544c3cff308bb068f8)
- Cleans up gruntfile a little [`f5ed5c3`](https://github.com/fomantic/Fomantic-UI/commit/f5ed5c3471a3cb3599bfa2663b2aab49684119d7)
- Add transition values for sticky scrolling [`9af15c5`](https://github.com/fomantic/Fomantic-UI/commit/9af15c5bb582addbbf57d24414d7fb91112ea3b9)
- Computer breakpoint is now 992 instead of 998 (match bootstrap) [`20ecf56`](https://github.com/fomantic/Fomantic-UI/commit/20ecf5648e3b8aa085c2a8cdd05d1943215a0683)
- Prevent menu button color inheritance. [`dd45a3c`](https://github.com/fomantic/Fomantic-UI/commit/dd45a3c724485de422fe600155dea7f08be10db9)
- Updates local dev guide [`f0ee48d`](https://github.com/fomantic/Fomantic-UI/commit/f0ee48dc33c21493bc96d6dd795937361866e035)
- add vk.com button style [`25ad519`](https://github.com/fomantic/Fomantic-UI/commit/25ad5190ade8bdcf67d6426f586aac03fb60efd0)
- Fixes issue #312. Fixes left/right styles possibly  applying to child ui elements [`afb0186`](https://github.com/fomantic/Fomantic-UI/commit/afb0186fd7b9444298dcf9676d21924e6e3a2220)
- deployed site now uses minified code [`295570d`](https://github.com/fomantic/Fomantic-UI/commit/295570d1bd100d63824b74f1ec2449ce721decd1)
- Updates gruntfile test runner, adds console clean after tests [`7ecb437`](https://github.com/fomantic/Fomantic-UI/commit/7ecb4372a581e3e53da3471d52e51f489db4c180)
- fixed the ":;" bug, which will cause rails assets pipeline compile error. [`f1acacb`](https://github.com/fomantic/Fomantic-UI/commit/f1acacba4db9817266455ad020437407ea2c6564)
- version tick [`5f9cbf6`](https://github.com/fomantic/Fomantic-UI/commit/5f9cbf6eccf2ef3d1acdc974edd7c22a4e54f47c)
- Adds developer info to readme [`a395e87`](https://github.com/fomantic/Fomantic-UI/commit/a395e87df383f8c4eb21688c668754adc4b444c1)
- menu fixes [`7642de5`](https://github.com/fomantic/Fomantic-UI/commit/7642de5a7276a78ef4aa3ad102802c19e874a5db)
- finally uses legit dropdown for page chooser [`60d7756`](https://github.com/fomantic/Fomantic-UI/commit/60d77564d7929f29025f99549375235f06d25516)
- Updates tab namespace [`4a866d9`](https://github.com/fomantic/Fomantic-UI/commit/4a866d9e88b03d07f0e28826a003c186849c184e)
- fixes issues with inline validation prompt removal [`9fc6a8d`](https://github.com/fomantic/Fomantic-UI/commit/9fc6a8da77c3807a915682f00513bb825a78b759)
- fixes safari issues with shape [`db70967`](https://github.com/fomantic/Fomantic-UI/commit/db7096741a184b87d6a2e51373bd819933d46a5a)
- zzz [`165ea37`](https://github.com/fomantic/Fomantic-UI/commit/165ea370de356dbaed7360f5ba795e141a4d41ae)
- Divider docs update [`2bddddd`](https://github.com/fomantic/Fomantic-UI/commit/2bddddd96441c8d4b360a0b6732b5fb5ec3d1cdc)
- Updates to server guide [`b3e4fde`](https://github.com/fomantic/Fomantic-UI/commit/b3e4fde59d1ab045299d2dd4948bdd879f205815)
- update release notes, version tick [`6d29761`](https://github.com/fomantic/Fomantic-UI/commit/6d29761eb3948cfd58e1cecb73328c643b302db5)
- add type='emeil' and some others [`2e82c14`](https://github.com/fomantic/Fomantic-UI/commit/2e82c14ea93bef5ee4bb90d2587c031f12cf790d)
- updates version due to patch for icons [`ed51ee9`](https://github.com/fomantic/Fomantic-UI/commit/ed51ee93e0e259f5934cf830c0e61a21bcae6552)
- fixes issue with chrome input [`1dbf44c`](https://github.com/fomantic/Fomantic-UI/commit/1dbf44cb1396e58af724450e04e5d66e9b513788)
- Fix segment when used with grid [`0700c51`](https://github.com/fomantic/Fomantic-UI/commit/0700c51eb9ac68630d4f985d4ed826c2c12c039e)
- Fix gruntfile comments [`415f658`](https://github.com/fomantic/Fomantic-UI/commit/415f6581adacb55fc3f1fa149713d978b7317221)
- Add namespaced event to sidebar [`21f9d11`](https://github.com/fomantic/Fomantic-UI/commit/21f9d11e8a1b9880cdbab82807d95adb14bca22f)
- Fix animation in webkit [`1a0b94e`](https://github.com/fomantic/Fomantic-UI/commit/1a0b94e97a0a1f23ef4788167472675b6cde26bc)
- Update google analytics [`25eecbd`](https://github.com/fomantic/Fomantic-UI/commit/25eecbd9688778382b72ae8b6cdfc16b9a94d67e)
- Fix divider colors on grid [`19e98a6`](https://github.com/fomantic/Fomantic-UI/commit/19e98a62465c5689009041728d02c10e8e2d4e17)
- remove rounding from other corners [`da6bdbd`](https://github.com/fomantic/Fomantic-UI/commit/da6bdbde430531b550245c9f737dcbaa1c86b3b6)
- removes mistaken headline commit (redub) [`73e8f2d`](https://github.com/fomantic/Fomantic-UI/commit/73e8f2dc9ac7e1863709d3571391744650c3d57c)
- removes mistaken headline commit [`eb5fed9`](https://github.com/fomantic/Fomantic-UI/commit/eb5fed9a37dcee5ca9781b39ad352a9669f10848)
- Fixes clearing example, adds transparent input example [`45116b8`](https://github.com/fomantic/Fomantic-UI/commit/45116b8a399140d41ab733913324f222c72e1ab7)
- Dropdown: Adds enhancement to store dropdown value even in cases without input #404 [`f47e721`](https://github.com/fomantic/Fomantic-UI/commit/f47e721b26eb9cfa71fb314a017844063cc727bb)
- Added a context option to the popup module to make its behavior closer to modal. [`55d7a8e`](https://github.com/fomantic/Fomantic-UI/commit/55d7a8ef552fd63c22568b49d16b5adfd4a7a320)
- Fixes typod values in button [`6250a04`](https://github.com/fomantic/Fomantic-UI/commit/6250a04f86eb77d85fb718942d872b7fa85a9a30)
- Adds coupling with grid/grid column [`64315d4`](https://github.com/fomantic/Fomantic-UI/commit/64315d4d6d2f9fe13b8eb7462007df37b24793d7)
- Updates spacing on list [`7cd8fb8`](https://github.com/fomantic/Fomantic-UI/commit/7cd8fb88b8cb3608c9761eb51700c0ba33abbc64)
- fix link paths [`1c5c14f`](https://github.com/fomantic/Fomantic-UI/commit/1c5c14f732fd3baaf6c853de06e9ffaaad8c927a)
- updates board links [`71af751`](https://github.com/fomantic/Fomantic-UI/commit/71af7515953bd90961e2d4c65e70e49e1b5b923b)
- removes old fonts, moves draft elements to doc files [`19ab61f`](https://github.com/fomantic/Fomantic-UI/commit/19ab61ff9448eccef1a377b7ec7882bb547742df)
- updates home tab [`275a4f8`](https://github.com/fomantic/Fomantic-UI/commit/275a4f8e9da47d055ca57d4aad419ef210c1cb8c)
- fixes input examples in menu [`8ad921d`](https://github.com/fomantic/Fomantic-UI/commit/8ad921da4cd420358a33fd5f90dbc728133d88e4)
- Tighten responsive breakpoints for docs, tighten step padding a lil [`8fd9cab`](https://github.com/fomantic/Fomantic-UI/commit/8fd9cabe85d43eb3f7fb453b12cb3d9a11764406)
- Button now inherits all sizes [`9675f9a`](https://github.com/fomantic/Fomantic-UI/commit/9675f9ab11f784245b73dbcbd1b0dfbffa62a693)
- Adds compatiblity with buttons [`06d63de`](https://github.com/fomantic/Fomantic-UI/commit/06d63de8fd30a208f38815fb8cdab34b5abc8c29)
- Fix preserve html setting [`874ef24`](https://github.com/fomantic/Fomantic-UI/commit/874ef24cf4051195376750275d66848312bdf19b)
- Couple bugfixes for scroll, inline grouped label margin fix [`ca52ee4`](https://github.com/fomantic/Fomantic-UI/commit/ca52ee430b655e0513db17e1dc19694ab6719d50)
- Only require scrollTo(0,0) for iOS fix, fix margin on stackable divider [`e225d36`](https://github.com/fomantic/Fomantic-UI/commit/e225d36aed3cf1afa5cf010980079cf04e8295bb)
- In-Menu input action button corrections. [`81ac1c9`](https://github.com/fomantic/Fomantic-UI/commit/81ac1c91bbf602b52b35cde2501b60895980d871)
- Updates translation text in readme [`997e1f9`](https://github.com/fomantic/Fomantic-UI/commit/997e1f949f94b687afe0dc8119110028756c2af2)
- Adds vk button example [`86cbe45`](https://github.com/fomantic/Fomantic-UI/commit/86cbe459c2e68ee8a9a64c758924b78d0d5cfd6d)
- Justified docs [`3d474c0`](https://github.com/fomantic/Fomantic-UI/commit/3d474c0ed11b17d577919addea6ab8db767b1a48)
- updates contributing [`18b56d2`](https://github.com/fomantic/Fomantic-UI/commit/18b56d250bb774dd7008a2b65a0ae144be52d5bc)
- removes center alignment [`e4330c6`](https://github.com/fomantic/Fomantic-UI/commit/e4330c69131f063c6f0c7a23f455d159435886bf)
- Fixes mobile return scroll, adds as default behavior [`0500a24`](https://github.com/fomantic/Fomantic-UI/commit/0500a246f75071173ff006750ad9354124d56a05)
- Fix mobile menu init on not tab pages [`9a92cd6`](https://github.com/fomantic/Fomantic-UI/commit/9a92cd651c614625b4895b1f0dfb2cd705ec2c81)
- Fixes bug where sometimes transitioned hidden elements would stay visible [`ec4e058`](https://github.com/fomantic/Fomantic-UI/commit/ec4e058662b5750632210d82c3977ce59e77a2fe)
- Moves dimmer to use request animation frame instead of debouncing [`577681a`](https://github.com/fomantic/Fomantic-UI/commit/577681a924f9030e2c4d10f4a44f5d2efa8d1024)
- Update RELEASE NOTES.md [`2f0816c`](https://github.com/fomantic/Fomantic-UI/commit/2f0816c93aa8c163dc100c08417534507f93c4e6)
- Updating release notes formatting [`9bf61d7`](https://github.com/fomantic/Fomantic-UI/commit/9bf61d7dcfd61050c997eef91da3c31d94607e6e)
- Add ok/cancel combination to the selectors list [`d9a1041`](https://github.com/fomantic/Fomantic-UI/commit/d9a1041092d6fbe3d4ca23b783142f85d2ca2ee7)
- Updates release notes [`933bba4`](https://github.com/fomantic/Fomantic-UI/commit/933bba44d90cdcb038c2b4bb6f78d39d1d7bb223)
- adds docs for #402 [`fc814c0`](https://github.com/fomantic/Fomantic-UI/commit/fc814c0ad7dd466d8b3b1823ab4ac6a7a685b554)
- Fixes date in release notes, updates grunt order on zip compression [`99c99c8`](https://github.com/fomantic/Fomantic-UI/commit/99c99c811446cfaf1f19957b541ece892be45822)
- Fixes incorrect not selector (does not support comma selectors inside not [`953d343`](https://github.com/fomantic/Fomantic-UI/commit/953d3435b0916a888afc8cf0079be935e42f6481)
- Updates responsive styles for mobile modal [`3cc8178`](https://github.com/fomantic/Fomantic-UI/commit/3cc8178d08876ff9f2c64bb6e8fe2ace68a78986)
- Rebuilds package after pull request [`7a9c7b2`](https://github.com/fomantic/Fomantic-UI/commit/7a9c7b24af1ee1376a8f30644b69de68a2575b53)
- added semantic.js to build using concat in grunt [`eac62f5`](https://github.com/fomantic/Fomantic-UI/commit/eac62f52bf06a468bd0ef4b4634ee39f2f15f516)
- build uncompressed v [`88ba204`](https://github.com/fomantic/Fomantic-UI/commit/88ba20429f52cd463d8dda5e6089a32832b9c3db)
- testing new repo [`fab1dc1`](https://github.com/fomantic/Fomantic-UI/commit/fab1dc1369552a4c6699d632bc6b7340abd9b5f3)
- fixes issue with labeled input icon [`6f6bd94`](https://github.com/fomantic/Fomantic-UI/commit/6f6bd941c08d5c3970bacd17479d8c3ec6c22481)
- form changes [`85f3f57`](https://github.com/fomantic/Fomantic-UI/commit/85f3f570dac2b41aaa1cb375a9cad8ae0914170d)
- Update localization bar [`3c4bc0c`](https://github.com/fomantic/Fomantic-UI/commit/3c4bc0c2bf366d6ebcba788b76a331571d9e9ee1)
- Updates formatting on extra content in card view [`7bb1ac4`](https://github.com/fomantic/Fomantic-UI/commit/7bb1ac409c1d2650c5be6509575b96f10cb840ac)
- Add flowing popup variation [`22dc6cb`](https://github.com/fomantic/Fomantic-UI/commit/22dc6cb4ba4e3fdf30b4afb7705a104d3142d66f)
- Fixes heinous typo in horizontal flip out [`e7d14d7`](https://github.com/fomantic/Fomantic-UI/commit/e7d14d79135352ab88fe9089271a55fe24bc7b54)
- Adds reset behavior to transition [`3e750d8`](https://github.com/fomantic/Fomantic-UI/commit/3e750d8b8ed8f9152f596b63e3d5c50efee80670)
- Fixes some typos in docs, popup docs example formatting [`926cc39`](https://github.com/fomantic/Fomantic-UI/commit/926cc390b4766ff75f2fbbf96781899d2dbb81c5)
- Fixes icon button formatting in example [`f06355a`](https://github.com/fomantic/Fomantic-UI/commit/f06355a43298dd0c9219a29689a904cb32c24a86)
- Fixes attached segment not receiving :first/:last child stylings [`7bfa4de`](https://github.com/fomantic/Fomantic-UI/commit/7bfa4de071b3bd961088efcf4274a00c34db7184)
- Add `checked` validation rule. [`2a06ffd`](https://github.com/fomantic/Fomantic-UI/commit/2a06ffd227815b7935616d323dda19e43f376855)
- Moves label coupling to label.less [`8f19744`](https://github.com/fomantic/Fomantic-UI/commit/8f19744afa9f4a053b809095e1ba398c23eb49e9)
- Reduce large icon size and add big size [`cca1223`](https://github.com/fomantic/Fomantic-UI/commit/cca12232cc8edde8e6b7f72026b65aea2e46337f)
- Forces list items to clear floats [`48b3494`](https://github.com/fomantic/Fomantic-UI/commit/48b3494cb33b6a53e8852ad49db027fb24854e6c)
- removes redundant line [`33c9b89`](https://github.com/fomantic/Fomantic-UI/commit/33c9b89d7400aaacbf89c7eb240b1ba973fac48a)
- Fix bug in segment only-child [`6a4ae27`](https://github.com/fomantic/Fomantic-UI/commit/6a4ae270a163253c154b49ee8ad53a1c809f713a)
- Removes class reset from show [`6280bce`](https://github.com/fomantic/Fomantic-UI/commit/6280bce801775611680fe3e9746a6cc8122a7740)
- fixes logic for more complex example source [`6bc92fa`](https://github.com/fomantic/Fomantic-UI/commit/6bc92fa26527671f6ecb970aafbc02acd5724b9d)
- Adds compact segment variation [`86e0585`](https://github.com/fomantic/Fomantic-UI/commit/86e05859c16f4f7b6ea7b6e1c2a484da5186b469)
- Fixes circular icon buttons to be perfect circles. #1141 [`69e2b05`](https://github.com/fomantic/Fomantic-UI/commit/69e2b052c104ad8a61d0d6208cf49c585de21c07)
- Remove 0% height from non simple dimmers [`9f48211`](https://github.com/fomantic/Fomantic-UI/commit/9f482118143a44d9d599fd26009f591d7509a270)
- Adds fluid card varaition #1116 [`2d3c60d`](https://github.com/fomantic/Fomantic-UI/commit/2d3c60d4c4091caf835e894b6aaff0967a87a1fe)
- Fix for dropdown destroy [`37f7dc9`](https://github.com/fomantic/Fomantic-UI/commit/37f7dc9bb9fd1adbdf907a66670a424541730dcd)
- Fix some anchor links not working [`3bc6f3d`](https://github.com/fomantic/Fomantic-UI/commit/3bc6f3d7ecc84cdd8528e78e312e22c1af46caf2)
- Comment out language modal for friday night, too much trouble [`738d105`](https://github.com/fomantic/Fomantic-UI/commit/738d1050af9bb9d5923141ae0db72731d0919251)
- Only call transition reset on modal dimmer hide when module available [`c036282`](https://github.com/fomantic/Fomantic-UI/commit/c036282550e1f3e463caef6126eafa589925f5e1)
- Doc: Icon class typos [`27016f2`](https://github.com/fomantic/Fomantic-UI/commit/27016f2704e43f975d44a3f2d6c5af2af06386c0)
- Doc: Reordered icons existing code [`137f33b`](https://github.com/fomantic/Fomantic-UI/commit/137f33b8b195c50708577da0fd46b2924b8a315c)
- Dropdown: Fixes issue where last matching item was found, without prioritizing value over text #502 [`cf6f6ab`](https://github.com/fomantic/Fomantic-UI/commit/cf6f6abcef1fbf97094249fe9eb543b9f7111004)
- Updates message docs about dismissable message [`d41ffa4`](https://github.com/fomantic/Fomantic-UI/commit/d41ffa427da70e9eb05ff895f7776f2fbe41e798)
- Keeping Modal in place [`1021857`](https://github.com/fomantic/Fomantic-UI/commit/10218571004ea9c5fdd91b2aec5fa0a7b1de4c2d)
- Adds browser support to readme [`8bd5939`](https://github.com/fomantic/Fomantic-UI/commit/8bd59393661b4619becd9f03862035eb57706fa5)
- Fixes title labels on doc header [`f278c50`](https://github.com/fomantic/Fomantic-UI/commit/f278c509d7d25a540522c104bedd4c9ac72cde80)
- remove some trailing spaces and add coverage badge to README [`d6ebd5b`](https://github.com/fomantic/Fomantic-UI/commit/d6ebd5b60ba89a7a6f97b34c71c122f70b6fc072)
- Reorder webfont urls to help prevent low quality icons in Chome on Windows [`ad46e10`](https://github.com/fomantic/Fomantic-UI/commit/ad46e10fda5035ffdf5b248df851744fb7b95bed)
- replaced "initial" with "text" [`a7a2380`](https://github.com/fomantic/Fomantic-UI/commit/a7a2380084f0612502112599d0236b472b2665ed)
- Darkens placeholder text color [`6806492`](https://github.com/fomantic/Fomantic-UI/commit/6806492c9f38921ee4c10657e0d6d2259f30ca50)
- Reduces the size of labeled icon buttons [`a96fac2`](https://github.com/fomantic/Fomantic-UI/commit/a96fac2e47d861b2b4e009ec4563320f1e2532d8)
- update header.less to use current @green color [`01858d6`](https://github.com/fomantic/Fomantic-UI/commit/01858d688bcc92c66e9c84ab3c3360d8792bf2cd)
- updates icon docs for rotate [`0998c5c`](https://github.com/fomantic/Fomantic-UI/commit/0998c5c02984ffbf20a4c503d995b874e3d716e0)
- rebuilds one last time [`f7c003f`](https://github.com/fomantic/Fomantic-UI/commit/f7c003f15bc5fbc70b5d6ad6491f6fa80f894e2d)
- fixes outdated icon on dropdown example [`e0a640b`](https://github.com/fomantic/Fomantic-UI/commit/e0a640b5d8d9fa520e3d0dcd036b0c5082cf36c2)
- fixes examples using grid to match 16 [`12cd9c7`](https://github.com/fomantic/Fomantic-UI/commit/12cd9c7cd9faaa133751db03fc940780f0634b2d)
- Fixes missing variable in input [`faedd3b`](https://github.com/fomantic/Fomantic-UI/commit/faedd3b9fd5329c1fb1d52f62c703d566fa19879)
- Fix attached/block inheritance. Now works together well [`1013cf5`](https://github.com/fomantic/Fomantic-UI/commit/1013cf512d64aaafa8c27e11e410c4dcbdac54f1)
- Fix horizontal segments inside grids [`05f4544`](https://github.com/fomantic/Fomantic-UI/commit/05f454447a562124a89052a0172198465b53413c)
- Fixes dropdown inside even-item menu [`dbf9d20`](https://github.com/fomantic/Fomantic-UI/commit/dbf9d20f2cc81f51fbcd3761be2c754f513ab379)
- Fixes placeholder on input element [`61dfb62`](https://github.com/fomantic/Fomantic-UI/commit/61dfb620278b6c0220272e11befe2940ac169c50)
- Button: Adds font family setting to buttons [`8abb1d6`](https://github.com/fomantic/Fomantic-UI/commit/8abb1d699eedbc0ad1ffd13da48e5d7b51fe6ef6)
- removes unnecessary example images [`134d1b9`](https://github.com/fomantic/Fomantic-UI/commit/134d1b9b8577e9fbebe1277383614a062f016dc0)
- Fixes dropdown position in sedcondary menus [`2f7f3ae`](https://github.com/fomantic/Fomantic-UI/commit/2f7f3ae857510f2cdd308f3fbf872120eed547b6)
- Fixes horizontal list content float [`7f7ac42`](https://github.com/fomantic/Fomantic-UI/commit/7f7ac4257add84f9e7246cf1bebc6eea004e9e77)
- Adds page grid coupling for segment [`eff7c2e`](https://github.com/fomantic/Fomantic-UI/commit/eff7c2e0899c3de64c179a839c05c8f64e5dd780)
- attempt at simplifying gtravis [`5db4fa4`](https://github.com/fomantic/Fomantic-UI/commit/5db4fa446bba0331bbea4295a6dfe3e0bf20db4a)
- updates formatting slightly in global vars [`cb6753a`](https://github.com/fomantic/Fomantic-UI/commit/cb6753a8e2224c127b56320cc77a62b7b8de9ece)
- Fixes regression with checkbox issue #154 [`3fb5741`](https://github.com/fomantic/Fomantic-UI/commit/3fb57418bcc90f3bd1eee048cd23d975a8a5a523)
- removes loading icon, css spinner is too imprecise [`e6250ef`](https://github.com/fomantic/Fomantic-UI/commit/e6250ef964303586542dd308be6a39eff6868d8e)
- Fixes layout regression in accordion [`605b036`](https://github.com/fomantic/Fomantic-UI/commit/605b03667321f00f471813e35f34058dc5275106)
- Fixes progress example init [`346d29c`](https://github.com/fomantic/Fomantic-UI/commit/346d29c1cd40fcc0aa431da51ad8c7ada0881c00)
- Fix issue with destroy in visibility [`ad7f3f6`](https://github.com/fomantic/Fomantic-UI/commit/ad7f3f662f378b7bb07179b3ba26e766b53f3913)
- Remove detachable from lang selector [`f071900`](https://github.com/fomantic/Fomantic-UI/commit/f071900e163ed85d2f31d55371dee004568bf2c9)
- Couple more vars in progress [`3d49a31`](https://github.com/fomantic/Fomantic-UI/commit/3d49a3140d1cce4ce761b3012831443ebd8f56a0)
- Update README.markdown [`e28c3e0`](https://github.com/fomantic/Fomantic-UI/commit/e28c3e0aad3e05178cbb0041d1b1267c3e3b59b6)
- Fixes some typos in release notes [`e7a4543`](https://github.com/fomantic/Fomantic-UI/commit/e7a4543fdc2792f676ee061ce70236f7bf7d3552)
- Update semantic.css [`92cbd8a`](https://github.com/fomantic/Fomantic-UI/commit/92cbd8adc83c844a1bc860dc149f8a2738789140)
- Update dependencies [`03a7e79`](https://github.com/fomantic/Fomantic-UI/commit/03a7e79137d644fd1ae671ea90fc3e95282cfd1e)
- comma instead of "or" [`f085f8c`](https://github.com/fomantic/Fomantic-UI/commit/f085f8c1fc305fcd02dc0717686a4b72594b7edd)
- Add ok/cancel combination to the selectors list [`cc9e0ba`](https://github.com/fomantic/Fomantic-UI/commit/cc9e0ba823fdfaa96bd9a19cf4bc76cf109fb5a0)
- Adds justify aligned to header [`63a53ed`](https://github.com/fomantic/Fomantic-UI/commit/63a53eda3444db4539bdea97eecc841456e15d70)
- Adds online assets to production only (ads/starred count) [`d0e9e9f`](https://github.com/fomantic/Fomantic-UI/commit/d0e9e9f47e444237865698121b13679de9de4cd6)
- Adds online assets to production only (ads/starred count) [`3d7441a`](https://github.com/fomantic/Fomantic-UI/commit/3d7441a38297c6e758486ef26ed200e913e719fc)
- Adds boolean example to dropdown page [`1d38efc`](https://github.com/fomantic/Fomantic-UI/commit/1d38efc6656b63bb2471317827ee9f966a3872e7)
- Fixes segment inside inverted segment having text color swiched #346 [`683d1d6`](https://github.com/fomantic/Fomantic-UI/commit/683d1d63cb8a12d753950c020fbb491e454323a5)
- Fixes :not specificity adding too much weight to button state selector [`6a3cf2c`](https://github.com/fomantic/Fomantic-UI/commit/6a3cf2cafcc7063bb8fd6144ef9e5152a8c58de8)
- fixes dropdown bug #256 [`f2a8fea`](https://github.com/fomantic/Fomantic-UI/commit/f2a8feab1b1355a9eac232d3fdb37b510da66ee1)
- Fixes circular icon inheritance issues [`18da1d0`](https://github.com/fomantic/Fomantic-UI/commit/18da1d00d9fbc47cd95e477f157bd5f83e0b9b5d)
- Moving grunt tasks to package.json so compatible with npm test [`d3de0a8`](https://github.com/fomantic/Fomantic-UI/commit/d3de0a85deebaf4bae2fddaf55d2f70fae907d74)
- updates release notes [`e5a0888`](https://github.com/fomantic/Fomantic-UI/commit/e5a088853941faba6f48f196fc079963e9c15a4d)
- fixes text item example [`4682f6b`](https://github.com/fomantic/Fomantic-UI/commit/4682f6bd5b13281a7a15de70ce53b842f31d2c22)
- fixes popup example [`10f74fd`](https://github.com/fomantic/Fomantic-UI/commit/10f74fd3d39a8c5b1372e96cd0e3fce4b02b27e6)
- fixes regression on some dropdowns with whitespace fix [`627a6a2`](https://github.com/fomantic/Fomantic-UI/commit/627a6a25af290419378baec663bd96fe6e85b116)
- removes redundant definition note [`899ece6`](https://github.com/fomantic/Fomantic-UI/commit/899ece6b12b35b6f8d0770ea7e3edc6c62079277)
- see reddit: turns down the font weight of the damn buttons [`bf85682`](https://github.com/fomantic/Fomantic-UI/commit/bf856822c1968b6666f96174e789469c7cf61e52)
- fixes toggle color [`8a345d1`](https://github.com/fomantic/Fomantic-UI/commit/8a345d190fc6e4a998fc9d742b8c86d13b58f0b3)
- shape: fixes header [`d35c48a`](https://github.com/fomantic/Fomantic-UI/commit/d35c48a4b4505f743f04be47929bc957ef712feb)
- Adds active min width and reset behavior [`c510193`](https://github.com/fomantic/Fomantic-UI/commit/c510193ac5450e9197ce605bb86755dd6b3bb033)
- Fix mobile example overflow with large images [`48eb9ab`](https://github.com/fomantic/Fomantic-UI/commit/48eb9ab060eb0f0e7db6ba8f9839eeb74c993b5f)
- #1097 Fixes issue with Piled Segment [`c984cce`](https://github.com/fomantic/Fomantic-UI/commit/c984ccefc32bd7ac59bbfd5485c5d4f019f27837)
- or text variable [`79caa95`](https://github.com/fomantic/Fomantic-UI/commit/79caa959416521b71c89b30e5a437ebe48b883d9)
- Changes to docs [`f79c658`](https://github.com/fomantic/Fomantic-UI/commit/f79c658422860173d4149d504bc281a0993aac79)
- Slight update to input sizing inside menus #553 [`d5d293d`](https://github.com/fomantic/Fomantic-UI/commit/d5d293ddf7ffd740fbdabfd04c74186b0ddff5b8)
- Doc: Added existing code for basic social icons [`40cebae`](https://github.com/fomantic/Fomantic-UI/commit/40cebae44932bb608d07b9e80166a05a19c9b391)
- Menu: adds fixed menu coupling with grid #479 [`656474f`](https://github.com/fomantic/Fomantic-UI/commit/656474fbe63cc8b65ef82bb2e3e068b66e5d9b91)
- Add detachable setting [`77f707a`](https://github.com/fomantic/Fomantic-UI/commit/77f707acee369c82f67766743feeb90ab59a46c3)
- Removes coverage adds translations to readme [`a2129f6`](https://github.com/fomantic/Fomantic-UI/commit/a2129f69a735d47cfde43a967256d5e67b8cb3a1)
- Fix Menu dropdowns not closing in IE11 #409 [`44b16bd`](https://github.com/fomantic/Fomantic-UI/commit/44b16bdb5da56a99629c6da8365d0c65a77d4bb6)
- Fixes issue with dropdown not receiving poiner cursor ala #309 #303 [`f19ba45`](https://github.com/fomantic/Fomantic-UI/commit/f19ba4576614738381fdf712d7fdda04467c3b5f)
- update global.variables. [`f444b7e`](https://github.com/fomantic/Fomantic-UI/commit/f444b7e3675be5e9c1f3dde8dd182fd3a152b7e3)
- Add hover state for white button [`b86d750`](https://github.com/fomantic/Fomantic-UI/commit/b86d750407afbf2119df8117bb5f63e42d524011)
- modifies release notes [`40431ed`](https://github.com/fomantic/Fomantic-UI/commit/40431eda5db671fe9938dcd63c7380ed9b2f0d3c)
- adds to settings doc [`4f8febb`](https://github.com/fomantic/Fomantic-UI/commit/4f8febbc8d1f588a6d6d4887643d9b42461c5adf)
- Adds some missing files to build [`68d5997`](https://github.com/fomantic/Fomantic-UI/commit/68d59976d18184a0de349a8153566bd5bae88f81)
- Update RELEASE NOTES.md [`40abc26`](https://github.com/fomantic/Fomantic-UI/commit/40abc26a4faf045fdbc6dd82d1e85ba5a3a8c69d)
- twiddling around with transition to fix in/out [`ace5a1f`](https://github.com/fomantic/Fomantic-UI/commit/ace5a1f411d81201ac34aded30e466cd4720e18b)
- packaging -- changed version to semver. removed deps folder. [`eb88b6f`](https://github.com/fomantic/Fomantic-UI/commit/eb88b6f0a383153f78c6f510976b156675573d30)
- Fixes issue with flag icons [`b43dc13`](https://github.com/fomantic/Fomantic-UI/commit/b43dc13198ea33e723c53a5ae126161f064b6648)
- Tweak to circular icons valign 141 [`05e184b`](https://github.com/fomantic/Fomantic-UI/commit/05e184b8afafb42baff98776a737482314a1b5f7)
- Make segment REM for margin/radius [`1deb6eb`](https://github.com/fomantic/Fomantic-UI/commit/1deb6eb70de48c89e243288ba39bbbca437fe77a)
- Updates disabled checkbox colors to be more legible [`6db252b`](https://github.com/fomantic/Fomantic-UI/commit/6db252bca38633be760d00abbb57a4ed355e48e6)
- Fix dupe of module instanciation in checkbox [`cbf8d76`](https://github.com/fomantic/Fomantic-UI/commit/cbf8d76265df5987f60618d9ba0ae24900c7f573)
- Fixing issues [`9574066`](https://github.com/fomantic/Fomantic-UI/commit/9574066d59ebf4ece57bda407520a4f608dec4e4)
- Sidebar- default mobile animation is now overlay [`7a4faf7`](https://github.com/fomantic/Fomantic-UI/commit/7a4faf7aae721749c91cd99b99732f7baa148600)
- Sets all debug to false [`b4fcb35`](https://github.com/fomantic/Fomantic-UI/commit/b4fcb35441e5cdcae5e96c1121f61bd40080cb94)
- Fix buttons in cards [`c1ce7f2`](https://github.com/fomantic/Fomantic-UI/commit/c1ce7f2c5ae9c94e4f34590bf8d727e26ffc4393)
- Fix sticky transition properties [`6856a89`](https://github.com/fomantic/Fomantic-UI/commit/6856a8907995373887bfae1876b0471c224ae6e4)
- Increase font size of messages slightly [`cba19ca`](https://github.com/fomantic/Fomantic-UI/commit/cba19ca5b55799be3e3e4cb0b234df5e04e28dfe)
- Fixes for divided grid [`974def4`](https://github.com/fomantic/Fomantic-UI/commit/974def4146df3bfef98b51d2284ebc248bf4d8af)
- Fix broken accordion due to ec029e3275d4a0c117b1b157e753e414f237abbf [`ee1df7c`](https://github.com/fomantic/Fomantic-UI/commit/ee1df7c90ea50bf08579f86628e1073c9f87709f)
- fix reversed hide/unhide basic icons [`aa79378`](https://github.com/fomantic/Fomantic-UI/commit/aa793789e2fd960e527b7085a9553561e7d8559a)
- Missing build files [`298ffae`](https://github.com/fomantic/Fomantic-UI/commit/298ffaea42d49bfd31dbe224d06c256c5adcc2f5)
- Fixes package.json causing build error [`aaf700d`](https://github.com/fomantic/Fomantic-UI/commit/aaf700dbe2a20954a14edc891642a1bf38d8d7ad)
- Fixes package.json causing build error [`f1872db`](https://github.com/fomantic/Fomantic-UI/commit/f1872dbaf5e555d836538d8d0fd64d024bea72bb)
- #573, checkbox example still missing label for [`527498b`](https://github.com/fomantic/Fomantic-UI/commit/527498bddf526b918c2e566a0d817d9cff6f3793)
- Doc: Typo in attention icon [`be4b934`](https://github.com/fomantic/Fomantic-UI/commit/be4b9346592be4a24f0df6d55b4ded56ab247711)
- Comment unused sticky menu item [`5a0a2e0`](https://github.com/fomantic/Fomantic-UI/commit/5a0a2e04168ffbad9a0c7999b3a2b0954f973ff5)
- Comment unused sticky menu item [`46c276c`](https://github.com/fomantic/Fomantic-UI/commit/46c276cf8d9f48315a2701aa0333f5812c5a03e4)
- Reverts #423, sidebar changes [`c85111d`](https://github.com/fomantic/Fomantic-UI/commit/c85111db987648cc4da45d6d26987b06e4253cf5)
- Fixes link path in docs [`78837bc`](https://github.com/fomantic/Fomantic-UI/commit/78837bcd5cb92b8aefe72248dfd0e336308b0773)
- Adds more translation details to README [`affea90`](https://github.com/fomantic/Fomantic-UI/commit/affea9028006a0581a2ef3c52e9c086ea02371ae)
- Updates release notes for 0.11.0 [`da1f9be`](https://github.com/fomantic/Fomantic-UI/commit/da1f9be04dd87fb59f6d0b48f2f4ab653ec3cb70)
- Modal: Fixes IE detection, IE11 now reports navigator.appName as Netscape and not Microsoft Internet Explorer LOL [`00a9209`](https://github.com/fomantic/Fomantic-UI/commit/00a92094383dca9ceefd05cd2373c35afd789dae)
- Moves forced repaint event only to dropdown [`06edf0d`](https://github.com/fomantic/Fomantic-UI/commit/06edf0dd82b52f494033a84c7ec5061a3136003e)
- Formatting on popup [`84c902a`](https://github.com/fomantic/Fomantic-UI/commit/84c902ac20ecd8dca65623989b701376bf189aee)
- Fixes bug in detatch where before was being used instead of insertBefore causing issues with siblings [`87f6f23`](https://github.com/fomantic/Fomantic-UI/commit/87f6f23c282c7509cc9fbca5869eefc8ab9b5d22)
- Fixes detatch to only occur on dimmer when element is not inside dimmer [`f5f3759`](https://github.com/fomantic/Fomantic-UI/commit/f5f37597aadd5e255de39fe764e63e0ff4c4b308)
- condition will never evaluate to true [`7e9e190`](https://github.com/fomantic/Fomantic-UI/commit/7e9e1904ff0423be2bef2df632bb56ea00974da8)
- Adds vk button to docs [`a08f001`](https://github.com/fomantic/Fomantic-UI/commit/a08f0011377c1b3c249891f544e5786b7c90113c)
- Fixed packaged version. Addresses #415. [`0acc013`](https://github.com/fomantic/Fomantic-UI/commit/0acc013f8f4ff42717c113879133af23f11b7abc)
- run grunt-coveralls after travis testing [`32250fb`](https://github.com/fomantic/Fomantic-UI/commit/32250fb4f67c87e40936de2d77776b6dc849f319)
- Fixes missing tags/ double props on homepage [`20135d7`](https://github.com/fomantic/Fomantic-UI/commit/20135d7c13f0ec4e9be5054c2a311b780136b689)
- Forces no negative margins on top level grids to avoid body overflow [`1ad5a0d`](https://github.com/fomantic/Fomantic-UI/commit/1ad5a0d75d8bed8fcb0a3ac073b0427a167495de)
- Fixes broken not selector, selection lists now move on hover [`6522138`](https://github.com/fomantic/Fomantic-UI/commit/65221387b546a2ee68c88f7e15478bc2a95f413a)
- errant console log removal and fixing right margin on labeled icon inputs [`ce9f96b`](https://github.com/fomantic/Fomantic-UI/commit/ce9f96b521b3c937af9075daccc4e6de6ac6581b)
- typo in sortable tables [`e46bde6`](https://github.com/fomantic/Fomantic-UI/commit/e46bde670b1c63af658db45147c18b115ea59aaf)
- updates module spec [`d0ca575`](https://github.com/fomantic/Fomantic-UI/commit/d0ca575e99c9ca11e64d3658a167a84c3ceb07b8)
- Fixes 1pixel jump in tabular menu [`0e1570c`](https://github.com/fomantic/Fomantic-UI/commit/0e1570c0f92e92a5d469954320dc27b965630ae0)
- adds share image [`30d6952`](https://github.com/fomantic/Fomantic-UI/commit/30d6952ad463144d229d6260bd5d4551d663d4ef)
- Darkens dropdown active color to make it more visible [`d0fc837`](https://github.com/fomantic/Fomantic-UI/commit/d0fc83759ce0dad6eed3144ba72cc9e68ef57d8b)
- Adds cursor formatting for icon input to prevent text selection cursor [`0b0123e`](https://github.com/fomantic/Fomantic-UI/commit/0b0123e063d21a523fa952af95cd1042c651cefb)
- bad typo [`73615d5`](https://github.com/fomantic/Fomantic-UI/commit/73615d59105bc3c461e579b55146eff8d83e29b0)
- Fixes license on composer [`b4ca8bb`](https://github.com/fomantic/Fomantic-UI/commit/b4ca8bbc01cc8673f9a3ca669bb256bb9d43aff7)
- updates release notes [`ff9b1b9`](https://github.com/fomantic/Fomantic-UI/commit/ff9b1b92c420b6165637563aabedce91cd562f73)
- Removes erroneous description from menu docs [`6fbf1ed`](https://github.com/fomantic/Fomantic-UI/commit/6fbf1edef993b88544a0925d0b32ba1b19277285)
- Version uptick [`1474d13`](https://github.com/fomantic/Fomantic-UI/commit/1474d13ed400766976c0268037eef98c2f827473)
- cosmetic error on homepage [`ebdf461`](https://github.com/fomantic/Fomantic-UI/commit/ebdf461a2d024e92a08c798ee607af7389be5ec3)
- removes massive size, too large [`6a26376`](https://github.com/fomantic/Fomantic-UI/commit/6a263763727c9f7f711ba96a97435609c3d63b5b)
- oups, forget to remove the line-height test in basic-icons's file [`912077a`](https://github.com/fomantic/Fomantic-UI/commit/912077a95cbf0a938f7a8e8345068b3e42bccbdd)
- updates release notes [`a1b048e`](https://github.com/fomantic/Fomantic-UI/commit/a1b048e428171d9370d142eff5209fb71d49f2ad)
- updates version # [`2bba917`](https://github.com/fomantic/Fomantic-UI/commit/2bba91772b4d8760fc4e85706fb44351fb2f2d1d)
- updates typo in form docs [`472350a`](https://github.com/fomantic/Fomantic-UI/commit/472350aed688aeae582eebc75efc0429c9a4d964)
- another extra comma in bower.json [`f59ddaf`](https://github.com/fomantic/Fomantic-UI/commit/f59ddafa5e9e449c9fdfa8617f143e8fba5b64c8)
- another broken icon on dropdown example [`0534a8a`](https://github.com/fomantic/Fomantic-UI/commit/0534a8ae8f0310e048efbaf86101c705be45c0d6)
- fit height [`9b971a5`](https://github.com/fomantic/Fomantic-UI/commit/9b971a56ae94f76e6f6c71281467a52d3d910719)
- slight tweak to spec json [`834e3ab`](https://github.com/fomantic/Fomantic-UI/commit/834e3abbd9c6ad3f4c88542925b0aab2c04756f4)
- fixes edit in css guide [`0b68c0b`](https://github.com/fomantic/Fomantic-UI/commit/0b68c0b8c890abe3eac1253ce1cd5e94662307e0)
- fixes accordion menu example [`d70ce4b`](https://github.com/fomantic/Fomantic-UI/commit/d70ce4b1ca51b85401655874239243d741360ba2)
- terrible grammar / typo fix [`fe70cf4`](https://github.com/fomantic/Fomantic-UI/commit/fe70cf462620f3e47bb724e4cc865f79f6fe0719)
- still had url messed up for accordion [`b052bfd`](https://github.com/fomantic/Fomantic-UI/commit/b052bfdb698e41f3dd0d42ffab59583efd8a0fa7)
- fixes accordion js link [`0d5f653`](https://github.com/fomantic/Fomantic-UI/commit/0d5f653ae4b4f570c69e1b08c6961c72aaa54d9b)
- Updates variations on table [`c32425e`](https://github.com/fomantic/Fomantic-UI/commit/c32425e6e2d093ddcb405f56aab63964027e4f80)
- tiny text fix [`e84560e`](https://github.com/fomantic/Fomantic-UI/commit/e84560e677168bd00c53fccd4c40054e95d6e9f9)
- packaging -- removing old deps from components. [`7cfb003`](https://github.com/fomantic/Fomantic-UI/commit/7cfb00314ae261f993f5f2d9b6bdc42e61533482)
- module language [`8812b37`](https://github.com/fomantic/Fomantic-UI/commit/8812b37097d4d2676b163a060ef586d86c995b0d)
- fixes chrome table edges [`eeeeb2a`](https://github.com/fomantic/Fomantic-UI/commit/eeeeb2af1449caa516103a73880d338ed3e58edf)
- Initial commit [`d37520a`](https://github.com/fomantic/Fomantic-UI/commit/d37520a7de17b9f6659614c14e091a46ccc54d16)
- Remove console log from modal [`49add36`](https://github.com/fomantic/Fomantic-UI/commit/49add3642aad631661c91b1ea8ac3e36c66a6440)
- Fix for backface visibility on shapes [`9de8f8f`](https://github.com/fomantic/Fomantic-UI/commit/9de8f8f62bc379cf3a34b3a65366ccf1ce408102)
- #1134 issue with ui input not having valign but using table-cell [`d819d74`](https://github.com/fomantic/Fomantic-UI/commit/d819d74132cefca9aef5cd942c6f877772dd6e2e)
- Remove console logs from dropdown, #1123 [`0219c60`](https://github.com/fomantic/Fomantic-UI/commit/0219c609b62952f4941ddc326a4e63f162c2f887)
- Feature stripe spacing [`22edfab`](https://github.com/fomantic/Fomantic-UI/commit/22edfab422d7cfd084f14420823b7a420a27cadf)
- Missing closing tag in loader [`16bc53c`](https://github.com/fomantic/Fomantic-UI/commit/16bc53cf6dff776d627ce2e6de93f5292956c667)
- Update release notes [`b5fa4b3`](https://github.com/fomantic/Fomantic-UI/commit/b5fa4b378873255f9431448d4d37882b6dc09c8c)
- Fix icon alignment in timeline feed view [`9c36f83`](https://github.com/fomantic/Fomantic-UI/commit/9c36f833166dcaa6b7e509395626dd4c97f84938)
- Fixes checkboxes not to submit form on enter [`d95a163`](https://github.com/fomantic/Fomantic-UI/commit/d95a163cc8ff42400b3dc5a5ac9d33bae6705912)
- Preserve new lines from original src [`702052e`](https://github.com/fomantic/Fomantic-UI/commit/702052e254f709b5627bf98ec5fc4e512a542ec1)
- Fixed labeled menu icon button icon positioning. [`8eb03ca`](https://github.com/fomantic/Fomantic-UI/commit/8eb03ca4ab32163b7653f8f8c528d1285b0ae6c9)
- Fixes issue where queued animation sometimes does not occur if same animation caused by lack of repaint [`1319c3f`](https://github.com/fomantic/Fomantic-UI/commit/1319c3f33ee1a7a6252fbe92403922cf56a02128)
- Adds debugging for tab hash [`b3f862e`](https://github.com/fomantic/Fomantic-UI/commit/b3f862e1cd2eb3a8c1be2f48c834abf6968b8b5a)
- Adds inverted border color variables [`08af12f`](https://github.com/fomantic/Fomantic-UI/commit/08af12fdc767613eef44d26e7c498af208672aaa)
- Fixes issue where direct child column could not use pc/tablet/mobile only [`9e4ea6a`](https://github.com/fomantic/Fomantic-UI/commit/9e4ea6a7ab69dda4415d9c888a696c21ccb90ddc)
- Fixes bug in jquery waypoint usage [`870b62a`](https://github.com/fomantic/Fomantic-UI/commit/870b62a377d98dc9aceab3a04127aa85dea668b2)
- update global colors [`c755566`](https://github.com/fomantic/Fomantic-UI/commit/c75556683c34a80df5f342d1fde6314983303ba4)
- adds coupling to dropdown to point arrow right direction automatically in vertical menu dropdowns [`2b45619`](https://github.com/fomantic/Fomantic-UI/commit/2b456192ca2e95e75fbc15b587eea135bc5bcaab)
- fixes affixed menu positioning [`6e17c75`](https://github.com/fomantic/Fomantic-UI/commit/6e17c75062ff3b6e211c88b189f1e67edd5c605e)
- Smaller size for menu fixed button [`5457b18`](https://github.com/fomantic/Fomantic-UI/commit/5457b186e380167cbf733fc0655dad5f6f3e1197)
- Add margins to right/left floated segments [`ff2d1da`](https://github.com/fomantic/Fomantic-UI/commit/ff2d1da1af87cd171845d3a791fccbed37780ea4)
- Keep swapping icon button alignment, this fixes dropdown icon alignment [`e146f5e`](https://github.com/fomantic/Fomantic-UI/commit/e146f5e786e83ef3439dd5066d68c327d09367e8)
- Fix language labels hiding on code samples [`44d62b8`](https://github.com/fomantic/Fomantic-UI/commit/44d62b874c95e4514459864470b5185213c25ab5)
- Adjust subtle colors [`5c310a8`](https://github.com/fomantic/Fomantic-UI/commit/5c310a85aee056d24163362ad2d7705bdff3d331)
- Add bottom pointing label instead of below pointing [`52245cc`](https://github.com/fomantic/Fomantic-UI/commit/52245ccbd5120a3dd7654bcb99710c80cf8c58c5)
- Fix label in example [`06ea60e`](https://github.com/fomantic/Fomantic-UI/commit/06ea60e558f0919a0a72cf3e6ca50760f3a5b8f1)
- Fix disabled step bg [`5306800`](https://github.com/fomantic/Fomantic-UI/commit/5306800ef66a30b76d1e79d3db3310ca633a1c0e)
- Fix header size again [`e4f4b2c`](https://github.com/fomantic/Fomantic-UI/commit/e4f4b2c19e1b9521156748913bbcf2c85db75584)
- Fix chinese language code [`0fcc666`](https://github.com/fomantic/Fomantic-UI/commit/0fcc666fedcd1347ee3057d179988abe27b84f2f)
- Add github theme to dropdown [`8d69656`](https://github.com/fomantic/Fomantic-UI/commit/8d69656a45b32208e89612029efcd44bb010b51c)
- Fix feed margin [`6cfd443`](https://github.com/fomantic/Fomantic-UI/commit/6cfd44359ce463892e38fe4c91b8e0e497267e1a)
- Add ui flag attribution [`82db2c7`](https://github.com/fomantic/Fomantic-UI/commit/82db2c79698f683e01f6690e0f60fe5e9ff93c3e)
- Swap video module icon [`b747338`](https://github.com/fomantic/Fomantic-UI/commit/b7473385f725aba3cd48ac93a1e55f72e3223fff)
- Experimenting with new header margins [`44e12e1`](https://github.com/fomantic/Fomantic-UI/commit/44e12e1872cdd5ac615c0daa6c7fb3bd57d41d50)
- Fix margin on buttons inside cards [`feb2135`](https://github.com/fomantic/Fomantic-UI/commit/feb2135b6633a967198dd864dc713f2bb5ecbfb1)
- Fixes dropdown offset on menu [`72c41b2`](https://github.com/fomantic/Fomantic-UI/commit/72c41b29548e98e2f24eda61ebb482a30e74856d)
- Adds selected item to callback for dropdown onChange [`1918957`](https://github.com/fomantic/Fomantic-UI/commit/1918957d458e4e61b944a37ef3cdbde029202b1f)
- Fix typo in grid rules [`18b8e2f`](https://github.com/fomantic/Fomantic-UI/commit/18b8e2f7cf7197c051ac3cad6be61c97d9cbbe9b)
- Reduces black to slightly more neutral [`f7f9f76`](https://github.com/fomantic/Fomantic-UI/commit/f7f9f7649bd4b97c1d9e723fcb1215eac306b975)
- Fix issue with animated button [`319a534`](https://github.com/fomantic/Fomantic-UI/commit/319a53492573bb54cc970be2d1e429fdeeeca5c4)
- Revise message definiton [`90f88ca`](https://github.com/fomantic/Fomantic-UI/commit/90f88cab90af673ee4dc00d18611eb9ecb5b8396)
- Update README.markdown [`7d89bb9`](https://github.com/fomantic/Fomantic-UI/commit/7d89bb98f9987dd3cfcf1f6ff7a50d859559b0c2)
- Fixes repo link [`9561d9a`](https://github.com/fomantic/Fomantic-UI/commit/9561d9a851d965980bbccf0ecea666ee9df9e6c6)
- Fixes checkboxes not triggering native change event for input [`f62d669`](https://github.com/fomantic/Fomantic-UI/commit/f62d669197bc6d88699af13f888c0f4abbe22c4c)
- #630 Fixes issue with right menu border [`dc50bec`](https://github.com/fomantic/Fomantic-UI/commit/dc50becdc9db2bf24186f0cccb283bfbce89ff15)
- Updates some doc issues on input [`77101d0`](https://github.com/fomantic/Fomantic-UI/commit/77101d03cda559f0d29acabd2958f2781eba30ea)
- Forgot to update site ver # [`819b608`](https://github.com/fomantic/Fomantic-UI/commit/819b6084270332a05ff67bc52a065455268b7444)
- Disables transition debug by default, too chatty [`339b236`](https://github.com/fomantic/Fomantic-UI/commit/339b2369e26bb7523597663142e6679aa02e9ec3)
- possible typo [`2b2abeb`](https://github.com/fomantic/Fomantic-UI/commit/2b2abebc5d20c3f7bb70e9fbaa758070821eb0e4)
- removed extra comma [`176185f`](https://github.com/fomantic/Fomantic-UI/commit/176185f88112fcb1340481c5b7c0343f49db872a)
- Update RELEASE NOTES.md [`82bb073`](https://github.com/fomantic/Fomantic-UI/commit/82bb0734d2eb7b6c28dc2bcb0f3c29522ba37b0f)
- Fixes secondary menu missing from docs [`d17b2e8`](https://github.com/fomantic/Fomantic-UI/commit/d17b2e849901b21f3a76014f8498e654ce78320f)
- Toying with bower main path to test whether wildcard resolves correctly [`29fdf71`](https://github.com/fomantic/Fomantic-UI/commit/29fdf711995d5513b0cf2d37d0236a9d402d5565)
- Doc: Removed missing icons from existing code [`dffc869`](https://github.com/fomantic/Fomantic-UI/commit/dffc8690bc49968b379fe26bedd64910ce98747f)
- Doc: Removed arrow class from location icon [`d768891`](https://github.com/fomantic/Fomantic-UI/commit/d76889104a9a8c1bab715253a7fd997062c263d2)
- Doc: Added missing forward icon [`0b1d552`](https://github.com/fomantic/Fomantic-UI/commit/0b1d5522b664bf0e0bbc7cd0d882132309b8c26c)
- Update description for onApprove callback [`634b87f`](https://github.com/fomantic/Fomantic-UI/commit/634b87f81d610749dea2f4510ffe90ba8ebbbfcb)
- Fixes date in release notes [`658b3ac`](https://github.com/fomantic/Fomantic-UI/commit/658b3ac7e232d4c37c69f18484228f4589a56445)
- Form: Fixes values to be trimmed when validating, #488 [`09b088a`](https://github.com/fomantic/Fomantic-UI/commit/09b088a7c4777e6ea8073170216aa08f77c860fb)
- Fixes specificity of button #483 [`28261ed`](https://github.com/fomantic/Fomantic-UI/commit/28261ed82fca587cc1e8d8cf8a1e2c063eddb7a9)
- Menu: Fixes z-index to be just below modals for fixed menu #505 [`0016012`](https://github.com/fomantic/Fomantic-UI/commit/0016012d30dad10bf76c4d4ce11657bba9ff9961)
- Note that docpad run depends on grunt build [`76854d5`](https://github.com/fomantic/Fomantic-UI/commit/76854d562ab29f2df90eadd2f4803590ac8f2578)
- Fixes clone url in README [`2080098`](https://github.com/fomantic/Fomantic-UI/commit/2080098f77044c2aa44fa98a6a484def5479a3f6)
- Modal: fixes dimmer and modal to use two separate checks for active status [`1ea95cb`](https://github.com/fomantic/Fomantic-UI/commit/1ea95cbab2c336271ff8daa968123c9be5332f46)
- moved save.conditions from module.create to module.show [`5239c8b`](https://github.com/fomantic/Fomantic-UI/commit/5239c8be8a784dee35cbed6ee089d154100a5d05)
- Fix form validation name [`3d6985f`](https://github.com/fomantic/Fomantic-UI/commit/3d6985fedb80f51023705383f9ac5d512f1468dd)
- case insensitive e-mail validation [`fede049`](https://github.com/fomantic/Fomantic-UI/commit/fede04934bfc4b556785d739cb9c5d4d430f799a)
- Fixes version number on homepage [`c748c99`](https://github.com/fomantic/Fomantic-UI/commit/c748c99fdee16e8e5cbae86597522648fe3c4464)
- Still fiddling with list float issues [`75096d1`](https://github.com/fomantic/Fomantic-UI/commit/75096d1ebe9ea065a71622082a5fd1739692c4a9)
- typo in popup docs [`333eb34`](https://github.com/fomantic/Fomantic-UI/commit/333eb34b43bdecad9d8df50d7618c2ec2752e7f6)
- Modified documentation. [`eadb752`](https://github.com/fomantic/Fomantic-UI/commit/eadb752105826bb9310ea31f86b35ba31b4345b6)
- Fixes floating menu dropdown position to not be overwritten [`37f281a`](https://github.com/fomantic/Fomantic-UI/commit/37f281ae60fb8a6f186822d87a16ecc3e0e5c045)
- Fixes labeled icon placement in chrome [`a624771`](https://github.com/fomantic/Fomantic-UI/commit/a624771152385e6e4a98f6d2062d231e1d726072)
- Updates browser support to include safari 6&gt; and opera 12.1&gt; [`d328cc4`](https://github.com/fomantic/Fomantic-UI/commit/d328cc4a2f83753284a2bd65293e210378d3876a)
- Removes vertical align fix causes issues in chrome [`84abf6e`](https://github.com/fomantic/Fomantic-UI/commit/84abf6e264476193fd92b7b07ae85757357f09d3)
- All icons are 1px too tall, uses same technique as bootstrap (offset1px on glyphicons) [`1817d93`](https://github.com/fomantic/Fomantic-UI/commit/1817d936388f0b9d15d2205202be0e61fb8805cd)
- swap conditional on dev packages [`eb60dfb`](https://github.com/fomantic/Fomantic-UI/commit/eb60dfb3a265f1e93efea5ab8ea0b084767c9cc5)
- whitespace [`3b4e3ea`](https://github.com/fomantic/Fomantic-UI/commit/3b4e3ea0071d7b0e0983853e08fe1e9794a0d765)
- block header now uses rgba [`158b9aa`](https://github.com/fomantic/Fomantic-UI/commit/158b9aae9266ae7948928375e8db64b3e6a2f2bc)
- increases opacity of icon message [`769554b`](https://github.com/fomantic/Fomantic-UI/commit/769554bb19587209889590b1011045df33ea96ef)
- Fixes dropdowns inside item images [`2492f23`](https://github.com/fomantic/Fomantic-UI/commit/2492f232662168e67aedb58de6ed4bea669e1da7)
- Fixes issue where input icon might be reversed when font color of parent is reversed [`6114de5`](https://github.com/fomantic/Fomantic-UI/commit/6114de56e11dbe381190f05539894a5eef2ee6b8)
- typo in release notes [`574df0c`](https://github.com/fomantic/Fomantic-UI/commit/574df0cd5f4b2c486b9bae71bbcb60c9172d17d3)
- removing verbose from tests [`63a7afb`](https://github.com/fomantic/Fomantic-UI/commit/63a7afb5fc24a18b3cb7bf80fbfea604f5d9a6d3)
- updates node on travis.yml [`f6d6622`](https://github.com/fomantic/Fomantic-UI/commit/f6d6622107868c4f71725899ed78e6cdcb970d32)
- wording on readme [`c5d67b3`](https://github.com/fomantic/Fomantic-UI/commit/c5d67b3d65e58fc60f291e2a7cd1ad8ec6362928)
- rebuilds zip [`8ac05ba`](https://github.com/fomantic/Fomantic-UI/commit/8ac05ba3cca9867faebf81b211459aa3071f49de)
- tiny checkbox example update [`f60fa4a`](https://github.com/fomantic/Fomantic-UI/commit/f60fa4addc2a2db654c26484a624135be4c79f74)
- Update RELEASE NOTES.md [`58672ba`](https://github.com/fomantic/Fomantic-UI/commit/58672ba788f27cc4fa247aee1be0780104abbe6d)
- Update RELEASE NOTES.md [`ca1c2df`](https://github.com/fomantic/Fomantic-UI/commit/ca1c2df362ecac30e894209ce0e92a269ca494d4)
- Fixes typo in accordion docs [`0fedfc7`](https://github.com/fomantic/Fomantic-UI/commit/0fedfc7b37b0cfdc17ed595c98490d6bd7c4fe01)
- upgrades docpad [`f2115a7`](https://github.com/fomantic/Fomantic-UI/commit/f2115a7e9c57fa123817e630021a5d949740c313)
- version uptick on home [`249d9d2`](https://github.com/fomantic/Fomantic-UI/commit/249d9d2c1e5ba952671d54054cf75cb44f8d26c6)
- wrong date in release notes [`bc9d3e2`](https://github.com/fomantic/Fomantic-UI/commit/bc9d3e2c8211e87ea4872f5c8ea2a7e4beefc566)
- updates keywords [`78357d8`](https://github.com/fomantic/Fomantic-UI/commit/78357d8e5c049b2070b037803f438653a0bda552)
- updates composer.json version # [`e6811bf`](https://github.com/fomantic/Fomantic-UI/commit/e6811bf6dd0397c27e2a417a5e391afba7d18fe5)
- Update RELEASE NOTES.md [`d2e7297`](https://github.com/fomantic/Fomantic-UI/commit/d2e7297e6bfa78284e13df704ccb0c599bad1f5d)
- rebuilds package with new example [`9374fdb`](https://github.com/fomantic/Fomantic-UI/commit/9374fdba40c176b1a87ed52302a81d7eb0f8b491)
- Update RELEASE NOTES.md [`ec02f52`](https://github.com/fomantic/Fomantic-UI/commit/ec02f52e9523e748c98ea5a5aaff20541ca8412f)
- Fixes dropdown to now set active item to whatever hidden input field is when using action updateForm [`45d3100`](https://github.com/fomantic/Fomantic-UI/commit/45d31009a803d8cae08d40699e831c5d8148cdc9)
- fixes typo in docs #107 [`0835f87`](https://github.com/fomantic/Fomantic-UI/commit/0835f878c03707a9cae32474b033da370680a7da)
- Added the input element of checkbox to the dom with 0 opacity, so that it ca [`bf36329`](https://github.com/fomantic/Fomantic-UI/commit/bf363293babc5bf063451aa11619d257fcd7e1fa)
- transition requires repaint after animation [`700fda5`](https://github.com/fomantic/Fomantic-UI/commit/700fda509eaaca8c56679917d11611a8c399cd65)
- fixes popup icon in message [`e74e9b1`](https://github.com/fomantic/Fomantic-UI/commit/e74e9b14edfc775b32ed7535c58765cd528e43ed)
- updates download zip [`7af5f3f`](https://github.com/fomantic/Fomantic-UI/commit/7af5f3f6a49b4e464f1b2309288f7a12ae3a0442)
- fixes scroll position on side menu [`04861b8`](https://github.com/fomantic/Fomantic-UI/commit/04861b80be72489681d915f39b30ab953b8eb210)
- updates zip [`908298a`](https://github.com/fomantic/Fomantic-UI/commit/908298a92d7c6456ebbaa3e2f77faebd938a36de)
- temporarily removes reference to roadmap [`5b93e21`](https://github.com/fomantic/Fomantic-UI/commit/5b93e2168dd9066f949ca83e092010d8b2685484)
- missing space in sentence [`e1d2b51`](https://github.com/fomantic/Fomantic-UI/commit/e1d2b517649fd086fe26c8679fcc4dcadf80f621)
- Update component.json [`e3899c2`](https://github.com/fomantic/Fomantic-UI/commit/e3899c2cdd880204180536773e795252249522ce)
- adds back in statistics to package [`de23357`](https://github.com/fomantic/Fomantic-UI/commit/de23357520f8692112eaf0d54e3e59874e254c5b)
- fixes padding on header [`fb4258e`](https://github.com/fomantic/Fomantic-UI/commit/fb4258e7ef382e960a1e0fcec763fa7775dfe495)
- test ssh [`0e44f92`](https://github.com/fomantic/Fomantic-UI/commit/0e44f925b3d8d004d7dbeebd0299074d3bd6c443)
- Update component.json [`524b881`](https://github.com/fomantic/Fomantic-UI/commit/524b8812d5d0fc6f20ff379df5cf44ca67ef4c2a)
- tertiary buttons fix [`37770fd`](https://github.com/fomantic/Fomantic-UI/commit/37770fdacf73d07c43c5fe430a0af8a5b33f8860)
- adds word-wrap [`d7282d7`](https://github.com/fomantic/Fomantic-UI/commit/d7282d7e3bed000ed946fa98f5f57afd755dc082)
- fixes the motherfucking line wrapping height issue on code samples [`2c226fe`](https://github.com/fomantic/Fomantic-UI/commit/2c226feb9bd65eceef694e9da04477c468c4559b)
- fixes item touch event on dropdown [`2824345`](https://github.com/fomantic/Fomantic-UI/commit/28243457ae72afad572b7a398aeb4875d976e716)
- fixing dropdown position [`b9b3b7b`](https://github.com/fomantic/Fomantic-UI/commit/b9b3b7b2e6ff23a686671c74e92b201d2b4857c4)
- lowers size of code icon [`5ae7c31`](https://github.com/fomantic/Fomantic-UI/commit/5ae7c310b36b24d090464ad284edc15cfe7fdef7)
- brightens tag in highlighting [`bb6f7b1`](https://github.com/fomantic/Fomantic-UI/commit/bb6f7b13725fdc76950c54e5201e102bc97f9d17)
- typo [`1beb9df`](https://github.com/fomantic/Fomantic-UI/commit/1beb9df9ad8a8c98524e7ebafb645dbf3a047320)
- fixes baseline for flat theme [`cb89e55`](https://github.com/fomantic/Fomantic-UI/commit/cb89e555c19c87f62bdaa95a4824c2681edd556c)
- Update release notes #1594 [`b51c091`](https://github.com/fomantic/Fomantic-UI/commit/b51c0911c402fb2ed79721584f9c5f968e20537d)
- #1594, Fix element blur on popup hide [`7156e4d`](https://github.com/fomantic/Fomantic-UI/commit/7156e4d67a8adbdd8f6c920b9abde8b03ad85a1a)
- Update notes [`76ef8af`](https://github.com/fomantic/Fomantic-UI/commit/76ef8afd156b92e5a002b808c5314e474979c33e)
- add devDependencies - gulp-chmod ^1.2.0 [`f7ac640`](https://github.com/fomantic/Fomantic-UI/commit/f7ac64054e2a833e00fd88486f90d057370c36e4)
- #1549 remove england alias from flag [`0a7e2cb`](https://github.com/fomantic/Fomantic-UI/commit/0a7e2cbbdfae95367ae525d625260f9fb23bdc56)
- Adds default var for #1536 [`0978e84`](https://github.com/fomantic/Fomantic-UI/commit/0978e84c733228dae393186b7c0d70ea0f38c77f)
- Fix secondary bug in #1532, dropdown focus state in form gets input marker [`9c3b5e7`](https://github.com/fomantic/Fomantic-UI/commit/9c3b5e70b6f1a5509c8b3184a8feca85d1795092)
- Fix cause of #1471 [`8e3a750`](https://github.com/fomantic/Fomantic-UI/commit/8e3a7503409226b9f1864db599e5ecb3845392a2)
- Remove console.log [`d4a9a9c`](https://github.com/fomantic/Fomantic-UI/commit/d4a9a9c6428b575ec7c4a95d37150f156d20b6cc)
- Fix method not exist error on transition [`6a11e49`](https://github.com/fomantic/Fomantic-UI/commit/6a11e491f1eceb17010aced948cd51acbce72d3b)
- Track changes in dist/ #1350 [`721681b`](https://github.com/fomantic/Fomantic-UI/commit/721681baad2240c630abd3d17ad47ab9cdd2078b)
- Update release notes [`e7dbd23`](https://github.com/fomantic/Fomantic-UI/commit/e7dbd23cee1ccb7a66d91f03dcecbfa1ad83b9b4)
- update release notes [`9557e3e`](https://github.com/fomantic/Fomantic-UI/commit/9557e3e8f769e1519b5fd2d8f0def3e18510ad87)
- Remove unnecessary method call [`6fcd510`](https://github.com/fomantic/Fomantic-UI/commit/6fcd5108dbb46b571886e4b18e7a89963f3b7181)
- Header font missing from h1-h5 without ui header #1314 [`58a7038`](https://github.com/fomantic/Fomantic-UI/commit/58a7038e51e1301014ee5b77ee9af71729fbabe7)
- Remove console log in transition [`e49aa0f`](https://github.com/fomantic/Fomantic-UI/commit/e49aa0f1373fccbf7d3ad287be2c61461e1ab6a3)
- Get rid of unnecessary z index in segment loading [`af5355c`](https://github.com/fomantic/Fomantic-UI/commit/af5355c08747b588d4c8dd823b191b34411470d1)
- Remove console log [`2d1e601`](https://github.com/fomantic/Fomantic-UI/commit/2d1e601acdd0443b8435a50a957c8ac21e6b754d)
- Remove errant console.log [`66b87c3`](https://github.com/fomantic/Fomantic-UI/commit/66b87c3e4926c5d085e844a0da204333406f4849)
- Text menus are now inline block [`d1330a6`](https://github.com/fomantic/Fomantic-UI/commit/d1330a6ec7064ef12d0e6c41d30f5527f81f3b8f)
- Fix issue with multiline checkbox [`7414407`](https://github.com/fomantic/Fomantic-UI/commit/7414407e4aeb27b8ae7f298ab630bd1aad576df2)
- Fix issue with input form align #1161 [`f90ad00`](https://github.com/fomantic/Fomantic-UI/commit/f90ad00f99652f667393c095c0cfb2114a648a8c)
- Fix for header [`f224c08`](https://github.com/fomantic/Fomantic-UI/commit/f224c0812020ac9095efea7903cf5e6bb127c624)
- Fix for transition class [`a147814`](https://github.com/fomantic/Fomantic-UI/commit/a1478149dc9f15bbf7f0ebff9c943dc1fe7c4ff5)
- active min width variable for progress [`265c5da`](https://github.com/fomantic/Fomantic-UI/commit/265c5dab9cdf78b4714a6667d5b696ad3dc9832b)
- Fix vertical divider offset [`7e98967`](https://github.com/fomantic/Fomantic-UI/commit/7e989674d9787f4f3394cf3c3fa6ba8c4bbcdeff)
- Fix height of slider [`63530b2`](https://github.com/fomantic/Fomantic-UI/commit/63530b2e2266d650edf2605cb7d3569c50b0722b)
- Adds comment to transition [`f424fc8`](https://github.com/fomantic/Fomantic-UI/commit/f424fc844f1112b1dca8444d0c0289e993c47677)
- Fixes masthead padding [`5fe7f55`](https://github.com/fomantic/Fomantic-UI/commit/5fe7f554c00fac88e71f482b28959e9dae4eb8b8)
- Reset on destroy on video component [`e019520`](https://github.com/fomantic/Fomantic-UI/commit/e019520f6f60a6b8d3852eca72728c77505cf833)
- Add max-width to card #1116 [`a898b02`](https://github.com/fomantic/Fomantic-UI/commit/a898b022c87efcb77ea5e4f1664cf3bc9b30c5cc)
- Add back in lato font until @import load order fixed in grunt [`631efd8`](https://github.com/fomantic/Fomantic-UI/commit/631efd86c0b44a29a0c2b800b17ac52b25facf48)
- Search selection dropdown now forces ui dropdown class [`6769eb1`](https://github.com/fomantic/Fomantic-UI/commit/6769eb1220a5beb72e5a9afb415bb5502b04fa2c)
- Progress bar now animates correctly when no width set [`44269aa`](https://github.com/fomantic/Fomantic-UI/commit/44269aae43047b21db97472fc69603d6c773814f)
- Removes dependency that no longer exists [`a584aa7`](https://github.com/fomantic/Fomantic-UI/commit/a584aa7bb11cb403091e446c0cb40e6c34cdab02)
- Remove minwidth from grid [`c5127e5`](https://github.com/fomantic/Fomantic-UI/commit/c5127e5161e6a0174d9836793800abeee5bc4f0c)
- typo in css [`e6401fb`](https://github.com/fomantic/Fomantic-UI/commit/e6401fb252e861aa35b340adf70d550c09923640)
- Fix table segments missing border [`250e464`](https://github.com/fomantic/Fomantic-UI/commit/250e4643dc71ee27ece9a4ebff9069fc85442ad1)
- Fix list table layout resizing [`0a756c7`](https://github.com/fomantic/Fomantic-UI/commit/0a756c75115eff0522da1af985419d6277676064)
- Removes double border from table segment [`8b99d17`](https://github.com/fomantic/Fomantic-UI/commit/8b99d173686bb86e990c491823efab8d1ce6ada2)
- Fix column row inside stackable grid [`0b78bd0`](https://github.com/fomantic/Fomantic-UI/commit/0b78bd028250423ecedf9b07f9ee160fe20c7465)
- Fix basic inverted background color in default theme [`535a79f`](https://github.com/fomantic/Fomantic-UI/commit/535a79f58ea153dc697944c526d50415ec1e4170)
- Fixes right padding on list [`a02e872`](https://github.com/fomantic/Fomantic-UI/commit/a02e872953950f50bf461c8a5719102d10709c4e)
- Adds visit component to debug [`53c6f57`](https://github.com/fomantic/Fomantic-UI/commit/53c6f57b7ec3958257df78f551a05eaed2df8cdc)
- Adds mobile icon alias [`c24d1bc`](https://github.com/fomantic/Fomantic-UI/commit/c24d1bc38ad1d080d23552983ba6b6130f4a2ae9)
- Adds semantic config to gitignore [`817f23c`](https://github.com/fomantic/Fomantic-UI/commit/817f23c64eaa02c6234a3b9f5d3370df0f7e5d52)
- Adds forced repaint to dropdown [`00bd3de`](https://github.com/fomantic/Fomantic-UI/commit/00bd3de60aee5a97d4eda2f084a836e7af2bfd4d)
- Update RELEASE NOTES.md [`23de475`](https://github.com/fomantic/Fomantic-UI/commit/23de4752dec1057fa6e9315a575d3180d744712b)
- adds docpad db to gitignore [`b23fd29`](https://github.com/fomantic/Fomantic-UI/commit/b23fd29c965349714113e0e06fa811c5ec870734)
- removes attempt on theme var overrides with lame LESS [`945467f`](https://github.com/fomantic/Fomantic-UI/commit/945467fcf9377a9acd45e11b52cfcb686a20546c)
- Fixes valign of solo icons [`5642207`](https://github.com/fomantic/Fomantic-UI/commit/5642207dad8155abbf1f322f7705af5e1ea77117)
- Adds margin bottom to list headers [`b58cf6f`](https://github.com/fomantic/Fomantic-UI/commit/b58cf6fd44bbc307ce3ba78c32f726b70392b444)
- Tab active now bold [`cb12543`](https://github.com/fomantic/Fomantic-UI/commit/cb1254343d5f771513d4071634aaabcaa09d2504)
- adds in grunt cli install again to travis build [`2880a9b`](https://github.com/fomantic/Fomantic-UI/commit/2880a9b1a045ffadffe0e9c918fed4454c7259ff)
- removes dimmer remove from destroy [`3674e28`](https://github.com/fomantic/Fomantic-UI/commit/3674e2833344b9e1824f8fd0e091f7b48c440380)
- add Behavior [`e7b4f84`](https://github.com/fomantic/Fomantic-UI/commit/e7b4f84e93b587655021312ff0f9e4bb8cac495e)
- adds zip file to build directory [`b5d06eb`](https://github.com/fomantic/Fomantic-UI/commit/b5d06eb3cebc7182b9ef2c272be785fb4b6d7f6e)
- Remove execute permission. [`3830f65`](https://github.com/fomantic/Fomantic-UI/commit/3830f6577d8545bfb5706e2f6aa31607ea4d3aae)
- Remove old image loaders [`880e5e5`](https://github.com/fomantic/Fomantic-UI/commit/880e5e5fd416c27c4f4fa242231a3f8e85e0f1ed)
- Fix extension on oauth example js file [`97e3103`](https://github.com/fomantic/Fomantic-UI/commit/97e310364b456ff4750ebda743c87194ce0309c7)
- Missing theme [`aad5d47`](https://github.com/fomantic/Fomantic-UI/commit/aad5d4715c2758fc19439e714750531cdbdfe739)
- Adds flags to build [`08823d8`](https://github.com/fomantic/Fomantic-UI/commit/08823d8391aa7ecd93a40eda63a1d98e96defc29)
- Adds project logo [`ed90e4a`](https://github.com/fomantic/Fomantic-UI/commit/ed90e4ac1fb89572f4effbcc5e1ae55802951b74)
- travis.yml now requires dot [`c93ab70`](https://github.com/fomantic/Fomantic-UI/commit/c93ab70351f7f74619dbb16eb1341ce27c9db48d)
- Adds favicon to build [`7caa083`](https://github.com/fomantic/Fomantic-UI/commit/7caa083bab2cba7f1db05da3b5c95ab42bb075dd)
- structure -- moved src from node project to main project. [`46a861c`](https://github.com/fomantic/Fomantic-UI/commit/46a861c3a1fe0e78934cb9035a76eb65dc4abc18)
